<?php

if (!class_exists('WP_List_Table')) {
    require_once(ABSPATH . 'wp-admin/includes/class-wp-list-table.php');
}

class Foodsearch_Menus_Table extends WP_List_Table {

    public $where_status = " where status != 3 ";

    public function __construct() {
        parent::__construct(array(
            'singular' => 'Menu Item',
            'plural' => 'Menu Items',
            'ajax' => false
        ));
    }

    protected function get_views() {
        $status = SELF::record_count_fds_status();
        $sts = '';
        if (isset($_REQUEST['status'])) {
            $sts = $_REQUEST['status'];
        }
        
        $status_links = array(
            "all" => '<a href="?page=menu-item" class="' . ($sts == '' ? 'current fds-link' : 'fds-link') . '" aria-current="page">' . esc_html__('all', 'wp-foodsearch') . ' <span class="count">(' . $status['total'] . ')</span></a>',
            "published" => '<a href="?page=menu-item&status=2" class="' . ($sts == 2 ? 'current fds-link' : 'fds-link') . '" aria-current="page">' . esc_html__('published', 'wp-foodsearch') . ' <span class="count">(' . $status['approved'] . ')</span></a>',
            "pending" => '<a href="?page=menu-item&status=1" class="' . ($sts == 1 ? 'current fds-link' : 'fds-link') . '" aria-current="page">' . esc_html__('pending', 'wp-foodsearch') . ' <span class="count">(' . $status['pending'] . ')</span></a>',
            "rejected" => '<a href="?page=menu-item&status=4" class="' . ($sts == 4 ? 'current fds-link' : 'fds-link') . '"  aria-current="page">' . esc_html__('rejected', 'wp-foodsearch') . ' <span class="count">(' . $status['rejected'] . ')</span></a>',
            "trashed" => '<a href="?page=menu-item&status=3" class="' . ($sts == 3 ? 'current fds-link' : 'fds-link') . '" aria-current="page">' . esc_html__('trashed', 'wp-foodsearch') . ' <span class="count">(' . $status['trashed'] . ')</span></a>'
        );
        return $status_links;
    }

    public function record_count_fds_status() {
        global $wpdb, $table_prefix;
        $tblname = 'menu_items';
        $wp_track_table = $table_prefix . "$tblname";
        $sql = "SELECT 
  COUNT(CASE WHEN status=1 THEN 1 ELSE NULL END) as 'pending',
  COUNT(CASE WHEN status=2 THEN 1 ELSE NULL END) as 'approved',
  COUNT(CASE WHEN status=3 THEN 1 ELSE NULL END) as 'trashed',
  COUNT(CASE WHEN status=4 THEN 1 ELSE NULL END) as 'rejected'
FROM $wp_track_table";
        $counts = $wpdb->get_row($sql);
        $total = $counts->pending + $counts->approved + $counts->rejected;
        return array('total' => $total, 'pending' => $counts->pending, 'approved' => $counts->approved, 'trashed' => $counts->trashed, 'rejected' => $counts->rejected);
    }

    public function record_count() {
        global $wpdb, $table_prefix;
        $tblname = 'menu_items';
        $wp_track_table = $table_prefix . "$tblname";

        if (!empty($_REQUEST['status'])) {
            $this->where_status = " where status = " . $_REQUEST['status'];
        }
        $sql = "SELECT COUNT(*) FROM $wp_track_table" . $this->where_status;
        if (isset($_REQUEST['s']) && !empty($_REQUEST['s'])) {
            $sql .= ' AND name LIKE "%' . $_REQUEST['s'] . '%"';
        }
        return $wpdb->get_var($sql);
    }

    public function get_records($per_page = 30, $page_number = 1) {
        global $wpdb, $table_prefix;
        $tblname = 'menu_items';
        if (!empty($_REQUEST['status'])) {
            $this->where_status = " where status = " . $_REQUEST['status'];
        }
        $wp_track_table = $table_prefix . "$tblname";
        $sql = "select * from $wp_track_table" . $this->where_status;
        if (isset($_REQUEST['s']) && !empty($_REQUEST['s'])) {
            $sql .= ' AND name LIKE "%' . $_REQUEST['s'] . '%"';
        }
        if (!empty($_REQUEST['orderby'])) {
            $sql .= ' ORDER BY ' . esc_sql($_REQUEST['orderby']);
            $sql .= !empty($_REQUEST['order']) ? ' ' . esc_sql($_REQUEST['order']) : ' DESC';
        } else {
            $sql .= ' ORDER BY id desc';
        }
        $sql .= " LIMIT $per_page";
        $sql .= ' OFFSET ' . ($page_number - 1) * $per_page;
      //  echo $sql;
        $result = $wpdb->get_results($sql, 'OBJECT');
        return $result;
    }

    function get_columns() {
        $columns = [
            'cb' => '<input type="checkbox" />',
            'name' => esc_html__('title', 'wp-foodsearch'),
            'price' => esc_html__('price', 'wp-foodsearch'),
            'restaurant_id' => esc_html__('restaurant', 'wp-foodsearch'),
            'category' => esc_html__('category', 'wp-foodsearch'),
            'status' => esc_html__('status', 'wp-foodsearch'),
            'action' => esc_html__('action', 'wp-foodsearch'),
        ];
        return $columns;
    }

    public function get_sortable_columns() {
        $sortable_columns = array(
            'name' => array('name', true),
            'price' => array('price', true),
            'restaurant_id' => array('restaurant_id', true),
        );
        return $sortable_columns;
    }

    public function column_default($item, $column_name) {
        switch ($column_name) {
            case 'status':
                switch ($item->status) {
                    case '1':
                        $stats_text = esc_html__('pending', 'wp-foodsearch');
                        $stats_bg_color = '#f0ad4e';
                        break;
                    case '2':
                        $stats_text = esc_html__('approved', 'wp-foodsearch');
                        $stats_bg_color = '#3d9a6e';
                        break;
                    case '3':
                        $stats_text = esc_html__('trashed', 'wp-foodsearch');
                        $stats_bg_color = '#d9534f';
                        break;
                    case '4':
                        $stats_text = esc_html__('rejected', 'wp-foodsearch');
                        $stats_bg_color = '#d9534f';
                        break;
                }
                $stats_txt_clr = '#fff';
                return "<span class='status-bg' style='background-color:" . $stats_bg_color . ";color:" . $stats_txt_clr . ";'>" . $stats_text . "</span>";
                break;
            case 'name':
                return "<div class='item-title-wrap'>
                            <div style='min-width: 78px;min-height: 78px;max-height: 78px;background: url(" . wp_get_attachment_url($item->attachment_id) . ") top center /cover'></div>
                            <a href='#' class='edit-menu-item fds-link' data-id='" . $item->id . "'  data-title='" . $item->name . "'>" . $item->name . "</a>
                        </div>";
                break;
            case 'price':
                return '<span class="main-price ' . ((!empty($item->discount_price) || $item->discount_price != 0) ? 'discount-price' : '') . '">' . $item->price . '</span>  ' . ((!empty($item->discount_price) || $item->discount_price != 0) ? ' | ' . $item->discount_price : '');
                break;
            case 'restaurant_id':
                $a = get_edit_post_link($item->restaurant_id);
                return "<a href='" . $a . "' class='fds-link'>" . get_the_title($item->restaurant_id) . "</a>";
                break;
            case 'category':
                $term = get_term_by('id', $item->category_id, 'food_item_cat');
                return (isset($term->name) ? $term->name : '');
                break;
            case 'action':
                if (empty($_REQUEST['status']) || $_REQUEST['status'] != 3) {
                    $actions = "<div class='fds-item-action'>";
                    $actions .= "<a class='menu-view fds-link' href='" . admin_url('post.php?post=' . $item->restaurant_id . '&action=edit&menu_id=' . $item->menu_id . '#menu-itmcon-' . $item->id) . "'><i class='dashicons dashicons-visibility' aria-hidden='true'></i><span>" . esc_html__('view', 'wp-foodsearch') . "</span></a>";
                    $actions .= "<a class='menu-edit fds-link edit-menu-item' data-id='" . $item->id . "' data-title='" . $item->name . "' href='#'><i class='dashicons dashicons-edit' aria-hidden='true'></i><span>" . esc_html__('edit', 'wp-foodsearch') . "</span></a>";
                    $actions .= "<a class='menu-trash fds-link' href=?page=menu-item&action=trash&record=" . $item->id . "><i class='dashicons dashicons-trash' aria-hidden='true'></i><span>" . esc_html__('trash', 'wp-foodsearch') . "</span></a>";
                    $actions .= "<a class='menu-duplicate fds-link' href=?page=menu-item&action=duplicate&record=" . $item->id . "><i class='dashicons dashicons-format-aside' aria-hidden='true'></i><span>" . esc_html__('clone', 'wp-foodsearch') . "</span></a>";
                    $actions .= "</div>";
                } else {
                    $actions = "<div class='fds-item-action'>";
                    $actions .= "<a class='menu-view fds-link' href=?page=menu-item&action=restore&record=" . $item->id . "&status=3><i class='dashicons dashicons-visibility' aria-hidden='true'></i><span>" . esc_html__('restore', 'wp-foodsearch') . "</span></a>";
                    $actions .= "</div>";
                }
                return $actions;
                break;
        }
    }

    function column_cb($item) {
        return sprintf('<input type="checkbox" name="bulk-delete[]" value="%s" />', $item->id);
    }

    function column_your_name($item) {
        $actions = array(
            'edit' => sprintf('<a href="?page=%s&action=%s&record=%s" class="fds-link">' . esc_html__('edit', 'wp-foodsearch') . '</a>', $_request['page'], 'edit', $item->id),
            'delete' => sprintf('<a href="?page=%s&action=%s&record=%s" class="fds-link">' . esc_html__('delete', 'wp-foodsearch') . '</a>', $_request['page'], 'delete', $item->id),
        );
        return sprintf('%1$s %2$s', $item['name'], $this->row_actions($actions));
    }

    public function get_bulk_actions() {
        $actions = ['bulk-approved' => esc_html__('publish', 'wp-foodsearch'), 'bulk-reject' => esc_html__('reject', 'wp-foodsearch'), 'bulk-pending' => esc_html__('pending', 'wp-foodsearch'), 'bulk-trash' => esc_html__('trash', 'wp-foodsearch'), 'bulk-delete' => esc_html__('delete', 'wp-foodsearch')];
        return $actions;
    }

    public static function delete_records($id) {
        global $wpdb, $table_prefix;
        $tblname = 'menu_items';
        $wp_track_table = $table_prefix . "$tblname";
        $wpdb->delete($wp_track_table, ['id' => $id], ['%d']);
    }

    public function no_items() {
        esc_html_e('no record found in the database.', 'wp-foodsearch');
    }

    public function duplicate_record($id) {
        global $wpdb, $table_prefix;
        $tblname = 'menu_items';
        $wp_track_table = $table_prefix . "$tblname";
        $where = array('id' => $id);
        $row = $wpdb->get_row("SELECT * from $wp_track_table WHERE ID = $id ", ARRAY_A);
        $row['id'] = '';
        $wpdb->insert($wp_track_table, $row);
    }

    public function pending_record($id) {
        global $wpdb, $table_prefix;
        $tblname = 'menu_items';
        $wp_track_table = $table_prefix . "$tblname";
        $data = array('status' => 1);
        $where = array('id' => $id);
        $wpdb->update($wp_track_table, $data, $where);
    }

    public function approved_record($id) {
        global $wpdb, $table_prefix;
        $tblname = 'menu_items';
        $wp_track_table = $table_prefix . "$tblname";
        $data = array('status' => 2);
        $where = array('id' => $id);
        $wpdb->update($wp_track_table, $data, $where);
    }

    public function restore_record($id) {
        global $wpdb, $table_prefix;
        $tblname = 'menu_items';
        $wp_track_table = $table_prefix . "$tblname";
        $data = array('status' => 1);
        $where = array('id' => $id);
        $wpdb->update($wp_track_table, $data, $where);
    }

    public function trash_record($id) {
        global $wpdb, $table_prefix;
        $tblname = 'menu_items';
        $wp_track_table = $table_prefix . "$tblname";
        $data = array('status' => 3);
        $where = array('id' => $id);
        $wpdb->update($wp_track_table, $data, $where);
    }

    public function reject_record($id) {
        global $wpdb, $table_prefix;
        $tblname = 'menu_items';
        $wp_track_table = $table_prefix . "$tblname";
        $data = array('status' => 4);
        $where = array('id' => $id);
        $wpdb->update($wp_track_table, $data, $where);
    }

    public function process_bulk_action() {
        if ('delete' === $this->current_action()) {
            self::delete_records(absint($_GET['record']));
        } else if ('trash' === $this->current_action()) {
            self::trash_record(absint($_GET['record']));
        } else if ('restore' === $this->current_action()) {
            self::restore_record(absint($_GET['record']));
        } else if ('duplicate' === $this->current_action()) {
            self::duplicate_record(absint($_GET['record']));
        } else if (( isset($_POST['action']) && $_POST['action'] == 'bulk-delete' ) || ( isset($_POST['action2']) && $_POST['action2'] == 'bulk-delete' )) {
            $delete_ids = esc_sql($_POST['bulk-delete']);
            foreach ($delete_ids as $id) {
                self::delete_records($id);
            }
        } else if (( isset($_POST['action']) && $_POST['action'] == 'bulk-trash' ) || ( isset($_POST['action2']) && $_POST['action2'] == 'bulk-trash' )) {
            $trash_ids = esc_sql($_POST['bulk-delete']);
            foreach ($trash_ids as $id) {
                self::trash_record($id);
            }
        } else if (( isset($_POST['action']) && $_POST['action'] == 'bulk-reject' ) || ( isset($_POST['action2']) && $_POST['action2'] == 'bulk-reject' )) {
            $trash_ids = esc_sql($_POST['bulk-delete']);
            foreach ($trash_ids as $id) {
                self::reject_record($id);
            }
        } else if (( isset($_POST['action']) && $_POST['action'] == 'bulk-pending' ) || ( isset($_POST['action2']) && $_POST['action2'] == 'bulk-pending' )) {
            $trash_ids = esc_sql($_POST['bulk-delete']);
            foreach ($trash_ids as $id) {
                self::pending_record($id);
            }
        } else if (( isset($_POST['action']) && $_POST['action'] == 'bulk-approved' ) || ( isset($_POST['action2']) && $_POST['action2'] == 'bulk-approved' )) {
            $trash_ids = esc_sql($_POST['bulk-delete']);
            foreach ($trash_ids as $id) {
                self::approved_record($id);
            }
        }
    }

    public function get_hidden_columns() {
        return array();
    }

    public function prepare_items() {
        $columns = $this->get_columns();
        $hidden = $this->get_hidden_columns();
        $sortable = $this->get_sortable_columns();
        $this->_column_headers = array($columns, $hidden, $sortable);
        $this->process_bulk_action();
        $per_page = $this->get_items_per_page('records_per_page', 30);
        $current_page = $this->get_pagenum();
        $total_items = self::record_count();
        $data = self::get_records($per_page, $current_page);
        $this->set_pagination_args([
            'total_items' => $total_items,
            'per_page' => $per_page,
        ]);
        $this->items = $data;
    }

}
