<?php

namespace FoodSearch\Dashboard_Settings;
use FoodSearch\Dashboard_Settings\Common_Functions as Common_Functions;

class Restaurant_Builder {

    protected static $_instance = null;

    public static function instance() {
        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }

    public function __construct() {
        
        add_action('admin_enqueue_scripts', array($this, 'admin_enqueue'));
        add_action('admin_enqueue_scripts', array($this, 'admin_enqueue_styles'), 999);
        
        add_action('init', array($this, 'includes'),10);
        
        add_filter('foodsearch_bk_dashboard_restaurant_builder_setins', array($this, 'restaurant_builder'));
    }
    
    public function includes() {
         include plugin_dir_path(dirname(__FILE__)) . 'dashboard-builder/common.php';
         include plugin_dir_path(dirname(__FILE__)) . 'dashboard-builder/rest-api.php';
         include plugin_dir_path(dirname(__FILE__)) . 'dashboard-builder/rider-dashboard-builder.php';
         include plugin_dir_path(dirname(__FILE__)) . 'dashboard-builder/customer-dashboard-builder.php';
         include plugin_dir_path(dirname(__FILE__)) . 'dashboard-builder/elements/elements.php';
    }
    
    public function admin_enqueue_styles() {
        if (isset($_GET['page']) && $_GET['page'] == 'foodsearch-plugin-settings') {
            
            wp_enqueue_style('foodsearch-dashboard-builder', foodsearch_plugin_get_url('assets/admin/css/build/css/dashboard-builder.css'), array(), \FoodSearch_Plugin::get_version());
        }
    }
    
    public function admin_enqueue() {
        
        wp_register_script('foodsearch-dashboard-builder', foodsearch_plugin_get_url('assets/admin/js/dashboard-builder.js', __FILE__), array('jquery'));
        $localize_strings = array(
            'site_url' => esc_url_raw( rest_url() ),
            'delete_conf_msg' => esc_html__('do you realy want to delete it?', 'wp-foodsearch'),
            'nonce' => wp_create_nonce('foodsearch-dashbilder-nonce'),
            'wpnonce' => wp_create_nonce('wp_rest'),
        );
        wp_localize_script('foodsearch-dashboard-builder', 'dashboard_builder_strings', $localize_strings);
    }
    
    public function restaurant_builder($html) {
        $common_functions = new Common_Functions;
        
        ob_start();
        $common_functions->dashboard_builder('restaurant');
        $html = ob_get_clean();
        
        return $html;
    }
    
    public function dashboard_menu_elements_list() {
        $elements = array(
            'account_settings' => array(
                'label' => esc_html__('account settings', 'wp-foodsearch'),
                'custom_fields' => true,
                'fields' => array(
                    'restaurant_name' => array(
                        'sort' => 0,
                        'label' => esc_html__('restaurant name', 'wp-foodsearch')
                    ),
                    'email_address' => array(
                        'sort' => 0,
                        'label' => esc_html__('email address', 'wp-foodsearch')
                    ),
                    'contact_number' => array(
                        'sort' => 0,
                        'label' => esc_html__('contact number', 'wp-foodsearch')
                    ),
                    'manager_name' => array(
                        'sort' => 0,
                        'label' => esc_html__('manager name', 'wp-foodsearch')
                    ),
                    'manager_number' => array(
                        'sort' => 0,
                        'label' => esc_html__('manager number', 'wp-foodsearch')
                    ),
                    'information' => array(
                        'sort' => 0,
                        'label' => esc_html__('restaurant information', 'wp-foodsearch')
                    ),
                    'cuisines' => array(
                        'sort' => 0,
                        'label' => esc_html__('restaurant cuisines', 'wp-foodsearch')
                    ),
                    'tags' => array(
                        'sort' => 0,
                        'label' => esc_html__('restaurant tags', 'wp-foodsearch')
                    ),
                    'delivery_time' => array(
                        'sort' => 0,
                        'label' => esc_html__('delivery time', 'wp-foodsearch')
                    ),
                    'delivery_fee' => array(
                        'sort' => 0,
                        'label' => esc_html__('delivery fee', 'wp-foodsearch')
                    ),
                    'preparation_time' => array(
                        'sort' => 0,
                        'label' => esc_html__('preparation time', 'wp-foodsearch')
                    ),
                    'min_delivery_order' => array(
                        'sort' => 0,
                        'label' => esc_html__('minimum order', 'wp-foodsearch')
                    ),
                    'max_delivery_order' => array(
                        'sort' => 0,
                        'label' => esc_html__('maximum order', 'wp-foodsearch')
                    ),
                    'order_process_type' => array(
                        'sort' => 0,
                        'label' => esc_html__('order process type', 'wp-foodsearch')
                    ),
                ),
            ),
            'logo_cover' => array(
                'label' => esc_html__('logo/cover image', 'wp-foodsearch'),
            ),
            'loc_address' => array(
                'label' => esc_html__('address', 'wp-foodsearch'),
            ),
            'change_password' => array(
                'label' => esc_html__('change password', 'wp-foodsearch'),
            ),
            'menu_builder' => array(
                'label' => esc_html__('menu builder', 'wp-foodsearch'),
            ),
            'nutritions' => array(
                'label' => esc_html__('nutritions', 'wp-foodsearch'),
            ),
            'choice_groups' => array(
                'label' => esc_html__('choice groups', 'wp-foodsearch'),
            ),
            'following_customers' => array(
                'label' => esc_html__('following customers', 'wp-foodsearch'),
            ),
            'reviews' => array(
                'label' => esc_html__('order reviews', 'wp-foodsearch'),
            ),
            'orders' => array(
                'label' => esc_html__('orders', 'wp-foodsearch'),
            ),
            'acc_switcher' => array(
                'label' => esc_html__('account switcher', 'wp-foodsearch'),
            ),
            'custom_box' => array(
                'label' => esc_html__('custom content', 'wp-foodsearch'),
                'removeable' => '0'
            ),
        );
        
        return apply_filters('foodsearch_restaurants_menu_elems_list', $elements);
    }

}

new Restaurant_Builder;
