<?php

use FoodSearch\Common_Functions;
use FoodSearch\User_Locations;

class MenuBuilder extends \FoodSearchPages\adminpages {

    protected static $_instance = null;

    public static function instance() {
        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }

    public function __construct() {
        // Adding columns
        add_action('admin_enqueue_scripts', [$this, 'register_script']);
        add_action('admin_enqueue_scripts', [$this, 'foodsearch_register_mapbox_scripts']);
        add_action('admin_enqueue_scripts', [$this, 'admin_styles'], 999);

        add_action('wp_ajax_nopriv_add_menu', array($this, 'add_menu'));
        add_action('wp_ajax_add_menu', array($this, 'add_menu'));

        add_action('wp_ajax_nopriv_edit_menu', array($this, 'edit_menu'));
        add_action('wp_ajax_edit_menu', array($this, 'edit_menu'));

        add_action('wp_ajax_nopriv_add_menuitems', array($this, 'add_menuitems'));
        add_action('wp_ajax_add_menuitems', array($this, 'add_menuitems'));

        add_action('wp_ajax_nopriv_edit_menuitems', array($this, 'edit_menuitems'));
        add_action('wp_ajax_edit_menuitems', array($this, 'edit_menuitems'));

        add_action('wp_ajax_nopriv_add_category', array($this, 'add_category'));
        add_action('wp_ajax_add_category', array($this, 'add_category'));

        add_action('wp_ajax_nopriv_update_item_category', array($this, 'updateItemCategoryForm'));
        add_action('wp_ajax_update_item_category', array($this, 'updateItemCategoryForm'));
    }

    public function register_script() {
        wp_enqueue_script('select2', foodsearch_plugin_get_url('assets/js/select2.min.js', __FILE__), array('jquery'));
        wp_enqueue_script('menu_builder_script', foodsearch_plugin_get_url('assets/js/menu_builder_script.js', __FILE__), array('jquery'));

        $empty_menus_con = '<div class="fds-no-menuitm">' . esc_html__('click below to add new menu items here.', 'wp-foodsearch') . '</div>'; 
        $localize_strings = array(
            'site_url' => esc_url_raw( rest_url() ),
            'url' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('ajax-nonce'),
            'wpnonce' =>wp_create_nonce('wp-rest'),
            'adminCheck' => (is_admin()?'true':'false'),
            'go_back' => esc_html__('go back', 'wp-foodsearch'),
            'nutri_info_txt' => esc_html__('nutritional information', 'wp-foodsearch'),
            'item_price_txt' => esc_html__('item price', 'wp-foodsearch'),
            'add_menuitm_txt' => esc_html__('add menu item', 'wp-foodsearch'),
            'type_menucat_name' => esc_html__('type menu category name', 'wp-foodsearch'),
            'empty_menus_htmltxt' => $empty_menus_con,
            'delete_conf_msg' => esc_html__('do you realy want to delete it?', 'wp-foodsearch'),
        );
        wp_localize_script('menu_builder_script', 'menu_builder_strings', $localize_strings);
    }
    function foodsearch_register_mapbox_scripts(){
        global $foodsearch_plugin_settings;
              
              $default_country = isset($foodsearch_plugin_settings['location_settings']['default_country']) ? $foodsearch_plugin_settings['location_settings']['default_country'] : '';
              
              $countries_json = '';
              if (!empty($default_country) && is_array($default_country)) {
                  $countries_json = json_encode($default_country);
              } else if (!empty($default_country)) {
                  $countries_json = json_encode(array($default_country));
              }
      
              $location_maps = isset($foodsearch_plugin_settings['location_settings']['loc_maps']) ? $foodsearch_plugin_settings['location_settings']['loc_maps'] : '';
              $map_type = isset($foodsearch_plugin_settings['location_settings']['map_type']) ? $foodsearch_plugin_settings['location_settings']['map_type'] : '';
              $map_zoom = isset($foodsearch_plugin_settings['location_settings']['default_map_zoom']) ? $foodsearch_plugin_settings['location_settings']['default_map_zoom'] : '';
      
              $google_api_key = isset($foodsearch_plugin_settings['api_settings']['google_api']) ? $foodsearch_plugin_settings['api_settings']['google_api'] : '';
              $mapbox_api_key = isset($foodsearch_plugin_settings['api_settings']['mapbox_api']) ? $foodsearch_plugin_settings['api_settings']['mapbox_api'] : '';
              
              if ($location_maps == 'on' && $map_type == 'google') {
                  $locations_obj = new User_Locations;
                  
                  $def_latlng = $locations_obj->get_default_latlng();
      
                  $default_lat_val = $def_latlng[0];
                  $default_lng_val = $def_latlng[1];
                  
                  if ($google_api_key != '') {
                      wp_register_script('foodsearch-google-map', 'https://maps.googleapis.com/maps/api/js?key=' . $google_api_key . '&libraries=places', array(), \FoodSearch_Plugin::get_version(), true);
                  } else {
                    
                      wp_register_script('foodsearch-google-map', 'https://maps.googleapis.com/maps/api/js?libraries=places', array(), \FoodSearch_Plugin::get_version(), true);
                  }
                  wp_register_script('foodsearch-googlemaps-js', foodsearch_plugin_get_url('assets/js/google-maps.js'), array('jquery'), \FoodSearch_Plugin::get_version(), true);
                  $localize_arr = array(
                    'site_url' => esc_url_raw( rest_url() ),
                      'wpnonce' => wp_create_nonce('wp_rest'),
                      'adminCheck' => (is_admin()?'true':'false'),
                      'api_key' => $google_api_key,
                      'mapbox_access_token' => $mapbox_api_key,
                      'def_countries' => $countries_json,
                      'lat' => $default_lat_val,
                      'lng' => $default_lng_val,
                      'zoom' => ($map_zoom > 0 ? $map_zoom : 6),
                  );
                  wp_localize_script('foodsearch-googlemaps-js', 'google_map_vars', $localize_arr);
                  wp_enqueue_script('foodsearch-google-map');
                  wp_enqueue_script('foodsearch-googlemaps-js');
              }
              else{   
                $mapbox_style = isset($foodsearch_plugin_settings['location_settings']['mapbox_style']) ? $foodsearch_plugin_settings['location_settings']['mapbox_style'] : '';
                  
                $locations_obj = new User_Locations;
                
                $def_latlng = $locations_obj->get_default_latlng();
                
                $default_lat_val = $def_latlng[0];
                $default_lng_val = $def_latlng[1];
      
                wp_register_style('foodsearch-mapbox', foodsearch_plugin_get_url('assets/scss/build/css/mapbox-gl.css'), array(), \FoodSearch_Plugin::get_version());
                wp_register_script('foodsearch-mapbox', 'https://api.mapbox.com/mapbox-gl-js/v2.6.1/mapbox-gl.js', array(), \FoodSearch_Plugin::get_version(), true);
                wp_register_script('foodsearch-mapbox-geocode', 'https://api.mapbox.com/mapbox-gl-js/plugins/mapbox-gl-geocoder/v4.7.2/mapbox-gl-geocoder.min.js', array(), \FoodSearch_Plugin::get_version(), true);
                wp_register_style('foodsearch-mapbox-geocode', foodsearch_plugin_get_url('assets/scss/build/css/mapbox-gl-geocoder.css'), array(), \FoodSearch_Plugin::get_version());
                wp_register_script('foodsearch-mapbox-js', foodsearch_plugin_get_url('assets/js/mapbox.js'), array('jquery'), \FoodSearch_Plugin::get_version(), true);
                wp_register_script('foodsearch-location-script', foodsearch_plugin_get_url('assets/js/locations.js'), array('jquery'), \FoodSearch_Plugin::get_version(), true);
      
                $localize_arr = array(
                    'api_key' => $mapbox_api_key,
                    'site_url' => esc_url_raw( rest_url() ),
                    'wpnonce' =>wp_create_nonce('wp-rest'),
                    'adminCheck' => (is_admin()?'true':'false'),
                    'map_style' => $mapbox_style,
                    'def_countries' => $countries_json,
                    'lat' => $default_lat_val,
                    'lng' => $default_lng_val,
                    'zoom' => ($map_zoom > 0 ? $map_zoom : 6),
                    'search_placeholder' => esc_html__('search location', 'wp-foodsearch'),
                );
                wp_localize_script('foodsearch-mapbox-js', 'mapbox_loc_vars', $localize_arr);
                $script_str_arr = array(
                  'site_url' => esc_url_raw( rest_url() ),
                  'wpnonce' => wp_create_nonce('wp_rest'),
                  'loc_maps' => $location_maps,
                  'maps_type' => $map_type,
                  'google_api' => $google_api_key,
                  'mapbox_api' => $mapbox_api_key,
                  'mapbox_style' => $mapbox_style,
                  'map_zoom' => $map_zoom,
                  'add_new_loctxt' => esc_html__('add new location', 'wp-foodsearch'),
                  'delete_msg' => esc_html__('do you really wants to delete this?', 'wp-foodsearch'),
                  'def_countries' => $countries_json,
              );
              wp_localize_script('foodsearch-location-script', 'dashboard_location_vars', $script_str_arr);
                wp_enqueue_style('foodsearch-mapbox');
                  wp_enqueue_script('foodsearch-mapbox');
                  wp_enqueue_script('foodsearch-mapbox-geocode');
                  wp_enqueue_style('foodsearch-mapbox-geocode');
                  wp_enqueue_script('foodsearch-mapbox-js');
                  wp_enqueue_script('foodsearch-location-script');
              }
        
      }

    public function admin_styles() {
        wp_enqueue_style('select2', foodsearch_plugin_get_url('assets/scss/build/css/select2.min.css', __FILE__), false);
        wp_enqueue_style('common-style', foodsearch_plugin_get_url('assets/scss/build/css/common.css', __FILE__), false);
        wp_enqueue_style('menu-builder-style', foodsearch_plugin_get_url('assets/scss/build/css/menu-builder.css', __FILE__), false);
    }
    
    public function menu_grid_boxes($menus, $place = '', $restaurant_id = 0) {
        if (!empty($menus)) {
            $user_id = get_current_user_id();
            foreach ($menus as $menu) {
                ?>
                <div class="fds-menus-grid-item" data-id="<?= $menu->id; ?>" data-nid="<?php echo ($user_id) ?>" data-rid="<?php echo ($restaurant_id) ?>" data-name="<?= $menu->name; ?>">
                    <div class="fds-menu-icon">
                        <i class="fds-menu-builder-empty-icon fds-icon fds-menu-one"></i>
                    </div>
                    <div class="fds-menus-title"><span><?= $menu->name; ?></span></div>
                    <div class="fds-menus-time">
                        <span class="fds-menu-opening">
                            <?php echo esc_html__('opening time', 'wp-foodsearch'); ?>
                            <?= foodsearch_getampmtime($menu->menu_start_time); ?></span>
                        <span class="fds-menu-closing">
                            <?php echo esc_html__('closing time', 'wp-foodsearch'); ?>
                            <?= foodsearch_getampmtime($menu->menu_end_time); ?>
                        </span>
                    </div>
                    <div class="fds-menu-ations">
                        <a href="javascript:void(0);" class="fds-body-action fds-updte-menubtn fds-link" data-bplc="<?php echo ($place == 'admin' ? 'y' : '') ?>"><i class="fds-icon fds-edit"></i></a>
                        <a href="javascript:void(0);" class="fds-body-action fds-remove-action fds-remve-menubtn fds-link"><i class="fds-icon fds-time-simple"></i></a>
                        <?php
                        if (is_admin() && self::menu_have_items($menu->id)) {
                            ?>
                            <div class="fds-btn fds-small-btn">
                                <a href="#" class="fds-export-menu-template fds-has-save fds-update-anything-action fds-link" data-id="<?php echo ($menu->id) ?>" data-rid="<?php echo ($menu->restaurant_id) ?>" data-nid="<?php echo ($user_id) ?>"><?php esc_html_e('export template', 'wp-foodsearch'); ?></a>
                            </div>
                            <?php
                        }
                        ?>
                    </div>
                    <div class="fds-loader-holder" style="display: none;"></div>
                </div>
                <?php
            }
        }
    }
    
    public static function menu_have_items($menu_id) {

        $user_id = get_current_user_id();
        if ($menu_id > 0) {
            $where = ' where menu_id =' . $menu_id;

            $categories = array();
            $menuitems = array();
            global $table_prefix, $wpdb;
            $table_name = $table_prefix . 'menu_items';
            $sql = "SELECT * FROM $table_name$where AND status=2 ORDER BY sort_order ASC";
            $results = $wpdb->get_results($sql);
            if (!empty($results)) {
                $menuitems['status'] = 'success';
                foreach ($results as $row) {
                    $menuitems['resturants'] = $row->restaurant_id;
                    $res[$row->category_id][] = $row;
                    if (!in_array($row->category_id, $categories)) {
                        $categories[] = $row->category_id;
                    }
                }
                $menuitems['results'] = $res;
            }
            
            if (isset($menuitems['results']) && count($menuitems['results']) > 0) {
                return true;
            }
        }
    }

    public function menu_items_bywhere_id($menu_id, $user_id = 0, $restauant_id = 0) {
        
        $common_functions = new Common_Functions;
        
        $content = '';
        if ($menu_id > 0) {
            $where = ' where menu_id =' . $menu_id;

            $categories = array();
            $menuitems = array();
            global $table_prefix, $wpdb;
            $table_name = $table_prefix . 'menu_items';
            $sql = "SELECT * FROM $table_name$where AND status=2 ORDER BY sort_order ASC";
            $results = $wpdb->get_results($sql);
            if (!empty($results)) {
                $menuitems['status'] = 'success';
                foreach ($results as $row) {
                    $menuitems['resturants'] = $row->restaurant_id;
                    $res[$row->category_id][] = $row;
                    if (!in_array($row->category_id, $categories)) {
                        $categories[] = $row->category_id;
                    }
                }
                $menuitems['results'] = $res;
            }
            $cats = array();
            if (count($categories) > 0) {
                foreach ($categories as $key => $category) {
                    $term = get_term_by('id', $category, 'food_item_cat');
                    $cats[$category]['id'] = $category;
                    $cats[$category]['name'] = isset($term->name) ? $term->name : '';
                }
            }
            $have_menu_data = false;

            $content .= '<div class="fds-menu-catslist-con" data-id="' . $menu_id . '">';
            if (isset($menuitems['results']) && count($menuitems['results']) > 0) {
                $have_menu_data = true;
                foreach ($menuitems['results'] as $key => $menusList) {
                    $content .= ' <div class="fds-menu-builder-list">
                    <div class="fds-menu-builder-header">
                    <i class="fds-icon fds-move-drager fds-builder-drager menu-category-sorter"></i> 
                    <div class="fds-column-title">
                        ' . $cats[$key]['name'] . '
                    </div>
                    <div class="fds-column-title">' . esc_html__('nutritional information', 'wp-foodsearch') . '</div>
                    <div class="fds-column-title">' . esc_html__('item price', 'wp-foodsearch') . '</div>
                    <div class="fds-column-title fds-column-actions">
                        <a href="javascript:void(0);" class="fds-builder-action fds-link fds-cat-settings" data-restaurant="' . $menuitems['resturants'] . '"  data-id="' . $cats[$key]['id'] . '"><i class="fds-icon fds-settings-work"></i></a>
                        <a href="javascript:void(0);" class="fds-builder-action fds-link fds-remove-menuitmscat" data-id="' . $cats[$key]['id'] . '"><i class="fds-icon fds-bin"></i></a>
                        <a href="javascript:void(0);" class="fds-builder-action fds-link fds-section-hide"><i class="fds-icon fds-down-arrow"></i></a>
                    </div>
                    </div>
                    <div class="fds-menu-builder-body" id="menu-itemsbox-' . $menu_id . '-' . $cats[$key]['id'] . '">';

                    $content .= '<div class="fds-menu-itemsholdr" data-id="' . $cats[$key]['id'] . '">';
                    foreach ($menusList as $menuitem) {
                        $restaurant_id = $menuitem->restaurant_id;
                        $menu_itmid = $menuitem->id;
                        
                        $menu_price = $menuitem->price;
                        $menu_discount_price = $menuitem->discount_price;
                        
                        $menu_offer_status = $menuitem->offer_status;

                        $menu_nutritions = $common_functions->get_menu_item_nutritions($restaurant_id, $menu_itmid);
                        $nutritions_html = '';
                        if (!empty($menu_nutritions)) {
                            $nutritions_html .= '<div class="fds-builder-veg">';
                            foreach ($menu_nutritions as $nutri_key => $nutri_item) {
                                $nutri_label = $nutri_item['title'];
                                $nutri_img = $nutri_item['image'];
                                $image_thumb = wp_get_attachment_image_src($nutri_img);
                                $image_src = isset($image_thumb[0]) ? $image_thumb[0] : '';
                                $nutritions_html .= '<a class="fds-link"><img src="' . $image_src . '" title="' . $nutri_label . '"></a>';
                            }
                            $nutritions_html .= '</div>';
                        }
                        $content .= '<div id="menu-itmcon-' . $menuitem->id . '" class="fds-menu-builder-inn">
                                        <div class="fds-menu-builder-inn-cell">
                                        <i class="fds-icon fds-move-drager fds-builder-inner-drager menu-item-sorter"></i>
                                            <div class="fds-builder-thumb">';
                        $image_id = $menuitem->attachment_id;
                        $image = wp_get_attachment_image_src($image_id);
                        $content .= '<a href="#" class="fds-menu-item-thumb fds-link" style="background: url(' . (isset($image[0]) ? $image[0] : '') . ') no-repeat top center / cover; "></a>
                                    <div class="fds-builder-content">
                                        <input type="hidden" name="foodsearch_menu_sort[item_id][]" value="' . $menuitem->id . '">
                                        <input type="hidden" name="foodsearch_menu_sort[item_cat_id][]" value="' . $menuitem->category_id . '">
                                        <input type="hidden" name="foodsearch_menu_sort[menu_id][]" value="' . $menu_itmid . '">
                                        <input type="hidden" name="foodsearch_menu_sort[restaurant_id][]" value="' . $menuitem->restaurant_id . '">
                                        <input type="hidden" name="foodsearch_menu_sort[item_position][]">
                                        <a href="#" class="fds-link">' . $menuitem->name . '</a>
                                        <p>' . $menuitem->details . '</p>
                                    </div>
                                </div>
                            </div>
                             <div class="fds-menu-builder-inn-cell">
                               ' . $nutritions_html . '
                             </div>
                           <div class="fds-menu-builder-inn-cell">
                               ' . ($menu_discount_price > 0 ? '<span class="fds-item-price fds-actual-price">' . Common_Functions::get_formatted_price($menu_price, 'menu-item') . '</span> <strong class="fds-discount-price">' . Common_Functions::get_formatted_price($menu_discount_price, 'menu-item') . '</strong>' : '<span class="fds-item-price">' . Common_Functions::get_formatted_price($menu_price, 'menu-item') . '</span>') . ($menu_offer_status == 1 ? ' <small class="fds-special-offer">' . esc_html__('special offer', 'wp-foodsearch') . '</small>' : '') . '
                           </div>
                           <div class="fds-menu-builder-inn-cell">
                                <div class="fds-menu-ations">
                                    <a href="#" class="fds-body-action byeditmenuitem fds-link" data-id="' . $menuitem->id . '" data-nid="' . $user_id . '"><i class="fds-icon fds-edit"></i></a><a href="javascript:void(0);" class="fds-body-action delet-action fds-remove-action remove-foodmenu-item fds-link" data-id="' . $menuitem->id . '" data-mid="' . $menu_id . '"><i class="fds-icon fds-time-simple"></i></a>
                                </div>
                            </div>
                        </div>';

                        $menuID = $menuitem->menu_id;
                    }
                    $content .= '</div>';
                    $content .= '<a href="#" class="byaddmenu fds-link" data-category="' . $key . '" data-restaurant="' . $menuitems['resturants'] . '" data-menu="' . $menuID . '" data-nid="' . $user_id . '"><i class="fds-icon fds-writing"></i> ' . esc_html__('add menu item', 'wp-foodsearch') . '</a></div></div>';
                }
            }
            $content .= '</div>';

            $content .= '<div class="fds-menu-builder-empty empty-menuitms-btncon"' . ($have_menu_data ? ' style="display:none;"' : '') . '>';
            $content .= '<i class="fds-menu-builder-empty-icon fds-icon fds-menu-one"></i>';
            $content .= '<div class="fds-menu-builder-empty-dec"><p>' . esc_html__('you have blank food menu start adding content or select menu from templates', 'wp-foodsearch') . '</p></div>';
            $content .= '<div class="fds-btn fds-medium-btn">';
            $content .= '<a href="javascript:void(0);" class="fds-additem-menugrid fds-has-bg fds-update-anything-action fds-link" data-nid="' . $user_id . '"><i class="fds-icon fds-writing"></i> ' . esc_html__('add new category', 'wp-foodsearch') . '</a>';
            $content .= '<a href="javascript:void(0);" class="sec-color fds-popup-menuitm-templates fds-has-save fds-link" data-id="' . $menu_id . '" data-nid="' . $user_id . '" data-rid="' . $restauant_id . '"><i class="fds-icon fds-writing"></i> ' . esc_html__('import from templates', 'wp-foodsearch') . '</a>';
            $content .= '</div>';
            $content .= '</div>';

            $content .= '<div class="fds-menu-builder-empty have-menuitms-btncon"' . ($have_menu_data ? '' : ' style="display:none;"') . '>';
            $content .= '<div class="fds-btn fds-medium-btn">';
            $content .= '<a href="javascript:void(0);" class="fds-additem-menugrid fds-has-bg fds-update-anything-action fds-link" data-nid="' . $user_id . '"><i class="fds-icon fds-writing"></i> ' . esc_html__('add new category', 'wp-foodsearch') . '</a>';
            $content .= '<a href="javascript:void(0);" class="sec-color fds-popup-menuitm-templates fds-has-save fds-link" data-id="' . $menu_id . '" data-nid="' . $user_id . '" data-rid="' . $restauant_id . '"><i class="fds-icon fds-writing"></i> ' . esc_html__('import from templates', 'wp-foodsearch') . '</a>';
            $content .= '</div>';
            $content .= '</div>';
        }

        return $content;
    }

    public function menu_title_by_id($menu_id) {
        global $table_prefix, $wpdb;
        $table_name = $table_prefix . 'menus';
        $sql = "SELECT name FROM $table_name WHERE 1=1 AND id=$menu_id";
        $result = $wpdb->get_col($sql);

        if (isset($result[0])) {
            return $result[0];
        }
    }

    public function add_menu() {

        global $foodsearch_form_fields;
        $content = '<div class="fds-booking-detail-title">
                    <h2 class="fds-heading-title">' . esc_html__('add new menu', 'wp-foodsearch') . '</h2>
                </div>
                <div class="fds-builder-popupform">
                <div class="fds-popupform-inner-wrap">';

        $args = array(
            'type' => 'hidden',
            'name' => 'restaurant_id',
            'value' => $_POST['restaurant'],
            'return' => true
        );
        $content .= $foodsearch_form_fields->input_field($args);

        $content .= '<div class="fds-form-field">';

        $args = array(
            'type' => 'text',
            'id' => 'title',
            'name' => 'title',
            'classes' => 'fds-input-style',
            'label' => esc_html__('title', 'wp-foodsearch'),
            'placeholder' => esc_html__('title', 'wp-foodsearch'),
            'required' => 'true',
            'value' => '',
            'return' => true
        );
        $content .= $foodsearch_form_fields->input_field($args);
        $content .= '</div><div class="fds-form-field select-field-con">';

        $values = array(
            'monday' => esc_html__('monday', 'wp-foodsearch'),
            'tuesday' => esc_html__('tuesday', 'wp-foodsearch'),
            'wednesday' => esc_html__('wednesday', 'wp-foodsearch'),
            'thursday' => esc_html__('thursday', 'wp-foodsearch'),
            'friday' => esc_html__('friday', 'wp-foodsearch'),
            'saturday' => esc_html__('saturday', 'wp-foodsearch'),
            'sunday' => esc_html__('sunday', 'wp-foodsearch'),
        );
        $args = array(
            'id' => 'menu_opening_days',
            'name' => 'menu_opening_days[]',
            'classes' => 'select_dropdown',
            'label' => esc_html__('menu opening days', 'wp-foodsearch'),
            'placeholder' => esc_html__('select menu opening days', 'wp-foodsearch'),
            'required' => 'true',
            'value' => $values,
            'selected' => '',
            'type' => 'multiple',
            'return' => true
        );
        $content .= $foodsearch_form_fields->select_field($args);
        $content .= '</div><div class="fds-form-field select-field-con">';

        $values = array();
        for ($i = 0; $i < 24; $i++) {
            for ($x = 0; $x <= 3; $x++) {
                $values[$i . ':' . (($x * 15) == 0 ? '00' : ($x * 15))] = $i . ':' . (($x * 15) == 0 ? '00' : ($x * 15));
            }
        }
        $args = array(
            'id' => 'menu_start_time',
            'name' => 'menu_start_time',
            'classes' => 'select_dropdown',
            'label' => esc_html__('menu start time', 'wp-foodsearch'),
            'placeholder' => esc_html__('select menu starting time', 'wp-foodsearch'),
            'required' => 'true',
            'value' => $values,
            'selected' => '',
            'return' => true
        );
        $content .= $foodsearch_form_fields->select_field($args);
        $content .= '</div><div class="fds-form-field select-field-con">';
        $args = array(
            'id' => 'menu_end_time',
            'name' => 'menu_end_time',
            'classes' => 'select_dropdown',
            'label' => esc_html__('menu closing time', 'wp-foodsearch'),
            'placeholder' => esc_html__('select menu closing time', 'wp-foodsearch'),
            'required' => 'true',
            'value' => $values,
            'selected' => '',
            'return' => true
        );
        $content .= $foodsearch_form_fields->select_field($args);
        $content .= '</div><div class="fds-form-field">';

        $args = array(
            'id' => 'details',
            'name' => 'details',
            'classes' => 'fds-textarea-style',
            'label' => esc_html__('menu details', 'wp-foodsearch'),
            'placeholder' => esc_html__('menu details', 'wp-foodsearch'),
            'value' => '',
            'return' => true
        );
        $content .= $foodsearch_form_fields->textarea_field($args);
        $content .= '</div><div class="fds-form-field select-field-con">';
        $values = array(
            '1' => esc_html__('pending', 'wp-foodsearch'),
            '2' => esc_html__('approve', 'wp-foodsearch'),
            '4' => esc_html__('reject', 'wp-foodsearch'),
        );
        
        if (isset($_POST['bplc']) && $_POST['bplc'] == 'y') {
            $args = array(
                'type' => 'single',
                'id' => 'status',
                'name' => 'status',
                'classes' => 'select_menu post-filed select_dropdown',
                'label' => esc_html__('select status', 'wp-foodsearch'),
                'value' => $values,
                'selected' => '',
                'required' => 'true',
                'return' => true
            );
            $content .= $foodsearch_form_fields->select_field($args);
        }
        
        $content .= '</div></div><div class="fds-add-newcat">';
        ob_start();
        wp_nonce_field('adding_menu', 'menu_save_nonce');
        $content .= ob_get_clean();
        
        $content .= '<div class="fds-btn fds-medium-btn">';
        $args = array(
            'type' => 'button',
            'id' => 'menuSaveBtn',
            'name' => 'save_menu',
            'classes' => 'fds-newcat-savebtn fds-has-save fds-update-anything-action',
            'value' => esc_html__('save menu', 'wp-foodsearch'),
            'return' => true
        );
        $content .= $foodsearch_form_fields->button($args);
        $content .= '  
                </div>
                </div>
            </div>';
        return ($content);
    }

    public function edit_menu() {
        
        $rand_id = rand(100000, 999999);
        $where = '';
        $menu_id = 0;
        if (isset($_POST['id'])) {
            $menu_id = $_POST['id'];
            $where = ' where id=' . $_POST['id'];
        }
        global $table_prefix, $wpdb, $foodsearch_form_fields;
        $table_name = $table_prefix . 'menus';
        $sql = "SELECT * FROM $table_name$where";
        $results = $wpdb->get_results($sql);
        $content = '';
        if (isset($results[0]) && count($results) > 0) {
            
            $menu_obj = $results[0];
            
            $menu_title = $menu_obj->name;
            $opening_days = $menu_obj->menu_opening_days;
            $opening_days = json_decode($opening_days, true);
            
            $start_time = $menu_obj->menu_start_time;
            $end_time = $menu_obj->menu_end_time;
            $menu_desc = $menu_obj->details;
            $menu_status = $menu_obj->status;

            $content .= '<div class="fds-booking-detail-title">
                <h2 class="fds-heading-title">' . esc_html__('edit menu', 'wp-foodsearch') . '</h2>
            </div>
            <div class="fds-builder-popupform">
            <div class="fds-popupform-inner-wrap">';

            $args = array(
                'type' => 'hidden',
                'name' => 'restaurant_id',
                'value' => $_POST['restaurant'],
                'return' => true
            );
            $content .= $foodsearch_form_fields->input_field($args);
            $args = array(
                'type' => 'hidden',
                'name' => 'id',
                'value' => $menu_id,
                'return' => true
            );
            $content .= $foodsearch_form_fields->input_field($args);

            $content .= '<div class="fds-form-field">';

            $args = array(
                'type' => 'text',
                'id' => 'title',
                'name' => 'title',
                'classes' => 'fds-input-style',
                'label' => esc_html__('title', 'wp-foodsearch'),
                'placeholder' => esc_html__('title', 'wp-foodsearch'),
                'required' => 'true',
                'value' => $menu_title,
                'return' => true
            );
            $content .= $foodsearch_form_fields->input_field($args);
            $content .= '</div><div class="fds-form-field select-field-con">';

            $values = array(
                'monday' => esc_html__('monday', 'wp-foodsearch'),
                'tuesday' => esc_html__('tuesday', 'wp-foodsearch'),
                'wednesday' => esc_html__('wednesday', 'wp-foodsearch'),
                'thursday' => esc_html__('thursday', 'wp-foodsearch'),
                'friday' => esc_html__('friday', 'wp-foodsearch'),
                'saturday' => esc_html__('saturday', 'wp-foodsearch'),
                'sunday' => esc_html__('sunday', 'wp-foodsearch'),
            );
            $args = array(
                'id' => 'menu_opening_days',
                'name' => 'menu_opening_days[]',
                'classes' => 'select_dropdown',
                'label' => esc_html__('menu opening days', 'wp-foodsearch'),
                'placeholder' => esc_html__('select menu opening days', 'wp-foodsearch'),
                'required' => 'true',
                'value' => $values,
                'selected' => $opening_days,
                'type' => 'multiple',
                'return' => true
            );
            $content .= $foodsearch_form_fields->select_field($args);
            $content .= '</div><div class="fds-form-field select-field-con">';

            $values = array();
            for ($i = 0; $i < 24; $i++) {
                for ($x = 0; $x <= 3; $x++) {
                    $values[$i . ':' . (($x * 15) == 0 ? '00' : ($x * 15))] = $i . ':' . (($x * 15) == 0 ? '00' : ($x * 15));
                }
            }
            $args = array(
                'id' => 'menu_start_time',
                'name' => 'menu_start_time',
                'classes' => 'select_dropdown',
                'label' => esc_html__('menu start time', 'wp-foodsearch'),
                'placeholder' => esc_html__('select menu starting time', 'wp-foodsearch'),
                'required' => 'true',
                'value' => $values,
                'selected' => $start_time,
                'return' => true
            );
            $content .= $foodsearch_form_fields->select_field($args);
            $content .= '</div><div class="fds-form-field select-field-con">';
            $args = array(
                'id' => 'menu_end_time',
                'name' => 'menu_end_time',
                'classes' => 'select_dropdown',
                'label' => esc_html__('menu closing time', 'wp-foodsearch'),
                'placeholder' => esc_html__('select menu closing time', 'wp-foodsearch'),
                'required' => 'true',
                'value' => $values,
                'selected' => $end_time,
                'return' => true
            );
            $content .= $foodsearch_form_fields->select_field($args);
            $content .= '</div><div class="fds-form-field">';

            $args = array(
                'id' => 'details',
                'name' => 'details',
                'classes' => 'fds-textarea-style',
                'label' => esc_html__('menu details', 'wp-foodsearch'),
                'placeholder' => esc_html__('menu details', 'wp-foodsearch'),
                'value' => $menu_desc,
                'return' => true
            );
            $content .= $foodsearch_form_fields->textarea_field($args);
            $content .= '</div><div class="fds-form-field select-field-con">';
            $values = array(
                '1' => esc_html__('pending', 'wp-foodsearch'),
                '2' => esc_html__('approve', 'wp-foodsearch'),
                '4' => esc_html__('reject', 'wp-foodsearch'),
            );
            
            if (isset($_POST['bplc']) && $_POST['bplc'] == 'y') {
                $args = array(
                    'type' => 'single',
                    'id' => 'status',
                    'name' => 'status',
                    'classes' => 'select_menu post-filed select_dropdown',
                    'label' => esc_html__('select status', 'wp-foodsearch'),
                    'value' => $values,
                    'selected' => $menu_status,
                    'required' => 'true',
                    'return' => true
                );
                $content .= $foodsearch_form_fields->select_field($args);
            }
            else if(isset($menu_status) && (!isset($_POST['bplc']) ||$_POST['bplc'] != 'y') ){
                $args = array(
                    'type' => 'hidden',
                    'id' => 'status',
                    'name' => 'status',
                    'classes' => 'fds-input-style',
                    'label' => esc_html__('status', 'wp-foodsearch'),
                    'placeholder' => esc_html__('status', 'wp-foodsearch'),
                    'required' => 'true',
                    'value' => $menu_status,
                    'return' => true
                );
                $content .= $foodsearch_form_fields->input_field($args);
            }

            $content .= '</div></div><div class="fds-add-newcat">';
            ob_start();
            wp_nonce_field('updating_menu', 'menu_save_nonce');
            $content .= ob_get_clean();
            
            $content .= '<div class="fds-btn fds-medium-btn">';
            $args = array(
                'type' => 'submit',
                'id' => 'fds-updatemenu-' . $rand_id,
                'name' => 'save_menu',
                'classes' => 'fds-updatemenu-savebtn fds-newcat-savebtn fds-update-anything-action fds-has-save',
                'value' => esc_html__('save menu', 'wp-foodsearch'),
                'return' => true
            );
            $content .= $foodsearch_form_fields->button($args);
            $content .= ' 
                </div>
                </div>
            </div>';
        }
        return $content;
    }

    public function add_menuitems() {
        global $foodsearch_form_fields;
        
        $common_functions = new Common_Functions;
        
        $is_admin = is_admin();
        
        $user_id = $_POST['n_id'];
        
        $restaurant_id = $_POST['restaurant'];
        
        $content = '<div class="fds-booking-detail-title">
            <h2 class="fds-heading-title">' . esc_html__('add menu item', 'wp-foodsearch') . '</h2>
        </div>
        <div class="fds-builder-popupform">
        <div class="fds-popupform-inner-wrap">';

        $args = array(
            'type' => 'hidden',
            'name' => 'restaurant_id',
            'value' => $restaurant_id,
            'return' => true
        );
        $content .= $foodsearch_form_fields->input_field($args);

        $args = array(
            'type' => 'hidden',
            'name' => 'category',
            'value' => $_POST['category'],
            'return' => true
        );
        $content .= $foodsearch_form_fields->input_field($args);
        $args = array(
            'type' => 'hidden',
            'name' => 'status',
            'value' => (isset($_POST['is_restpage']) && $_POST['is_restpage'] == '1' ? '2' : '1'),
            'return' => true
        );
        $content .= $foodsearch_form_fields->input_field($args);
        $args = array(
            'type' => 'hidden',
            'name' => 'menu_id',
            'value' => $_POST['menu'],
            'return' => true
        );
        $content .= $foodsearch_form_fields->input_field($args);
        $content .= '<div class="fds-popupform-offer-coll">
                        <div><div class="fds-popup-inner">';
        $args = array(
            'type' => 'text',
            'id' => 'up_title',
            'name' => 'title',
            'classes' => 'post-filed',
            'label' => esc_html__('item title', 'wp-foodsearch'),
            'placeholder' => esc_html__('item title', 'wp-foodsearch'),
            'required' => true,
            'value' => '',
            'return' => true
        );
        $content .= $foodsearch_form_fields->input_field($args);
        $content .= '</div><div class="fds-popup-inner menuitem-price-con">';
        $args = array(
            'type' => 'number',
            'id' => 'up_price',
            'name' => 'price',
            'classes' => 'post-filed',
            'label' => sprintf(esc_html__('price %s', 'wp-foodsearch'), esc_html__(common_functions::curency_symbol('menu_item'), 'wp-foodsearch')),
            'placeholder' => wp_strip_all_tags(Common_Functions::get_formatted_price('45', 'menu_item')),
            'required' => true,
            'value' => '',
            'step'=>'0.01',
            'return' => true
        );
        $content .= $foodsearch_form_fields->input_field($args);
        $content .= '</div><div class="fds-popup-inner menuitem-discprice-con">';
        $args = array(
            'type' => 'number',
            'id' => 'up_discount_price',
            'name' => 'discount_price',
            'classes' => 'post-filed',
            'label' => esc_html__('discount price', 'wp-foodsearch'),
            'placeholder' => wp_strip_all_tags(Common_Functions::get_formatted_price('40', 'menu_item')),
            'value' => '',
            'step'=>'0.01',
            'return' => true
        );
        $content .= $foodsearch_form_fields->input_field($args);
        $content .= '</div><div class="fds-popup-inner">';
        $args = array(
            'id' => 'up_offer_status',
            'name' => 'offer_status',
            'label' => esc_html__('special offer', 'wp-foodsearch'),
            'value' => '',
            'return' => true
        );
        $content .= $foodsearch_form_fields->switch2_field($args);

        $content .= '</div></div>';



        $content .= '<div>
                            <label class="fds-input-label">' . esc_html__('browse photo', 'wp-foodsearch') . '</label>
                            <div class="fds-popupform-file-upload image-upload" data-sizerr="' . esc_html__('file size is too large to upload.', 'wp-foodsearch') . '" data-typerr="' . esc_html__('only correct format images are allowed to upload.', 'wp-foodsearch') . '">';
        
        $uplod_img_class = 'fds-upload fds-uplod-fooditm';
        if ($is_admin) {
            $uplod_img_class = 'fds-upload';
        }
        
        $img_rand = rand(1000000, 9999999);
        if (!$is_admin) {
            $content .= '<a href="#" class="' . $uplod_img_class . ' fds-link fds-user-openmedia srcbg-' . $img_rand . '" data-nid="' . $user_id . '" data-pid="' . $restaurant_id . '" data-apid="' . $img_rand . '" data-aptype="id"><i class="fds-icon fds-camera"></i></a>';
        } else {
            $content .= '<a href="#" class="' . $uplod_img_class . ' fds-link"><i class="fds-icon fds-camera"></i></a>';
        }
        
        $content .= '<a href="#" class="fds-remove fds-link" style="display:none"><i class="dashicons-before dashicons-no"></i></a>
        <input type="hidden" name="image" class="img-' . $img_rand . '" value="">';
        if (!$is_admin) {
            //
        }
        $content .= '<div class="fds-loader-holder" style="display:none;"></div></div>
            </div>
        </div>';

        // description
        $content .= '<div class="fds-popupform-offer-coll"><div class="fds-popup-inner">';
        $args = array(
            'id' => 'menu-item-description',
            'name' => 'item_details',
            'classes' => 'fds-textarea-style',
            'label' => esc_html__('description', 'wp-foodsearch'),
            'value' => '',
            'return' => true
        );
        $content .= $foodsearch_form_fields->textarea_field($args);
        $content .= '</div></div>';
        //
        
        $content .= '
        <div class="fds-popupform-fullsec-coll">
            <div>';
        $args = array(
            'type' => 'multiple',
            'id' => 'up_item_choice_gruop',
            'name' => 'item_choice_gruop[]',
            'classes' => 'post-filed food-item-cgdd',
            'label' => esc_html__('select choice group', 'wp-foodsearch'),
            'value' => '',
            'selected' => '',
            'return' => true
        );
        $content .= $foodsearch_form_fields->select_field($args);

        $content .= '
                    </div> </div>
        <div class="fds-popupform-fullsec-coll">
        <div>';
        $args = array(
            'type' => 'multiple',
            'id' => 'up_item_nutritions',
            'name' => 'item_nutritions[]',
            'classes' => 'post-filed food-item-nutridd',
            'label' => esc_html__('select nutritions', 'wp-foodsearch'),
            'value' => '',
            'selected' => '',
            'return' => true
        );
        $content .= $foodsearch_form_fields->select_field($args);

        $content .= '
        </div> </div>
                    <div class="fds-menu-builder-list">
                    <div class="menu-builder-actsin">

                        <div class="fds-menu-builder-header"><i class="fds-icon fds-move-drager fds-builder-drager"></i> 
                            <div class="fds-column-title">' . esc_html__('variation title', 'wp-foodsearch') . '</div>
                            <div class="fds-column-title">' . esc_html__('item price', 'wp-foodsearch') . '</div>
                            <div class="fds-column-title fds-column-actions">
                                <a href="#" class="fds-builder-action fds-link"><i class="fds-icon fds-sheet"></i></a>
                                <a href="#" class="fds-builder-action fds-link"><i class="fds-icon fds-settings-work"></i></a>
                                <a href="#" class="fds-builder-action fds-link"><i class="fds-icon fds-bin"></i></a>
                            </div>
                        </div>
                        <div class="fds-menu-builder-body">';
        $content .= '<div class="fds-menu-builder-inn" style="display: none">
                                    <i class="fds-icon fds-move-drager fds-builder-inner-drager"></i>
                                <div class="fds-menu-builder-inn-cell">';
        $args = array(
            'type' => 'text',
            'id' => 'variation_name',
            'name' => 'variation_name[]',
            'classes' => 'post-filed',
            'label' => '',
            'value' => '',
            'return' => true
        );
        $content .= $foodsearch_form_fields->input_field($args);
        $content .= '</div>';
        $content .= '<div class="fds-menu-builder-inn-cell">';
        $args = array(
            'type' => 'number',
            'id' => 'variation_price',
            'name' => 'variation_price[]',
            'classes' => 'post-filed',
            'label' => '',
            'value' => '',
            'step'=>'0.01',
            'return' => true
        );
        $content .= $foodsearch_form_fields->input_field($args);
        $content .= '</div>';
        $content .= '<div class="fds-menu-builder-inn-cell">
                                    <a href="#" class="fds-body-action fds-link delet-action fds-remove-action fds-remove-variation"><i class="fds-icon fds-time-simple"></i></a>
                                </div>
                            </div>';

        $content .= '</div><a href="#" class="fds-add-action fds-link fds-add-varitaion"><i class="fds-icon fds-plus-simple"></i>' . esc_html__(' add more variations', 'wp-foodsearch') . '</a></div></div></div><div class="fds-add-newcat">';
        
        $content .= '<div class="fds-btn fds-medium-btn">';
        $args = array(
            'type' => 'submit',
            'id' => 'menuItemSave',
            'name' => 'menuItemSave',
            'classes' => 'fds-newcat-savebtn fds-has-save fds-update-anything-action',
            'value' => esc_html__('add item', 'wp-foodsearch'),
            'return' => true
        );
        $content .= $foodsearch_form_fields->button($args);
        $content .= '</div>';
        ob_start();
        wp_nonce_field('adding_menuitem', 'menu_item_nonce');
        $content .= ob_get_clean();
        $content .= '</div>
                    <!--// Restaurant Builder //-->

                </div>
            </div><div class="result-status"></div>';
        return $content;
    }

    public function edit_menuitems() {
        $is_admin = is_admin();
        
        $common_functions = new Common_Functions;
        
        $user_id = $_POST['n_id'];
        
        $where = '';
        if (isset($_POST['id'])) {
            $where = ' where id =' . $_POST['id'];
        }
        global $table_prefix, $wpdb, $foodsearch_form_fields;
        $table_name = $table_prefix . 'menu_items';
        $sql = "SELECT * FROM $table_name$where";
        $results = $wpdb->get_results($sql);
        $content = '';
        if (isset($results) && count($results) > 0) {
            foreach ($results as $key => $menuItem) {
                
                $restaurant_id = $menuItem->restaurant_id;
                $menu_id = $menuItem->id;
                
                $restaurant_nutritions = $common_functions->get_restaurant_nutritions($restaurant_id);
                $restaurant_nutri_items = array();
                if (!empty($restaurant_nutritions)) {
                    foreach ($restaurant_nutritions as $nutri_key => $nutri_item) {
                        $restaurant_nutri_items[$nutri_key] = $nutri_item['title'];
                    }
                }
                
                $menu_nutri_items = array();
                $menu_nutritions = $common_functions->get_menu_item_nutritions($restaurant_id, $menu_id);
                if (!empty($menu_nutritions)) {
                    foreach ($menu_nutritions as $nutri_key => $nutri_item) {
                        $menu_nutri_items[] = $nutri_key;
                    }
                }
                
                $content = '<div class="fds-booking-detail-title">
                    <h2 class="fds-heading-title">' . esc_html__('edit menu item', 'wp-foodsearch') . '</h2>
                </div>
                <div class="fds-builder-popupform">
                <div class="fds-popupform-inner-wrap">';
                $args = array(
                    'type' => 'hidden',
                    'name' => 'id',
                    'value' => $menuItem->id,
                    'return' => true,
                );
                $content .= $foodsearch_form_fields->input_field($args);

                $args = array(
                    'type' => 'hidden',
                    'name' => 'restaurant_id',
                    'value' => $menuItem->restaurant_id,
                    'return' => true
                );
                $content .= $foodsearch_form_fields->input_field($args);

                $args = array(
                    'type' => 'hidden',
                    'name' => 'category',
                    'value' => $menuItem->category_id,
                    'return' => true
                );
                $content .= $foodsearch_form_fields->input_field($args);

                $args = array(
                    'type' => 'hidden',
                    'name' => 'image',
                    'value' => $menuItem->attachment_id,
                    'return' => true
                );
                $content .= $foodsearch_form_fields->input_field($args);

                $args = array(
                    'type' => 'hidden',
                    'name' => 'menu_id',
                    'value' => $menuItem->menu_id,
                    'return' => true
                );
                $content .= $foodsearch_form_fields->input_field($args);
                $args = array(
                    'type' => 'hidden',
                    'name' => 'status',
                    'value' => $menuItem->status,
                    'return' => true
                );
                $content .= $foodsearch_form_fields->input_field($args);
                
                //
                $variation = json_decode($menuItem->variations, true);
                
                $has_variations = false;
                if (!empty($menuItem->variations) && count($variation) > 0) {
                    $has_variations = true;
                }
                
                $content .= '<div class="fds-popupform-offer-coll">
                <div><div class="fds-popup-inner">';
                $args = array(
                    'type' => 'text',
                    'id' => 'up_title',
                    'name' => 'title',
                    'classes' => 'post-filed',
                    'required' => true,
                    'label' => esc_html__('item title', 'wp-foodsearch'),
                    'placeholder' => esc_html__('item title', 'wp-foodsearch'),
                    'value' => $menuItem->name,
                    'return' => true
                );
                $content .= $foodsearch_form_fields->input_field($args);
                $content .= '</div><div class="fds-popup-inner menuitem-price-con"' . ($has_variations ? ' style="display: none;"' : '') . '>';
                $args = array(
                    'type' => 'number',
                    'id' => 'up_price',
                    'name' => 'price',
                    'classes' => 'post-filed',
                    'label' => sprintf(esc_html__('price %s', 'wp-foodsearch'), common_functions::curency_symbol('menu_item')),
                    'placeholder' => wp_strip_all_tags(Common_Functions::get_formatted_price('45', 'menu_item')),
                    'required' => true,
                    'value' => $menuItem->price,
                    'step'=>'0.01',
                    'return' => true
                );
                $content .= $foodsearch_form_fields->input_field($args);
                $content .= '</div><div class="fds-popup-inner menuitem-discprice-con"' . ($has_variations ? ' style="display: none;"' : '') . '>';
                $args = array(
                    'type' => 'number',
                    'id' => 'up_discount_price',
                    'name' => 'discount_price',
                    'classes' => 'post-filed',
                    'label' => esc_html__('discount price', 'wp-foodsearch'),
                    'placeholder' => wp_strip_all_tags(Common_Functions::get_formatted_price('40', 'menu_item')),
                    'value' => $menuItem->discount_price,
                    'step'=>'0.01',
                    'return' => true
                );
                $content .= $foodsearch_form_fields->input_field($args);
                $content .= '</div><div class="fds-popup-inner">';
                $args = array(
                    'id' => 'up_offer_status',
                    'name' => 'offer_status',
                    'label' => esc_html__('special offer', 'wp-foodsearch'),
                    'value' => (isset($menuItem->offer_status) && $menuItem->offer_status == '1' ? '1' : '0'),
                    'checked' => (isset($menuItem->offer_status) && $menuItem->offer_status == '1' ? '1' : '0'),
                    'return' => true
                );
                $content .= $foodsearch_form_fields->switch2_field($args);

                $content .= '</div></div>';
                $content .= '<div><label class="fds-input-label">' . esc_html__('browse photo', 'wp-foodsearch') . '</label> <div class="fds-popupform-file-upload image-upload" data-sizerr="' . esc_html__('file size is too large to upload.', 'wp-foodsearch') . '" data-typerr="' . esc_html__('only correct format images are allowed to upload.', 'wp-foodsearch') . '">';
                $image_id = $menuItem->attachment_id;
                
                $uplod_img_class = 'fds-upload fds-uplod-fooditm';
                if ($is_admin) {
                    $uplod_img_class = 'fds-upload';
                }
                $img_rand = rand(1000000, 9999999);
                if ($image = wp_get_attachment_image_src($image_id)) {
                    if (!$is_admin) {
                        $content .= '<a href="#" class="' . $uplod_img_class . ' fds-link fds-user-openmedia srcbg-' . $img_rand . '" data-nid="' . $user_id . '" data-pid="' . $menuItem->restaurant_id . '" data-apid="' . $img_rand . '" data-aptype="id" style="background: url(' . $image[0] . ') no-repeat top center / cover; "></a>';
                    } else {
                        $content .= '<a href="#" class="' . $uplod_img_class . ' fds-link" style="background: url(' . $image[0] . ') no-repeat top center / cover; "></a>';
                    }
                    $content .= '<a href="#" class="fds-remove fds-link"><i class="dashicons-before dashicons-no"></i></a>
                    <input type="hidden" name="image" class="img-' . $img_rand . '" value="' . $image_id . '">';
                    if (!$is_admin) {
                        //
                    }
                } else {
                    if (!$is_admin) {
                        $content .= '<a href="#" class="' . $uplod_img_class . ' fds-link fds-user-openmedia srcbg-' . $img_rand . '" data-nid="' . $user_id . '" data-pid="' . $menuItem->restaurant_id . '" data-apid="' . $img_rand . '" data-aptype="id"><i class="fds-icon fds-camera"></i></a>';
                    } else {
                        $content .= '<a href="#" class="' . $uplod_img_class . ' fds-link"><i class="fds-icon fds-camera"></i></a>';
                    }
                    $content .= '<a href="#" class="fds-remove fds-link" style="display:none"><i class="dashicons-before dashicons-no"></i></a>
                    <input type="hidden" name="image" class="img-' . $img_rand . '" value="">';
                    if (!$is_admin) {
                        //
                    }
                }
                $content .= '<div class="fds-loader-holder" style="display:none;"></div></div>
                        </div>
                    </div>';
                    
                // description
                $content .= '<div class="fds-popupform-offer-coll"><div class="fds-popup-inner">';
                $args = array(
                    'id' => 'menu-item-description',
                    'name' => 'item_details',
                    'classes' => 'fds-textarea-style',
                    'label' => esc_html__('description', 'wp-foodsearch'),
                    'value' => foodsearch_esc_wp_editor($menuItem->details),
                    'return' => true
                );
                $content .= $foodsearch_form_fields->textarea_field($args);
                $content .= '</div></div>';
                //

                $content .= '<div class="fds-popupform-fullsec-coll">
                        <div>';
                $values = SELF::menuChoiceGroupIncId($menuItem->choice_groups_id);
                $args = array(
                    'type' => 'multiple',
                    'id' => 'up_item_choice_gruop',
                    'name' => 'item_choice_gruop[]',
                    'classes' => 'post-filed food-item-cgdd',
                    'label' => esc_html__('select choice group', 'wp-foodsearch'),
                    'value' => $values,
                    'selected' => explode(',', $menuItem->choice_groups_id),
                    'return' => true
                );
                $content .= $foodsearch_form_fields->select_field($args);

                $content .= '</div> </div>
                <div class="fds-popupform-fullsec-coll">
                <div>';
                $args = array(
                    'type' => 'multiple',
                    'id' => 'up_item_nutritions',
                    'name' => 'item_nutritions[]',
                    'classes' => 'post-filed food-item-nutridd',
                    'label' => esc_html__('select nutritions', 'wp-foodsearch'),
                    'value' => $restaurant_nutri_items,
                    'selected' => $menu_nutri_items,
                    'return' => true
                );
                $content .= $foodsearch_form_fields->select_field($args);
                $content .= '
                </div> </div>';

                $content .= '
                <div class="fds-menu-builder-list">
                    <div class="menu-builder-actsin">
                    <div class="fds-menu-builder-header"><i class="fds-icon fds-move-drager fds-builder-drager"></i> 
                        <div class="fds-column-title">' . esc_html__('variation title', 'wp-foodsearch') . '</div>
                        <div class="fds-column-title">' . esc_html__('item price', 'wp-foodsearch') . '</div>
                        <div class="fds-column-title fds-column-actions">
                            <a href="#" class="fds-builder-action fds-link"><i class="fds-icon fds-sheet"></i></a>
                            <a href="#" class="fds-builder-action fds-link"><i class="fds-icon fds-settings-work"></i></a>
                            <a href="#" class="fds-builder-action fds-link"><i class="fds-icon fds-bin"></i></a>
                        </div>
                    </div>
                <div class="fds-menu-builder-body">';
                if (!empty($menuItem->variations) && count($variation) > 0) {
                    foreach ($variation as $k => $val) {
                        $content .= '<div class="fds-menu-builder-inn"> <i class="fds-icon fds-move-drager fds-builder-inner-drager menu-item-sorter"></i>
                                <div class="fds-menu-builder-inn-cell">
                                   ';
                        $args = array(
                            'type' => 'text',
                            'id' => '',
                            'name' => 'variation_name[]',
                            'classes' => 'post-filed',
                            'label' => '',
                            'required' => 'true',
                            'value' => $val['variation_name'],
                            'return' => true
                        );
                        $content .= $foodsearch_form_fields->input_field($args);
                        $content .= '</div>';
                        $content .= '<div class="fds-menu-builder-inn-cell">';
                        $args = array(
                            'type' => 'number',
                            'id' => '',
                            'name' => 'variation_price[]',
                            'classes' => 'post-filed',
                            'label' => '',
                            'required' => 'true',
                            'value' => $val['variation_price'],
                            'step'=>'0.01',
                            'return' => true
                        );
                        $content .= $foodsearch_form_fields->input_field($args);
                        $content .= '</div>';
                        $content .= '<div class="fds-menu-builder-inn-cell">
                                    <a href="#" class="fds-body-action delet-action fds-link fds-remove-action fds-remove-variation"><i class="fds-icon fds-time-simple"></i></a>
                                </div>
                            </div>';
                    }
                } else {
                    $content .= '<div class="fds-menu-builder-inn" style="display: none"> 
                                <i class="fds-icon fds-move-drager fds-builder-inner-drager"></i>
                                <div class="fds-menu-builder-inn-cell">
                                   ';
                    $args = array(
                        'type' => 'text',
                        'id' => '',
                        'name' => 'variation_name[]',
                        'classes' => 'post-filed',
                        'label' => '',
                        'value' => '',
                        'return' => true
                    );
                    $content .= $foodsearch_form_fields->input_field($args);
                    $content .= '</div>';
                    $content .= '<div class="fds-menu-builder-inn-cell">';
                    $args = array(
                        'type' => 'number',
                        'id' => '',
                        'name' => 'variation_price[]',
                        'classes' => 'post-filed',
                        'label' => '',
                        'value' => '',
                        'return' => true
                    );
                    $content .= $foodsearch_form_fields->input_field($args);
                    $content .= '</div>';
                    $content .= '<div class="fds-menu-builder-inn-cell">
                                    <a href="#" class="fds-body-action fds-link delet-action fds-remove-action fds-remove-variation"><i class="fds-icon fds-time-simple"></i></a></div></div>';
                }
                $content .= '</div><a href="#" class="fds-add-action fds-add-varitaion fds-link"><i class="fds-icon fds-plus-simple"></i>' . esc_html__(' add more variations', 'wp-foodsearch') . '</a></div></div></div><div class="fds-add-newcat">';
                
                $content .= '<div class="fds-btn fds-medium-btn">';
                $args = array(
                    'type' => 'submit',
                    'id' => 'menuItemUpdate',
                    'name' => 'menuItemUpdate',
                    'classes' => 'fds-newcat-savebtn fds-has-save fds-update-anything-action',
                    'value' => esc_html__('save', 'wp-foodsearch'),
                    'return' => true
                );
                $content .= $foodsearch_form_fields->button($args);
                $content .= '</div>';
                
                ob_start();
                wp_nonce_field('updating_menuitem', 'menu_item_nonce');
                $content .= ob_get_clean();
                $content .= '</div></div>
                </div>
            </div>';
            }
        }
        return $content;
    }

    public function add_category() {
        global $foodsearch_form_fields;
        $content = '<div class="fds-booking-detail-title">
                    <h2 class="fds-heading-title">' . esc_html__('add new category', 'wp-foodsearch') . '</h2>
                </div>
                <div class="fds-builder-popupform">
                <div class="fds-popupform-inner-wrap">
                    ';

        $content .= '<div class="fds-popupform-fullsec-coll">
                        <div>';
        $args = array(
            'type' => 'text',
            'id' => 'up_title',
            'name' => 'title',
            'classes' => 'post-filed',
            'label' => esc_html__('name', 'wp-foodsearch'),
            'placeholder' => esc_html__('category name', 'wp-foodsearch'),
            'value' => '',
            'return' => true
        );
        $content .= $foodsearch_form_fields->input_field($args);
        $content .= '</div></div><div class="fds-popupform-fullsec-coll"><div>';
        $args = array(
            'type' => 'single',
            'id' => 'up_categories',
            'name' => 'category',
            'classes' => 'post-filed food-item-category-dropdown',
            'label' => esc_html__('select parent category', 'wp-foodsearch'),
            'value' => '',
            'selected' => '',
            'required' => 'true',
            'return' => true
        );
        $content .= $foodsearch_form_fields->select_field($args);

        $content .= '</div> </div>';

        $content .= '<div class="fds-add-newcat">';
        $args = array(
            'type' => 'button',
            'id' => 'menuCategorySave',
            'name' => 'menuCategorySave',
            'classes' => 'fds-newcat-savebtn',
            'value' => esc_html__('save', 'wp-foodsearch'),
            'return' => true
        );
        $content .= $foodsearch_form_fields->button($args);

        $content .= '</div>
            </div>';
        return $content;
    }

    public function menuChoiceGroupIncId($id) {
        global $table_prefix, $wpdb;
        $table_name = $table_prefix . 'menu_choice_group';

        $result = $results = '';
        if ($id != '') {
            $sql = "SELECT * FROM $table_name where id IN(" . $id . ")";
            $result = $wpdb->get_results($sql);
            $where = '';
            if (!empty($id)) {
                $where = "where id NOT IN (" . $id . ")";
            }
            $sql = "SELECT * FROM $table_name $where ORDER BY RAND() limit 99";
            $results = $wpdb->get_results($sql);
        }
        $p = array();

        if (!empty($result)) {
            foreach ($result as $post) {
                $p[$post->id] = $post->name;
            }
        }
        if (!empty($results)) {
            foreach ($results as $post) {
                $p[$post->id] = $post->name;
            }
        }
        return $p;
    }

    public function updateItemCategoryForm(){
        $id = $_POST['id'];
        $resturant_id = $_POST['resturantid'];
        global $foodsearch_form_fields;
        $term = get_term_meta($id,'_'.$resturant_id.'_cat_item_desc');
        if($term){
            $term = $term[0];
        }
        else{
            $term = '';
        }
        $content = '<div class="fds-booking-detail-title">
        <h2 class="fds-heading-title">' . esc_html__('Update Item Category', 'wp-foodsearch') . '</h2>
        </div>
        <div class="fds-builder-popupform">
        <div class="fds-popupform-inner-wrap">';

        $args = array(
            'type' => 'hidden',
            'name' => 'category',
            'value' => $id,
            'return' => true
        );
        $content .= $foodsearch_form_fields->input_field($args);
        $args = array(
            'type' => 'hidden',
            'name' => 'resturant_id',
            'value' => $resturant_id,
            'return' => true
        );
        $content .= $foodsearch_form_fields->input_field($args);
        $content .= '<div class="fds-popupform-offer-coll">
                        <div><div class="fds-popup-inner">';
        $args = array(
            'type' => 'textarea',
            'id' => 'cat_item_description',
            'name' => 'cat_item_description',
            'classes' => 'fds-textarea-style',
            'label' => esc_html__('Category Description', 'wp-foodsearch'),
            'placeholder' => esc_html__('Category Description', 'wp-foodsearch'),
            'required' => true,
            'value' => $term,
            'return' => true
        );
        $content .= $foodsearch_form_fields->textarea_field($args);
        $content .= '</div></div></div></div>';
        $content .= '<div class="fds-add-newcat"><div class="fds-btn fds-medium-btn">';
        $args = array(
            'type' => 'button',
            'id' => 'itemCatUpdate',
            'name' => 'itemCatUpdate',
            'classes' => 'fds-newcat-savebtn fds-has-save fds-update-anything-action',
            'value' => esc_html__('Update Category', 'wp-foodsearch'),
            'return' => true
        );
        $content .= $foodsearch_form_fields->button($args);
        $content .= '</div></div></div>';
        return $content;
    }

}

new MenuBuilder();
