<?php

namespace FoodSearch\Plugin_Settings;
use FoodSearch\Icon_Picker;
use FoodSearch\Plugin_Settings\Settings_Fields;
use FoodSearch\Dashboard_Settings\Common_Functions as Dashboard_Common;

class Settings_Page {
    
    public $settings_url;
    public $setting_fields = array();
    public $option_name = 'foodsearch_plugin_settings';

    public function __construct() {
        
        $this->settings_url = admin_url('admin.php?page=foodsearch-plugin-settings');
        
        $this->includes();
        
        $settins_fields = new Settings_Fields;
        
        $this->setting_fields = $settins_fields->list_set();
        
        add_action('init', array($this, 'save_settings'), 10);
        add_action('init', array($this, 'change_fields_conditions'), 10);
        add_action('init', array($this, 'init'), 10);
        add_action('admin_enqueue_scripts', array($this, 'admin_enqueue'), 999);
        
        add_action('rest_api_init', array($this, 'register_api'), 5);
        
        add_filter('foodsearch_plugin_setins_tab_section_html', array($this, 'dash_builder_tab_html'), 1, 3);
        
        //
        add_action('admin_bar_menu', array($this, 'settings_in_admin_bar'), 101);
    }
    
    public function admin_enqueue() {
        
        if (isset($_GET['page']) && $_GET['page'] == 'foodsearch-plugin-settings') {
            
            wp_enqueue_style('foodsearch-settings-fields', foodsearch_plugin_get_url('assets/admin/css/build/css/setting.css'), array(), \FoodSearch_Plugin::get_version());
        }
    }
    
    public function init() {
        global $foodsearch_plugin_settings;
        
        $option_key = $this->option_name;
        $foodsearch_plugin_settings = get_option($option_key);
    }
    
    public function includes() {
        include plugin_dir_path(dirname(__FILE__)) . 'settings/form-fields.php';
        include plugin_dir_path(dirname(__FILE__)) . 'settings/settings-fields.php';
    }
    
    public function register_api() {

        register_rest_route('wp/v1', 'search-plugin-options', array(
            'methods' => 'GET',
            'callback' => [$this, 'search_plugin_options'],
           'permission_callback' =>  'admin_permissions_check',
        ));
    }
    
    public function admin_menu() {
        add_menu_page(esc_html__('Foodsearch settings', 'wp-foodsearch'), esc_html__('Foodsearch settings', 'wp-foodsearch'), 'administrator', 'foodsearch-plugin-settings', array($this, 'settings_page'));
    }
    
    public function settings_in_admin_bar($admin_bar) {
        $admin_bar->add_menu( array(
            'id' => 'fds-foodsearch-options',
            'parent' => 'fds-foodsearch-plugin',
            'title' => esc_html__('Settings', 'wp-foodsearch'),
            'href' => admin_url('admin.php?page=foodsearch-plugin-settings'),
            'meta' => array(
                'title' => esc_html__('Settings', 'wp-foodsearch'),
            ),
        ));
        
        $side_menu_links = self::side_menu_links();
        
        foreach ($side_menu_links as $side_menu_id => $side_menu_link) {
            $sett_label = $side_menu_link['label'];
            $admin_bar->add_menu( array(
                'id' => 'fds-settings-' . $side_menu_id,
                'parent' => 'fds-foodsearch-options',
                'title' => $sett_label,
                'href' => admin_url('admin.php?page=foodsearch-plugin-settings&tab=' . $side_menu_id),
                'meta' => array(
                    'title' => $sett_label,
                ),
            ));
        }
    }
    
    public function settings_page() {
        global $pagenow;
        
        wp_enqueue_script('pickr');
        
        // icon picker enqueue
        wp_enqueue_style('foodsearch-iconpiker');
        wp_enqueue_script('foodsearch-iconpiker');
        
        $all_fields = $this->setting_fields;
        
        $settings_url = $this->settings_url;
        $menu_tabs = self::side_menu_links();
        
        $active_tab = isset($_GET['tab']) ? $_GET['tab'] : '';
        $active_tab = $active_tab != '' && isset($menu_tabs[$active_tab]) ? $active_tab : '';
        
        $settings_tab = $active_tab != '' ? $active_tab : 'general';
        
        $active_sec = isset($_GET['section']) ? $_GET['section'] : '';
        
        if ($active_sec != '' && isset($menu_tabs[$active_tab]['submenu'][$active_sec])) {
            $settings_tab = $active_sec;
        }
        
        ob_start();
        ?>
        <div class="fds-plugin-settings">
            <div class="fds-panel-header">
                <div class="fds-header-heading"><?php esc_html_e('foodsearch options', 'wp-foodsearch') ?> <small><?php echo \foodsearch_plugin::get_version() ?></small></div>
                <div class="fds-setings-serch-con" data-page="<?php echo admin_url($pagenow) ?>">
                    <div class="fds-select-field">
                        <select id="fds-setting-search-item" data-placeholder="<?php esc_html_e('search options', 'wp-foodsearch') ?>" class="fds-setingsrch-select">
                            <option value=""><?php esc_html_e('search options', 'wp-foodsearch') ?></option>
                        </select>
                    </div>
                </div>
            </div>
            <div class="fds-general-wrapper">
                <div class="fds-panel-menu-list">
                    <ul class="fds-options-wrap">
                        <?php
                        $tabs_counter = 1;
                        foreach ($menu_tabs as $menu_tab_key => $tab_item) {
                            $active_class = '';
                            if ($active_tab == '' && $tabs_counter == 1) {
                                $active_class = ' active';
                            } else if ($active_tab != '' && $active_tab == $menu_tab_key) {
                                $active_class = ' active';
                            }
                            ?>
                            <li class="side-itm-menu<?php echo ($active_class) ?> fds-list-item">
                                <a href="<?php echo add_query_arg(array('tab' => $menu_tab_key), $settings_url) ?>" class="fds-link"><span><?php echo (isset($tab_item['icon']) ? '<i class="' . $tab_item['icon'] . '"></i> ' : '') ?><?php echo ($tab_item['label']) ?></span><?php echo (isset($tab_item['submenu']) && !empty($tab_item['submenu']) ? ' <i class="fds-icon fds-down-arrow"></i>' : '') ?></a>
                                <?php
                                if (isset($tab_item['submenu']) && !empty($tab_item['submenu'])) {
                                    $sub_menus = $tab_item['submenu'];

                                    $show_submenu = false;
                                    if ($menu_tab_key == $active_tab) {
                                        $show_submenu = true;
                                    }
                                    ?>
                                    <ul class="submenu-con fds-options-wrap"<?php echo ($show_submenu ? '' : ' style="display: none;"') ?>>
                                        <?php
                                        foreach ($sub_menus as $submenu_key => $submenu_itm) {
                                            $active_class = '';
                                            if ($active_sec != '' && $active_sec == $submenu_key) {
                                                $active_class = ' active';
                                            }
                                            ?>
                                            <li class="submenu-itm<?php echo ($active_class) ?> fds-list-item"><a href="<?php echo add_query_arg(array('tab' => $menu_tab_key, 'section' => $submenu_key), $settings_url) ?>" class="fds-link"><span><?php echo (isset($submenu_itm['icon']) ? '<i class="' . $submenu_itm['icon'] . '"></i> ' : '') ?><?php echo ($submenu_itm['label']) ?></span></a></li>
                                            <?php
                                        }
                                        ?>
                                    </ul>
                                    <?php
                                }
                                ?>
                            </li>
                            <?php
                            $tabs_counter++;
                        }
                        ?>
                    </ul>
                </div>
                <div class="fds-content-panel">
                    <?php
                    ob_start();
                    if (isset($all_fields[$settings_tab])) {
                        $fields_set = $all_fields[$settings_tab];
                        $this->settings_section($fields_set, $settings_tab);
                    }
                    $html = ob_get_clean();
                    echo apply_filters('foodsearch_plugin_setins_tab_section_html', $html, $all_fields, $settings_tab, $this);
                    ?>
                </div>
            </div>
        </div>
        <?php
        $html = ob_get_clean();
        echo apply_filters('foodsearch_all_plugin_settings_html', $html, $settings_tab, $this);
    }
    
    public static function side_menu_links() {
        $tabs = array(
            'general' => array(
                'label' => esc_html__('General', 'wp-foodsearch'),
                'icon' => 'dashicons dashicons-admin-home',
            ),
            'register' => array(
                'label' => esc_html__('Login/Register', 'wp-foodsearch'),
                //'icon' => 'dashicons-groups',
                'icon' => 'dashicons dashicons-admin-users',
            ),
            'dashboard' => array(
                'label' => esc_html__('Dashboard Settings', 'wp-foodsearch'),
                'icon' => 'dashicons dashicons-admin-generic',
            ),
            'dashboard_builder' => array(
                'label' => esc_html__('Dashboard Builder', 'wp-foodsearch'),
                'icon' => 'fds-icon fds-user',
                'submenu' => array(
                    'restaurant_builder' => array(
                        'label' => esc_html__('Restaurant Dashboard', 'wp-foodsearch'),
                    ),
                    'customer_builder' => array(
                        'label' => esc_html__('Customer Dashboard', 'wp-foodsearch'),
                    ),
                )
            ),
            'restaurant_settings' => array(
                'label' => esc_html__('Restaurant Settings', 'wp-foodsearch'),
                'icon' => 'dashicons dashicons-admin-generic',
            ),
            'payment' => array(
                'label' => esc_html__('Payment Settings', 'wp-foodsearch'),
                'icon' => 'dashicons dashicons-admin-generic',
            ),
            'api_settings' => array(
                'label' => esc_html__('API Settings', 'wp-foodsearch'),
                'icon' => 'dashicons dashicons-admin-generic',
            ),
            'email_settings' => array(
                'label' => esc_html__('Email Settings', 'wp-foodsearch'),
                'icon' => 'dashicons dashicons-email',
                'submenu' => array(
                    'user_emails' => array(
                        'label' => esc_html__('User Email Templates', 'wp-foodsearch'),
                    ),
                    'restaurant_emails' => array(
                        'label' => esc_html__('Restaurant Email Templates', 'wp-foodsearch'),
                    ),
                    'customer_emails' => array(
                        'label' => esc_html__('Customer Email Templates', 'wp-foodsearch'),
                    ),
                )
            ),
            'location_settings' => array(
                'label' => esc_html__('Location Settings', 'wp-foodsearch'),
                'icon' => 'dashicons dashicons-location',
            ),
            'review_settings' => array(
                'label' => esc_html__('Review Settings', 'wp-foodsearch'),
                'icon' => 'dashicons dashicons-star-half',
            ),
        );
        
        
        return apply_filters('foodsearch_plugin_settings_menu_tabs', $tabs);
    }
    
    public static function get_menu_parent($sec_tab, $menu_tabs) {
        $parent_menu = '';
        foreach ($menu_tabs as $menu_key => $menu_itm) {
            if (isset($menu_itm['submenu'][$sec_tab])) {
                $parent_menu = $menu_key;
                break;
            }
        }
        return $parent_menu;
    }
    
    public function dash_builder_tab_html($html, $atts, $settings_tab) {
        if ($settings_tab == 'restaurant_builder' || $settings_tab == 'customer_builder') {
            ob_start();
            ?>
            <div class="fds-content-full-column">
                <div class="setsec-label-holdr">
                    <h2 class="fds-heading-title"><?php esc_html_e('dashboard builder settings', 'wp-foodsearch') ?></h2>
                </div>
            </div>
            <div class="fds-content-full-column">
                <div style="display: none;">
                    <?php
                    $editor_id = 'dash-bulider-exm-contnt';
                    $editor_settings = array(
                        'media_buttons' => false,
                        'textarea_name' => 'dash_bulider_exm_contnt',
                        'quicktags' => array('buttons' => 'strong,em,del,ul,ol,li,close'),
                        'tinymce' => array(
                            'toolbar1' => 'bold,bullist,numlist,italic,underline,alignleft,aligncenter,alignright,separator,link,unlink,undo,redo,caned_resp_button',
                            'toolbar2' => '',
                            'toolbar3' => '',
                        ),
                    );
                    wp_editor('', $editor_id, $editor_settings);
                    ?>
                </div>
                <?php
                echo apply_filters("foodsearch_bk_dashboard_{$settings_tab}_setins", '');
                ?>
            </div>
            <?php
            $html = ob_get_clean();
        }
        
        echo ($html);
    }
    
    public function settings_section($atts, $settings_tab) {
        
        global $foodsearch_is_section_open, $foodsearch_setsection_started;

        $sec_id = isset($atts['id']) ? $atts['id'] : '';
        $sec_html_class = $sec_id != '' ? ' fds-settins-' . str_replace('_', '-', $sec_id) : '';
        ?>
        <form class="fds-pluginsetin-form" data-id="<?php echo ($sec_id) ?>" method="post">
            <?php $this->action_buttons('top'); ?>
            <div class="fds-settings-msg" style="display:none;"></div>
            <div class="fds-content-full-column">
                <div class="setsec-label-holdr">
                    <h2 class="fds-heading-title"><?php echo (isset($atts['title']) ? $atts['title'] : '') ?></h2>
                    <?php
                    if (isset($atts['desc']) && $atts['desc'] != '') {
                        ?>
                        <em><?php echo ($atts['desc']) ?></em>
                        <?php
                    }
                    ?>
                </div>
            </div>
            <?php
            echo apply_filters('foodsearch_opts_sec_before_fields', '', $atts, $settings_tab);
            if (isset($atts['fields']) && !empty($atts['fields'])) {
                $foodsearch_is_section_open = false;
                $foodsearch_setsection_started = false;
                $fields = $atts['fields'];
                ob_start();
                foreach ($fields as $field) {
                    $this->field_item_html($field, $sec_id);
                }
                $fields_html = ob_get_clean();
                echo force_balance_tags($fields_html);
            }
            echo apply_filters('foodsearch_opts_sec_after_fields', '', $atts, $settings_tab);
            
            $this->action_buttons('bottom');
            wp_nonce_field('foodsearch-plugin-settings');
            ?>
            <input type="hidden" name="foodsearch_plugin_settins_tab" value="<?php echo ($settings_tab) ?>">
            <input type="hidden" name="fds_plugin_settings_action" value="">
        </form>
        <?php
    }
    
    public function action_buttons($place) {
        ?>
        <div class="fds-bar-action">
            <i class="fds-icon fds-group"></i>
            <div class="fds-btn fds-small-btn">
                <a href="#" class="fds-save-changes fds-has-bg fds-link"><?php esc_html_e('save changes', 'wp-foodsearch') ?></a>
                <a href="#" class="fds-reset-section fds-link"><?php esc_html_e('reset section', 'wp-foodsearch') ?></a>
                <a href="#" class="fds-reset-all fds-link"><?php esc_html_e('reset all', 'wp-foodsearch') ?></a>
            </div>
        </div>
        <?php
    }
    
    public function search_plugin_options() {
        $all_fields = $this->setting_fields;
        
        $responsedata = array('error' => '1', 'results' => array());

        $menu_tabs = self::side_menu_links();
        
        $search_keyword = isset($_REQUEST['search']) ? $_REQUEST['search'] : '';
        
        $option_fields = array();
        foreach ($all_fields as $sec_tab => $field_sec) {
            if (!isset($menu_tabs[$sec_tab])) {
                $parent_tab = self::get_menu_parent($sec_tab, $menu_tabs);
                $sec_tab = $parent_tab != '' ? $parent_tab . '|' . $sec_tab : $sec_tab;
            }
            if (isset($field_sec['fields']) && !empty($field_sec['fields'])) {
                foreach ($field_sec['fields'] as $field_itm) {
                    $field_title = $field_itm['title'];
                    if ($search_keyword != '') {
                        if (preg_match("/{$search_keyword}/i", $field_title) || $search_keyword == $field_title) {
                            $option_fields[$field_itm['id']] = array(
                                'tab' => $sec_tab,
                                'title' => $field_title,
                            );
                        }
                    } else {
                        $option_fields[$field_itm['id']] = array(
                            'tab' => $sec_tab,
                            'title' => $field_title,
                        );
                    }
                }
            }
        }

        $results_count = 1;
        $responsedata['error'] = '0';
        foreach ($option_fields as $option_key => $field_itm) {
            $page_tab = $field_itm['tab'];
            $option_label = $field_itm['title'];
            $option_id = $page_tab . '|' . $option_key;
            $responsedata['results'][] = array('id' => $option_id, 'text' => $option_label);
            
            if ($results_count >= 10) {
                break;
            }
            
            $results_count++;
        }
        
        wp_send_json($responsedata);
    }
    
    public function field_item_html($field, $sec_id) {

        global $foodsearch_plugin_settings, $foodsearch_is_section_open, $foodsearch_setsection_started;
        
        $field_type = $field['type'];
        $field_id = isset($field['id']) ? $field['id'] : '';
        $field_html_id = $field_id != '' ? 'fds-field-' . str_replace('_', '-', $field_id) : '';
        $field_html_class = $field_id != '' ? ' fds-setfield-' . str_replace('_', '-', $field_id) : '';
        
        //
        if ($field_type == 'section') {
            $foodsearch_is_section_open = true;
        } else if ($field_type == 'section_close') {
            $foodsearch_is_section_open = false;
        }
        
        if ($foodsearch_is_section_open && $field_type != 'section') {
            //
        }
        
        if ($field_type == 'section') {
            $field_html_class .= ' section-info-con';
        }
        
        //
        $field_style = '';
        
        if (isset($field['condition']) && !empty($field['condition'])) {
            $field_conditions = $field['condition'];
            
            $condition_flag = true;
            foreach ($field_conditions as $condition_key => $condition) {
                
                if (!isset($foodsearch_plugin_settings[$sec_id][$condition_key])) {
                    continue;
                }
                $cond_field_val = $foodsearch_plugin_settings[$sec_id][$condition_key];
                $cond_field_val = is_array($cond_field_val) ? $cond_field_val : array($cond_field_val);
                
                $compare_val = isset($condition['value']) ? $condition['value'] : '';
                $compare_operator = isset($condition['compare']) ? $condition['compare'] : '';
                
                if (is_array($compare_val)) {
                    $similarty_check = array_intersect($compare_val, $cond_field_val);
                    if ($compare_operator == '!=') {
                        if (!empty($similarty_check)) {
                            $condition_flag = false;
                        }
                    } else {
                        if (empty($similarty_check)) {
                            $condition_flag = false;
                        }
                    }
                } else {
                    if ($compare_operator == '!=') {
                        if (in_array($compare_val, $cond_field_val)) {
                            $condition_flag = false;
                        }
                    } else {
                        if (!in_array($compare_val, $cond_field_val)) {
                            $condition_flag = false;
                        }
                    }
                }
            }
            if ($condition_flag === false) {
                $field_style .= ' display:none;';
            }
        }
        
        if ($foodsearch_is_section_open && $field_type != 'section' && !$foodsearch_setsection_started) {
            $foodsearch_setsection_started = true;
            echo '<div class="fields-section-holder">';
        }
        ?>
        <div id="<?php echo ($field_html_id) ?>" class="<?php echo apply_filters('foodsearch_opts_sec_field_conclass', 'fds-content-full-column' . $field_html_class, $field, $sec_id) ?>"<?php echo ($field_style != '' ? ' style="' . $field_style . '"' : '') ?>>
            <?php
            if ($field_type == 'section') {
                ?>
                <div class="setsec-section-holdr">
                    <h3><?php echo (isset($field['title']) ? $field['title'] : '') ?></h3>
                    <?php
                    if (isset($field['desc']) && $field['desc'] != '') {
                        ?>
                        <p><?php echo ($field['desc']) ?></p>
                        <?php
                    }
                    ?>
                </div>
                <?php
            } else {
                ob_start();
                ?>
                <div class="setsec-field-holdr">
                    <div class="fds-content-column">
                        <span class="fds-panel-title"><?php echo (isset($field['title']) ? $field['title'] : '') ?></span>
                        <?php
                        if (isset($field['desc']) && $field['desc'] != '') {
                            ?>
                            <p><?php echo ($field['desc']) ?></p>
                            <?php
                        }
                        ?>
                    </div>
                    <div class="fds-content-column">
                        <?php echo apply_filters("foodsearch_settings_field_{$field_type}_html", '', $field, $sec_id) ?>
                    </div>
                </div>
                <?php
                $field_html = ob_get_clean();
                echo apply_filters("foodsearch_opts_sec_field_html", $field_html, $field, $sec_id);
            }
            ?>
        </div>
        <?php
        if ($field_type == 'section_close') {
            echo '</div>';
            $foodsearch_setsection_started = false;
        }
    }
    
    public function save_settings() {
        
        if (isset($_POST['foodsearch_plugin_settings']) && isset($_POST['fds_plugin_settings_action']) && current_user_can('administrator')) {
            check_admin_referer('foodsearch-plugin-settings');
            
            $option_key = $this->option_name;
            $post_data = isset($_POST['foodsearch_plugin_settings']) ? $_POST['foodsearch_plugin_settings'] : '';
            
            $saved_options = get_option($option_key);
            $saved_options = empty($saved_options) ? array() : $saved_options;
            
            $action_type = $_POST['fds_plugin_settings_action'];
            
            if ($action_type == 'reset_section') {
                $this->reset_section($option_key);
                wp_send_json(array('error' => '2', 'msg' => esc_html__('settings reset for this section.', 'wp-foodsearch')));
            } else if ($action_type == 'reset_all') {
                $this->reset_all($option_key);
                wp_send_json(array('error' => '2', 'msg' => esc_html__('all settings reset.', 'wp-foodsearch')));
            } else {
                foreach ($post_data as $option_sec_key => $option_sec_data) {
                    $saved_options[$option_sec_key] = $option_sec_data;
                }
                update_option($option_key, $saved_options);
                wp_send_json(array('error' => '0', 'msg' => esc_html__('all settings saved.', 'wp-foodsearch')));
            }
        }
    }
    
    public function reset_section($option_key) {
        $all_fields = $this->setting_fields;

        $data_sec_key = isset($_POST['foodsearch_plugin_settins_tab']) ? $_POST['foodsearch_plugin_settins_tab'] : '';

        if ($data_sec_key != '' && isset($all_fields[$data_sec_key])) {
            $fields_data = $all_fields[$data_sec_key];
            $data_arr = array();
            if (isset($fields_data['fields']) && !empty($fields_data['fields'])) {
                $opt_id = $fields_data['id'];
                $opt_fields = $fields_data['fields'];

                foreach ($opt_fields as $field_itm) {
                    if (isset($field_itm['id'])) {
                        $field_default_val = isset($field_itm['default']) ? $field_itm['default'] : '';
                        $data_arr[$field_itm['id']] = $field_default_val;
                    }
                }
                
                $saved_options = get_option($option_key);
                $saved_options = empty($saved_options) ? array() : $saved_options;
                $saved_options[$opt_id] = $data_arr;
                
                update_option($option_key, $saved_options);
            }
            //
        }
    }
    
    public function reset_all($option_key) {
        $all_fields = $this->setting_fields;

        if (!empty($all_fields)) {
            $data_arr = array();
            foreach ($all_fields as $fields_tab => $fields_data) {
                if (isset($fields_data['fields']) && !empty($fields_data['fields'])) {
                    $opt_id = $fields_data['id'];
                    $opt_fields = $fields_data['fields'];
                    
                    foreach ($opt_fields as $field_itm) {
                        if (isset($field_itm['id'])) {
                            $field_default_val = isset($field_itm['default']) ? $field_itm['default'] : '';
                            $data_arr[$opt_id][$field_itm['id']] = $field_default_val;
                        }
                    }
                }
            }
            //
            update_option($option_key, $data_arr);
        }
    }
    
    public function change_fields_conditions() {
        if (isset($_POST['foodsearch_plugin_settings']) && isset($_POST['plugin_settings_cond_check']) && current_user_can('administrator')) {
            
            $fields_tab = $_POST['foodsearch_plugin_settins_tab'];
            $all_fields = $this->setting_fields;
            
            $all_fields_conditions = array();
            if (isset($all_fields[$fields_tab]) && !empty($all_fields[$fields_tab])) {
                $tab_id = $all_fields[$fields_tab]['id'];
                $tab_fields = $all_fields[$fields_tab]['fields'];
                
                foreach ($tab_fields as $field) {
                    
                    $field_id = $field['id'];
                    $field_html_class = $field_id != '' ? '.fds-setfield-' . str_replace('_', '-', $field_id) : '';
                    
                    $all_fields_conditions[$field_id] = array(
                        'class' => $field_html_class,
                        'html' => 'on',
                    );
                    if (isset($field['condition']) && !empty($field['condition'])) {
                        
                        $field_conditions = $field['condition'];

                        $condition_flag = true;
                        foreach ($field_conditions as $condition_key => $condition) {

                            if (!isset($_POST['foodsearch_plugin_settings'][$tab_id][$condition_key])) {
                                continue;
                            }
                            $cond_field_val = $_POST['foodsearch_plugin_settings'][$tab_id][$condition_key];
                            $cond_field_val = is_array($cond_field_val) ? $cond_field_val : array($cond_field_val);

                            $compare_val = isset($condition['value']) ? $condition['value'] : '';
                            $compare_operator = isset($condition['compare']) ? $condition['compare'] : '';

                            if (is_array($compare_val)) {
                                $similarty_check = array_intersect($compare_val, $cond_field_val);
                                if ($compare_operator == '!=') {
                                    if (!empty($similarty_check)) {
                                        $condition_flag = false;
                                    }
                                } else {
                                    if (empty($similarty_check)) {
                                        $condition_flag = false;
                                    }
                                }
                            } else {
                                if ($compare_operator == '!=') {
                                    if (in_array($compare_val, $cond_field_val)) {
                                        $condition_flag = false;
                                    }
                                } else {
                                    if (!in_array($compare_val, $cond_field_val)) {
                                        $condition_flag = false;
                                    }
                                }
                            }
                        }
                        if ($condition_flag === false) {
                            $all_fields_conditions[$field_id] = array(
                                'class' => $field_html_class,
                                'html' => 'off',
                            );
                        }
                    }
                }
            }
            
            wp_send_json(array('error' => '0', 'conditions' => $all_fields_conditions));
        }
    }

}

global $foodsearch_settings_main_page;

$foodsearch_settings_main_page = new Settings_Page;
