var foodsearch_geoloc_curr_request;
function foodsearch_set_map_latlng_marker(lat, lng, zoom) {
    "use strict";
    
    var loc_maps = dashboard_location_vars.loc_maps;
    var loc_map_type = dashboard_location_vars.maps_type;
    var mapbox_api_key = dashboard_location_vars.mapbox_api;
    var mapbox_style = dashboard_location_vars.mapbox_style;
    
    lat = parseFloat(lat);
    lng = parseFloat(lng);
    zoom = zoom > 0 ? parseInt(zoom) : zoom;
    
    if (loc_maps == 'on') {
        if (loc_map_type == 'mapbox' && mapbox_api_key != '' && mapbox_style != '') {

            setTimeout(function() {
                var map_cords = [lng, lat];
                foodsearch__map.flyTo({
                    center: map_cords,
                    zoom: zoom,
                });
                document.querySelector('.fds-map-lat-field').value = lat;
                document.querySelector('.fds-map-lng-field').value = lng;

                // remove markers 
                if (foodsearch_map_markers !== null) {
                    for (var i = foodsearch_map_markers.length - 1; i >= 0; i--) {
                        foodsearch_map_markers[i].remove();
                    }
                }
                //
                var new_marker = new mapboxgl.Marker({
                    draggable: true
                }).setLngLat(map_cords).addTo(foodsearch__map);
                foodsearch_map_markers.push(new_marker);
                new_marker.on('dragend', function () {
                    var lngLat = new_marker.getLngLat();
                    document.querySelector('.fds-map-lat-field').value = lngLat.lat;
                    document.querySelector('.fds-map-lng-field').value = lngLat.lng;
                    foodsearch_get_map_cords_addres(lngLat.lat, lngLat.lng);
                });
            }, 600);
            
        } else if (loc_map_type == 'google') {
            var pos = {
                lat: lat,
                lng: lng
            };
            foodsearch__map.setCenter(pos);
            foodsearch__map.setZoom(zoom);
            document.querySelector('.fds-map-lat-field').value = lat;
            document.querySelector('.fds-map-lng-field').value = lng;

            // clear previous markers
            for (var i = 0; i < foodsearch_map_markers.length; i++) {
                foodsearch_map_markers[i].setMap(null);
            }

            var marker = new google.maps.Marker({
                map: foodsearch__map,
                position: pos,
                draggable: true,
            });
            foodsearch_map_markers.push(marker);

            google.maps.event.addListener(marker, 'dragend', function () {
                document.querySelector('.fds-map-lat-field').value = this.getPosition().lat();
                document.querySelector('.fds-map-lng-field').value = this.getPosition().lng();
                foodsearch_get_map_cords_addres(this.getPosition().lat, this.getPosition().lng);
            });
        }
    }
}

function foodsearch_check_location_latlng() {
    "use strict";
    var def_zoom = dashboard_location_vars.map_zoom;
    var request = jQuery.ajax({
        url: "https://ipinfo.io/json",
        dataType: "json"
    });
    request.done(function (result) {
        if (result != null && typeof result.loc !== undefined && result.loc != '') {
            var address = result.city + ' ' + result.country;
            document.querySelector('.fds-loc-address-field').value = address;
            var latlng_str = result.loc;
            var latlng = latlng_str.split(',');
            var lat = latlng[0];
            var lng = latlng[1];
            foodsearch_set_map_latlng_marker(lat, lng, def_zoom);
        } else {
            foodsearch_geoloc_ipinfo_fallback();
        }
    });
    request.fail(function () {
        foodsearch_geoloc_ipinfo_fallback();
    });
}

function foodsearch_geoloc_ipinfo_fallback() {
    "use strict";
    var def_zoom = dashboard_location_vars.map_zoom;
    var request = jQuery.ajax({
        url: "//ip-api.com/json",
        dataType: "json"
    });
    request.done(function (result) {
      
        if (typeof result.lat !== undefined && result.lat != '') {
            var address = result.city + ' ' + result.country;
            document.querySelector('.fds-loc-address-field').value = address;
            var lat = result.lat;
            var lng = result.lon;
            foodsearch_set_map_latlng_marker(lat, lng, def_zoom);
        }
    });
}
function foodsearch_set_user_current_locate(position) {
    "use strict";
    
    var lat = position.coords.latitude;
    var lng = position.coords.longitude;
    
    //if (typeof foodsearch_geoloc_curr_request == 'undefined') {
        
        var def_zoom = dashboard_location_vars.map_zoom;
        foodsearch_set_map_latlng_marker(lat, lng, def_zoom);

        var this_parent = jQuery('.fds-addupd-location');
        var addres_field = this_parent.find('.fds-loc-address-field');
        this_parent.find('.fds-get-current-location').append('<div class="fds-inline-loader"><div class="fds-loader"></div></div>');

        foodsearch_geoloc_curr_request = jQuery.ajax({
            type: "POST",
            dataType: "json",
            url: dashboard_location_vars.site_url + 'wp/v1/get-map-cords-addres',
            data: {
                lat: lat,
                lng: lng,
            },            
            beforeSend: function (xhr) {
                if(dashboard_location_vars.adminCheck!='true'){
                    xhr.setRequestHeader('X-WP-Nonce', dashboard_location_vars.wpnonce);
               }  
            }
        });
        foodsearch_geoloc_curr_request.done(function (response) {
            addres_field.val(response.address).attr('value', response.address);
            jQuery('.fds-map-adr-field').val(response.address);
        });
        foodsearch_geoloc_curr_request.always(function () {
            this_parent.find('.fds-get-current-location').find('.fds-inline-loader').remove();
        });
    // }
    // else{
    //     console.log('hi in curnt loc '+foodsearch_geoloc_curr_request);
    // }
}
jQuery(document).on('click', '.fds-get-current-location', function(ev) {
   
    "use strict";
    ev.preventDefault();
    if (navigator.geolocation) {
        const options = {
            enableHighAccuracy: true,
            timeout: 5000,
            maximumAge: 1
        };
        function foodsearch_geolocation_access_err(error) {
            console.warn('ERROR(' + error.code + '): ' + error.message);
            foodsearch_check_location_latlng();
        }
        navigator.geolocation.getCurrentPosition(foodsearch_set_user_current_locate, foodsearch_geolocation_access_err, options);
    } else {
        console.log("Geolocation is not supported.");
        foodsearch_check_location_latlng();
    }
});



function foodsearch_get_map_cords_addres(lat, lng) {
    "use strict";
    var this_parent = jQuery('.fds-user-locations');
    this_parent.append('<div class="fds-loader-holder"><div class="fds-loader"></div></div>');
    var geoloc_request = jQuery.ajax({
        type: "POST",
        dataType: "json",
        url: dashboard_location_vars.site_url + 'wp/v1/get-map-cords-addres',
        data: {
            lat: lat,
            lng: lng,
        },            
        beforeSend: function (xhr) {
            if(dashboard_location_vars.adminCheck!='true'){
                xhr.setRequestHeader('X-WP-Nonce', dashboard_location_vars.wpnonce);
           }  
        }
    });
    geoloc_request.done(function (response) {
        if (response.address != '') {
            this_parent.find('.fds-loc-address-field').val(response.address);
            jQuery('.fds-map-adr-field').val(response.address);
        }
    });
    geoloc_request.always(function () {
        this_parent.find('.fds-loader-holder').remove();
    });
}
jQuery(document).on('focusout','.fds-loc-address-field',function (e) {
    let text = jQuery(this).val();
    let text2 = jQuery('input.fds-map-adr-field').val();  
    setTimeout(function(text,text2){   
        if(text!==text2){  
     jQuery.ajax({
         type: "post",
         dataType: "json",
         url:dashboard_location_vars.site_url + 'wp/v1/get-location-lat-lng-on-address',
         data:  {
             address:jQuery('.fds-loc-address-field').val(),
         },            
         beforeSend: function (xhr) {
         
         if(dashboard_location_vars.adminCheck!='true'){
                 xhr.setRequestHeader('X-WP-Nonce', dashboard_location_vars.wpnonce);
         }  
         },
         success: function(data){
             var def_zoom = dashboard_location_vars.map_zoom;
             jQuery('.fds-map-adr-field').val(data.address);
             jQuery('.fds-loc-address-field').val(data.address);
         if(data.lat==''){
             foodsearch_check_location_latlng();
         }
         else{ 
             foodsearch_set_map_latlng_marker(data.lat, data.lng, def_zoom);
         }
 
         }
     });
    }
    }, 1000,text,text2);        
})
jQuery(document).on('click', '.add-location-btn', function() {
    "use strict";
    var _this = jQuery(this);
    var upper_appnder_con = _this.parents('.fds-user-locations').find('.fds-saved-locations-list');
    var appendr_locs_con = _this.parents('.fds-user-locations').find('.fds-saved-locations-list .fds-all-saved-locs');
    var this_parent = _this.parents('.fds-addupd-location');
    var address_field = this_parent.find('.fds-loc-address-field');
    this_parent.append('<div class="fds-loader-holder"><div class="fds-loader"></div></div>');

    var form_data = this_parent.find('input,textarea').serialize();

    var request = jQuery.ajax({
        type: "POST",
        dataType: "json",
        url: dashboard_location_vars.site_url + 'wp/v1/foodsearch-add-user-location',
        data: form_data,            
        beforeSend: function (xhr) {
            if(dashboard_location_vars.adminCheck!='true'){
                xhr.setRequestHeader('X-WP-Nonce', dashboard_location_vars.wpnonce);
           }  
        }
    });
    request.done(function (response) {

        var msg_rand = Math.floor(Math.random() * 1000000) + 1;
        if (response.error == '0') {
            foodsearch_submit_msg_alert('alert-msg-' + msg_rand, response.msg, 'fds-alert-success');
            address_field.val('').attr('value', '');
            appendr_locs_con.find('.savin-new-addres-itm').remove();
            //appendr_locs_con.append(response.html);
            appendr_locs_con.removeAttr('style');
            upper_appnder_con.find('.fds-add-loc-triger').removeAttr('style');
            this_parent.hide();
            jQuery.ajax({
                type: "post",
                dataType: "json",
                url:dashboard_location_vars.site_url + 'wp/v1/foodsearch-saved-location-list',
                data:  {
                    pid:response.post_id,
                },            
                beforeSend: function (xhr) {
                   if(dashboard_location_vars.adminCheck!='true'){
                        xhr.setRequestHeader('X-WP-Nonce', dashboard_location_vars.wpnonce);
                    }  
                },
                success: function(data){
                    upper_appnder_con.show();
                    appendr_locs_con.html(data.html).show();

                }
            });
        } else if (response.error == '2') {
            foodsearch_submit_msg_alert('alert-msg-' + msg_rand, response.msg, 'fds-alert-info');
        } else {
            foodsearch_submit_msg_alert('alert-msg-' + msg_rand, response.msg, 'fds-alert-danger');
        }
    });
    request.always(function () {
        this_parent.find('.fds-loader-holder').remove();
    });
});

jQuery(document).on('click', '.fds-add-loc-triger', function(ev) {
    "use strict";
    ev.preventDefault();
    var _this = jQuery(this);
    var saved_locs_con = _this.parents('.fds-user-locations').find('.fds-saved-locations-list .fds-all-saved-locs');
    //
    saved_locs_con.append('\
    <div class="saved-loc-item savin-new-addres-itm">\
        <span class="address-con"><i class="fds-icon fds-marker-thin"></i> ' + dashboard_location_vars.add_new_loctxt + '</span>\
    </div>');
    
    var form_con = _this.parents('.fds-user-locations').find('.fds-addupd-location');
    
    form_con.find('.fds-locs-hding').removeAttr('style');
    form_con.find('.update-loc-hding').hide();
    form_con.find('.add-location-btn').removeAttr('style');
    form_con.find('.update-location-btn').hide();
    
    //
    if (!form_con.is(':visible')) {
        form_con.removeAttr('style');
        if (form_con.find('.fds-location-map-outer').length > 0) {
            form_con.find('.fds-location-map-outer').addClass('fds-outer-visible');
        }

        // require address field
        form_con.find('input[name="fds_loc_address"]').attr('required', '');
    }
    if (form_con.find('.fds-get-current-location').length > 0) {
        form_con.find('.fds-get-current-location').trigger('click');
    }
    
    if (form_con.find('.fds-loc-id-field').length > 0) {
        form_con.find('.fds-loc-id-field').val('');
    }
    
    var address_field = form_con.find('.fds-loc-address-field');
    
    address_field.val('').attr('value', '');
    form_con.find('.fds-map-lat-field').val('');
    form_con.find('.fds-map-lng-field').val('');
    form_con.find('.fds-address-floor-field').val('');
    form_con.find('.fds-address-notes-field').val('').html('');
    address_field.trigger('focus');
    
    _this.hide();
    
    return false;
});

jQuery(document).on('keypress keyup blur', '.fds-loc-address-field', function () {
    "use strict";
    var _this = jQuery(this);
    if (_this.val() != '') {
        _this.parents('.fds-user-locations').find('.savin-new-addres-itm .address-con').html('<i class="fds-icon fds-marker-thin"></i> ' + _this.val());
    }
});

jQuery(document).on('click', '.fds-edit-user-loc', function(ev) {
    "use strict";
    ev.preventDefault();
    var _this = jQuery(this);
    var loc_id = _this.attr('data-id');
    var n_id = _this.attr('data-nid');
    var this_parent = _this.parents('.fds-user-locations');
    this_parent.find('.fds-add-loc-triger').removeAttr('style');
    this_parent.find('.savin-new-addres-itm').remove();
    var form_con = this_parent.find('.fds-addupd-location');
    var address_field = form_con.find('.fds-loc-address-field');
    this_parent.append('<div class="fds-loader-holder"><div class="fds-loader"></div></div>');
    jQuery('.fds-list-item').removeClass('fds-list-item-active');
    _this.addClass('fds-list-item-active');
    var def_map_zoom = dashboard_location_vars.map_zoom;

    var request = jQuery.ajax({
        type: "POST",
        dataType: "json",
        url: dashboard_location_vars.site_url + 'wp/v1/foodsearch-edit-loc-form',
        data: {
            loc_id: loc_id,
            nid: n_id,
        },            
        beforeSend: function (xhr) {
            if(dashboard_location_vars.adminCheck!='true'){
                xhr.setRequestHeader('X-WP-Nonce', dashboard_location_vars.wpnonce);
           }  
        }
    });
    request.done(function (response) {
        form_con.find('.fds-locs-hding').hide();
        form_con.find('.update-loc-hding').removeAttr('style');
        form_con.find('.add-location-btn').hide();
        form_con.find('.update-location-btn').removeAttr('style').attr('data-id', loc_id);

        address_field.val(response.address).attr('value', response.address);
        jQuery('.fds-loc-address-field').val(response.address);
        jQuery('.fds-map-adr-field').val(response.address);
        form_con.find('.fds-map-lat-field').val(response.lat);
        form_con.find('.fds-map-lng-field').val(response.lng);
        form_con.find('.fds-address-floor-field').val(response.floor_unit);
        form_con.find('.fds-address-notes-field').val(response.notes);
        
        if (form_con.find('.fds-loc-id-field').length > 0) {
            form_con.find('.fds-loc-id-field').val(loc_id);
        }
        
        form_con.find('.fds-addres-labl-other').val(response.label_other);
      
        var adres_labl = response.label != '' && response.label != null ? response.label : 'home';
        form_con.find('input[class=fds-addres-labl-field]').parents('.labl-itm').removeClass('active-labl');        
        form_con.find('input[class=fds-addres-labl-field]').parents('.labl-itm').find('i.fds-icon').removeAttr('style');
        form_con.find('input[class=fds-addres-labl-field][value=' + adres_labl  + ']').parents('.labl-itm').addClass('active-labl');
        form_con.find('input[class=fds-addres-labl-field][value=' + adres_labl  + ']').find('i.fds-icon').css({'background-color': 'rgb(228, 42, 69)','color': 'rgb(255, 255, 255'});
        form_con.find('input[class=fds-addres-labl-field][value=' + adres_labl  + ']').attr('checked', 'checked').trigger('click');

        if (!form_con.is(':visible')) {
            form_con.removeAttr('style');
            if (form_con.find('.fds-location-map-outer').length > 0) {
                form_con.find('.fds-location-map-outer').addClass('fds-outer-visible');
            }

            // require address field
            form_con.find('input[name="fds_loc_address"]').attr('required', '');
        }
        
        var marker_lat = response.lat;
        var marker_lng = response.lng;
        foodsearch_set_map_latlng_marker(marker_lat, marker_lng, def_map_zoom);
        
        address_field.trigger('focus');
    });
    request.always(function () {
        this_parent.find('.fds-loader-holder').remove();
    });
    
    return false;
});

jQuery(document).on('click', '.fds-remove-user-loc', function(ev) {
    "use strict";
    ev.preventDefault();
    var _this = jQuery(this);
    var loc_id = _this.attr('data-id');
    var n_id = _this.attr('data-nid');
    var this_parent = _this.parents('.fds-user-locations');
    
    jQuery.fds_confirm_popup({
        message: dashboard_location_vars.delete_msg,
        buttons: {
            Yes: {
                class: 'fds-accept-btn',
                action: function () {
                    
                    this_parent.append('<div class="fds-loader-holder"><div class="fds-loader"></div></div>');
                    var request = jQuery.ajax({
                        type: "POST",
                        dataType: "json",
                        url: dashboard_location_vars.site_url + 'wp/v1/foodsearch-remove-user-location',
                        data: {
                            loc_id: loc_id,
                            n_id: n_id
                        },            
                        beforeSend: function (xhr) {
                            if(dashboard_location_vars.adminCheck!='true'){
                                xhr.setRequestHeader('X-WP-Nonce', dashboard_location_vars.wpnonce);
                           }  
                        }
                    });
                    request.done(function (response) {

                        var msg_rand = Math.floor(Math.random() * 1000000) + 1;
                        if (response.error == '0') {
                            foodsearch_submit_msg_alert('alert-msg-' + msg_rand, response.msg, 'fds-alert-success');
                            jQuery('#loc-adress-itm-' + loc_id).remove();
                        } else if (response.error == '2') {
                            foodsearch_submit_msg_alert('alert-msg-' + msg_rand, response.msg, 'alert-warning');
                        } else {
                            foodsearch_submit_msg_alert('alert-msg-' + msg_rand, response.msg, 'fds-alert-danger');
                        }
                    });
                    request.always(function () {
                        this_parent.find('.fds-loader-holder').remove();
                    });
                    jQuery.fds_confirm_popup.hide();
                },
            },
            No: {
                class: 'fds-decline-btn',
                action: function () {
                    jQuery.fds_confirm_popup.hide();
                }
            }
        }
    });
});

jQuery(document).on('click', '.update-location-btn', function() {
    "use strict";
    var _this = jQuery(this);
    var loc_id = _this.attr('data-id');
    var this_parent = _this.parents('.fds-addupd-location');
    this_parent.append('<div class="fds-loader-holder"><div class="fds-loader"></div></div>');

    jQuery('#offset').val(0);
    var form_data = this_parent.find('input,textarea').serialize() + '&id=' + loc_id;

    var request = jQuery.ajax({
        type: "POST",
        dataType: "json",
        url: dashboard_location_vars.site_url + 'wp/v1/foodsearch-update-user-location',
        data: form_data,            
        beforeSend: function (xhr) {
            if(dashboard_location_vars.adminCheck!='true'){
                xhr.setRequestHeader('X-WP-Nonce', dashboard_location_vars.wpnonce);
           }  
        }
    });
    request.done(function (response) {

        var msg_rand = Math.floor(Math.random() * 1000000) + 1;
        if (response.error == '0') {
            foodsearch_submit_msg_alert('alert-msg-' + msg_rand, response.msg, 'fds-alert-success');
            this_parent.hide();
            jQuery.ajax({
                type: "post",
                dataType: "json",
                url:dashboard_location_vars.site_url + 'wp/v1/foodsearch-saved-location-list',
                data:  {
                    pid:response.post_id,
                },            
                beforeSend: function (xhr) {
                   if(dashboard_location_vars.adminCheck!='true'){
                xhr.setRequestHeader('X-WP-Nonce', dashboard_location_vars.wpnonce);
}  
                },
                success: function(data){
                    jQuery('.fds-all-saved-locs').html(data.html);

                }
            });
           
        } else if (response.error == '2') {
            foodsearch_submit_msg_alert('alert-msg-' + msg_rand, response.msg, 'alert-warning');
        } else {
            foodsearch_submit_msg_alert('alert-msg-' + msg_rand, response.msg, 'fds-alert-danger');
        }
    });
    request.always(function () {
        this_parent.find('.fds-loader-holder').remove();
    });
});

jQuery(document).on('click', '.fds-addres-change', function() {
  //  alert('hi');
    var marker_lat = jQuery(this).attr('data-lat');
    var marker_lng = jQuery(this).attr('data-lng');
    var adrs = jQuery(this).text();
    adrs = adrs.trim();
    var map_zoom = dashboard_location_vars.map_zoom;
    foodsearch_set_map_latlng_marker(marker_lat, marker_lng, map_zoom);
    foodsearch_modal_popup_open('fds-location-mpopup');
    jQuery('.fds-loc-address-field').val(adrs);
    
});
jQuery(document).on('click', '.fds-addres-change-resturant', function() {
    //  alert('hi');
    
    jQuery('#offset').val(0);
      var marker_lat = jQuery(this).attr('data-lat');
    var marker_lng = jQuery(this).attr('data-lng');
    var adrs = jQuery(this).text();
    adrs = adrs.trim();
      var map_zoom = dashboard_location_vars.map_zoom;
      jQuery('.update-popup-location').addClass('update-popup-res-location').removeClass('update-popup-location');
      foodsearch_set_map_latlng_marker(marker_lat, marker_lng, map_zoom);
      foodsearch_modal_popup_open('fds-location-mpopup');
      jQuery('.fds-loc-address-field').val(adrs);
      
  });

jQuery(document).on('change', '.fds-addres-labl-field', function() {
    "use strict";
    var _this = jQuery(this);
    var this_prent = _this.parents('.addres-labels-con');
    this_prent.find('.labl-itm').removeClass('active-labl');
    this_prent.find('.labl-itm').find('i').removeAttr('style');
    _this.parents('.labl-itm').addClass('active-labl').find('i').css({'background-color':'#e42a45','color': '#ffffff'});
    if (_this.val() == 'other') {
        this_prent.find('.other-label-text').removeAttr('style');
    } else {
        this_prent.find('.other-label-text').hide();
    }
});
jQuery(document).on('click','.update-popup-location',function(){
    "use strict";
    
    jQuery('#offset').val(0);
    var _this = jQuery(this);
    var this_prent = _this.parents('.fds-location-map-outer');
    this_prent.append('<div class="fds-loader-holder"><div class="fds-loader"></div></div>');
    jQuery.ajax({
        type: "post",
        dataType: "json",
        url:dashboard_location_vars.site_url + 'wp/v1/update-user-delivery-location',
        data:  {
            lat:this_prent.find('.fds-map-lat-field').val(),
            lng:this_prent.find('.fds-map-lng-field').val(),
            address:this_prent.find('.fds-map-adr-field').val(),
            order_type:_this.attr('data-value'),
        },            
        beforeSend: function (xhr) {
           if(dashboard_location_vars.adminCheck!='true'){
        xhr.setRequestHeader('X-WP-Nonce', dashboard_location_vars.wpnonce);
}  
        },
        success: function(data){
            jQuery('.fds-location-block-wrap').show();
            jQuery('#fds-address-block').html(data.data.address);
            jQuery('#fds-order-type-block').html(data.data.order_type);
            
            jQuery.ajax({
                type: "get",
                dataType: 'json',
                url: dashboard_location_vars.site_url + 'wp/v1/call-restaurants',
                data: jQuery('#frm_restaurant_listing').serialize(),
                success: function(res){
                    foodsearch_modal_popup_close();
                    jQuery('#restaurant_area').html(res.html);  
                    foodsearch_update_counter(); 
                    this_prent.find('.fds-loader-holder').remove();
                  foodsearch_update_loc( jQuery('#offset').val() );
                }
            });

        }
    });
})

jQuery(document).on('click','.update-popup-res-location',function(){
    "use strict";
    var _this = jQuery(this);
    var this_prent = _this.parents('.fds-location-map-outer');
    this_prent.append('<div class="fds-loader-holder"><div class="fds-loader"></div></div>');
    jQuery.ajax({
        type: "post",
        dataType: "json",
        url:dashboard_location_vars.site_url + 'wp/v1/update-user-delivery-location',
        data:  {
            lat:this_prent.find('.fds-map-lat-field').val(),
            lng:this_prent.find('.fds-map-lng-field').val(),
            address:this_prent.find('.fds-map-adr-field').val(),
            order_type:_this.attr('data-value'),
            resID:this_prent.find('.fds-rest-id-field').val(),
        },            
        beforeSend: function (xhr) {
           if(dashboard_location_vars.adminCheck!='true'){
        xhr.setRequestHeader('X-WP-Nonce', dashboard_location_vars.wpnonce);
}  
        },
        success: function(data){            
            jQuery('.fds-location-block-wrap').show();
            jQuery('#fds-address-block').html(data.data.address);
            jQuery('#fds-order-type-block').html(data.data.order_type);
            var msg_rand = Math.floor(Math.random() * 1000000) + 1;
            jQuery.ajax({
                type: "get",
                dataType: 'json',
                url: dashboard_location_vars.site_url + 'wp/v1/restaurants-delivery-check',                
                success: function(res){                   
                    this_prent.find('.fds-loader-holder').remove();  
                    if(res.status==true){
                        foodsearch_modal_popup_close();                    
                       foodsearch_submit_msg_alert('alert-msg-' + msg_rand, res.msg, 'fds-alert-success');
                    }
                    else{
                        foodsearch_submit_msg_alert('alert-msg-' + msg_rand, res.msg, 'fds-alert-danger');
                    }
                }
            });

        }
    });
})