<?php

namespace FoodSearch\Dashboard;
use FoodSearch\Common_Functions as General_Functions;
use FoodSearch\user_orders as FoodSearch_Orders;

class Common_Functions {
    
    public function __construct() {
        add_action('init', [$this, 'add_rewrite_rules'], 15);
        add_filter('foodsearch_user_dashboard_menu_html', [$this, 'dashboard_menu_html'], 10, 3);
        add_filter('foodsearch_user_dashmenu_section_html', [$this, 'dashmenu_section_html'], 10, 4);
        
        // for reset password redirect
        add_filter('foodsearch_dashboard_redirect_if_not_login', [$this, 'redirect_if_not_login']);
        add_filter('foodsearch_user_dash_shortcode_html', [$this, 'reset_password_form_html']);
        
        add_action('wp_print_styles', array($this, 'front_styles'), 999);
    }
    
    public function front_styles() {
        require_once(ABSPATH . 'wp-admin/includes/file.php');
        WP_Filesystem();
        global $wp_filesystem, $foodsearch_plugin_settings, $foodsearch_upload_files_extpath;
        
        $foodsearch_upload_files_extpath = 'dashboard-css';
        
        add_filter('upload_dir', 'foodsearch_public_upload_files_path');
        $wp_upload_dir = wp_upload_dir();
        $css_files_dir = $wp_upload_dir['path'];
        $css_files_url = $wp_upload_dir['url'];
        remove_filter('upload_dir', 'foodsearch_public_upload_files_path');
        
        $dashboard_page_id = isset($foodsearch_plugin_settings['dashboard_settings']['dashboard_page']) ? $foodsearch_plugin_settings['dashboard_settings']['dashboard_page'] : '';
        
        $dashboard_page_id = $dashboard_page_id != '' ? foodsearch__get_post_id($dashboard_page_id) : '';

        $user_id = get_current_user_id();
        $restaurant_id = General_Functions::user_restaurant_id($user_id);
        
        $dashboard_type = $restaurant_id > 0 ? 'restaurant' : 'customer';
        
        $css_file = $css_files_dir . '/' . $dashboard_type . '-dashboard-styles.css';
        
        if (file_exists($css_file) && is_page($dashboard_page_id) && is_user_logged_in()) {
            $css_file_url = $css_files_url . '/' . $dashboard_type . '-dashboard-styles.css';
            wp_enqueue_style($dashboard_type . '-dashboard-custom', $css_file_url, array(), rand(10000, 99999));
        }
    }
    
    public function add_rewrite_rules() {
        global $foodsearch_plugin_settings;
        
        $dashboard_page_id = isset($foodsearch_plugin_settings['dashboard_settings']['dashboard_page']) ? $foodsearch_plugin_settings['dashboard_settings']['dashboard_page'] : '';
        $dashboard_page_id = $dashboard_page_id != '' ? foodsearch__get_post_id($dashboard_page_id) : '';
        
        if ($dashboard_page_id > 0 && get_post_type($dashboard_page_id) == 'page') {
            
            $page_obj = get_post($dashboard_page_id);
            $page_slug = $page_obj->post_name;
            $page_id = $page_obj->ID;
            
            add_rewrite_tag('%tab%', '([^&]+)');
            add_rewrite_rule('^' . $page_slug . '/([^/]+)/?$', 'index.php?page_id=' . $page_id . '&tab=$matches[1]', 'top');
        }
    }
    
    public function to_check_nonce() {
        if (defined("WP_CACHE")) {
            return false;
        }
    }
    
    public function save_user_type($post_data) {
        
        $user_id = $post_data['nid'];
        $user_obj = get_user_by('id', $user_id);
        
        $display_name = isset($user_obj->display_name) ? $user_obj->display_name : '';
        
        $user_type = sanitize_title($post_data['user_type']);
        if ($user_type != 'restaurant') {
            $user_type = 'customer';
        }
        update_user_meta($user_id, 'foodsearch_user_type', $user_type);
        if ($user_type == 'restaurant') {
            $restaurant_post = array(
                'post_title' => wp_strip_all_tags($display_name),
                'post_type' => 'restaurants',
                'post_status' => 'publish',
                'post_author' => $user_id,
            );
            wp_insert_post($restaurant_post);
        }
        if ($user_type == 'customer') {
            $customer_post = array(
                'post_title' => wp_strip_all_tags($display_name),
                'post_type' => 'customers',
                'post_status' => 'publish',
                'post_author' => $user_id,
            );
            wp_insert_post($customer_post);
        }
    }
    
    public function dashboard_menu_html($html, $user_type, $get_tab) {
        $menus_list = get_option("foodsearch_dashboard_{$user_type}_menus_list");
        
        $menu_item_key = '';
        if (!empty($menus_list)) {
            foreach ($menus_list as $menu_key => $menu_data) {
                if (isset($menu_data['slug']) && $menu_data['slug'] == $get_tab) {
                    $menu_item_key = $menu_key;
                }
            }
        }
        if ($menu_item_key != '' && isset($menus_list[$menu_item_key]['sections']) && !empty($menus_list[$menu_item_key]['sections'])) {
            $menu_data = $menus_list[$menu_item_key];
            $menu_sections = $menus_list[$menu_item_key]['sections'];
            uasort($menu_sections, function ($a, $b) {
                if ($a['sort'] == $b['sort']) {
                    $ret_val = 0;
                }
                $ret_val = ($a['sort'] < $b['sort']) ? -1 : 1;
                return $ret_val;
            });
            foreach ($menu_sections as $section_key => $section_data) {
                $html .= apply_filters('foodsearch_user_dashmenu_section_html', '', $user_type, $menu_data, $section_key);
            }
        }
        
        return $html;
    }
    
    public function dashmenu_section_html($html, $user_type, $menu_data, $section_key) {
        $section_data = $menu_data['sections'][$section_key];
        
        $section_label = $section_data['label'];
        $section_label_switch = isset($section_data['sect_label_switch']) ? $section_data['sect_label_switch'] : 'on';
        //$section_wraper_switch = isset($section_data['sect_wrapper_switch']) ? $section_data['sect_wrapper_switch'] : 'on';
        ob_start();
        
        echo '<div id="dashboard-sec-' . $section_key . '" class="fds-resturant-dashboard-wrap-box">';
        if ($section_label_switch == 'on') {
            ?>
            <div class="fds-section-title-wrap">
                <h2 class="fds-heading-title"><?php echo ($section_label) ?></h2>
            </div>
            <?php
        }
        echo '<div class="fds-dashboard-inner-section">';
        
        if (isset($section_data['elements']) && !empty($section_data['elements'])) {
            $section_elements = $section_data['elements'];
            uasort($section_elements, function ($a, $b) {
                if ($a['sort'] == $b['sort']) {
                    $ret_val = 0;
                }
                $ret_val = ($a['sort'] < $b['sort']) ? -1 : 1;
                return $ret_val;
            });

            foreach ($section_elements as $element_key => $element_data) {
                $element_type = $element_data['type'];
                $element_label = $element_data['label'];
                $label_hdin_html = '';
                if ($element_label != '') {
                    ob_start();
                    ?>
                    <div class="fds-formpart-hding"><strong class="fds-locs-hding"><?php echo ($element_label) ?></strong></div>
                    <?php
                    $label_hdin_html = ob_get_clean();
                }
                echo '<div id="dashboard-element-' . $element_key . '" class="fds-dashboard-element elem-' . $user_type . '-' . $element_type . '">' . $label_hdin_html . apply_filters("foodsearch_{$user_type}_dash_{$element_type}_html", '', $menu_data, $section_key, $element_key) . '</div>';
            }
        }
        
        echo '</div>';
        echo '</div>';

        $html = ob_get_clean();
        
        return $html;
    }
    
    public function saving_dashboard_settings($post_data) {
       //echo '<pre>'.print_r($post_data,true).'</pre>';
      
        $user_id = $post_data['fds_nonce_id'];

        $user_type = General_Functions::user_type($user_id);

        $restaurant_id = 0;
        if ($user_type == 'restaurant') {
            $restaurant_id = General_Functions::user_restaurant_id($user_id);
            
            $post_detail = '';
            if (isset($post_data['restaurant_info_detail'])) {
                $post_detail = foodsearch_esc_wp_editor($post_data['restaurant_info_detail']);
            }
            foreach ($post_data as $post_key => $post_value) {
                $post_value = foodsearch_esc_html($post_value);
                if (strstr($post_key, 'fds_setting_')) {
                  
                    if ($post_key == 'fds_setting_restaurant_name') {
                       // echo 'hi';
                        $up_post = array(
                            'ID' => $restaurant_id,
                            'post_title' => $post_value,
                            'post_content' => $post_detail,
                        );
                        wp_update_post($up_post);
                    } else {
                        $meta_key = str_replace('fds_setting_', 'foodsearch_', $post_key);
                        //if (metadata_exists('post', $restaurant_id, $meta_key)) {
                            update_post_meta($restaurant_id, $meta_key, $post_value);
                        // }
                        // else{
                        //     add_post_meta($restaurant_id, $meta_key, $post_value);
                        // }
                    }
                }
            }
           // exit();
            //
            $daysArray = array(
                array('day' => esc_html__('monday', 'wp-foodsearch'), 'key' => 'monday'),
                array('day' => esc_html__('tuesday', 'wp-foodsearch'), 'key' => 'tuesday'),
                array('day' => esc_html__('wednesday', 'wp-foodsearch'), 'key' => 'wednesday'),
                array('day' => esc_html__('thursday', 'wp-foodsearch'), 'key' => 'thursday'),
                array('day' => esc_html__('friday', 'wp-foodsearch'), 'key' => 'friday'),
                array('day' => esc_html__('saturday', 'wp-foodsearch'), 'key' => 'saturday'),
                array('day' => esc_html__('sunday', 'wp-foodsearch'), 'key' => 'sunday')
            );
            foreach ($daysArray as $day) {
                $opening_hour_key = 'restaurant_' . $day['key'] . '_opening_hour';
                $closing_hour_key = 'restaurant_' . $day['key'] . '_closing_hour';
                $status_key = 'restaurant_' . $day['key'] . '_status';

                $opening_hour = isset($post_data[$opening_hour_key]) ? $post_data[$opening_hour_key] : '';
                $closing_hour = isset($post_data[$closing_hour_key]) ? $post_data[$closing_hour_key] : '';
                $status = isset($post_data[$status_key]) ? $post_data[$status_key] : '';

                update_post_meta($restaurant_id, $opening_hour_key, $opening_hour);
                update_post_meta($restaurant_id, $closing_hour_key, $closing_hour);
                update_post_meta($restaurant_id, $status_key, $status);
            }
            //
            if (isset($post_data['fds_restaurant_cuisines'])) {
                $cats = $post_data['fds_restaurant_cuisines'];
                wp_set_post_terms($restaurant_id, $cats, 'food_cuisine', false);
            }
            if (isset($post_data['fds_restaurant_tags'])) {
                $posted_tags = $post_data['fds_restaurant_tags'];
                $tags = [];
                if (!empty($posted_tags)) {
                    foreach ($posted_tags as $posted_tag) {
                        if ($posted_tag > 1) {
                            $tags[] = $posted_tag;
                        } else if ($posted_tag != '') {
                            $tag_term = get_term_by('name', $posted_tag, 'restaurant_tag');
                            if (!isset($tag_term->term_id)) {
                                wp_insert_term($posted_tag, 'restaurant_tag');
                                $tag_term = get_term_by('name', $posted_tag, 'restaurant_tag');
                            }
                            if (isset($tag_term->term_id)) {
                                $tags[] = $tag_term->name;
                            }
                        }
                    }
                }
                wp_set_post_terms($restaurant_id, $tags, 'restaurant_tag', false);
            }
            do_action('foodsearch_aftersave_dashboard_restaurant', $restaurant_id);
        } else {
            $customer_id = General_Functions::user_customer_id($user_id);
            $first_name = $last_name = '';
            foreach ($post_data as $post_key => $post_value) {
                $post_value = foodsearch_esc_html($post_value);
                if (strstr($post_key, 'fds_setting_')) {
                    
                    if ($post_key == 'fds_setting_first_name') {
                        $first_name = $post_value;
                    } else if ($post_key == 'fds_setting_last_name') {
                        $last_name = $post_value;
                    } else {
                        $meta_key = str_replace('fds_setting_', 'foodsearch_', $post_key);
                        update_post_meta($customer_id, $meta_key, $post_value);
                    }
                }
            }
            if ($first_name != '') {
                $display_name = $first_name;
                $display_name .= $last_name != '' ? ' ' . $last_name : '';
                
                $user_args = array(
                    'ID' => $user_id,
                    'first_name' => $first_name,
                    'last_name' => $last_name,
                    'display_name' => $display_name,
                );
                wp_update_user($user_args);
                
                //
                $up_post = array(
                    'ID' => $customer_id,
                    'post_title' => $display_name,
                );
                wp_update_post($up_post);
            }
        }
        
        do_action('foodsearch_after_save_dashboard_settings', $user_id, $restaurant_id);
    }
    
    public function change_password($post_data) {
        $user_id = $post_data['fds_nonce_id'];
        $user_obj = get_user_by('id', $user_id);
        
        $current_pass = isset($post_data['fds_current_pass']) ? $post_data['fds_current_pass'] : '';
        $new_pass = isset($post_data['fds_new_pass']) ? $post_data['fds_new_pass'] : '';
        $conf_pass = isset($post_data['fds_confnew_pass']) ? $post_data['fds_confnew_pass'] : '';
        
        if (!wp_check_password($current_pass, $user_obj->data->user_pass, $user_obj->ID)) {
            wp_send_json(array('msg' => esc_html__('you have entered the incorrect current password.', 'wp-foodsearch'), 'error' => '1'));
        }
        
        if ($new_pass != $conf_pass) {
            wp_send_json(array('msg' => esc_html__('new password and confirm password does not match.', 'wp-foodsearch'), 'error' => '2'));
        }
        
        $user_args = array(
            'ID' => $user_id,
            'user_pass' => $new_pass,
        );
        wp_update_user($user_args);
    }
    
    public function upload_cover_image() {
        $user_id = $_POST['n_id'];

        $user_type = General_Functions::user_type($user_id);

        if ($user_type == 'restaurant') {
            $restaurant_id = General_Functions::user_restaurant_id($user_id);
            $wp_upload_dir = wp_upload_dir();

            $upload_file = $_FILES['fds_restaurant_cover'];

            require_once ABSPATH . 'wp-admin/includes/image.php';
            require_once ABSPATH . 'wp-admin/includes/file.php';
            require_once ABSPATH . 'wp-admin/includes/media.php';

            $allowed_image_types = array(
                'jpg|jpeg' => 'image/jpeg',
                'png' => 'image/png',
                'gif' => 'image/gif',
            );

            $status_upload = wp_handle_upload($upload_file, array('test_form' => false, 'mimes' => $allowed_image_types));

            if (empty($status_upload['error'])) {
                $image = wp_get_image_editor($status_upload['file']);
                $img_resized_name = $status_upload['file'];

                if (!is_wp_error($image)) {

                    $file_url = isset($status_upload['url']) ? $status_upload['url'] : '';

                    $upload_file_path = $wp_upload_dir['path'] . '/' . basename($file_url);

                    // Check the type of file. We'll use this as the 'post_mime_type'.
                    $filetype = wp_check_filetype(basename($file_url), null);

                    // Prepare an array of post data for the attachment.
                    $attachment = array(
                        'guid' => $wp_upload_dir['url'] . '/' . basename($upload_file_path),
                        'post_mime_type' => $filetype['type'],
                        'post_title' => preg_replace('/\.[^.]+$/', '', ($upload_file['name'])),
                        'post_author' => $user_id,
                        'post_status' => 'inherit'
                    );

                    // Insert the attachment.
                    $attach_id = wp_insert_attachment($attachment, $upload_file_path, $restaurant_id);

                    // Generate the metadata for the attachment, and update the database record.
                    $attach_data = wp_generate_attachment_metadata($attach_id, $upload_file_path);
                    wp_update_attachment_metadata($attach_id, $attach_data);

                    update_post_meta($restaurant_id, 'foodsearch_restaurant_banner', $attach_id);

                    $user_thumb_image = wp_get_attachment_image_src($attach_id, 'full');
                    $img_url = isset($user_thumb_image[0]) && esc_url($user_thumb_image[0]) != '' ? $user_thumb_image[0] : '';
                    
                    wp_send_json(array('msg' => esc_html__('cover photo uploaded successfully.', 'wp-foodsearch'), 'img' => $img_url, 'error' => '0'));
                }
            }
        }
        wp_send_json(array('msg' => esc_html__('cover photo uploading failed.', 'wp-foodsearch'), 'img' => '', 'error' => '1'));
    }
    
    public function change_user_photo() {
        $user_id = $_POST['n_id'];

        $user_type = General_Functions::user_type($user_id);

        if ($user_type == 'restaurant') {
            $restaurant_id = General_Functions::user_restaurant_id($user_id);
            $wp_upload_dir = wp_upload_dir();

            $upload_file = $_FILES['fds_user_photo'];

            $test_uploaded_file = is_uploaded_file($upload_file['tmp_name']);

            require_once ABSPATH . 'wp-admin/includes/image.php';
            require_once ABSPATH . 'wp-admin/includes/file.php';
            require_once ABSPATH . 'wp-admin/includes/media.php';

            $allowed_image_types = array(
                'jpg|jpeg' => 'image/jpeg',
                'png' => 'image/png',
                'gif' => 'image/gif',
            );

            $status_upload = wp_handle_upload($upload_file, array('test_form' => false, 'mimes' => $allowed_image_types));

            if (empty($status_upload['error'])) {

                $image = wp_get_image_editor($status_upload['file']);
                $img_resized_name = $status_upload['file'];

                if (!is_wp_error($image)) {

                    $file_url = isset($status_upload['url']) ? $status_upload['url'] : '';

                    $upload_file_path = $wp_upload_dir['path'] . '/' . basename($file_url);

                    // Check the type of file. We'll use this as the 'post_mime_type'.
                    $filetype = wp_check_filetype(basename($file_url), null);

                    // Prepare an array of post data for the attachment.
                    $attachment = array(
                        'guid' => $wp_upload_dir['url'] . '/' . basename($upload_file_path),
                        'post_mime_type' => $filetype['type'],
                        'post_title' => preg_replace('/\.[^.]+$/', '', ($upload_file['name'])),
                        'post_author' => $user_id,
                        'post_status' => 'inherit'
                    );

                    // Insert the attachment.
                    $attach_id = wp_insert_attachment($attachment, $upload_file_path, $restaurant_id);

                    // Generate the metadata for the attachment, and update the database record.
                    $attach_data = wp_generate_attachment_metadata($attach_id, $upload_file_path);
                    wp_update_attachment_metadata($attach_id, $attach_data);

                    set_post_thumbnail($restaurant_id, $attach_id);

                    $user_thumb_image = wp_get_attachment_image_src($attach_id, 'full');
                    $img_url = isset($user_thumb_image[0]) && esc_url($user_thumb_image[0]) != '' ? $user_thumb_image[0] : '';
                    
                    wp_send_json(array('msg' => esc_html__('logo updated successfully.', 'wp-foodsearch'), 'img' => $img_url, 'error' => '0'));
                }
            }
            wp_send_json(array('msg' => esc_html__('there is some error in uploading this file.', 'wp-foodsearch'), 'error' => '1'));
        } else {
            $customer_id = General_Functions::user_customer_id($user_id);
            if (isset($_FILES['fds_user_photo']) && $_FILES['fds_user_photo'] != '') {
                global $foodsearch_upload_files_extpath, $foodsearch_upload_subdir_extpath;

                $foodsearch_upload_files_extpath = 'customer-profile-photos';
                
                $subdir_folder_name = current_time('timestamp') + rand(10000, 99999);
                $foodsearch_upload_subdir_extpath = $subdir_folder_name;

                add_filter('upload_dir', 'foodsearch_public_upload_files_path');

                // Get the path to the upload directory.
                $wp_upload_dir = wp_upload_dir();

                $upload_file = $_FILES['fds_user_photo'];

                $test_uploaded_file = is_uploaded_file($upload_file['tmp_name']);

                require_once ABSPATH . 'wp-admin/includes/image.php';
                require_once ABSPATH . 'wp-admin/includes/file.php';
                require_once ABSPATH . 'wp-admin/includes/media.php';

                $allowed_image_types = array(
                    'jpg|jpeg' => 'image/jpeg',
                    'png' => 'image/png',
                    'gif' => 'image/gif',
                );

                $status_upload = wp_handle_upload($upload_file, array('test_form' => false, 'mimes' => $allowed_image_types));

                if (empty($status_upload['error'])) {

                    $file_url = isset($status_upload['url']) ? $status_upload['url'] : '';
                    $upload_file_path = $wp_upload_dir['path'] . '/' . basename($file_url);

                    $folder_path = $wp_upload_dir['path'];

                    $image = wp_get_image_editor($upload_file_path);

                    if (!is_wp_error($image)) {
                        // remove previous image
                        $img_data = get_user_meta($user_id, 'foodsearch_user_img_data', true);
                        if (isset($img_data['path'])) {
                            $img_path = $img_data['path'];
                            $file_name = $img_data['file_name'];

                            $root_folder = str_replace($file_name, '', $img_path);

                            require_once(ABSPATH . 'wp-admin/includes/file.php');
                            WP_Filesystem();
                            global $wp_filesystem;
                            $wp_filesystem->rmdir($root_folder, true);
                        }
                        
                        //
                        $file_name = basename($file_url);

                        $file_args = array(
                            'path' => $upload_file_path,
                            'url' => $file_url,
                            'folder_name' => $subdir_folder_name,
                            'file_name' => $file_name,
                        );
                        
                        update_user_meta($user_id, 'foodsearch_user_img_data', $file_args);
                        
                        $img_url = apply_filters('foodsearch_user_image_file_url', $file_url, $user_id);

                        wp_send_json(array('msg' => esc_html__('profile photo updated successfully.', 'wp-foodsearch'), 'img' => $img_url, 'error' => '0'));
                    }
                }

                remove_filter('upload_dir', 'foodsearch_public_upload_files_path');
            }
            wp_send_json(array('msg' => esc_html__('there is some error in uploading this file.', 'wp-foodsearch'), 'error' => '1'));
        }
    }
    
    public function remove_user_photo($post_data) {
        $user_id = $post_data['n_id'];

        $user_type = General_Functions::user_type($user_id);

        if ($user_type == 'restaurant') {
            $restaurant_id = General_Functions::user_restaurant_id($user_id);
            
            $img_thumb_id = get_post_thumbnail_id($restaurant_id);
            wp_delete_attachment($img_thumb_id, true);
            
            $img_url = get_avatar_url($user_id, array('size' => 200));
            wp_send_json(array('msg' => esc_html__('logo deleted successfully.', 'wp-foodsearch'), 'img' => $img_url, 'error' => '0'));
        } else {
            $img_data = get_user_meta($user_id, 'foodsearch_user_img_data', true);
            if (isset($img_data['path'])) {
                $img_path = $img_data['path'];
                $file_name = $img_data['file_name'];
                
                $root_folder = str_replace($file_name, '', $img_path);

                require_once(ABSPATH . 'wp-admin/includes/file.php');
                WP_Filesystem();
                global $wp_filesystem;
                $wp_filesystem->rmdir($root_folder, true);
            }
            
            update_user_meta($user_id, 'foodsearch_user_img_data', '');
            
            $img_url = get_avatar_url($user_id, array('size' => 200));
            wp_send_json(array('msg' => esc_html__('profile photo deleted successfully.', 'wp-foodsearch'), 'img' => $img_url, 'error' => '0'));
        }
    }
    
    public function add_nutrition_popup($post_data) {
        
        global $foodsearch_form_fields;
        
        $is_admin = is_admin();
        
        $user_id = $post_data['n_id'];
        $restaurant_id = $post_data['restaurant_id'];
        $nutri_id = 0;
        
        $nutri_title = '';
        $nutri_img = '';
        $img_src = '';
        
        if (isset($post_data['nutri_id']) && $post_data['nutri_id'] > 0) {
            $nutri_id = $post_data['nutri_id'];
            
            $nutritions_list = get_post_meta($restaurant_id, 'foodsearch_nutritions_list', true);
            if (isset($nutritions_list[$nutri_id])) {
                $nutrition_itm = $nutritions_list[$nutri_id];
                $nutri_title = $nutrition_itm['title'];
                $nutri_img = $nutrition_itm['image'];
                $image_thumb = wp_get_attachment_image_src($nutri_img, 'thumbnail');
                $img_src = isset($image_thumb[0]) ? $image_thumb[0] : '';
            }
        }
        
        $popup_title = esc_html__('add nutrition item', 'wp-foodsearch');
        if ($nutri_id > 0) {
            $popup_title = esc_html__('update item', 'wp-foodsearch');
        }
        
        $content = '<div class="fds-booking-detail-title">
            <h2 class="fds-heading-title">' . $popup_title . '</h2>
        </div>
        <div class="fds-nutri-popupform">
        <form class="add-nutrition-list-form" method="post">
        <div class="fds-popupform-inner-wrap">';

        $args = array(
            'type' => 'hidden',
            'name' => 'restaurant_id',
            'value' => $restaurant_id,
            'return' => true
        );
        $content .= $foodsearch_form_fields->input_field($args);
        $args = array(
            'type' => 'hidden',
            'name' => 'n_id',
            'value' => $user_id,
            'return' => true
        );
        $content .= $foodsearch_form_fields->input_field($args);
        
        if ($nutri_id > 0) {
            $args = array(
                'type' => 'hidden',
                'name' => 'nutri_id',
                'value' => $nutri_id,
                'return' => true
            );
            $content .= $foodsearch_form_fields->input_field($args);
        }

        $content .= '<div class="fds-popupform-offer-coll">
                        <div><div class="fds-popup-inner">';
        $args = array(
            'type' => 'text',
            'id' => 'up_title',
            'name' => 'title',
            'classes' => 'post-filed',
            'required' => true,
            'label' => esc_html__('item title', 'wp-foodsearch'),
            'placeholder' => esc_html__('item title', 'wp-foodsearch'),
            'value' => $nutri_title,
            'return' => true
        );
        $content .= $foodsearch_form_fields->input_field($args);
        $content .= '</div></div>';

        $content .= '<div>
        <label class="fds-input-label">' . esc_html__('browse photo *', 'wp-foodsearch') . '</label>
        <div class="fds-popupform-file-upload image-upload" data-sizerr="' . esc_html__('file size is too large to upload.', 'wp-foodsearch') . '" data-typerr="' . esc_html__('only correct format images are allowed to upload.', 'wp-foodsearch') . '">';
        
        //
        $img_rand = rand(1000000, 9999999);
        if (!$is_admin) {
            $content .= '<a href="#" class="fds-upload fds-link fds-user-openmedia srcbg-' . $img_rand . '" data-nid="' . $user_id . '" data-pid="' . $restaurant_id . '" data-apid="' . $img_rand . '" data-aptype="id"' . ($img_src != '' ? ' style="background: url(' . $img_src . ') no-repeat top center / cover;"' : '') . '>';
        } else {
            $content .= '<a href="#" class="fds-upload fds-link"' . ($img_src != '' ? ' style="background: url(' . $img_src . ') no-repeat top center / cover;"' : '') . '>';
        }
        
        if ($img_src == '') {
            $content .= ' <i class="fds-icon fds-camera"></i>';
        }
        $content .= '</a>
        <a href="#" class="fds-remove fds-link"' . ($img_src == '' ? ' style="display:none"' : '') . '><i class="dashicons-before dashicons-no"></i></a>
        <input type="hidden" name="image" class="img-' . $img_rand . '" value="' . $nutri_img . '" required>';
        if (!$is_admin) {
            //$content .= '<input type="file" class="fooditm-img-uploder fds-update-anything-action" data-gid="' . $user_id . '" data-nid="' . $restaurant_id . '">';
        }
        $content .= '</div>
        </div>
        </div>';

        $content .= '<div class="fds-loader-holder" style="display:none;"></div></div>';
        
        $content .= '<div class="fds-add-newcat">';
        ob_start();
        wp_nonce_field('fds_nutrition', '_nonce');
        $content .= ob_get_clean();
        $content .= '<div class="fds-btn fds-medium-btn">';
        $args = array(
            'type' => 'submit',
            'id' => 'nutrition-item-add',
            'name' => 'nutrition_item_save',
            'classes' => 'fds-newcat-savebtn fds-has-save fds-update-anything-action',
            'value' => ($nutri_id > 0 ? esc_html__('update', 'wp-foodsearch') : esc_html__('add item', 'wp-foodsearch')),
            'return' => true
        );
        $content .= $foodsearch_form_fields->button($args);
        $content .= '</div>';
        $content .= '</div>';
        $content .= '</form>';
        $content .= '</div>';
        
        wp_send_json(array('html' => $content, 'error' => '0'));
    }
    
    public function save_nutrition_item($post_data) {
        
        if ($this->to_check_nonce()) {
            if (!isset($_POST['_nonce']) || !wp_verify_nonce($_POST['_nonce'], 'fds_nutrition')) {
                $responsedata = array('error' => '1', 'html' => '', 'msg' => 'Session token has expired, please reload the page and try again.');
                wp_send_json($responsedata);
            }
        }
        
        $title = foodsearch_esc_html($post_data['title']);
        
        $image = foodsearch_esc_html($post_data['image']);
        
        $user_id = $post_data['n_id'];
        $restaurant_id = $post_data['restaurant_id'];

        $nutri_id = 0;
        if (isset($post_data['nutri_id']) && $post_data['nutri_id'] > 0) {
            $nutri_id = $post_data['nutri_id'];
        }
        
        if ($title == '') {
            wp_send_json(array('html' => '', 'msg' => esc_html__('title field is required.', 'wp-foodsearch'), 'error' => '1'));
        }
        if ($image == '') {
            wp_send_json(array('html' => '', 'msg' => esc_html__('image is required to upload.', 'wp-foodsearch'), 'error' => '1'));
        }
        
        $rand_id = $nutri_id > 0 ? $nutri_id : rand(1000000, 9999999);
        
        $nutritions_list = get_post_meta($restaurant_id, 'foodsearch_nutritions_list', true);
        
        $nutritions_list = !empty($nutritions_list) ? $nutritions_list : array();
        
        $new_nutri = array(
            'title' => $title,
            'image' => $image,
        );
        
        $nutritions_list[$rand_id] = $new_nutri;
        
        update_post_meta($restaurant_id, 'foodsearch_nutritions_list', $nutritions_list);

        $image_thumb = wp_get_attachment_image_src($image, 'thumbnail');
        $img_src = isset($image_thumb[0]) ? $image_thumb[0] : '';
        
        if ($nutri_id > 0) {
            ob_start();
            ?>
            <script>
                jQuery('#nutri-item-<?php echo ($rand_id) ?>').find('.fds-item-title').html('<?php echo esc_js($title) ?>');
                jQuery('#nutri-item-<?php echo ($rand_id) ?>').find('.fds-item-thumb img').attr('src', '<?php echo esc_js($img_src) ?>');
            </script>
            <?php
            $html = ob_get_clean();
            $success_msg = esc_html__('item updated successfully.', 'wp-foodsearch');
        } else {
            ob_start();
            ?>
            <div id="nutri-item-<?php echo ($rand_id) ?>" class="multi-list-itm">
                <div class="itm-titl-img">
                    <div class="fds-item-thumb"><img src="<?php echo ($img_src) ?>" alt=""></div>
                    <strong class="fds-item-title"><?php echo ($title) ?></strong>
                </div>

                <div class="fds-menu-ations">
                    <a href="javascript:void(0);" class="fds-body-action fds-updte-nutribtn fds-link" data-id="<?php echo ($rand_id) ?>" data-nid="<?php echo ($user_id) ?>" data-rid="<?php echo ($restaurant_id) ?>"><i class="fds-icon fds-edit"></i></a>
                    <a href="javascript:void(0);" class="fds-body-action fds-remove-action fds-remove-nutribtn fds-link" data-id="<?php echo ($rand_id) ?>" data-rid="<?php echo ($restaurant_id) ?>"><i class="fds-icon fds-time-simple"></i></a>
                </div>
            </div>
            <?php
            $html = ob_get_clean();
            $success_msg = esc_html__('item added successfully.', 'wp-foodsearch');
        }
        
        wp_send_json(array('html' => $html, 'msg' => $success_msg, 'error' => '0'));
    }
    
    public function remove_nutrition_item($post_data) {
        $restaurant_id = $post_data['restaurant_id'];
        $nutri_id = $post_data['nutri_id'];
        
        $nutritions_list = get_post_meta($restaurant_id, 'foodsearch_nutritions_list', true);
        
        if (isset($nutritions_list[$nutri_id])) {
            unset($nutritions_list[$nutri_id]);
            
            update_post_meta($restaurant_id, 'foodsearch_nutritions_list', $nutritions_list);
        }
        wp_send_json(array('msg' => esc_html__('item deleted successfully.', 'wp-foodsearch'), 'error' => '0'));
    }
    
    public function get_restaurant_nutritions($request_data) {
        $restaurant_id = $request_data['restaurant_id'];
        $nutritions_list = get_post_meta($restaurant_id, 'foodsearch_nutritions_list', true);
        $responsedata = array('error' => '1', 'results' => array());
        
        if (!empty($nutritions_list)) {
            $responsedata['error'] = '0';
            foreach ($nutritions_list as $n_key => $n_itm) {
                $nutri_label = $n_itm['title'];
                $responsedata['results'][] = array('id' => $n_key, 'text' => $nutri_label);
            }
        }
        
        wp_send_json($responsedata);
    }
    
    public function get_restaurant_orderdetail($post_data) {
        
        global $table_prefix, $wpdb, $foodsearch_user_orders_obj, $foodsearch_plugin_settings;

        $restaurant_id = $post_data['restaurant_id'];
        $order_id = $post_data['n_id'];
        
        $table_name = $table_prefix . 'fds_orders';
        $order_result = $wpdb->get_row("SELECT * FROM $table_name WHERE order_id=$order_id", 'ARRAY_A');
        
        $order_meta = FoodSearch_Orders::get_order_meta($order_id);
        $first_name = FoodSearch_Orders::order_meta_value($order_meta, 'billing_first_name');
        $last_name = FoodSearch_Orders::order_meta_value($order_meta, 'billing_last_name');
        $billing_email = FoodSearch_Orders::order_meta_value($order_meta, 'billing_email');
        $billing_phone = FoodSearch_Orders::order_meta_value($order_meta, 'billing_phone');
        $billing_address = FoodSearch_Orders::order_meta_value($order_meta, 'billing_address');
        $billing_address_lat = FoodSearch_Orders::order_meta_value($order_meta, 'address_lat');
        $billing_address_lng = FoodSearch_Orders::order_meta_value($order_meta, 'address_lng');

        $customer_name = '';
        if ($first_name != '') {
            $customer_name .= $first_name;
            if ($last_name != '') {
                $customer_name .= ' ' . $last_name;
            }
        }

        $order_status = $order_result['status'];
        
        $status_list = FoodSearch_Orders::get_order_statuses();
        
        $order_status_label = $foodsearch_user_orders_obj->get_order_status_tclr($order_status);
        
        $create_date = $order_result['date_created'];
        $create_date_formate = date_i18n(get_option('date_format'), strtotime($create_date));
        $create_time_formate = date_i18n(get_option('time_format'), strtotime($create_date));

        ob_start();
        ?>
        <div class="fds-booking-detail-title">
            <h2 class="fds-heading-title"><?php esc_html_e('order detail', 'wp-foodsearch'); ?></h2>
            <span><a href="<?=esc_url_raw( rest_url('wp/v1/') );?>customer-order-pdf-print/?id=<?=$order_id;?>" target="_blank"><?php echo esc_html__('Print Order Detail', 'wp-foodsearch'); ?> <i class="fds-icon fds-printer"></i></a></span>
            
            <span><?php printf(esc_html__('status: %s', 'wp-foodsearch'), $order_status_label); ?></span>
        </div>
        <ul class="fds-booking-detail-info fds-options-wrap">
            <li class="fds-list-item">
                <span><?php esc_html_e('order date', 'wp-foodsearch'); ?></span>
                <small><?php echo ($create_date_formate) ?></small>
                <small><?php echo ($create_time_formate) ?></small>
            </li>
            <li class="fds-list-item">
                <span><?php esc_html_e('customer name', 'wp-foodsearch'); ?></span>
                <small><?php echo ($customer_name) ?></small>
                <small><?php printf(esc_html__('order id: #%s', 'wp-foodsearch'), $order_id); ?></small>
            </li>
            <li class="fds-list-item">
                <span><?php esc_html_e('customer contact', 'wp-foodsearch'); ?></span>
                <?php
                if ($billing_phone != '') {
                    ?>
                    <a href="tel:<?php echo ($billing_email) ?>" class="fds-link"><?php echo ($billing_phone) ?></a>
                    <?php
                }
                ?>
                <a href="mailto:<?php echo ($billing_email) ?>" class="fds-link fds-cus-email"><?php echo ($billing_email) ?></a>
            </li>
        </ul>

        <div class="fds-plugin-modal-box-inner">
            <?php
            if ($billing_address != '') {
                if ($billing_address_lat != '' && $billing_address_lng != '') {
                    $view_map_loc = $billing_address_lat . ',' . $billing_address_lng;
                } else {
                    $view_map_loc = urlencode($billing_address);
                }
                ?>
                <div class="fds-ordersum-address">
                    <span class="fds-order-address-icon"><i class="fds-icon fds-marker-thin"></i></span>
                    <small class="fds-order-address-holdr"><?php echo ($billing_address) ?></small>
                    <div class="fds-btn fds-small-btn">
                        <a href="https://www.google.com/maps/search/<?php echo ($view_map_loc) ?>" class="fds-link fds-has-bg" target="_blank"><?php esc_html_e('view on map', 'wp-foodsearch'); ?></a>
                    </div>
                </div>
                <span class="fds-booking-detail-mini-title"><?php esc_html_e('order summary', 'wp-foodsearch'); ?></span>
                <?php
            }
            $order_items = $foodsearch_user_orders_obj->get_order_items($order_id, 'menu_items');
            if (!empty($order_items)) {

                $order_subtotal = $order_result['total_sales'];
                $order_net_total = $order_result['net_total'];
                ?>
                <div id="fds-order-items-list" class="orderdet-items-wrap">
                    <div class="orderdet-items-inside">
                        <div class="fds-table-items-wrapper">
                            <ul class="fds-table-item-row item-row-heder fds-options-wrap">
                                <li class="table-item-heditm itm-name fds-list-item"><?php esc_html_e('item', 'wp-foodsearch'); ?></li>
                                <li class="table-item-heditm itm-cost fds-list-item"><?php esc_html_e('cost', 'wp-foodsearch'); ?></li>
                                <li class="table-item-heditm itm-qty fds-list-item"><?php esc_html_e('qty', 'wp-foodsearch'); ?></li>
                                <li class="table-item-heditm itm-totl fds-list-item"><?php esc_html_e('total', 'wp-foodsearch'); ?></li>
                            </ul>
                            <?php
                            $items_counter = 1;
                            $total_order_items = count($order_items);
                            $menu_itms_open = false;
                            foreach ($order_items as $order_item) {
                                $order_item_id = $order_item['order_item_id'];
                                $order_item_name = $order_item['order_item_name'];
                                $order_item_type = $order_item['order_item_type'];
                                if ($order_item_type == 'menu_item' || $order_item_type == 'menu_item_extra') {
                                    $order_item_meta = $foodsearch_user_orders_obj->get_order_item_meta($order_item_id);
                                    $item_menu_id = $foodsearch_user_orders_obj->order_item_meta_value($order_item_meta, 'menu_id');
                                    $item_qty = $foodsearch_user_orders_obj->order_item_meta_value($order_item_meta, 'qty');
                                    $item_subtotal = $foodsearch_user_orders_obj->order_item_meta_value($order_item_meta, 'subtotal');

                                    $table_name = $table_prefix . 'menu_items';
                                    $menu_itmsql = "SELECT * FROM $table_name WHERE id=$item_menu_id";
                                    $menu_itm_obj = $wpdb->get_row($menu_itmsql);

                                    $image_src = '';
                                    $image_id = $menu_itm_obj->attachment_id;
                                    if ($image_id > 0) {
                                        $image_thumb = wp_get_attachment_image_src($image_id);
                                        $image_src = isset($image_thumb[0]) ? $image_thumb[0] : '';
                                    }
                                    $menu_itm_label = $menu_itm_obj->name;

                                    $item_alltotal = $item_subtotal * $item_qty;
                                    
                                    if ($items_counter > 1) {
                                        if ($order_item_type == 'menu_item_extra' && $menu_itms_open === false) {
                                            echo '<div class="fds-table-list-items active-list-itms items-con-' . $rand_num . '">';
                                            $menu_itms_open = true;
                                        } else if ($order_item_type == 'menu_item' && $menu_itms_open === false) {
                                            $rand_num = rand(1000000, 9999999);
                                            echo '<div class="fds-item-table-list fds-to-list-itms" data-id="' . $rand_num . '">';
                                        } else if ($order_item_type == 'menu_item' && $menu_itms_open === true) {
                                            $rand_num = rand(1000000, 9999999);
                                            $menu_itms_open = false;
                                            echo '</div><div class="fds-item-table-list fds-to-list-itms" data-id="' . $rand_num . '">';
                                        }
                                    } else {
                                        $rand_num = rand(1000000, 9999999);
                                        echo '<div class="fds-item-table-list fds-to-list-itms" data-id="' . $rand_num . '">';
                                    }
                                    ?>
                                    <ul class="fds-order-item-row fds-options-wrap">
                                        <li class="table-item-cell itm-name fds-list-item">
                                            <img src="<?php echo ($image_src) ?>" class="order-itm-thumbnail" alt="">
                                            <span class="order-name"><?php echo ($menu_itm_label) ?></span>
                                        </li>
                                        <li class="table-item-cell itm-cost fds-list-item">
                                            <span class="order-itm-amount"><?php echo (General_Functions::get_formatted_price($item_subtotal)) ?></span>
                                        </li>
                                        <li class="table-item-cell itm-qty fds-list-item">
                                            <small class="times">x</small> <?php echo ($item_qty) ?>
                                        </li>
                                        <li class="table-item-cell itm-totl fds-list-item">
                                            <span class="order-itm-total"><?php echo (General_Functions::get_formatted_price($item_alltotal)) ?></span>
                                        </li>
                                    </ul>
                                    <?php
                                    if ($items_counter > 1) {
                                        if ($items_counter == $total_order_items && $menu_itms_open === true) {
                                            echo '</div>';
                                        }
                                        if ($order_item_type == 'menu_item') {
                                            echo '</div>';
                                        }
                                    } else {
                                        echo '</div>';
                                    }
                                    $items_counter++;
                                }
                            }
                            ?>
                        </div>
                        <div class="fds-order-totals-items">
                            <ul class="fds-total-itmscon fds-options-wrap">
                                <li class="ordrtotl-label fds-list-item"><?php esc_html_e('items subtotal:', 'wp-foodsearch'); ?></li>
                                <li class="fds-list-item">
                                    <span class="ordrtotl-amount"><?php echo (General_Functions::get_formatted_price($order_subtotal)) ?></span>
                                </li>
                            </ul>
                            <?php
                            $delivery_fee = isset($order_result['shipping_total']) ? $order_result['shipping_total'] : '';
                            if ($delivery_fee > 0) {
                                ?>
                                <ul class="fds-total-itmscon fds-options-wrap">
                                    <li class="ordrtotl-label fds-list-item"><?php esc_html_e('delivery charges:', 'wp-foodsearch'); ?></li>
                                    <li class="fds-list-item">
                                        <span class="ordrtotl-amount"><?php echo (General_Functions::get_formatted_price($delivery_fee)) ?></span>
                                    </li>
                                </ul>
                                <?php
                            }
                            
                            $order_vat_switch = isset($foodsearch_plugin_settings['payment_settings']['order_vat_tax']) ? $foodsearch_plugin_settings['payment_settings']['order_vat_tax'] : '';
                            
                            $order_tax_amount = isset($order_result['tax_total']) ? $order_result['tax_total'] : '';
                            
                            $vat_amount = 0;
                            if ($order_tax_amount > 0) {
                                $vat_amount = $order_tax_amount;
                            }
                            if ($vat_amount > 0 || $order_vat_switch == 'on') {
                                ?>
                                <ul class="fds-total-itmscon fds-options-wrap">
                                    <li class="ordrtotl-label fds-list-item"><?php esc_html_e('vat:', 'wp-foodsearch'); ?></li>
                                    <li class="fds-list-item">
                                        <span class="ordrtotl-amount"><?php echo (General_Functions::get_formatted_price($vat_amount)) ?></span>
                                    </li>
                                </ul>
                                <?php
                            }
                            ?>
                            <ul class="fds-total-itmscon fds-options-wrap">
                                <li class="ordrtotl-label fds-list-item"><?php esc_html_e('order total:', 'wp-foodsearch'); ?></li>
                                <li class="fds-list-item">
                                    <span class="ordrtotl-amount"><?php echo (General_Functions::get_formatted_price($order_net_total)) ?></span>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
                <?php
            }
            ?>
        </div>
        <?php
        $html = ob_get_clean();
        
        wp_send_json(array('html' => $html, 'msg' => '', 'error' => '0'));
    }
    
    public function get_customer_orderdetail($post_data) {
        
        global $table_prefix, $wpdb, $foodsearch_user_orders_obj, $foodsearch_plugin_settings;

        $user_id = $post_data['t_id'];
        $order_id = $post_data['n_id'];
        
        $table_name = $table_prefix . 'fds_orders';
        $order_result = $wpdb->get_row("SELECT * FROM $table_name WHERE order_id=$order_id", 'ARRAY_A');
        
        $order_meta = FoodSearch_Orders::get_order_meta($order_id);
        $first_name = FoodSearch_Orders::order_meta_value($order_meta, 'billing_first_name');
        $last_name = FoodSearch_Orders::order_meta_value($order_meta, 'billing_last_name');
        $billing_email = FoodSearch_Orders::order_meta_value($order_meta, 'billing_email');
        $billing_phone = FoodSearch_Orders::order_meta_value($order_meta, 'billing_phone');
        $billing_address = FoodSearch_Orders::order_meta_value($order_meta, 'billing_address');

        $customer_name = '';
        if ($first_name != '') {
            $customer_name .= $first_name;
            if ($last_name != '') {
                $customer_name .= ' ' . $last_name;
            }
        }

        $order_status = $order_result['status'];
        
        $status_list = FoodSearch_Orders::get_order_statuses();
        
        $order_status_label = $foodsearch_user_orders_obj->get_order_status_tclr($order_status);
        
        $create_date = $order_result['date_created'];
        $create_date_formate = date_i18n(get_option('date_format'), strtotime($create_date));
        $create_time_formate = date_i18n(get_option('time_format'), strtotime($create_date));

        ob_start();
        ?>
        <div class="fds-booking-detail-title">
            <h2 class="fds-heading-title"><?php esc_html_e('order detail', 'wp-foodsearch'); ?></h2>
            <span><?php printf(esc_html__('status: %s', 'wp-foodsearch'), $order_status_label); ?></span>
        </div>
        
        <div class="fds-plugin-modal-box-inner">
            <?php
            $order_items = $foodsearch_user_orders_obj->get_order_items($order_id, 'menu_items');
            if (!empty($order_items)) {

                $order_subtotal = $order_result['total_sales'];
                $order_net_total = $order_result['net_total'];
                ?>
                <div id="fds-order-items-list" class="orderdet-items-wrap">
                    <div class="orderdet-items-inside">
                        <div class="fds-table-items-wrapper">
                            <ul class="fds-table-item-row item-row-heder fds-options-wrap">
                                <li class="table-item-heditm itm-name fds-list-item"><?php esc_html_e('item', 'wp-foodsearch'); ?></li>
                                <li class="table-item-heditm itm-cost fds-list-item"><?php esc_html_e('cost', 'wp-foodsearch'); ?></li>
                                <li class="table-item-heditm itm-qty fds-list-item"><?php esc_html_e('qty', 'wp-foodsearch'); ?></li>
                                <li class="table-item-heditm itm-totl fds-list-item"><?php esc_html_e('total', 'wp-foodsearch'); ?></li>
                            </ul>
                            <?php
                            $items_counter = 1;
                            $total_order_items = count($order_items);
                            $menu_itms_open = false;
                            foreach ($order_items as $order_item) {
                                $order_item_id = $order_item['order_item_id'];
                                $order_item_name = $order_item['order_item_name'];
                                $order_item_type = $order_item['order_item_type'];
                                if ($order_item_type == 'menu_item' || $order_item_type == 'menu_item_extra') {
                                    $order_item_meta = $foodsearch_user_orders_obj->get_order_item_meta($order_item_id);
                                    $item_menu_id = $foodsearch_user_orders_obj->order_item_meta_value($order_item_meta, 'menu_id');
                                    $item_qty = $foodsearch_user_orders_obj->order_item_meta_value($order_item_meta, 'qty');
                                    $item_subtotal = $foodsearch_user_orders_obj->order_item_meta_value($order_item_meta, 'subtotal');

                                    $table_name = $table_prefix . 'menu_items';
                                    $menu_itmsql = "SELECT * FROM $table_name WHERE id=$item_menu_id";
                                    $menu_itm_obj = $wpdb->get_row($menu_itmsql);

                                    $image_src = '';
                                    $image_id = $menu_itm_obj->attachment_id;
                                    if ($image_id > 0) {
                                        $image_thumb = wp_get_attachment_image_src($image_id);
                                        $image_src = isset($image_thumb[0]) ? $image_thumb[0] : '';
                                    }
                                    $menu_itm_label = $menu_itm_obj->name;

                                    $item_alltotal = $item_subtotal * $item_qty;
                                    
                                    if ($items_counter > 1) {
                                        if ($order_item_type == 'menu_item_extra' && $menu_itms_open === false) {
                                            echo '<div class="fds-table-list-items active-list-itms items-con-' . $rand_num . '">';
                                            $menu_itms_open = true;
                                        } else if ($order_item_type == 'menu_item' && $menu_itms_open === false) {
                                            $rand_num = rand(1000000, 9999999);
                                            echo '<div class="fds-item-table-list fds-to-list-itms" data-id="' . $rand_num . '">';
                                        } else if ($order_item_type == 'menu_item' && $menu_itms_open === true) {
                                            $rand_num = rand(1000000, 9999999);
                                            $menu_itms_open = false;
                                            echo '</div><div class="fds-item-table-list fds-to-list-itms" data-id="' . $rand_num . '">';
                                        }
                                    } else {
                                        $rand_num = rand(1000000, 9999999);
                                        echo '<div class="fds-item-table-list fds-to-list-itms" data-id="' . $rand_num . '">';
                                    }
                                    ?>
                                    <ul class="fds-order-item-row fds-options-wrap">
                                        <li class="table-item-cell itm-name fds-list-item">
                                            <img src="<?php echo ($image_src) ?>" class="order-itm-thumbnail" alt="">
                                            <span class="order-name"><?php echo ($menu_itm_label) ?></span>
                                        </li>
                                        <li class="table-item-cell itm-cost fds-list-item">
                                            <span class="order-itm-amount"><?php echo (General_Functions::get_formatted_price($item_subtotal)) ?></span>
                                        </li>
                                        <li class="table-item-cell itm-qty fds-list-item">
                                            <small class="times">x</small> <?php echo ($item_qty) ?>
                                        </li>
                                        <li class="table-item-cell itm-totl fds-list-item">
                                            <span class="order-itm-total"><?php echo (General_Functions::get_formatted_price($item_alltotal)) ?></span>
                                        </li>
                                    </ul>
                                    <?php
                                    if ($items_counter > 1) {
                                        if ($items_counter == $total_order_items && $menu_itms_open === true) {
                                            echo '</div>';
                                        }
                                        if ($order_item_type == 'menu_item') {
                                            echo '</div>';
                                        }
                                    } else {
                                        echo '</div>';
                                    }
                                    $items_counter++;
                                }
                            }
                            ?>
                        </div>
                        <div class="fds-order-totals-items">
                            <ul class="fds-total-itmscon fds-options-wrap">
                                <li class="ordrtotl-label fds-list-item"><?php esc_html_e('items subtotal:', 'wp-foodsearch'); ?></li>
                                <li class="fds-list-item">
                                    <span class="ordrtotl-amount"><?php echo (General_Functions::get_formatted_price($order_subtotal)) ?></span>
                                </li>
                            </ul>
                            <?php
                            $delivery_fee = isset($order_result['shipping_total']) ? $order_result['shipping_total'] : '';
                            if ($delivery_fee > 0) {
                                ?>
                                <ul class="fds-total-itmscon fds-options-wrap">
                                    <li class="ordrtotl-label fds-list-item"><?php esc_html_e('delivery charges:', 'wp-foodsearch'); ?></li>
                                    <li class="fds-list-item">
                                        <span class="ordrtotl-amount"><?php echo (General_Functions::get_formatted_price($delivery_fee)) ?></span>
                                    </li>
                                </ul>
                                <?php
                            }
                            
                            $order_vat_switch = isset($foodsearch_plugin_settings['payment_settings']['order_vat_tax']) ? $foodsearch_plugin_settings['payment_settings']['order_vat_tax'] : '';
                            
                            $order_tax_amount = isset($order_result['tax_total']) ? $order_result['tax_total'] : '';
                            
                            $vat_amount = 0;
                            if ($order_tax_amount > 0) {
                                $vat_amount = $order_tax_amount;
                            }
                            if ($vat_amount > 0 || $order_vat_switch == 'on') {
                                ?>
                                <ul class="fds-total-itmscon fds-options-wrap fds-list-item">
                                    <li class="ordrtotl-label fds-list-item"><?php esc_html_e('vat:', 'wp-foodsearch'); ?></li>
                                    <li class="fds-list-item">
                                        <span class="ordrtotl-amount"><?php echo (General_Functions::get_formatted_price($vat_amount)) ?></span>
                                    </li>
                                </ul>
                                <?php
                            }
                            ?>
                            <ul class="fds-total-itmscon fds-options-wrap">
                                <li class="ordrtotl-label fds-list-item"><?php esc_html_e('order total:', 'wp-foodsearch'); ?></li>
                                <li class="fds-list-item">
                                    <span class="ordrtotl-amount"><?php echo (General_Functions::get_formatted_price($order_net_total)) ?></span>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
                <?php
            }
            ?>
        </div>
        <?php
        $html = ob_get_clean();
        
        wp_send_json(array('html' => $html, 'msg' => '', 'error' => '0'));
    }
    
    public function restaurant_update_order_status($post_data) {
        global $table_prefix, $wpdb, $foodsearch_user_orders_obj;

        $order_id = $post_data['nid'];
        $order_status = $post_data['status'];
        
        $table_name = $table_prefix . 'fds_orders';
        $order_result = $wpdb->get_row("SELECT * FROM $table_name WHERE order_id=$order_id", 'ARRAY_A');
        
        if (!isset($order_result['status'])) {
            wp_send_json(array('msg' => esc_html__('error: order not found.', 'wp-foodsearch'), 'error' => '1'));
        }
        
        $order_meta = FoodSearch_Orders::get_order_meta($order_id);
        $restaurant_id = FoodSearch_Orders::order_meta_value($order_meta, 'restaurant_id');
        $user_id = General_Functions::restaurant_user_id($restaurant_id);
        
        $foodsearch_user_orders_obj->order_status_history($order_id, $order_status, $user_id);
        
        if ($order_status == 'completed') {
            $foodsearch_user_orders_obj->completed_record($order_id);
        } else if ($order_status == 'pending') {
            $foodsearch_user_orders_obj->pending_record($order_id);
        } else if ($order_status == 'processing') {
            $foodsearch_user_orders_obj->processing_record($order_id);
        } else if ($order_status == 'cancelled') {
            $foodsearch_user_orders_obj->cancelled_record($order_id);
        }
        
        wp_send_json(array('msg' => esc_html__('status updated successfully.', 'wp-foodsearch'), 'error' => '0'));
    }
    
    public function redirect_if_not_login($flag) {
        if (isset($_GET['tab_action']) && $_GET['tab_action'] == 'reset-password-request') {
            $flag = false;
        }
        
        return $flag;
    }
    
    public function reset_password_form_html($html) {
        if (isset($_GET['tab_action']) && $_GET['tab_action'] == 'reset-password-request') {
            
            global $foodsearch_plugin_settings;
            $detail_container = isset($foodsearch_plugin_settings['restaurant_settings']['detail_container']) ? $foodsearch_plugin_settings['restaurant_settings']['detail_container'] : '';
            $detail_container_width = isset($foodsearch_plugin_settings['restaurant_settings']['detail_container_width']) ? $foodsearch_plugin_settings['restaurant_settings']['detail_container_width'] : '';
            
            $key = isset($_GET['key']) ? $_GET['key'] : '';
            $user_id = isset($_GET['user_id']) && $_GET['user_id'] > 0 ? $_GET['user_id'] : 0;
            
            $show_form = true;
            if ($key == '') {
                $show_form = false;
            }
            
            if ($show_form) {
                $user_obj = get_user_by('id', $user_id);
                if (!isset($user_obj->ID)) {
                    $show_form = false;
                }
            }
            
            if ($show_form) {
                $user_login = isset($user_obj->user_login) ? $user_obj->user_login : '';
                $user = check_password_reset_key($key, $user_login);

		if (is_wp_error($user)) {
                    $show_form = false;
                }
            }
            
            ob_start();
            ?>
            <div class="fds-user-dashboard fds-reset-password-page"<?php echo ($detail_container == 'on' && $detail_container_width > 0 ? ' style="width: ' . absint($detail_container_width) . 'px;"' : '') ?>>
                <?php
                if ($show_form) {
                    ?>
                    <div class="fds-resturant-dashboard-wrap-box">
                        <div class="fds-section-title-wrap">
                            <h2 class="fds-heading-title"><?php esc_html_e('Reset Password', 'wp-foodsearch') ?></h2>
                        </div>
                        <div class="fds-dashboard-inner-section">
                            <form class="fds-common-form fds-user-resetpass-form" method="post">
                                <div class="fds-dashform-field fds-form-field fds-field-halfcalc">
                                    <div class="label_wrap"><label class="fds-input-label"><?php esc_html_e('password', 'wp-foodsearch') ?></label></div>
                                    <input type="password" name="fds_user_password" class="fds-input-style" value="" placeholder="<?php esc_html_e('password', 'wp-foodsearch') ?>">
                                </div>
                                <div class="fds-dashform-field fds-form-field fds-field-halfcalc">
                                    <div class="label_wrap"><label class="fds-input-label"><?php esc_html_e('confirm password', 'wp-foodsearch') ?></label></div>
                                    <input type="password" name="fds_user_confpass" class="fds-input-style" value="" placeholder="<?php esc_html_e('confirm password', 'wp-foodsearch') ?>">
                                </div>
                                <div class="fds-dashform-field fds-form-field">
                                    <div class="fds-loader-holder" style="display:none;"></div>
                                    <div class="fds-submitbtn-con">
                                        <div class="fds-btn fds-medium-btn">
                                            <input type="hidden" name="uid" value="<?php echo ($user_id) ?>">
                                            <input type="hidden" name="key" value="<?php echo ($key) ?>">
                                            <?php wp_nonce_field('ajax-forgotpass-nonce', 'security-resetpass'); ?>
                                            <input type="submit" class="fds-has-bg fds-update-anything-action" value="<?php esc_html_e('save password', 'wp-foodsearch') ?>">
                                        </div>
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                    <?php
                } else {
                    ?>
                    <div class="foodsearch-noitm-found">
                        <img src="<?php echo foodsearch_plugin_get_url('assets/images/not-found.svg') ?>" alt="">
                        <p><?php esc_html_e('this key is invalid or has already been used. please reset your password again if needed.', 'wp-foodsearch') ?></p>
                    </div>
                    <?php
                }
                ?>
            </div>
            <?php
            $html = ob_get_clean();
        }
        
        return $html;
    }
    public function restaurant_listing($data){        
          $args = array(  
            'post_type' => 'restaurants',
            'post_status' => 'publish',
            'posts_per_page' =>  $data['np'],
            'offset' => $data['offset']
        );
        $loop = new \WP_Query( $args ); 
        $restaurants = array();
        if($loop->have_posts()){
          $i=1;
            while ( $loop->have_posts() ) : $loop->the_post();                
                $bg = get_the_post_thumbnail_url(get_the_ID());
                if ( empty($bg) ) {
                    $bg = plugin_dir_url(__FILE__)."../includes/wp-foodsearch-blocks/images/no-image.jpg";
                }
                $restaurants[$i]['thumbnail'] = $bg;
                $restaurants[$i]['id'] = get_the_ID();
                $restaurants[$i]['title'] = get_the_title();
                $restaurants[$i]['url'] = get_permalink();
                $restaurants[$i]['slug'] = get_post_field( 'post_name', get_the_ID() );
                $restaurants[$i]['excerpt'] = get_the_excerpt();
                $restaurants[$i]['meta_tags']['min_order'] = get_post_meta( get_the_ID(), 'foodsearch_min_delivery_order', true ) ;
                $ads = get_post_meta( get_the_ID(), 'foodsearch_locations_list', true ) ;
                if($ads){
                foreach($ads as $addrs){
                    if(isset($addrs['label'])){
                        $addresses['home'] = $addrs;
                    }
                    else{                        
                        $addresses['home'] = ['address'=>'Not Yet Added'];
                    }
                }
            }
            else{                        
                $addresses['home'] = ['address'=>'Not Yet Added'];
            }

                $restaurants[$i]['meta_tags']['address'] = $addresses;
                $restaurants[$i]['meta_tags']['rating'] = get_post_meta( get_the_ID(), 'oveall_review_avg_rating', true ) ;
                $restaurants[$i]['meta_tags']['review_count'] = get_post_meta(get_the_ID(), 'oveall_review_count', true ) ;            
                $restaurants[$i]['meta_tags']['opening_time'] = get_post_meta( get_the_ID(), 'restaurant_'.strtolower(date('l')).'_opening_hour', true ) ;            
                $restaurants[$i]['meta_tags']['closeing_time'] = get_post_meta( get_the_ID(), 'restaurant_'.strtolower(date('l')).'_closing_hour', true ) ;
                $i++;
            endwhile;
            wp_reset_postdata();
        }
         return $restaurants;
    }
    public function restaurant_list_filter($attr){
        global $wpdb, $post;   
    wp_reset_query();
    wp_reset_postdata();

$join = "";
$keyword = "";
$cuisine = "";
$delivery = "";
$take_away = "";
$ratings = "";
$meta_tbl = "";
$order = " ORDER BY $wpdb->posts.post_date DESC ";
if ( !isset ( $attr['offset'] ) ) $attr['offset'] = 0;

if ( isset($attr['keyword']) && $attr['keyword'] != "" ) {
  $keyword = $wpdb->esc_like($attr['keyword']);
  $keyword = " AND (
      $wpdb->posts.post_title LIKE '" . esc_sql('%') . $keyword . esc_sql('%') . "'
      OR $wpdb->posts.post_excerpt LIKE '" . esc_sql('%') . $keyword . esc_sql('%') . "'
      OR $wpdb->posts.post_content LIKE '" . esc_sql('%') . $keyword . esc_sql('%') . "'
      OR ID IN (
          SELECT object_id 
          FROM $wpdb->term_relationships AS TR 
          INNER JOIN $wpdb->term_taxonomy AS TT ON TR.term_taxonomy_id = TT.term_taxonomy_id
          INNER JOIN $wpdb->terms AS T ON TT.term_id = T.term_id
          WHERE T.name LIKE '" . esc_sql('%') . $keyword . esc_sql('%') . "'
        )
    )
  ";
}

if ( isset($attr['order']) ) {
  if ( $attr['order'] == "best-match" ) {
    $meta_tbl = " , $wpdb->postmeta";
    $order = " AND $wpdb->postmeta.meta_key = 'foodsearch_total_orders' ORDER BY $wpdb->postmeta.meta_value + 0 DESC ";
  }
  else if ( $attr['order'] == "title" ) {
    $order = " ORDER BY $wpdb->posts.post_title ASC ";
  }
  else if ( $attr['order'] == "rating" ) {
    $meta_tbl = " , $wpdb->postmeta";
    $order = " AND $wpdb->postmeta.meta_key = 'oveall_review_avg_rating' ORDER BY $wpdb->postmeta.meta_value + 0 DESC ";
  }
  else if ( $attr['order'] == "minimum-order" ) {
    $meta_tbl = " , $wpdb->postmeta";
    $order = " AND $wpdb->postmeta.meta_key = 'foodsearch_min_delivery_order' ORDER BY $wpdb->postmeta.meta_value + 0 ASC ";
  }
  else if ( $attr['order'] == "minimum-delivery-fee" ) {
    $meta_tbl = " , $wpdb->postmeta";
    $order = " AND $wpdb->postmeta.meta_key = 'foodsearch_delivery_fee' ORDER BY $wpdb->postmeta.meta_value + 0 ASC ";
  }
  else if ( $attr['order'] == "fastest-delivery" ) {
    $meta_tbl = " , $wpdb->postmeta";
    $order = " AND $wpdb->postmeta.meta_key = 'foodsearch_delivery_time' ORDER BY $wpdb->postmeta.meta_value + 0 ASC ";
  }
  else if ( $attr['order'] == "reviews" ) {
    $meta_tbl = " , $wpdb->postmeta";
    $order = " AND $wpdb->postmeta.meta_key = 'oveall_review_count' ORDER BY $wpdb->postmeta.meta_value DESC + 0 ";
  }
}

if ( isset($attr['cuisine']) ) {
  $cuisine = is_array($attr['cuisine']) ? implode (",", $attr['cuisine']) : trim($attr['cuisine'], ",") ;
  
  $cuisine = preg_filter('/^/', "'", $cuisine);
  $cuisine = preg_filter('/$/', "'", $cuisine);
  $cuisine = str_replace(",", "','", $cuisine);

  $cuisine_ids = $wpdb->get_results( "SELECT GROUP_CONCAT(term_id) AS ids FROM `$wpdb->terms` WHERE slug IN ($cuisine) " );
  $cuisine_ids = $cuisine_ids[0]->ids;

  $cuisine_total = count(explode(",",$cuisine_ids));
  $cuisine = " AND ( 
      (
        SELECT COUNT(1)
        FROM $wpdb->term_relationships
        WHERE term_taxonomy_id IN ($cuisine_ids)
        AND object_id = $wpdb->posts.ID
      ) = $cuisine_total
    )
  ";
}

if ( isset($attr['delivery']) && $attr['delivery'] > 0 && $attr['delivery'] != "undefined" ) {
  $join = "INNER JOIN $wpdb->postmeta AS mt1 ON ( $wpdb->posts.ID = mt1.post_id )";
  $delivery = " AND ( mt1.meta_key = 'foodsearch_order_process_type' AND mt1.meta_value IN ('delivery','both') ) ";
}

if ( isset($attr['take_away']) && $attr['take_away'] > 0 && $attr['take_away'] != "undefined" ) {
  $join = "INNER JOIN $wpdb->postmeta AS mt1 ON ( $wpdb->posts.ID = mt1.post_id )";
  $take_away = " AND ( mt1.meta_key = 'foodsearch_order_process_type' AND mt1.meta_value IN ('takeaway','both') ) ";
}

if ( isset($attr['ratings']) && $attr['ratings'] > 0 && $attr['ratings'] != "undefined" ) {
  $join .= "INNER JOIN $wpdb->postmeta AS mt2 ON ( $wpdb->posts.ID = mt2.post_id )";
  if ( $attr['ratings'] == 5 ) $rat = " BETWEEN '5' AND '5' ";
  else if ( $attr['ratings'] == 4 ) $rat = " BETWEEN '4' AND '4.9' ";
  else if ( $attr['ratings'] == 3 ) $rat = " BETWEEN '3' AND '3.9' ";
  else if ( $attr['ratings'] == 4 ) $rat = " BETWEEN '2' AND '2.9' ";
  $ratings = " AND ( mt2.meta_key = 'oveall_review_avg_rating' AND CAST(mt2.meta_value AS SIGNED) " . $rat . " ) ";
}

$sql = " SELECT *
      FROM $wpdb->posts $meta_tbl
      $join
      WHERE 1=1
      $keyword
      $cuisine
      $delivery
      $take_away
      $ratings
      AND $wpdb->posts.post_type = 'restaurants' AND $wpdb->posts.post_status = 'publish'
      $order
      ";

$sql .= " LIMIT " . $attr['offset'] . ", " . $attr['np'];
$posts = $wpdb->get_results($sql);
// echo '<pre>'.print_r($posts,true).'</pre>';
// exit();
        $i=0;
        foreach($posts as $post){
            $bg = get_the_post_thumbnail_url($post->ID);
            if ( empty($bg) ) {
                $bg = plugin_dir_url(__FILE__)."../includes/wp-foodsearch-blocks/images/no-image.jpg";
            }
            $restaurants[$i]['thumbnail'] = $bg;
            $restaurants[$i]['id'] =$post->ID;
            $restaurants[$i]['title'] = $post->post_title;
            $restaurants[$i]['url'] = get_permalink($post->ID);
            $restaurants[$i]['slug'] = get_post_field( 'post_name', $post->ID );
            $restaurants[$i]['excerpt'] = $post->post_excerpt;
            $restaurants[$i]['meta_tags']['min_order'] = get_post_meta( $post->ID, 'foodsearch_min_delivery_order', true ) ;
            $ads = get_post_meta( $post->ID, 'foodsearch_locations_list', true ) ;
            if($ads){
            foreach($ads as $addrs){
                if(isset($addrs['label'])){
                    $addresses['home'] = $addrs;
                }
                else{                        
                    $addresses['home'] = ['address'=>'Not Yet Added'];
                }
            }
        }
        else{                        
            $addresses['home'] = ['address'=>'Not Yet Added'];
        }

            $restaurants[$i]['meta_tags']['address'] = $addresses;
            $restaurants[$i]['meta_tags']['rating'] = get_post_meta( $post->ID, 'oveall_review_avg_rating', true ) ;
            $restaurants[$i]['meta_tags']['review_count'] = get_post_meta($post->ID, 'oveall_review_count', true ) ;            
            $restaurants[$i]['meta_tags']['opening_time'] = get_post_meta( $post->ID, 'restaurant_'.strtolower(date('l')).'_opening_hour', true ) ;            
            $restaurants[$i]['meta_tags']['closeing_time'] = get_post_meta( $post->ID, 'restaurant_'.strtolower(date('l')).'_closing_hour', true ) ;
            $i++;
        }

        return $restaurants;
    }
    function restaurant_basis_detail($data){
        $post = get_post( $data['id']);
        $i=0;
            $bg = get_the_post_thumbnail_url($post->ID);
            if ( empty($bg) ) {
                $bg = plugin_dir_url(__FILE__)."../includes/wp-foodsearch-blocks/images/no-image.jpg";
            }
            $restaurants[$i]['thumbnail'] = $bg;
            $restaurants[$i]['id'] =$post->ID;
            $restaurants[$i]['title'] = $post->post_title;
            $restaurants[$i]['url'] = get_permalink($post->ID);
            $restaurants[$i]['slug'] = get_post_field( 'post_name', $post->ID );
            $restaurants[$i]['excerpt'] = $post->post_excerpt;
            $restaurants[$i]['meta_tags']['min_order'] = get_post_meta( $post->ID, 'foodsearch_min_delivery_order', true ) ;
            $restaurants[$i]['meta_tags']['min_time'] = get_post_meta( $post->ID, 'foodsearch_delivery_time', true ) ;
            $ads = get_post_meta( $post->ID, 'foodsearch_locations_list', true ) ;
            if($ads){
            foreach($ads as $addrs){
                if(isset($addrs['label'])){
                    $addresses['home'] = $addrs;
                }
                else{                        
                    $addresses['home'] = ['address'=>'Not Yet Added'];
                }
            }
        }
        else{                        
            $addresses['home'] = ['address'=>'Not Yet Added'];
        }

            $restaurants[$i]['meta_tags']['address'] = $addresses;
            $restaurants[$i]['meta_tags']['rating'] = get_post_meta( $post->ID, 'oveall_review_avg_rating', true ) ;
            $restaurants[$i]['meta_tags']['review_count'] = get_post_meta($post->ID, 'oveall_review_count', true ) ;            
            $restaurants[$i]['meta_tags']['opening_time'] = get_post_meta( $post->ID, 'restaurant_'.strtolower(date('l')).'_opening_hour', true ) ;            
            $restaurants[$i]['meta_tags']['closeing_time'] = get_post_meta( $post->ID, 'restaurant_'.strtolower(date('l')).'_closing_hour', true ) ;
            $i++;
        return $restaurants;
    }
    public function restaurant_menu_list($data){
        global $table_prefix, $wpdb;
         $table_name = $table_prefix . 'menus';
         $results = $wpdb->get_results("SELECT * FROM $table_name WHERE restaurant_id = ".$data['id']." order by id desc");
       foreach($results as $k=>$result){
        $resturants[$k] = json_decode(json_encode($result,true),true);
        $resturants[$k]['menu'] = $this->restaurant_menu_items($result->id);
       }

         return $resturants;
    }
    private function restaurant_menu_items($menu_id){
        $where = ' where menu_id =' . $menu_id;

            $categories = array();
            $menuitems = array();
            global $table_prefix, $wpdb;
            $table_name = $table_prefix . 'menu_items';
            $sql = "SELECT * FROM $table_name$where AND status=2 ORDER BY sort_order ASC";
            $results = $wpdb->get_results($sql,ARRAY_A);
            if (!empty($results)) {
                $v=0;
                foreach ($results as $row) {
                    $menuitems[$row['category_id']][$v] = $row;                    
                    $menuitems[$row['category_id']][$v]['variations'] = json_decode($row['variations'],true);
                    if (!in_array($row['category_id'], $categories)) {
                        $categories[] = $row['category_id'];
                    }
                    $v++;
                }
            }
            $cats = array();
            if (count($categories) > 0) {
                foreach ($categories as $key => $category) {
                    $term = get_term_by('id', $category, 'food_item_cat');                   
                    $cats[$category] = isset($term->name) ? $term->name : '';
                }
            }           
            return ['cats'=>$cats,'menuitems'=>$menuitems];
    }
}

new Common_Functions;
