<?php

namespace FoodSearch\Dashboard\Customer;

use FoodSearch\Common_Functions;
use FoodSearch\User_Locations;

class Favourite_Restaurants {
    
    public function __construct() {
        
        add_filter('foodsearch_customer_dash_favourite_restaurants_html', [$this, 'content'], 10, 4);
    }
    
    public function content($html, $menu_data, $section_key, $element_key) {
        
        $common_functions = new Common_Functions;
        
        $user_id = get_current_user_id();
        
        $customer_id = Common_Functions::user_customer_id($user_id);
        
        $fav_list = $common_functions->restaurant_fav_list($customer_id, 'customer');
        
        ob_start();
        if (!empty($fav_list)) {
            $foodsearch_user_geo_loc = User_Locations::user_current_location();
            ?>
            <div class="fds-restaurants-shortlists">
                <div class="fds-listing-item-wrap">
                    <?php
                    foreach ($fav_list as $fav_itm) {
                        $restaurant_id = $fav_itm['id'];
                        $restaurant_user_id = Common_Functions::customer_user_id($restaurant_id);
                        $logo_url = foodsearch_restaurant_logo_url($restaurant_user_id, $restaurant_id);
                        
                        $restaurant_cats = wp_get_post_terms($restaurant_id, 'food_item_cat');
                        $restaurant_cuisines = wp_get_post_terms($restaurant_id, 'food_cuisine');
                        ?>
                        <div class="fds-col-4">
                            <div class="fds-restaurants-shortlists-inner">
                                <div class="fds-action-btns">
                                    <a href="#" class="fds-body-action fds-remove-action fds-remove-fav-restaurant fds-link" data-id="<?php echo ($restaurant_id) ?>" data-nid="<?php echo ($user_id) ?>"><i class="fds-icon fds-time-simple"></i></a>
                                </div>
                                <div class="fds-item-thumb"><a href="<?php echo get_permalink($restaurant_id) ?>" class="fds-link"><img src="<?php echo ($logo_url) ?>" alt=""></a></div>
                                <div class="fds-restaurants-shortlists-text">
                                    <a href="<?php echo get_permalink($restaurant_id) ?>" class="fds-restaurants-shortlists-title fds-link"><?php echo get_the_title($restaurant_id) ?></a>
                                    <div class="fds-restaurants-shortlists-link">
                                        <?php
                                        if (isset($restaurant_cuisines[0]->name)) {
                                            ?>
                                            <a class="fds-link"><i class="fds-icon fds-cutlery-line"></i> <?php echo ($restaurant_cuisines[0]->name) ?></a>
                                            <?php
                                        }
                                        $restaurant_distances = Common_Functions::restaurant_distance_from_user_loc($foodsearch_user_geo_loc, $restaurant_id);
                                        if (isset($restaurant_distances[0]['distance'])) {
                                            ?>
                                            <a class="fds-right-link fds-link"><i class="fds-icon fds-pin-line"></i> <?php echo ($restaurant_distances[0]['distance']) ?> Km</a>
                                            <?php
                                        }
                                        ?>
                                    </div>
                                    <?php
                                    if (!empty($restaurant_cats)) {
                                        ?>
                                        <div class="shortlists-favtags-uper">
                                            <?php
                                            $cats_count = 1;
                                            foreach ($restaurant_cats as $restaurant_cat) {
                                                echo ($cats_count > 1 ? ',&nbsp;' : '');
                                                ?>
                                                <a class="fds-restaurants-shortlists-tags fds-link"><?php echo ($restaurant_cat->name) ?></a>
                                                <?php
                                                $cats_count++;
                                            }
                                            ?>
                                        </div>
                                        <?php
                                    }
                                    ?>
                                </div>
                                <a href="<?php echo get_permalink($restaurant_id) ?>" class="fds-restaurants-shortlists-btn fds-link"><i class="fds-icon fds-menu-one"></i> <?php esc_html_e('view menu', 'wp-foodsearch'); ?></a>
                            </div>
                        </div>
                        <?php
                    }
                    ?>
                </div>
            </div>
            <?php
        } else {
            ?>
            <div class="foodsearch-noitm-found">
                <img src="<?php echo foodsearch_plugin_get_url('assets/images/not-found.svg') ?>" alt="">
                <p><?php esc_html_e('no record found.', 'wp-foodsearch') ?></p>
            </div>
            <?php
        }
        $html = ob_get_clean();
        
        return $html;
    }

}

new Favourite_Restaurants;
