<?php

namespace FoodSearch\Dashboard\Restaurant;

use FoodSearch\Common_Functions;
use FoodSearch\user_orders as FoodSearch_Orders;

class Orders {

    public function __construct() {

        add_filter('foodsearch_restaurant_dash_orders_html', [$this, 'content'], 10, 4);
        
        add_action('rest_api_init', [$this, 'register_api'], 5);
    }
    
    public function register_api() {

        register_rest_route('wp/v1', 'restaurant-orders-load-more', array(
            'methods' => 'GET',
            'callback' => [$this, 'load_more_orders_list'],
           'permission_callback' =>  'admin_permissions_check',
        ));
    }
    

    public function content($html, $menu_data, $section_key, $element_key) {

        global $foodsearch_user_orders_obj;

        wp_enqueue_style('jquery-datetimepicker');
        wp_enqueue_script('jquery-datetimepicker');
        
        $element_data = $menu_data['sections'][$section_key]['elements'][$element_key];
        
        $element_label = isset($element_data['label']) ? $element_data['label'] : '';
        if ($element_label == '') {
            $element_label = esc_html__('recent orders', 'wp-foodsearch');
        }

        $user_id = get_current_user_id();

        $restaurant_id = Common_Functions::user_restaurant_id($user_id);

        $order_statuses = FoodSearch_Orders::get_order_statuses();

        $per_page = 20;
        $total_orders = $foodsearch_user_orders_obj->get_restaurant_orders_total_count($restaurant_id, $_GET);
        $orders_list = $foodsearch_user_orders_obj->get_restaurant_filtered_orders($restaurant_id, $_GET);
     //   echo '<pre>'.print_r($orders_list,true).'</pre>';
        
        ob_start();
        ?>
        <div class="fds-section-title-wrap fds-restaurant-orders-page">
            <?php
            if ($element_label != '') {
                ?>
                <h2 class="fds-heading-title"><?php echo ($element_label) ?></h2>
                <?php
            }
            
            $get_tab = get_query_var('tab');

            $get_keyword = isset($_GET['filter_orders_keyword']) ? foodsearch_esc_html($_GET['filter_orders_keyword']) : '';
            $get_order_type = isset($_GET['filter_orders_type']) ? foodsearch_esc_html($_GET['filter_orders_type']) : '';
            $get_order_status = isset($_GET['filter_orders_status']) ? foodsearch_esc_html($_GET['filter_orders_status']) : '';
            $get_order_date = isset($_GET['filter_orders_date']) ? foodsearch_esc_html($_GET['filter_orders_date']) : '';
            ?>
            <div class="fds-order-filters">
                <form class="restaurant-filter-orders-form" method="get" autocomplete="off">
                    <span class="fds-dashboard-inner-top-filter"><?php esc_html_e('filter by', 'wp-foodsearch'); ?>:</span>
                    <div class="fds-form-field">
                        <div class="fds-select-field">
                            <select class="fds-select-dropdown" name="filter_orders_type" data-placeholder="<?php esc_html_e('order type', 'wp-foodsearch'); ?>">
                                <option value=""><?php esc_html_e('order type', 'wp-foodsearch'); ?></option>
                                <option value="delivery"<?php echo ($get_order_type == 'delivery' ? ' selected' : '') ?>><?php esc_html_e('delivery', 'wp-foodsearch'); ?></option>
                                <option value="take_away"<?php echo ($get_order_type == 'take_away' ? ' selected' : '') ?>><?php esc_html_e('take away', 'wp-foodsearch'); ?></option>
                            </select>
                        </div>
                    </div>
                    <div class="fds-form-field">
                        <div class="fds-select-field">
                            <select class="fds-select-dropdown" name="filter_orders_status" data-placeholder="<?php esc_html_e('order status', 'wp-foodsearch'); ?>">
                                <option value=""><?php esc_html_e('order status', 'wp-foodsearch'); ?></option>
                                <?php
                                foreach ($order_statuses as $status_key => $status_label) {
                                    if ($status_key == 'trash' || $status_key == 'refunded' || $status_key == 'failed') {
                                        continue;
                                    }
                                    ?>
                                    <option value="<?php echo ($status_key) ?>"<?php echo ($get_order_status == $status_key ? ' selected' : '') ?>><?php echo ($status_label) ?></option>
                                    <?php
                                }
                                ?>
                            </select>
                        </div>
                    </div>
                    <div class="fds-form-field">
                        <input type="text" name="filter_orders_date" class="fds-input-style fds-filter-orders-date" value="<?php echo ($get_order_date) ?>" placeholder="<?php esc_html_e('order date', 'wp-foodsearch'); ?>">
                    </div>
                    <div class="fds-form-field">
                        <div class="fds-search-field">
                            <input type="hidden" name="tab" value="<?php echo ($get_tab) ?>">
                            <input type="text" name="filter_orders_keyword" class="fds-input-style" value="<?php echo ($get_keyword) ?>" placeholder="<?php esc_html_e('order id/customer', 'wp-foodsearch'); ?>">
                            <input type="submit" value="">
                            <i class="fds-icon fds-search"></i>
                        </div>
                    </div>
                </form>
                <i class="fds-dashboard-inner-top-money fds-icon fds-shopping-cart"></i>
            </div>
            <?php
            //
            add_action('wp_footer', function() {
                ?>
                <script>
                    jQuery(document).ready(function () {
                        jQuery('.fds-filter-orders-date').datetimepicker({
                            format: 'd-m-Y',
                            timepicker: false,
                            maxDate: '<?php echo current_time('d-m-Y') ?>'
                        });
                    });
                </script>
                <?php
            }, 99);
            ?>
        </div>
        <?php
        if (!empty($orders_list)) {
            ?>
            <div id="fds-user-orders-mainlist" class="fds-recet-order-list">
                <div class="fds-recet-order-thead">
                    <div><?php esc_html_e('date', 'wp-foodsearch'); ?></div>
                    <div><?php esc_html_e('order id', 'wp-foodsearch'); ?></div>
                    <div><?php esc_html_e('type', 'wp-foodsearch'); ?></div>
                    <div><?php esc_html_e('detail', 'wp-foodsearch'); ?></div>
                    <div><?php esc_html_e('order price', 'wp-foodsearch'); ?></div>
                    <div><?php esc_html_e('comission', 'wp-foodsearch'); ?></div>
                    <div><?php esc_html_e('status', 'wp-foodsearch'); ?></div>
                    <div><?php esc_html_e('detail', 'wp-foodsearch'); ?></div>
                </div>
                <?php
                foreach ($orders_list as $order_result) {
                    $order_id = $order_result['order_id'];
                    
                    $this->order_itm_detail($order_id, $order_result, $user_id);
                }
                ?>
            </div>
            <?php
            if ($total_orders > $per_page) {
                $total_pages = ceil($total_orders / $per_page);
                ?>
                <div id="fds-restaurant-orders-morebtn" class="fds-lodmore-btnsec">
                    <div class="fds-btn fds-medium-btn">
                        <a href="#" class="fds-lodmore-btn fds-has-bg fds-link" data-nid="<?php echo ($user_id) ?>" data-tpages="<?php echo($total_pages) ?>" data-gtopage="2"><?php esc_html_e('load more', 'wp-foodsearch') ?></a>
                    </div>
                </div>
                <?php
            }
            add_action('wp_footer', function() {
                ?>
                <div id="fds-orderdet-mpopup" class="fds-modal-popup fds-popup-hide fds-orderdet-modal">
                    <div class="fds-modal-container">
                        <a href="javascript:void(0);" class="fds-popup-closebtn fds-link"><i class="fds-icon fds-time-simple"></i></a>
                        <div class="fds-modal-inner-area">
                            <div class="fds-modal-content-area">
                                <div class="fds-dynm-modal-content">
                                    <div class="fds-loader-holder"><div class="fds-loader"></div></div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <?php
            }, 20);
        } else {
            ?>
            <div class="foodsearch-noitm-found">
                <img src="<?php echo foodsearch_plugin_get_url('assets/images/not-found.svg') ?>" alt="">
                <p><?php esc_html_e('no record found.', 'wp-foodsearch') ?></p>
            </div>
            <?php
        }
        $html = ob_get_clean();

        return $html;
    }
    
    public function order_itm_detail($order_id, $order_result, $user_id) {
        global $foodsearch_user_orders_obj;

        $restaurant_id = Common_Functions::user_restaurant_id($user_id);

        $order_statuses = FoodSearch_Orders::get_order_statuses();
        
        $order_meta = FoodSearch_Orders::get_order_meta($order_id);
        $first_name = FoodSearch_Orders::order_meta_value($order_meta, 'billing_first_name');
        $last_name = FoodSearch_Orders::order_meta_value($order_meta, 'billing_last_name');

        $order_type = FoodSearch_Orders::order_meta_value($order_meta, 'order_type');

        //
        $order_status_updated = false;
        $order_status_histry = FoodSearch_Orders::order_meta_value($order_meta, 'status_history');
        $order_status_histry = $order_status_histry != '' ? maybe_unserialize($order_status_histry) : '';
        if (!empty($order_status_histry) && is_array($order_status_histry)) {
            foreach ($order_status_histry as $status_histry) {
                if (isset($status_histry['user']) && $status_histry['user'] == $user_id && ($status_histry['status'] == 'completed' || $status_histry['status'] == 'cancelled')) {
                    $order_status_updated = true;
                    break;
                }
            }
        }
        //

        $order_title = 'Order #' . $order_id;
        if ($first_name != '' && $last_name != '') {
            $order_title .= " ($first_name $last_name)";
        }

        $order_status = $order_result['status'];

        $status_label = $foodsearch_user_orders_obj->get_order_status_tclr($order_status);
        $status_color = $foodsearch_user_orders_obj->get_order_status_tclr($order_status, 'color');

        $create_date = $order_result['date_created'];
        $create_date_formate = date_i18n(get_option('date_format'), strtotime($create_date));

        $order_net_total = $order_result['net_total'];
        ?>
        <div class="fds-recet-order-tbody">
            <div class="fds-recet-order-cell"><?php echo ($create_date_formate) ?></div>
            <div class="fds-recet-order-cell">#<?php echo ($order_id) ?></div>
            <div class="fds-recet-order-cell"><a class="fds-recet-order-btn fds-link"><?php echo ($order_type == 'take_away' ? esc_html__('take away', 'wp-foodsearch') : esc_html__('delivery', 'wp-foodsearch')) ?></a></div>
            <div class="fds-recet-order-cell"><?php echo ($order_title) ?></div>
            <div class="fds-recet-order-cell"><span><?php echo (Common_Functions::get_formatted_price($order_net_total)) ?></span></div>
            <div class="fds-recet-order-cell"><span>-<?php echo (Common_Functions::get_formatted_price(0)) ?></span></div>
            <?php
            if ($order_status_updated) {
                ?>
                <div class="fds-recet-order-cell"><strong style="background-color: <?php echo ($status_color) ?>;"><?php echo ($status_label) ?></strong></div>
                <?php
            } else {
                ?>
                <div class="fds-recet-order-cell">
                    <div class="fds-restaurant-order-status" data-nid="<?php echo ($order_id) ?>">
                        <strong class="fds-to-orderstatus-update fds-update-anything-action" style="background-color: <?php echo ($status_color) ?>;"><?php echo ($status_label) ?> <i class="fds-icon fds-down-arrow"></i></strong>
                        <ul class="fds-order-status-list-box fds-order-status-list fds-options-wrap">
                            <?php
                            foreach ($order_statuses as $status_key => $status_label) {
                                if ($status_key == 'trash' || $status_key == 'on-hold' || $status_key == 'refunded' || $status_key == 'failed') {
                                    continue;
                                }
                                ?>
                                <li class="fds-list-item"><a href="#" class="fds-link" data-key="<?php echo ($status_key) ?>"><?php echo ($status_label) ?></a></li>
                                <?php
                            }
                            ?>
                        </ul>
                    </div>
                </div>
                <?php
            }
            ?>
            <div class="fds-recet-order-cell"><a href="#" class="fds-recet-order-link fds-get-orderdet-popup fds-link" data-restaurant="<?php echo ($restaurant_id) ?>" data-nid="<?php echo ($order_id) ?>"><?php esc_html_e('detail', 'wp-foodsearch'); ?> <i class="fds-icon fds-plus-circle-o"></i></a></div>
        </div>
        <?php
    }
    
    public function load_more_orders_list() {
        $user_id = $_REQUEST['n_id'];
        $page_num = $_REQUEST['page_num'];
        
        global $foodsearch_user_orders_obj;

        $restaurant_id = Common_Functions::user_restaurant_id($user_id);

        $orders_list = $foodsearch_user_orders_obj->get_restaurant_filtered_orders($restaurant_id, '', $page_num);
        
        ob_start();
        foreach ($orders_list as $order_result) {
            $order_id = $order_result['order_id'];

            $this->order_itm_detail($order_id, $order_result, $user_id);
        }
        $html = ob_get_clean();
        
        wp_send_json(array('error' => '0', 'html' => $html));
    }

}

new Orders;
