<?php

namespace FoodSearch\Dashboard\Restaurant;
use FoodSearch\Common_Functions;

class Settings {
    
    public function __construct() {
        
        add_filter('foodsearch_restaurant_dash_account_settings_html', [$this, 'content'], 10, 4);
    }
    
    public function content($html, $menu_data, $section_key, $element_key) {

        global $foodsearch_common_functions;

        $element_data = $menu_data['sections'][$section_key]['elements'][$element_key];

        $user_id = get_current_user_id();
        $user_obj = get_user_by('id', $user_id);

        $restaurant_id = Common_Functions::user_restaurant_id($user_id);
        $restaurant_post = get_post($restaurant_id);

        ob_start();
        ?>
        <form class="fds-common-form dashboard-settings-form" method="post">
            <?php
            if (isset($element_data['item_fields']) && !empty($element_data['item_fields'])) {

                $item_fields = $element_data['item_fields'];

                uasort($item_fields, function ($a, $b) {
                    if ($a['sort'] == $b['sort']) {
                        $ret_val = 0;
                    }
                    $ret_val = ($a['sort'] < $b['sort']) ? -1 : 1;
                    return $ret_val;
                });
                foreach ($item_fields as $field_key => $field_data) {
                    $label = isset($field_data['label']) ? $field_data['label'] : '';
                    $enabled = isset($field_data['status']) ? $field_data['status'] : 'on';
                    $required = isset($field_data['required']) ? $field_data['required'] : '';
                    $col_width = isset($field_data['width']) ? $field_data['width'] : '2';

                    if ($field_key == 'restaurant_name') {
                        $itm_value = isset($restaurant_post->post_title) ? $restaurant_post->post_title : '';
                    } else if ($field_key == 'email_address') {
                        $itm_value = isset($user_obj->user_email) ? $user_obj->user_email : '';
                    } else {
                        $itm_value = get_post_meta($restaurant_id, 'foodsearch_' . $field_key, true);
                    }

                    if ($enabled == 'on') {
                        $act_width = 100 / $col_width;
                        ?>
                        <div class="fds-dashform-field fds-form-field" style="flex: 0 0 calc(<?php echo ($act_width) ?>% - 20px);">
                            <div class="label_wrap"><label class="fds-input-label"><?php echo ($label) ?><?php echo ($required == 'on' ? ' *' : '') ?></label></div>
                            <?php
                            if ($field_key == 'information') {
                                $classes_arr = array('fds-textarea-style');
                                $field_class = implode(' ', $classes_arr);
                                
                                $post_detail = isset($restaurant_post->post_content) ? $restaurant_post->post_content : '';
                                $editor_args = array(
                                    'media_buttons' => false,
                                    'editor_class' => 'fds-editor-field',
                                    'quicktags' => false,
                                    'tinymce' => array(
                                        'toolbar1' => 'bold,bullist,numlist,italic,underline,alignleft,aligncenter,alignright,separator,link,unlink,undo,redo,caned_resp_button',
                                        'toolbar2' => '',
                                        'toolbar3' => '',
                                    ),
                                );
                                $post_detail = foodsearch_esc_wp_editor($post_detail);
                                ?>
                                <textarea name="restaurant_info_detail" class="<?php echo ($field_class) ?>"<?php echo ($required == 'on' ? ' required' : '') ?> placeholder="<?php echo ($label) ?>"><?php echo ($post_detail) ?></textarea>
                                <?php
                                
                            } else if ($field_key == 'cuisines') {
                                $classes_arr = array('fds-select-style');
                                $field_class = implode(' ', $classes_arr);
                                
                                $restaurant_cats_objs = wp_get_post_terms($restaurant_id, 'food_cuisine');
                                $restaurant_cats = [];
                                if (!empty($restaurant_cats_objs)) {
                                    foreach ($restaurant_cats_objs as $restaurant_cat_obj) {
                                        $restaurant_cats[] = $restaurant_cat_obj->term_id;
                                    }
                                }
                                
                                $cats_list = get_terms(array(
                                    'taxonomy' => 'food_cuisine',
                                    'hide_empty' => false,
                                ));
                                ?>
                                <div class="fds-select-field fds-multi-select">
                                    <select name="fds_restaurant_<?php echo ($field_key) ?>[]" class="select_dropdown" multiple="" data-placeholder="<?php echo ($label) ?>">
                                        <?php
                                        if (!empty($cats_list)) {
                                            foreach ($cats_list as $cat_itm) {
                                                ?>
                                                <option value="<?php echo ($cat_itm->term_id) ?>"<?php echo (!empty($restaurant_cats) && in_array($cat_itm->term_id, $restaurant_cats) ? ' selected' : '') ?>><?php echo ($cat_itm->name) ?></option>
                                                <?php
                                            }
                                        }
                                        ?>
                                    </select>
                                </div>
                                <?php
                            } else if ($field_key == 'tags') {
                                $classes_arr = array('fds-select-style');
                                $field_class = implode(' ', $classes_arr);
                                
                                $restaurant_tags_objs = wp_get_post_terms($restaurant_id, 'restaurant_tag');
                                ?>
                                <div class="fds-select-field fds-multi-select">
                                    <select name="fds_restaurant_<?php echo ($field_key) ?>[]" class="restaurant-tags-group" multiple="multiple" data-placeholder="<?php echo ($label) ?>">
                                        <?php
                                        if (!empty($restaurant_tags_objs)) {
                                            foreach ($restaurant_tags_objs as $tag_itm) {
                                                ?>
                                                <option value="<?php echo ($tag_itm->name) ?>" selected><?php echo ($tag_itm->name) ?></option>
                                                <?php
                                            }
                                        }
                                        ?>
                                    </select>
                                </div>
                                <?php
                            } else if ($field_key == 'order_process_type') {
                                $classes_arr = array('fds-select-style');
                                $field_class = implode(' ', $classes_arr);
                                ?>
                                <div class="fds-select-field">
                                    <select name="fds_setting_<?php echo ($field_key) ?>" class="select_dropdown" data-placeholder="<?php echo ($label) ?>">
                                        <option value="both"<?php echo ($itm_value == 'both' ? ' selected' : '') ?>><?php echo esc_html__('delivery &amp; takeaway both', 'wp-foodsearch'); ?></option>
                                        <option value="delivery"<?php echo ($itm_value == 'delivery' ? ' selected' : '') ?>><?php echo esc_html__('delivery only', 'wp-foodsearch'); ?></option>
                                        <option value="takeaway"<?php echo ($itm_value == 'takeaway' ? ' selected' : '') ?>><?php echo esc_html__('takeaway only', 'wp-foodsearch'); ?></option>
                                    </select>
                                </div>
                                <?php
                            } else {
                                $classes_arr = array('fds-input-style');
                                $field_class = implode(' ', $classes_arr);
                                ?>
                                <input type="<?php echo ($field_key == 'email_address' ? 'email' : 'text') ?>" name="fds_setting_<?php echo ($field_key) ?>" class="<?php echo ($field_class) ?>"<?php echo ($required == 'on' ? ' required' : '') ?><?php echo ($field_key == 'email_address' ? ' readonly' : '') ?> value="<?php echo ($itm_value) ?>" placeholder="<?php echo ($label) ?>">
                                <?php
                            }
                            ?>
                        </div>
                        <?php
                    }
                }
                ?>
                <div class="fds-restaurant-opening-hours" style="flex: 0 0 calc(100% - 20px);">
                    <div class="fds-formpart-hding"><strong class="fds-locs-hding"><?php esc_html_e('opening time', 'wp-foodsearch') ?></strong></div>
                    <?php
                    $foodsearch_common_functions->restaurant_hours_settings($restaurant_id);
                    ?>
                </div>
                <div class="fds-dashform-field fds-form-field">
                    <div class="fds-submitbtn-con">
                        <input type="hidden" name="fds_nonce_id" value="<?php echo ($user_id) ?>">
                        <?php
                        wp_nonce_field('ajax-settings-nonce', 'dashboard-settings');
                        ?>
                        <div class="fds-btn fds-medium-btn">
                            <button type="submit" class="fds-has-bg fds-update-anything-action"><?php esc_html_e('save settings', 'wp-foodsearch') ?></button>
                        </div>
                    </div>
                    <?php
                    echo apply_filters('foodsearch_restaurant_dash_setin_savebtn_after', '', $user_id);
                    ?>
                </div>
                <?php
            }
            ?>
        </form>
        <?php
        $html = ob_get_clean();
        
        echo ($html);
    }

}

new Settings;
