<?php

namespace FoodSearch\Dashboard;
use FoodSearch\Common_Functions as General_Functions;

class shortcode {

    public function __construct() {
        add_shortcode('foodsearch_dashboard', [$this, 'shortcode']);
        add_filter('foodsearch_dashboard_main_panel_html', [$this, 'main_panel_html'], 10, 3);
        add_filter('foodsearch_user_dashboard_sidebar_nav', [$this, 'sidebar_nav'], 10, 3);
        add_filter('foodsearch_user_dashboard_top_header', [$this, 'top_header'], 10, 3);
        
        add_filter('wp', [$this, 'dashboard_redirect']);
    }
    
    public function dashboard_redirect() {
        if (!is_user_logged_in()) {
            global $foodsearch_plugin_settings;

            $dashboard_page_slug = isset($foodsearch_plugin_settings['dashboard_settings']['dashboard_page']) ? $foodsearch_plugin_settings['dashboard_settings']['dashboard_page'] : '';
            $login_page_slug = isset($foodsearch_plugin_settings['register_settings']['loginreg_page']) ? $foodsearch_plugin_settings['register_settings']['loginreg_page'] : '';
            
            $dashboard_page_id = foodsearch__get_post_id($dashboard_page_slug);
            
            if ($dashboard_page_id > 0 && is_page($dashboard_page_id)) {
                $login_page_id = 0;
                if (!empty($login_page_slug)) {
                    $login_page_id = foodsearch__get_post_id($login_page_slug);
                }
                if ($login_page_id > 0) {
                    $redierct_url = get_permalink($login_page_id);
                } else {
                    $redierct_url = home_url('/');
                }

                if (apply_filters('foodsearch_dashboard_redirect_if_not_login', true)) {
                    wp_redirect($redierct_url);
                    exit();
                }
            }
        }
    }

    public function shortcode($attr = array()) {
        global $dashboard_page_id;
        $common_functions = new General_Functions;
        
        wp_enqueue_script('foodsearch-dashboard-common');
        
        $dashboard_page_id = get_the_id();
        ob_start();

        $user_id = get_current_user_id();
        $user_type = General_Functions::user_type($user_id);
        if (is_user_logged_in()) {
            ?>
            <div class="fds-wrapper">
                <?php
                echo apply_filters('foodsearch_user_dashboard_sidebar_nav', '', $user_id, $user_type);
                ?>
                <div class="fds-main-content fds-dashboard-content">
                    <div class="fds-main-section fds-typo-wrap">

                        <?php
                        echo apply_filters('foodsearch_user_dashboard_top_header', '', $user_id, $user_type);
                        ?>

                        <div class="fds-dashboard-main-title">
                            <h1 class="fds-heading-title"><?php esc_html_e('dashboard', 'wp-foodsearch') ?></h1>
                            <span><?php esc_html_e('welcome to your dashboard', 'wp-foodsearch') ?></span>
                        </div>

                        <div class="fds-resturant-dashboard-wrapper">
                            <?php
                            ob_start();
                            ?>
                            <div class="choose-userdash-type">
                                <div class="choose-usertype-box">
                                    <a href="javascript:void(0);" data-utyp="restaurant" data-nid="<?php echo ($user_id) ?>" class="fds-userchose-type fds-userchose-restaurant fds-link">
                                        <span class="usertype-img-box">
                                            <img src="<?php echo foodsearch_plugin_get_url('assets/images/box-svg1.svg') ?>" alt="">
                                        </span>
                                        <?php esc_html_e('i am restaurant', 'wp-foodsearch') ?>
                                    </a>
                                </div>
                                <div class="choose-usertype-box">
                                    <a href="javascript:void(0);" data-utyp="customer" data-nid="<?php echo ($user_id) ?>" class="fds-userchose-type fds-userchose-customer fds-link">
                                        <span class="usertype-img-box">
                                            <img src="<?php echo foodsearch_plugin_get_url('assets/images/box-svg3.svg') ?>" alt="">
                                        </span>
                                        <?php esc_html_e('i am customer', 'wp-foodsearch') ?>
                                    </a>
                                </div>
                            </div>
                            <?php
                            $html = ob_get_clean();
                            echo apply_filters('foodsearch_dashboard_main_panel_html', $html, $user_id, $user_type);
                            ?>
                        </div>
                    </div>
                </div>
            </div>
            <?php
        } else {
            echo do_shortcode('[foodsearch_user_form for="login"]');
        }
        $html = ob_get_clean();
        $html = apply_filters('foodsearch_user_dash_shortcode_html', $html);
        return $html;
    }
    
    public function menu_nav_list($user_type) {
        $nav_menu = array(
            'dashboard' => array(
                'label' => esc_html__('dashboard', 'wp-foodsearch'),
                'icon' => 'fds-icon fds-dashboard',
            ),
        );
        if ($user_type == 'restaurant') {
            $menus_list = get_option("foodsearch_dashboard_restaurant_menus_list");

            if (!empty($menus_list)) {
                uasort($menus_list, function ($a, $b) {
                    if ($a['sort'] == $b['sort']) {
                        $ret_val = 0;
                    }
                    $ret_val = ($a['sort'] < $b['sort']) ? -1 : 1;
                    return $ret_val;
                });
                $nav_menu = array();
                foreach ($menus_list as $menu_key => $menu_data) {
                    $menu_slug = $menu_data['slug'];
                    $menu_label = $menu_data['label'];
                    $menu_icon = $menu_data['icon'] != '' ? $menu_data['icon'] : 'fds-icon fds-dashboard';
                    $nav_menu[$menu_slug] = array(
                        'label' => $menu_label,
                        'icon' => $menu_icon,
                    );
                }
            }
            $nav_menu = apply_filters('foodsearch_restaurant_dash_nav_menulist', $nav_menu);
        } else if ($user_type == 'customer') {
            $menus_list = get_option("foodsearch_dashboard_customer_menus_list");
            if (!empty($menus_list)) {
                uasort($menus_list, function ($a, $b) {
                    if ($a['sort'] == $b['sort']) {
                        $ret_val = 0;
                    }
                    $ret_val = ($a['sort'] < $b['sort']) ? -1 : 1;
                    return $ret_val;
                });
                $nav_menu = array();
                foreach ($menus_list as $menu_key => $menu_data) {
                    $menu_slug = $menu_data['slug'];
                    $menu_label = $menu_data['label'];
                    $menu_icon = $menu_data['icon'] != '' ? $menu_data['icon'] : 'fds-icon fds-dashboard';
                    $nav_menu[$menu_slug] = array(
                        'label' => $menu_label,
                        'icon' => $menu_icon,
                    );
                }
            }
            $nav_menu = apply_filters('foodsearch_customer_dash_nav_menulist', $nav_menu);
        }
        
        return $nav_menu;
    }
    
    public function main_panel_html($html, $user_id, $user_type) {
        
        $user_types = array('restaurant', 'customer');

        if ($user_type != '' && in_array($user_type, $user_types)) {
            $menus_list = get_option("foodsearch_dashboard_{$user_type}_menus_list");
            $html = '';
            $nav_menu = $this->menu_nav_list($user_type);
            $get_tab = get_query_var('tab');

            if ($get_tab != '' && isset($nav_menu[$get_tab])) {
                $html = apply_filters('foodsearch_user_dashboard_menu_html', '', $user_type, $get_tab);
            }
            if ($get_tab == '' && !empty($menus_list)) {
                 uasort($menus_list, function ($a, $b) {
                    if ($a['sort'] == $b['sort']) {
                        $ret_val = 0;
                    }
                    $ret_val = ($a['sort'] < $b['sort']) ? -1 : 1;
                    return $ret_val;
                });
                foreach ($menus_list as $menu_key => $menu_data) {
                    $menu_tab_slug = $menu_data['slug'];
                    $html = apply_filters('foodsearch_user_dashboard_menu_html', '', $user_type, $menu_tab_slug);
                    break;
                }
            }
            
            if ($html == '') {
                $html = apply_filters('foodsearch_user_dash_content_html', '', $user_type);
            }
        }
        
        return $html;
    }
    
    public function sidebar_nav($html, $user_id, $user_type) {
        global $foodsearch_plugin_settings, $dashboard_page_id;

        $dashboard_logo_url = isset($foodsearch_plugin_settings['dashboard_bilder_settings']['dashboard_logo']) ? $foodsearch_plugin_settings['dashboard_bilder_settings']['dashboard_logo'] : '';
        
        $dashboard_url = get_permalink($dashboard_page_id);
        
        $nav_menu = $this->menu_nav_list($user_type);
        if ($user_type == 'restaurant') {
            $userdash_page_slug = isset($foodsearch_plugin_settings['dashboard_settings']['dashboard_page']) ? $foodsearch_plugin_settings['dashboard_settings']['dashboard_page'] : '';
        } else {
            $userdash_page_slug = isset($foodsearch_plugin_settings['dashboard_settings']['dashboard_page']) ? $foodsearch_plugin_settings['dashboard_settings']['dashboard_page'] : '';
        }
        $userdash_page_id = foodsearch__get_post_id($userdash_page_slug);
        
        $get_tab = get_query_var('tab');
        $get_tab = isset($nav_menu[$get_tab]) ? $get_tab : '';
        ob_start();
        ?>
        <div class="fds-plugin-nav">
            <a href="#" class="fds-plugin-nav-btn fds-link"><i class="fds-icon fds-menu-bar"></i></a>
            <?php
            if ($dashboard_logo_url != '') {
                ?>
                <a href="<?php echo ($dashboard_url) ?>" class="fds-plugin-logo fds-link"><img src="<?php echo ($dashboard_logo_url) ?>" alt="<?php esc_html_e('dashboard', 'wp-foodsearch') ?>"></a>
                <?php
            }
            ?>
            <ul class="fds-options-wrap">
                <?php
                $menu_counter = 1;
                foreach ($nav_menu as $menu_key => $menu_itm) {
                    $activ_class = '';
                    if ($get_tab == '' && $menu_counter == 1) {
                        $activ_class = ' fds-active-menu';
                    } else if ($get_tab != '' && $get_tab == $menu_key) {
                        $activ_class = ' fds-active-menu';
                    }
                    
                    if (strpos($dashboard_url, '?') === false && $dashboard_page_id == $userdash_page_id) {
                        $menu_url = $dashboard_url . $menu_key;
                    } else {
                        $menu_url = add_query_arg(array('tab' => $menu_key), $dashboard_url);
                    }
                    ?>
                    <li class="fds-dashmenu-itm<?php echo ($activ_class) ?> fds-list-item"><a href="<?php echo ($menu_url) ?>" class="fds-link"><i class="<?php echo ($menu_itm['icon']) ?>"></i> <span class="fds-menu-txt"><?php echo ($menu_itm['label']) ?></span></a></li>
                    <?php
                    $menu_counter++;
                }
                ?>
                <li class="fds-list-item"><a href="<?php echo wp_logout_url(home_url('/')) ?>" class="fds-link"><i class="fds-icon fds-sign-arrow"></i> <span class="fds-menu-txt"><?php esc_html_e('sign out', 'wp-foodsearch') ?></span></a></li>
            </ul>
        </div>
        <?php
        $html = ob_get_clean();
        
        return $html;
    }
    
    public function top_header($html, $user_id, $user_type) {
        
        global $foodsearch_plugin_settings, $dashboard_page_id;
        
        $user_obj = get_user_by('id', $user_id);
        $display_title = isset($user_obj->display_name) ? $user_obj->display_name : '';
        if ($user_type == 'restaurant') {
            $common_functions = new General_Functions;

            $restaurant_id = General_Functions::user_restaurant_id($user_id);
            $user_img_url = foodsearch_restaurant_logo_url($user_id, $restaurant_id);
            
            $display_title = get_the_title($restaurant_id);
            $userdash_page_slug = isset($foodsearch_plugin_settings['dashboard_settings']['dashboard_page']) ? $foodsearch_plugin_settings['dashboard_settings']['dashboard_page'] : '';
        } else {
            $user_img_url = foodsearch_customer_photo_url($user_id);
            $userdash_page_slug = isset($foodsearch_plugin_settings['dashboard_settings']['dashboard_page']) ? $foodsearch_plugin_settings['dashboard_settings']['dashboard_page'] : '';
        }
        $userdash_page_id = foodsearch__get_post_id($userdash_page_slug);
        
        $dashboard_url = get_permalink($dashboard_page_id);
        
        $nav_menu = $this->menu_nav_list($user_type);
        
        $get_tab = get_query_var('tab');
        $get_tab = isset($nav_menu[$get_tab]) ? $get_tab : '';

        ob_start();
        ?>
        <div class="fds-dashboard-header">
            <a href="<?php echo home_url('/') ?>" class="fds-dashboard-home-icon fds-link"><i class="fds-icon fds-home"></i></a>
            <?php
            if ($user_type == 'customers') {
                global $foodsearch_plugin_settings;
                $restaurants_listing = isset($foodsearch_plugin_settings['restaurant_settings']['restaurant_listing_page']) ? $foodsearch_plugin_settings['restaurant_settings']['restaurant_listing_page'] : '';
                $restaurants_page_id = $restaurants_listing != '' ? foodsearch__get_post_id($restaurants_listing) : '';
                
                if ($restaurants_page_id > 0) {
                    $restaurants_page_url = get_permalink($restaurants_page_id);
                }
                ?>
                <form class="fds-dashboard-search" method="get" action="<?php echo $restaurants_page_url; ?>">
                    <?php echo foodsearch_search_field_html(); ?>
                </form>
                <?php
            }
            ?>
            <div class="fds-dashboard-resturant-user">
                <a href="#" class="fds-dashboard-user-bell fds-link" style="display: none;"><i class="fds-icon fds-bell-simple"></i> <span>0</span></a>
                <a href="javascript:void(0);" class="fds-dashboard-user-link userlinks-dropbtn fds-link"><?php echo ($display_title) ?> <i class="fds-icon fds-down-arrow-fill"></i> <img src="<?php echo ($user_img_url) ?>" alt=""></a>

                <div class="fds-useracount-dropnav">
                    <ul class="fds-options-wrap">
                        <?php
                        $menu_counter = 1;
                        foreach ($nav_menu as $menu_key => $menu_itm) {
                            $activ_class = '';
                            if ($get_tab == '' && $menu_counter == 1) {
                                $activ_class = ' fds-active-menu';
                            } else if ($get_tab != '' && $get_tab == $menu_key) {
                                $activ_class = ' fds-active-menu';
                            }
                            if (strpos($dashboard_url, '?') === false && $dashboard_page_id == $userdash_page_id) {
                                $menu_url = $dashboard_url . $menu_key;
                            } else {
                                $menu_url = add_query_arg(array('tab' => $menu_key), $dashboard_url);
                            }
                            ?>
                            <li class="fds-list-item<?php echo ($activ_class) ?>"><a href="<?php echo ($menu_url) ?>" class="fds-link"><i class="<?php echo ($menu_itm['icon']) ?>"></i> <?php echo ($menu_itm['label']) ?></a></li>
                            <?php
                            $menu_counter++;
                        }
                        ?>
                        <li class="fds-list-item"><a href="<?php echo wp_logout_url(home_url('/')) ?>" class="fds-link"><i class="fds-icon fds-sign-arrow"></i> <?php esc_html_e('sign out', 'wp-foodsearch') ?></a></li>
                    </ul>
                </div>
            </div>
        </div>
        <?php
        $html = ob_get_clean();
        
        return $html;
    }

}

new shortcode();
