<?php

/**
 * Fired during plugin activation
 *
 * @since      1.0.0
 *
 * @package    FoodSearch_Plugin
 * @subpackage FoodSearch_Plugin/helper/classes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 */
class FoodSearch_Plugin_Activator {
    
     public function __construct() {
         SELF::create_database_table();
         SELF::activate();
         
        // $this->locationDateInsert();
     }
    /**
     * Short Description. (use period)
     *
     * Long Description.
     *
     * @since    1.0.0
     */
    public static function activate() {
        update_option('wp_foodsearch_plugin_active', 'yes');

        $is_installed_already = get_option('wp_foodsearch_plugin_installed');
        if (!$is_installed_already) {
            self::create_pages();
            update_option('wp_foodsearch_plugin_installed', 1);
        }
        
        do_action('foodsearch_plugin_activator_hook');
        if (! wp_next_scheduled ( 'foodsearch_cart_reset_cron' )) {
            wp_schedule_event(time(), 'hourly', 'foodsearch_cart_reset_cron');
        }
        
        //
    }
    
    public static function create_pages() {
        
        global $fds_plugin_setting_fields;
        
        $login_page_slug = 'fds-login';
        $login_page_obj = get_page_by_path($login_page_slug, 'OBJECT', 'page');
        
        if (!isset($login_page_obj->ID)) {
            $page_post = array(
                'post_title' => 'Login/Registration',
                'post_name' => $login_page_slug,
                'post_type' => 'page',
                'post_content' => '[foodsearch_user_form for="login"]',
                'post_status' => 'publish',
            );
            $login_page_id = wp_insert_post($page_post);
        } else {
            $login_page_id = $login_page_obj->ID;
        }
        
        $dash_page_slug = 'fds-dashboard';
        $dash_page_obj = get_page_by_path($dash_page_slug, 'OBJECT', 'page');
        
        if (!isset($dash_page_obj->ID)) {
            $page_post = array(
                'post_title' => 'Dashboard',
                'post_name' => $dash_page_slug,
                'post_type' => 'page',
                'post_content' => '[foodsearch_dashboard]',
                'post_status' => 'publish',
            );
            $dash_page_id = wp_insert_post($page_post);
        } else {
            $dash_page_id = $dash_page_obj->ID;
        }
        
        $chckout_page_slug = 'fds-order-checkout';
        $chckout_page_obj = get_page_by_path($chckout_page_slug, 'OBJECT', 'page');
        
        if (!isset($chckout_page_obj->ID)) {
            $page_post = array(
                'post_title' => 'Order Checkout',
                'post_name' => $chckout_page_slug,
                'post_type' => 'page',
                'post_content' => '[fds_checkout]',
                'post_status' => 'publish',
            );
            $chckout_page_id = wp_insert_post($page_post);
        } else {
            $chckout_page_id = $chckout_page_obj->ID;
        }
        
        $setting_data = get_option('foodsearch_plugin_settings');
        
        if (!$setting_data) {
            $setting_fields = $fds_plugin_setting_fields->list_set();
            
            // save default values
            if (!empty($setting_fields)) {
                $data_arr = array();
                foreach ($setting_fields as $fields_tab => $fields_data) {
                    if (isset($fields_data['fields']) && !empty($fields_data['fields'])) {
                        $opt_id = $fields_data['id'];
                        $opt_fields = $fields_data['fields'];

                        foreach ($opt_fields as $field_itm) {
                            if (isset($field_itm['id'])) {
                                $field_default_val = isset($field_itm['default']) ? $field_itm['default'] : '';
                                $data_arr[$opt_id][$field_itm['id']] = $field_default_val;
                            }
                        }
                    }
                }
                //
                update_option('foodsearch_plugin_settings', $data_arr);
            }
        }
        
        $setting_data = get_option('foodsearch_plugin_settings');
        
        //
        $login_page_obj = get_post($login_page_id);
        $dash_page_obj = get_post($dash_page_id);
        $chkout_page_obj = get_post($chckout_page_id);
        
        if (isset($login_page_obj->post_name) && isset($setting_data['register_settings']['loginreg_page'])) {
            $login_page_name = $login_page_obj->post_name;
            $setting_data['register_settings']['loginreg_page'] = $login_page_name;
        }
        if (isset($dash_page_obj->post_name) && isset($setting_data['dashboard_settings']['dashboard_page'])) {
            update_post_meta($dash_page_id, '_wp_page_template', 'foodsearch-full-page.php');
            $dash_page_name = $dash_page_obj->post_name;
            $setting_data['dashboard_settings']['dashboard_page'] = $dash_page_name;
        }
        if (isset($chkout_page_obj->post_name) && isset($setting_data['payment_settings']['checkout_page'])) {
            $chkout_page_name = $chkout_page_obj->post_name;
            $setting_data['payment_settings']['checkout_page'] = $chkout_page_name;
        }
        
        update_option('foodsearch_plugin_settings', $setting_data);
    }
  
    public static function create_database_table()
    {
        global $table_prefix, $wpdb;
        
        $collate = '';

        if ( $wpdb->has_cap( 'collation' ) ) {
            $collate = $wpdb->get_charset_collate();
        }
        
        $max_index_length = 191;

        $tblname = 'menus';
        $wp_track_table = $table_prefix . "$tblname";

        #Check to see if the table exists already, if not, then create it

        if($wpdb->get_var( "show tables like '$wp_track_table'" ) != $wp_track_table)
        {

            $sql = "CREATE TABLE `". $wp_track_table . "` ( ";
            $sql .= "  `id`  int(11)   NOT NULL auto_increment, ";
            $sql .= "  `name`  varchar(150)   NOT NULL, ";
            $sql .= "  `slug`  varchar(150)   NOT NULL, ";
            $sql .= "  `menu_opening_days`  varchar(255)   NULL, ";
            $sql .= "  `menu_start_time`  varchar(10)   NULL, ";
            $sql .= "  `menu_end_time`  varchar(10)   NULL, ";
            $sql .= "  `restaurant_id`  int(10)   NOT NULL, ";
            $sql .= "  `details`  text    NULL, ";
            $sql .= "  `status` int(1) DEFAULT 0 NOT NULL, ";
            $sql .= "  PRIMARY KEY `id` (`id`) ";
            $sql .= ") $collate;";

            require_once( ABSPATH . '/wp-admin/includes/upgrade.php' );
            dbDelta($sql);
        }


        $tblname = 'menu_items';
        $wp_track_table = $table_prefix . "$tblname";

        #Check to see if the table exists already, if not, then create it

        if($wpdb->get_var( "show tables like '$wp_track_table'" ) != $wp_track_table)
        {

            $sql = "CREATE TABLE `". $wp_track_table . "` ( ";
            $sql .= "  `id`  int(11)   NOT NULL auto_increment, ";
            $sql .= "  `name`  varchar(150)   NOT NULL, ";
            $sql .= "  `price`  double  NOT NULL, ";
            $sql .= "  `discount_price`  double   NULL, ";
            $sql .= "  `offer_status`  int(10)   NULL, ";
            $sql .= "  `attachment_id`  int   NOT NULL, ";
            $sql .= "  `category_id`  varchar(100)   NOT NULL, ";
            $sql .= "  `choice_groups_id`  varchar(100)   NULL, ";
            $sql .= "  `variations`  text   NULL, ";
            $sql .= "  `restaurant_id`  int   NOT NULL, ";
            $sql .= "  `menu_id`  int   NOT NULL, ";
            $sql .= "  `details`  text    NULL, ";
            $sql .= "  `status` int(1) DEFAULT 0 NOT NULL, ";
            $sql .= "  `sort_order` int(11) DEFAULT 0 NOT NULL, ";
            $sql .= "  PRIMARY KEY `id` (`id`) ";
            $sql .= ") $collate;";

            require_once( ABSPATH . '/wp-admin/includes/upgrade.php' );
            dbDelta($sql);
        }
        
        $tblname = 'menu_itemmeta';
        $wp_track_table = $table_prefix . "$tblname";
        
        if($wpdb->get_var( "show tables like '$wp_track_table'" ) != $wp_track_table) {

            $sql = "CREATE TABLE `$wp_track_table` (
            menu_meta_id BIGINT UNSIGNED NOT NULL auto_increment,
            menu_item_id BIGINT UNSIGNED NOT NULL,
            meta_key varchar(255) default NULL,
            meta_value longtext NULL,
            PRIMARY KEY  (menu_meta_id),
            KEY menu_item_id (menu_item_id),
            KEY meta_key (meta_key(32))
            ) $collate;";

            require_once( ABSPATH . '/wp-admin/includes/upgrade.php' );
            dbDelta($sql);
        }

        $tblname = 'menu_choice_group';
        $wp_track_table = $table_prefix . "$tblname";

        #Check to see if the table exists already, if not, then create it

        if($wpdb->get_var( "show tables like '$wp_track_table'" ) != $wp_track_table)
        {

            $sql = "CREATE TABLE `". $wp_track_table . "` ( ";
            $sql .= "  `id`  int(11)   NOT NULL auto_increment, ";
            $sql .= "  `name`  varchar(150)   NOT NULL, ";
            $sql .= "  `min`  int(5)   NOT NULL, ";
            $sql .= "  `max`  int(5)   NOT NULL, ";
            $sql .= "  `menuItem_id`  text   NOT NULL, ";
            $sql .= "  `restaurant_id`  int   NOT NULL, ";
            $sql .= "  `status` int(1) DEFAULT 0 NOT NULL, ";
            $sql .= "  PRIMARY KEY `id` (`id`) ";
            $sql .= ") $collate; ";

            require_once( ABSPATH . '/wp-admin/includes/upgrade.php' );
            dbDelta($sql);
        }
        
        //
        // Order tables
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        
        if($wpdb->get_var( "show tables like '$wp_track_table'" ) != $wp_track_table) {

            $sql = "CREATE TABLE `$wp_track_table` (
            order_id bigint(20) unsigned NOT NULL auto_increment,
            parent_id bigint(20) unsigned DEFAULT 0 NOT NULL,
            date_created datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
            date_created_gmt datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
            num_items_sold int(11) DEFAULT 0 NOT NULL,
            total_sales double DEFAULT 0 NOT NULL,
            tax_total double DEFAULT 0 NOT NULL,
            shipping_total double DEFAULT 0 NOT NULL,
            net_total double DEFAULT 0 NOT NULL,
            returning_customer boolean DEFAULT NULL,
            status varchar(200) NOT NULL,
            customer_id BIGINT UNSIGNED NOT NULL,
            PRIMARY KEY (order_id),
            KEY date_created (date_created),
            KEY customer_id (customer_id),
            KEY status (status({$max_index_length}))
            ) $collate;";

            require_once( ABSPATH . '/wp-admin/includes/upgrade.php' );
            dbDelta($sql);
        }
        $tblname = 'fds_order_products';
        $wp_track_table = $table_prefix . "$tblname";
        
        if($wpdb->get_var( "show tables like '$wp_track_table'" ) != $wp_track_table) {

            $sql = "CREATE TABLE `$wp_track_table` (
            order_item_id BIGINT UNSIGNED NOT NULL auto_increment,
            order_id BIGINT UNSIGNED NOT NULL,
            product_id BIGINT UNSIGNED NOT NULL,
            variation_id BIGINT UNSIGNED NOT NULL,
            customer_id BIGINT UNSIGNED NULL,
            date_created datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
            product_qty INT NOT NULL,
            product_net_revenue double DEFAULT 0 NOT NULL,
            product_gross_revenue double DEFAULT 0 NOT NULL,
            coupon_amount double DEFAULT 0 NOT NULL,
            tax_amount double DEFAULT 0 NOT NULL,
            shipping_amount double DEFAULT 0 NOT NULL,
            shipping_tax_amount double DEFAULT 0 NOT NULL,
            PRIMARY KEY  (order_item_id),
            KEY order_id (order_id),
            KEY product_id (product_id),
            KEY customer_id (customer_id),
            KEY date_created (date_created)
            ) $collate;";

            require_once( ABSPATH . '/wp-admin/includes/upgrade.php' );
            dbDelta($sql);
        }
        $tblname = 'fds_order_meta';
        $wp_track_table = $table_prefix . "$tblname";
        
        if($wpdb->get_var( "show tables like '$wp_track_table'" ) != $wp_track_table) {

            $sql = "CREATE TABLE `$wp_track_table` (
            order_meta_id BIGINT UNSIGNED NOT NULL auto_increment,
            order_id BIGINT UNSIGNED NOT NULL,
            meta_key varchar(255) default NULL,
            meta_value longtext NULL,
            PRIMARY KEY  (order_meta_id),
            KEY order_id (order_id)
            ) $collate;";

            require_once( ABSPATH . '/wp-admin/includes/upgrade.php' );
            dbDelta($sql);
        }
        $tblname = 'fds_order_items';
        $wp_track_table = $table_prefix . "$tblname";
        
        if($wpdb->get_var( "show tables like '$wp_track_table'" ) != $wp_track_table) {

            $sql = "CREATE TABLE `$wp_track_table` (
            order_item_id BIGINT UNSIGNED NOT NULL auto_increment,
            order_item_name TEXT NOT NULL,
            order_item_type varchar(200) NOT NULL DEFAULT '',
            order_id BIGINT UNSIGNED NOT NULL,
            PRIMARY KEY  (order_item_id),
            KEY order_id (order_id)
            ) $collate;";

            require_once( ABSPATH . '/wp-admin/includes/upgrade.php' );
            dbDelta($sql);
        }
        $tblname = 'fds_order_itemmeta';
        $wp_track_table = $table_prefix . "$tblname";
        
        if($wpdb->get_var( "show tables like '$wp_track_table'" ) != $wp_track_table) {

            $sql = "CREATE TABLE `$wp_track_table` (
            meta_id BIGINT UNSIGNED NOT NULL auto_increment,
            order_item_id BIGINT UNSIGNED NOT NULL,
            meta_key varchar(255) default NULL,
            meta_value longtext NULL,
            PRIMARY KEY  (meta_id),
            KEY order_item_id (order_item_id),
            KEY meta_key (meta_key(32))
            ) $collate;";

            require_once( ABSPATH . '/wp-admin/includes/upgrade.php' );
            dbDelta($sql);
        }
        

        $tblname = 'fds_locations';
        $wp_track_table = $table_prefix . "$tblname";

        #Check to see if the table exists already, if not, then create it

        if($wpdb->get_var( "show tables like '$wp_track_table'" ) != $wp_track_table)
        {

            $sql = "CREATE TABLE `". $wp_track_table . "` ( ";
            $sql .= "  `id` BIGINT UNSIGNED NOT NULL auto_increment, ";
            $sql .= "  `post_id`  BIGINT UNSIGNED NOT NULL, ";
            $sql .= "  `post_type` varchar(20) NULL DEFAULT 'customers', ";
            $sql .= "  `lat`  varchar(20)   NULL, ";
            $sql .= "  `lng`  varchar(20)   NULL, ";
            $sql .= "  `city`  varchar(150)   NULL, ";
            $sql .= "  `state`  varchar(150)   NULL, ";
            $sql .= "  `country`  varchar(150)   NULL, ";
            $sql .= "  `zip_code`  varchar(20)   NULL, ";
            $sql .= "  `detail`  longtext    NULL, ";           
            $sql .= "   PRIMARY KEY `id` (`id`), ";
            $sql .= "   KEY `post_id` (`post_id`), "; 
            $sql .= "   KEY `post_type` (`post_type`) "; 
            $sql .= ") $collate; ";

            require_once( ABSPATH . '/wp-admin/includes/upgrade.php' );
            dbDelta($sql);
        }
       
    }
    
}
