<?php

namespace FoodSearch;
use FoodSearch\User_Locations;
use FoodSearch\Common_Functions;
use FoodSearch\User_Forms\Common_Functions as User_Common_Funcs;


class user_orders {

    public function __construct() {
        add_action('admin_enqueue_scripts', array($this, 'admin_style_scripts'));
        add_action('rest_api_init', [$this, 'register_api'], 5);
        
        add_action('init', array($this, 'order_update'), 1);
        
        add_shortcode('fds_checkout', array($this, 'checkout_shortcode'));
        
        add_action('wp', array($this, 'order_detail_set_template'));
        
        add_filter('foodsearch_user_dash_shortcode_html', [$this, 'order_thankyou_html']);
    }

    public function register_api() {

        register_rest_route('wp/v1', 'user-ordercart-submit-act', array(
            'methods' => 'POST',
            'callback' => [$this, 'ordercart_submit_action'],
           'permission_callback' =>  'admin_permissions_check',
        ));
        register_rest_route('wp/v1', 'user-order-checkout-submit', array(
            'methods' => 'POST',
            'callback' => [$this, 'ordercart_checkout'],
           'permission_callback' =>  'admin_permissions_check',
        ));
        register_rest_route('wp/v1', 'customer-order-pdf-print', array(
            'methods' => 'GET',
            'callback' => array($this, 'pdfPrint'),
            'permission_callback' =>  'admin_permissions_check',
        )); 
    }
    
    public function admin_style_scripts() {
        if (isset($_GET['page']) && $_GET['page'] == 'fds_orders') {
            //
        }
    }
    public function pdfPrint(){
        $id = $_GET['id'];
        //echo plugin_dir_path(dirname(dirname(__FILE__))) . 'modules/invoice/pdf-template/invoice-template.php';
        require plugin_dir_path(dirname(dirname(__FILE__))) . 'modules/invoice/pdf-template/invoice-template.php';
        
        invoicePrint($id);
    }
    
    public function to_check_nonce() {
        if (defined("WP_CACHE")) {
            return false;
        }
    }
    
    public function ordercart_submit_action() {
        global $foodsearch_plugin_settings;
         
        if ($this->to_check_nonce()) {
            if (!isset($_POST['_nonce']) || !wp_verify_nonce($_POST['_nonce'], 'cart_to_order')) {
                $responsedata = array('error' => '1', 'url' => '', 'msg' => 'Session token has expired, please reload the page and try again.');
                wp_send_json($responsedata);
            }
        }
        
        $chekout_page = isset($foodsearch_plugin_settings['payment_settings']['checkout_page']) ? $foodsearch_plugin_settings['payment_settings']['checkout_page'] : '';
        
        if (isset($_POST['order_type'])) {
            $order_type = $_POST['order_type'];
            if ($order_type == '2') {
                $order_type = 'take_away';
            } else {
                $order_type = 'delivery';
            }
            $_SESSION['foodsearch_order_type'] = $order_type;
        }
        
        $chekout_page_id = foodsearch__get_post_id($chekout_page);
        $url = get_permalink($chekout_page_id);
        
        wp_send_json(array('error' => '0', 'url' => $url));
    }
    
    public function checkout_shortcode($atts) {
        global $foodsearch_plugin_settings;
        
        wp_enqueue_script('foodsearch-restaurant-cart');
        
        $cart_items = isset($_SESSION['cartitems']) ? $_SESSION['cartitems'] : '';
        
        ob_start();

        if (!empty($cart_items)) {
            $restaurant_id = $_SESSION['restaurant'];
            $order_type = isset($_SESSION['foodsearch_order_type'])?$_SESSION['foodsearch_order_type']:'delivery';
            $user_id = 0;
            $user_fname = '';
            $user_lname = '';
            $email_address = '';
            $phone_number = '';
            $user_address = '';

            $post_obj_id = 0;
            if (is_user_logged_in()) {
                $user_id = get_current_user_id();
                $get_user_obj = get_user_by('id', $user_id);
                $user_fname = isset($get_user_obj->first_name) ? $get_user_obj->first_name : '';
                $user_lname = isset($get_user_obj->last_name) ? $get_user_obj->last_name : '';
                $email_address = isset($get_user_obj->user_email) ? $get_user_obj->user_email : '';

                $user_type = Common_Functions::user_type($user_id);

                if ($user_type == 'restaurant') {
                    $post_obj_id =  Common_Functions::user_restaurant_id($user_id);
                    $phone_number = get_post_meta($restaurant_id, 'foodsearch_contact_number', true);
                } else {
                    $post_obj_id = $customer_id = Common_Functions::user_customer_id($user_id);
                    $phone_number = get_post_meta($customer_id, 'foodsearch_contact_number', true);
                }

            }
            $loc_obj = new User_Locations;
            $userform_common_funcs = new User_Common_Funcs;
            ?>
            <div class="fds-checkout-maincon">
                <form id="fds-order-checkout-form" method="post">
                    <div class="fds-loader-holder" style="display: none;"></div>
                    <div class="fds-checkout-userdata-con">
                        <div class="fds-checkout-addres-wrap">
                            <?php
                            $loc_atts = array(
                                'place' => 'checkout'
                            );
                            $loc_obj->add_locations($user_id, $post_obj_id, $loc_atts);
                            ?>
                        </div>
                        <div class="fds-checkout-fields-wrap">
                            <div class="fds-user-formpart">
                                <input type="hidden" name="restaurant_id" value="<?php echo ($restaurant_id) ?>">
                                <input type="hidden" name="n_id" value="<?php echo ($user_id) ?>">
                                <div class="fds-form-field">
                                    <div class="label_wrap"><label class="fds-input-label"><?php esc_html_e('first name *', 'wp-foodsearch'); ?></label></div>
                                    <input type="text" name="first_name" class="fds-input-style" required="" value="<?php echo ($user_fname) ?>">
                                </div>
                                <div class="fds-form-field">
                                    <div class="label_wrap"><label class="fds-input-label"><?php esc_html_e('last name *', 'wp-foodsearch'); ?></label></div>
                                    <input type="text" name="last_name" class="fds-input-style" required="" value="<?php echo ($user_lname) ?>">
                                </div>
                                <div class="fds-form-field">
                                    <div class="label_wrap"><label class="fds-input-label"><?php esc_html_e('email *', 'wp-foodsearch'); ?></label></div>
                                    <input type="email" name="email" class="fds-input-style" required="" value="<?php echo ($email_address) ?>">
                                </div>
                                <div class="fds-form-field">
                                    <div class="label_wrap"><label class="fds-input-label"><?php esc_html_e('phone *', 'wp-foodsearch'); ?></label></div>
                                    <input type="text" name="phone_number" class="fds-input-style" required="" value="<?php echo ($phone_number) ?>">
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="fds-checkout-cart-con">
                        <div class="fds-user-formpart checkout-cart-summary">
                            <div class="fds-formpart-hding"><strong><?php esc_html_e('cart summary', 'wp-foodsearch'); ?></strong></div>
                            <div class="fds-cart-itms">
                                <?php
                                $order_vat_switch = isset($foodsearch_plugin_settings['payment_settings']['order_vat_tax']) ? $foodsearch_plugin_settings['payment_settings']['order_vat_tax'] : '';
                                $order_vat_percentage = isset($foodsearch_plugin_settings['payment_settings']['vat_tax_amount']) ? $foodsearch_plugin_settings['payment_settings']['vat_tax_amount'] : '';

                                $tprice = 0;
                                $content = '';
                                foreach ($cart_items as $keys => $item) {
                                    $variation = '';
                                    $price = 0;
                                    if (isset($item['variation'])) {
                                        $variation = ' (' . $item['variation']['name'] . ')';
                                        $price = $item['variation']['price'];
                                    } else {
                                        $price = $item['basicprice'];
                                    }
                                    $qty = $item['qty'];
                                   
                                    $content .= '
                                    <ul class="fds-baskit-cart-list fds-options-wrap">
                                    <li class="fds-cartsum-menuitem fds-list-item"><a class="sumry-menuitem fds-link">' . foodsearch_menuItemNameByID($item['id']) . $variation . ' X '.$qty.'</a> <span>' . Common_Functions::get_formatted_price($price) . '</span></li>';
                                    if (isset($item['extras'])) {
                                        foreach ($item['extras'] as $key => $extras) {
                                            foreach ($extras as $k => $extra) {
                                                $content .= '<li class="fds-cartsum-menuextra fds-list-item"><a class="fds-link">' . ucfirst(str_replace('_', ' ', $key)) . ': ' . $extra['name'] . '</a>
                                                            <small>' . Common_Functions::get_formatted_price($extra['price']) . '</small>
                                                        </li>';
                                                $price += (int)$extra['price'];
                                            }
                                        }
                                    }
                                    $content .= '</ul>';
                                    $tprice += $qty*$price;
                                }
                                echo ($content);
                                
                                $net_total = $tprice;
                                ?>
                            </div>
                            <div class="fds-subtotal-con">
                                <div class="subtotal-itm-con">
                                    <strong><?php esc_html_e('subtotal', 'wp-foodsearch'); ?></strong>
                                    <span><?php echo (Common_Functions::get_formatted_price($tprice)) ?></span>
                                </div>
                                <?php                               
                               $order_process_type = get_post_meta($restaurant_id, 'foodsearch_order_process_type', true);
                               $delivery_charges = get_post_meta($restaurant_id, 'foodsearch_delivery_fee', true);
                                if ($delivery_charges > 0 && ($order_process_type == 'delivery' || $order_process_type == 'both') && $order_type != 'take_away') {
                                    $net_total += $delivery_charges;
                                    ?>
                                    <div class="subtotal-itm-con">
                                        <strong><?php esc_html_e('delivery fee', 'wp-foodsearch'); ?></strong>
                                        <span><?php echo (Common_Functions::get_formatted_price($delivery_charges)) ?></span>
                                    </div>
                                    <?php
                                }
                                $total_vat_amount = 0;
                                if ($order_vat_switch == 'on' && $order_vat_percentage > 0 && $tprice > 0 && !(isset($foodsearch_plugin_settings['payment_settings']['wc_cart_active']) && $foodsearch_plugin_settings['payment_settings']['wc_cart_active']=='on' &&  class_exists( 'WooCommerce' ))) {
                                    $total_vat_amount = $net_total * ($order_vat_percentage/100);
                                    $net_total += $total_vat_amount;
                                }
                                else{
                                    $order_vat_switch = 'off';
                                }
                                if ($order_vat_switch == 'on') {
                                    ?>
                                    <div class="subtotal-itm-con">
                                        <strong><?php printf(esc_html__('vat (%s)', 'wp-foodsearch'), $order_vat_percentage . '%'); ?></strong>
                                        <span><?php echo (Common_Functions::get_formatted_price($total_vat_amount)) ?></span>
                                    </div>
                                    <?php
                                }
                                ?>
                            </div>
                            <div class="fds-carttotal-con">
                                <strong><?php esc_html_e('total', 'wp-foodsearch'); ?></strong>
                                <span><?php echo (Common_Functions::get_formatted_price($net_total)) ?></span>
                            </div>
                        </div>
                        <div class="fds-user-formpart payment-methods-con">
                            <div class="fds-formpart-hding"><strong><?php esc_html_e('payment method', 'wp-foodsearch'); ?></strong></div>
                            <div class="fds-paymethod-field">
                                <div class="fds-radio-itm">
                                    <label for="cod-payment-method">
                                        <input id="cod-payment-method" type="radio" checked="" name="payment_method" value="cod">
                                        <div class="img-labl-con">
                                            <span class="fds-itm-label"><img src="<?php echo foodsearch_plugin_get_url('assets/images/payment-cash.png') ?>" alt="<?php esc_html_e('cash on delivery', 'wp-foodsearch'); ?>"> <?php esc_html_e('cash on delivery', 'wp-foodsearch'); ?></span>
                                            <i class="fds-icon fds-arrow-short"></i>
                                        </div>
                                    </label>
                                </div>
                            </div>
                        </div>
                        <div class="fds-placeorder-con fds-btn fds-large-btn">
                            <?php
                            wp_nonce_field('checkout_place_order', '_nonce');
                            ?>
                            <button type="submit" class="fds-chckout-order-btn fds-update-anything-action fds-has-bg"><?php esc_html_e('place order', 'wp-foodsearch') ?></button>
                        </div>
                        <?php $userform_common_funcs->form_submit_terms('checkout') ?>
                    </div>
                </form>
            </div>
            <?php
        } else {
            ?>
            <p><?php esc_html_e('your cart is empty.', 'wp-foodsearch') ?></p>
            <?php
        }

        $html = ob_get_clean();
        
        return $html;
    }
    
    public function ordercart_checkout() {
        
        if ($this->to_check_nonce()) {
            if (!isset($_POST['_nonce']) || !wp_verify_nonce($_POST['_nonce'], 'checkout_place_order')) {
                $responsedata = array('error' => '1', 'msg' => 'Session token has expired, please reload the page and try again.');
                wp_send_json($responsedata);
            }
        }
        
        if (!isset($_POST['fds_loc_address']) || (isset($_POST['fds_loc_address']) && $_POST['fds_loc_address'] == '')) {
            $responsedata = array('error' => '1', 'msg' => 'Please add full address.');
            wp_send_json($responsedata);
        }
        
        $first_name = $last_name = $user_email = $phone_number = '';
        
        if (isset($_POST['first_name']) && $_POST['first_name'] != '') {
            $first_name = foodsearch_esc_html($_POST['first_name']);
        }
        if (isset($_POST['last_name']) && $_POST['last_name'] != '') {
            $last_name = foodsearch_esc_html($_POST['last_name']);
        }
        if (isset($_POST['email']) && $_POST['email'] != '') {
            $user_email = foodsearch_esc_html($_POST['email']);
        }
        if (isset($_POST['phone_number']) && $_POST['phone_number'] != '') {
            $phone_number = foodsearch_esc_html($_POST['phone_number']);
        }
        if ($first_name == '' || $last_name == '' || $user_email == '' || $phone_number == '') {
            $responsedata = array('error' => '1', 'msg' => 'Please fill all required fields.');
            wp_send_json($responsedata);
        }
        
        if (isset($_SESSION['cartitems']) && !empty($_SESSION['cartitems'])) {
            
            global $foodsearch_plugin_settings;
            
            $cart_detail = $_SESSION['cartitems'];
            $order_detail = array(
                'post_data' => $_POST,
                'cart' => $cart_detail,
            );
            
            $order_id = $this->create_order($order_detail);
            
            $cookie_name = 'foodsearch_customer_created_order_id';
            $cookie_value = $order_id;
            setcookie($cookie_name, "", time() - 86400);
            setcookie($cookie_name, $cookie_value, time() + (86400 * 30 * 30), "/");
            
            $dashboard_page = isset($foodsearch_plugin_settings['dashboard_settings']['dashboard_page']) ? $foodsearch_plugin_settings['dashboard_settings']['dashboard_page'] : '';
            $dashboard_page_id = $dashboard_page != '' ? foodsearch__get_post_id($dashboard_page) : '';
            $dashboard_page_url = get_permalink($dashboard_page_id);
            
            $redirect_url = add_query_arg(array('order_tab' => 'detail', 'order_id' => $order_id), $dashboard_page_url);
            
            wp_send_json(array('error' => '0', 'redirect' => $redirect_url, 'msg' => esc_html__('order placed successfully.', 'wp-foodsearch')));
        }
        
        wp_send_json(array('error' => '1', 'msg' => esc_html__('your cart is empty.', 'wp-foodsearch')));
    }
    
    public function save_order_meta($order_id, $meta_key, $meta_value) {
        
        global $wpdb, $table_prefix;

        $data = array();
        $data['order_id'] = $order_id;
        $data['meta_key'] = $meta_key;
        $data['meta_value'] = $meta_value;

        $table_name = $table_prefix . 'fds_order_meta';
        $meta_query = "SELECT order_meta_id FROM $table_name WHERE order_id=$order_id AND meta_key='$meta_key'";
        $meta_id = $wpdb->get_col($meta_query);
        if (isset($meta_id[0])) {

            $meta_row_id = $meta_id[0];

            $where = array('order_meta_id' => $meta_row_id);
            $wpdb->update($table_name, $data, $where);
            
            $order_meta_id = $meta_row_id;
        } else {

            $wpdb->insert($table_name, $data);

            $order_meta_id = $wpdb->insert_id;
        }
        
        return $order_meta_id;
    }
    
    private function insert_order_item($item_title, $item_type, $order_id) {
        
        global $wpdb, $table_prefix;

        $data = array();
        $data['order_item_name'] = $item_title;
        $data['order_item_type'] = $item_type;
        $data['order_id'] = $order_id;

        $table_name = $table_prefix . 'fds_order_items';
        $wpdb->insert($table_name, $data);
        
        $order_item_id = $wpdb->insert_id;
        
        return $order_item_id;
    }
    
    private function insert_order_item_meta($order_item_id, $meta_key, $meta_value) {
        
        global $wpdb, $table_prefix;

        $data = array();
        $data['order_item_id'] = $order_item_id;
        $data['meta_key'] = $meta_key;
        $data['meta_value'] = $meta_value;

        $table_name = $table_prefix . 'fds_order_itemmeta';
        $wpdb->insert($table_name, $data);
        
        $order_itemmeta_id = $wpdb->insert_id;
        
        return $order_itemmeta_id;
    }
    
    public static function order_paymethod_name($order_detail) {
        $method = esc_html__('cash on delivery', 'wp-foodsearch');
        
        return $method;
    }

    public function create_order($order_detail) {
        global $table_prefix, $wpdb, $foodsearch_plugin_settings;
        
        $current_time = current_time('timestamp');
        
        $post_data = $order_detail['post_data'];
        
        $cart_detail = $order_detail['cart'];
        
        $restaurant_id = $post_data['restaurant_id'];
        $user_id = $post_data['n_id'];
        
        //echo '<pre>'.print_r($post_data,true).'</pre>';
        $payment_method = isset($post_data['payment_method']) ? $post_data['payment_method'] : '';
        
        $billing_first_name = isset($post_data['first_name']) ? foodsearch_esc_html($post_data['first_name']) : '';
        $billing_last_name = isset($post_data['last_name']) ? foodsearch_esc_html($post_data['last_name']) : '';
        $billing_email = isset($post_data['email']) ? foodsearch_esc_html($post_data['email']) : '';
        $billing_phone = isset($post_data['phone_number']) ? foodsearch_esc_html($post_data['phone_number']) : '';
        $billing_address = isset($post_data['fds_loc_address']) ? foodsearch_esc_html($post_data['fds_loc_address']) : '';
        $address_floor_unit = isset($post_data['fds_address_floor']) ? foodsearch_esc_html($post_data['fds_address_floor']) : '';
        $address_lat = isset($post_data['fds_location_lat']) ? foodsearch_esc_html($post_data['fds_location_lat']) : '';
        $address_lng = isset($post_data['fds_location_lng']) ? foodsearch_esc_html($post_data['fds_location_lng']) : '';
        $address_rider_notes = isset($post_data['fds_address_notes']) ? foodsearch_esc_html($post_data['fds_address_notes']) : '';
        $address_label = isset($post_data['fds_address_label']) ? foodsearch_esc_html($post_data['fds_address_label']) : '';
        $address_label_other = isset($post_data['fds_address_label_other']) ? foodsearch_esc_html($post_data['fds_address_label_other']) : '';
        
        if ($user_id > 0) {
            // add user location
            $fds_loc_id = rand(100000, 999999);
            if (isset($post_data['fds_loc_id']) && $post_data['fds_loc_id'] > 0) {
                $fds_loc_id = $post_data['fds_loc_id'];
            }
            $loc_obj = new User_Locations;
            
            $loc_item = array(
                'address' => $billing_address,
                'floor_unit' => $address_floor_unit,
                'lat' => $address_lat,
                'lng' => $address_lng,
                'map_zoom' => '7',
                'notes' => $address_rider_notes,
                'label' => $address_label,
                'label_other' => $address_label_other,
            );

            $loc_obj->add_adress_to_list($user_id, $loc_item,$fds_loc_id);
        }
        
        if ($billing_first_name != '') {
            $biling_full_name = $billing_first_name;
            if ($billing_last_name != '') {
                $biling_full_name .= ' ' . $billing_last_name;
            }
        }
        
        $date_created = current_time('Y-m-d H:i:s');
        $date_created_gmt = current_time('Y-m-d H:i:s', 1);
        
        $total_sales = 0;
        $net_total = 0;
        
        foreach ($cart_detail as $menu_itm) {
            $item_price = isset($menu_itm['basicprice']) ? $menu_itm['basicprice'] : 0;
            if (isset($menu_itm['variation']['price'])) {
                $item_price = $menu_itm['variation']['price'];
            }
            $total_sales += ($item_price > 0 ? $item_price : 0)*$menu_itm['qty'];
            
            if (isset($menu_itm['extras'])) {
                foreach ($menu_itm['extras'] as $choice_groups) {
                    foreach ($choice_groups as $choice_itm) {
                        $extra_price = isset($choice_itm['price']) ? $choice_itm['price'] : '';
                        $total_sales += $extra_price > 0 ? $extra_price : 0;
                    }
                }
            }
        }
        $net_total = $total_sales;
        
        $order_status = 'pending';
        
        // order type
        $order_type = 'delivery';
        if (isset($_SESSION['foodsearch_order_type'])) {
            $order_type = $_SESSION['foodsearch_order_type'];
        }
        
        // delivery fee
        $order_process_type = get_post_meta($restaurant_id, 'foodsearch_order_process_type', true);
        $order_delivery_fee = 0;
        $delivery_fee = get_post_meta($restaurant_id, 'foodsearch_delivery_fee', true);
        if ($delivery_fee > 0 && ($order_process_type == 'delivery' || $order_process_type == 'both') && $order_type != 'take_away') {
            $order_delivery_fee = $delivery_fee;
            $net_total += $delivery_fee;
        }
        
        // vat tax amount
        $vat_tax_total = 0;
        $order_vat_switch = isset($foodsearch_plugin_settings['payment_settings']['order_vat_tax']) ? $foodsearch_plugin_settings['payment_settings']['order_vat_tax'] : '';
        $order_vat_percentage = isset($foodsearch_plugin_settings['payment_settings']['vat_tax_amount']) ? $foodsearch_plugin_settings['payment_settings']['vat_tax_amount'] : '';
        if ($order_vat_switch == 'on' && $order_vat_percentage > 0) {
            $order_vat_amount = $net_total * ($order_vat_percentage/100);
            $net_total += $order_vat_amount;
            $vat_tax_total = $order_vat_amount;
        }
        
        // insert order
        $data = array();
        $data['date_created'] = $date_created;
        $data['date_created_gmt'] = $date_created_gmt;
        $data['num_items_sold'] = count($cart_detail);
        $data['total_sales'] = $total_sales;
        $data['net_total'] = $net_total;
        $data['status'] = $order_status;
        $data['customer_id'] = $user_id;
        if ($vat_tax_total > 0) {
            $data['tax_total'] = $vat_tax_total;
        }
        if ($order_delivery_fee > 0) {
            $data['shipping_total'] = $order_delivery_fee;
        }
        
        $table_name = $table_prefix . 'fds_orders';
        $wpdb->insert($table_name, $data);
        $order_id = $wpdb->insert_id;
        
        // update restaurant orders counter
        foodsearch_update_orders_counter($restaurant_id);
        
        // insert order meta (billing info)
        $this->save_order_meta($order_id, 'billing_first_name', $billing_first_name);
        $this->save_order_meta($order_id, 'billing_last_name', $billing_last_name);
        $this->save_order_meta($order_id, 'billing_full_name', $biling_full_name);
        $this->save_order_meta($order_id, 'billing_email', $billing_email);
        $this->save_order_meta($order_id, 'billing_phone', $billing_phone);
        $this->save_order_meta($order_id, 'billing_address', $billing_address);
        $this->save_order_meta($order_id, 'address_floor_unit', $address_floor_unit);
        $this->save_order_meta($order_id, 'address_lat', $address_lat);
        $this->save_order_meta($order_id, 'address_lng', $address_lng);
        $this->save_order_meta($order_id, 'address_rider_notes', $address_rider_notes);
        // insert order meta (pay method)
        $this->save_order_meta($order_id, 'payment_method', $payment_method);
        // insert order meta (order type)
        $this->save_order_meta($order_id, 'order_type', $order_type);
        // insert order meta (restaurant id)
        $this->save_order_meta($order_id, 'restaurant_id', $restaurant_id);
        // insert order meta (status history)
        $status_history = array(
            array(
                'status' => $order_status,
                'time' => $current_time,
                'user' => $user_id
            )
        );
        $status_history = maybe_serialize($status_history);
        $this->save_order_meta($order_id, 'status_history', $status_history);
        
        foreach ($cart_detail as $menu_itm) {
            
            $menu_id = $menu_itm['id'];
            $item_price = isset($menu_itm['basicprice']) ? $menu_itm['basicprice'] : 0;
            if (isset($menu_itm['variation']['price'])) {
                $item_price = $menu_itm['variation']['price'];
            }
           // $item_price =  $item_price* $menu_itm['qty'];   
            
            // insert order product
            $data = array();
            $data['order_id'] = $order_id;
            $data['product_id'] = $menu_id;
            $data['variation_id'] = 0;
            $data['customer_id'] = $user_id;
            $data['date_created'] = $date_created;
            $data['product_qty'] = 1;

            $table_name = $table_prefix . 'fds_order_products';
            
            $wpdb->insert($table_name, $data);
            
            // insert order item
            $item_title = foodsearch_menuItemNameByID($menu_id);
            if (isset($menu_itm['variation']['name'])) {
                $item_title .= ' (' . $menu_itm['variation']['name'] . ')';
            }
            $order_item_id = $this->insert_order_item($item_title, 'menu_item', $order_id);
            
            // insert order item meta (menu id)
            $this->insert_order_item_meta($order_item_id, 'menu_id', $menu_id);
            // insert order item meta (quantity)
            $this->insert_order_item_meta($order_item_id, 'qty', $menu_itm['qty']);
            // insert order item meta (subtotal amount)
            $this->insert_order_item_meta($order_item_id, 'subtotal', $item_price);
            // insert order item meta (total amount)
            $this->insert_order_item_meta($order_item_id, 'total', $item_price);
            
            if (isset($menu_itm['extras'])) {
                foreach ($menu_itm['extras'] as $choice_groups) {
                    foreach ($choice_groups as $choice_itm) {
                        $extra_itm_id = isset($choice_itm['id']) ? $choice_itm['id'] : '';
                        $extra_label = isset($choice_itm['name']) ? $choice_itm['name'] : '';
                        $extra_price = isset($choice_itm['price']) ? $choice_itm['price'] : '0';
                       // $extra_price = $menu_itm['qty']*$extra_price;
                        // insert order item
                        $order_item_id = $this->insert_order_item($extra_label, 'menu_item_extra', $order_id);
                        
                        // insert order item meta (menu id)
                        $this->insert_order_item_meta($order_item_id, 'menu_id', $extra_itm_id);
                        // insert order item meta (quantity)
                        $this->insert_order_item_meta($order_item_id, 'qty', $menu_itm['qty']);
                        // insert order item meta (subtotal amount)
                        $this->insert_order_item_meta($order_item_id, 'subtotal', $extra_price);
                        // insert order item meta (total amount)
                        $this->insert_order_item_meta($order_item_id, 'total', $extra_price);
                    }
                }
            }
        }
        
        // new order noification
        do_action('foodsearch_notify_to_restaurant_new_order', $order_id);
        do_action('foodsearch_notify_to_customer_new_order', $order_id);
        
        unset($_SESSION['cartitems']);
        unset($_SESSION['foodsearch_order_type']);
        
        return $order_id;
    }
    
    public static function get_order_meta($order_id) {
        global $wpdb, $table_prefix;
        
        $result = false;
        
        if ($order_id > 0) {
            $table_name = $table_prefix . 'fds_order_meta';
            $result = $wpdb->get_results("SELECT * FROM $table_name WHERE order_id=$order_id", 'ARRAY_A');
        }
        return $result;
    }
    
    public static function order_meta_value($order_meta, $meta_key) {
        
        $meta_value = false;
        if ($meta_key != '' && !empty($order_meta)) {
            foreach ($order_meta as $meta_item) {
                if (isset($meta_item['meta_key']) && $meta_item['meta_key'] == $meta_key) {
                    $meta_value = $meta_item['meta_value'];
                    break;
                }
            }
        }
        return $meta_value;
    }
    
    public function get_order_item_meta($item_id) {
        global $wpdb, $table_prefix;
        
        $result = false;
        
        if ($item_id > 0) {
            $table_name = $table_prefix . 'fds_order_itemmeta';
            $result = $wpdb->get_results("SELECT * FROM $table_name WHERE order_item_id=$item_id", 'ARRAY_A');
        }
        return $result;
    }
    
    public function order_item_meta_value($item_meta, $meta_key) {
        
        $meta_value = false;
        if ($meta_key != '' && !empty($item_meta)) {
            foreach ($item_meta as $meta_item) {
                if (isset($meta_item['meta_key']) && $meta_item['meta_key'] == $meta_key) {
                    $meta_value = $meta_item['meta_value'];
                    break;
                }
            }
        }
        return $meta_value;
    }
    
    public function get_order_items($order_id, $type) {
        global $wpdb, $table_prefix;
        
        $result = false;
        
        if ($order_id > 0) {
            $table_name = $table_prefix . 'fds_order_items';
            
            if ($type == 'menu_items') {
                $where = " AND (order_item_type='menu_item' OR order_item_type='menu_item_extra')";
            } else {
                $where = " AND order_item_type='$type'";
            }
            $result = $wpdb->get_results("SELECT * FROM $table_name WHERE order_id={$order_id}{$where} ORDER BY order_item_id ASC", 'ARRAY_A');
        }
        return $result;
    }
    
    public static function get_order_statuses() {
        $order_statuses = array(
            'pending' => esc_html__('pending', 'wp-foodsearch'),
            'processing' => esc_html__('processing', 'wp-foodsearch'),
            'on-hold' => esc_html__('on hold', 'wp-foodsearch'),
            'completed' => esc_html__('completed', 'wp-foodsearch'),
            'cancelled' => esc_html__('cancelled', 'wp-foodsearch'),
            'refunded' => esc_html__('refunded', 'wp-foodsearch'),
            'failed' => esc_html__('failed', 'wp-foodsearch'),
            'trash' => esc_html__('trash', 'wp-foodsearch'),
        );
        
        return apply_filters('foodsearch_orders_statuses_list', $order_statuses);
    }
    
    public static function get_order_colors() {
        global $foodsearch_plugin_settings;
        
        $option_settings = isset($foodsearch_plugin_settings['general_options']) ? $foodsearch_plugin_settings['general_options'] : '';
        
        $order_colors = array(
            'completed' => isset($option_settings['completed_status_color']) ? $option_settings['completed_status_color'] : '#3d9a6e',
            'pending' => isset($option_settings['pending_status_color']) ? $option_settings['pending_status_color'] : '#f0ad4e',
            'processing' => isset($option_settings['processing_status_color']) ? $option_settings['processing_status_color'] : '#c8d7e1',
            'on-hold' => isset($option_settings['on-hold_status_color']) ? $option_settings['on-hold_status_color'] : '#f8dda7',
            'cancelled' => isset($option_settings['cancelled_status_color']) ? $option_settings['cancelled_status_color'] : '#cbcbcb',
            'refunded' => isset($option_settings['refunded_status_color']) ? $option_settings['refunded_status_color'] : '#d7cad2',
            'failed' => isset($option_settings['failed_status_color']) ? $option_settings['failed_status_color'] : '#d9534f',
            'trash' => isset($option_settings['trash_status_color']) ? $option_settings['trash_status_color'] : '#d9534f',
        );
        
        return apply_filters('foodsearch_orders_status_colors_list', $order_colors);
    }
    
    public function get_order_status_tclr($status = 'failed', $type = 'label') {
        $order_statuses = self::get_order_statuses();
        $order_colors = self::get_order_colors();
        
        if ($type == 'color' && isset($order_colors[$status])) {
            return $order_colors[$status];
        } else if (isset($order_statuses[$status])) {
            return $order_statuses[$status];
        }
    }
    
    public function get_order_paymethods() {
        $methods = array(
            'cod' => esc_html__('cash on delivery', 'wp-foodsearch'),
        );
        
        return apply_filters('foodsearch_orders_pay_methods_list', $methods);
    }
    
    public function get_order_paymethod_label($pay_method) {
        $methods = $this->get_order_paymethods();
        
        if (isset($methods[$pay_method])) {
            return $methods[$pay_method];
        }
    }
    
    public function get_restaurant_orders_total_count($restaurant_id, $get_data) {
        global $wpdb, $table_prefix;
        
        $get_keyword = isset($get_data['filter_orders_keyword']) ? foodsearch_esc_html($get_data['filter_orders_keyword']) : '';
        $get_order_type = isset($get_data['filter_orders_type']) ? foodsearch_esc_html($get_data['filter_orders_type']) : '';
        $get_order_status = isset($get_data['filter_orders_status']) ? foodsearch_esc_html($get_data['filter_orders_status']) : '';
        $get_order_date = isset($get_data['filter_orders_date']) ? foodsearch_esc_html($get_data['filter_orders_date']) : '';
        
        $order_table = $table_prefix . 'fds_orders';
        $order_meta_table = $table_prefix . 'fds_order_meta';
        
        $sql = "SELECT COUNT(*) FROM $order_table as orders";
        $sql .= " LEFT JOIN $order_meta_table as order_meta ON (order_meta.order_id=orders.order_id)";

        if ($get_keyword != '') {
            $sql .= " LEFT JOIN $order_meta_table as order_meta1 ON (order_meta1.order_id=orders.order_id)";
            $sql .= " LEFT JOIN $order_meta_table as order_meta2 ON (order_meta2.order_id=orders.order_id)";
            $sql .= " LEFT JOIN $order_meta_table as order_meta3 ON (order_meta3.order_id=orders.order_id)";
        }
        if ($get_order_type != '') {
            $sql .= " LEFT JOIN $order_meta_table as order_meta2 ON (order_meta2.order_id=orders.order_id)";
        }
        $sql .= " WHERE order_meta.meta_key='restaurant_id' AND order_meta.meta_value=$restaurant_id";
        if ($get_keyword != '') {
            $sql .= " AND ("
                    . "(order_meta1.meta_key='billing_full_name' AND order_meta1.meta_value LIKE '%$get_keyword%')"
                    . " OR (order_meta2.meta_key='billing_first_name' AND order_meta2.meta_value LIKE '%$get_keyword%')"
                    . " OR (order_meta3.meta_key='billing_last_name' AND order_meta3.meta_value LIKE '%$get_keyword%')"
                    . " OR orders.order_id='$get_keyword'"
                    . ")";
        }
        if ($get_order_type != '') {
            $sql .= " AND order_meta2.meta_key='order_type' AND order_meta2.meta_value='$get_order_type'";
        }
        if ($get_order_status != '') {
            $sql .= " AND orders.status='$get_order_status'";
        }
        if ($get_order_date != '') {
            $sql .= " AND date_format(date(orders.date_created),'%d-%m-%Y')='$get_order_date'";
        }
        $order_count = $wpdb->get_var($sql);
        
        return $order_count;
    }
    
    public function get_restaurant_filtered_orders($restaurant_id, $get_data, $page_num = 0) {
        global $wpdb, $table_prefix;
        
        $offset = 0;
        $per_page = 20;
        if ($page_num > 1) {
            $offset = ($page_num - 1) * $per_page;
        }
        
        $get_keyword = isset($get_data['filter_orders_keyword']) ? foodsearch_esc_html($get_data['filter_orders_keyword']) : '';
        $get_order_type = isset($get_data['filter_orders_type']) ? foodsearch_esc_html($get_data['filter_orders_type']) : '';
        $get_order_status = isset($get_data['filter_orders_status']) ? foodsearch_esc_html($get_data['filter_orders_status']) : '';
        $get_order_date = isset($get_data['filter_orders_date']) ? foodsearch_esc_html($get_data['filter_orders_date']) : '';
        
        $order_table = $table_prefix . 'fds_orders';
        $order_meta_table = $table_prefix . 'fds_order_meta';
        
        $sql = "SELECT orders.* FROM $order_table as orders";
        $sql .= " LEFT JOIN $order_meta_table as order_meta ON (order_meta.order_id=orders.order_id)";

        if ($get_keyword != '') {
            $sql .= " LEFT JOIN $order_meta_table as order_meta1 ON (order_meta1.order_id=orders.order_id)";
            $sql .= " LEFT JOIN $order_meta_table as order_meta2 ON (order_meta2.order_id=orders.order_id)";
            $sql .= " LEFT JOIN $order_meta_table as order_meta3 ON (order_meta3.order_id=orders.order_id)";
        }
        if ($get_order_type != '') {
            $sql .= " LEFT JOIN $order_meta_table as order_meta2 ON (order_meta2.order_id=orders.order_id)";
        }
        $sql .= " WHERE order_meta.meta_key='restaurant_id' AND order_meta.meta_value=$restaurant_id";
        if ($get_keyword != '') {
            $sql .= " AND ("
                    . "(order_meta1.meta_key='billing_full_name' AND order_meta1.meta_value LIKE '%$get_keyword%')"
                    . " OR (order_meta2.meta_key='billing_first_name' AND order_meta2.meta_value LIKE '%$get_keyword%')"
                    . " OR (order_meta3.meta_key='billing_last_name' AND order_meta3.meta_value LIKE '%$get_keyword%')"
                    . " OR orders.order_id='$get_keyword'"
                    . ")";
        }
        if ($get_order_type != '') {
            $sql .= " AND order_meta2.meta_key='order_type' AND order_meta2.meta_value='$get_order_type'";
        }
        if ($get_order_status != '') {
            $sql .= " AND orders.status='$get_order_status'";
        }
        if ($get_order_date != '') {
            $sql .= " AND date_format(date(orders.date_created),'%d-%m-%Y')='$get_order_date'";
        }
        $sql .= " GROUP BY order_id ORDER BY orders.order_id DESC LIMIT 20 OFFSET $offset";
        
        $order_results = $wpdb->get_results($sql, 'ARRAY_A');
        
        return $order_results;
    }
    
    public function get_customer_orders_total_count($customer_id, $get_data) {
        global $wpdb, $table_prefix;
        
        $get_keyword = isset($get_data['filter_orders_keyword']) ? foodsearch_esc_html($get_data['filter_orders_keyword']) : '';
        $get_order_type = isset($get_data['filter_orders_type']) ? foodsearch_esc_html($get_data['filter_orders_type']) : '';
        $get_order_status = isset($get_data['filter_orders_status']) ? foodsearch_esc_html($get_data['filter_orders_status']) : '';
        $get_order_date = isset($get_data['filter_orders_date']) ? foodsearch_esc_html($get_data['filter_orders_date']) : '';
        
        $order_table = $table_prefix . 'fds_orders';
        $order_meta_table = $table_prefix . 'fds_order_meta';
        
        $sql = "SELECT COUNT(*) FROM $order_table as orders";
        if ($get_keyword != '') {
            
            // check/get similar restaurant ids
            $posts_sql = "SELECT ID FROM $wpdb->posts WHERE post_type='restaurants' AND post_title LIKE '%$get_keyword%'";
            $search_restaurants_ids = $wpdb->get_col($posts_sql);
            $search_restaurants_ids = !empty($search_restaurants_ids) ? $search_restaurants_ids : array(0);
            $search_restaurants_ids = implode(',', $search_restaurants_ids);
            //
            
            $sql .= " LEFT JOIN $order_meta_table as order_meta1 ON (order_meta1.order_id=orders.order_id)";
        }
        if ($get_order_type != '') {
            $sql .= " LEFT JOIN $order_meta_table as order_meta2 ON (order_meta2.order_id=orders.order_id)";
        }
        $sql .= " WHERE orders.customer_id=$customer_id";
        if ($get_keyword != '') {
            $sql .= " AND ((order_meta1.meta_key='restaurant_id' AND order_meta1.meta_value IN ($search_restaurants_ids)) OR orders.order_id='$get_keyword')";
        }
        if ($get_order_type != '') {
            $sql .= " AND order_meta2.meta_key='order_type' AND order_meta2.meta_value='$get_order_type'";
        }
        if ($get_order_status != '') {
            $sql .= " AND orders.status='$get_order_status'";
        }
        if ($get_order_date != '') {
            $sql .= " AND date_format(date(orders.date_created),'%d-%m-%Y')='$get_order_date'";
        }
        
        $order_count = $wpdb->get_var($sql);
        
        return $order_count;
    }
    
    public function get_customer_filtered_orders($customer_id, $get_data, $page_num = 0) {
        global $wpdb, $table_prefix;
        
        $offset = 0;
        $per_page = get_option( 'posts_per_page' );
        if ($page_num > 1) {
            $offset = ($page_num - 1) * $per_page;
        }
        
        $get_keyword = isset($get_data['filter_orders_keyword']) ? foodsearch_esc_html($get_data['filter_orders_keyword']) : '';
        $get_order_type = isset($get_data['filter_orders_type']) ? foodsearch_esc_html($get_data['filter_orders_type']) : '';
        $get_order_status = isset($get_data['filter_orders_status']) ? foodsearch_esc_html($get_data['filter_orders_status']) : '';
        $get_order_date = isset($get_data['filter_orders_date']) ? foodsearch_esc_html($get_data['filter_orders_date']) : '';
        
        $order_table = $table_prefix . 'fds_orders';
        $order_meta_table = $table_prefix . 'fds_order_meta';
        
        $sql = "SELECT orders.* FROM $order_table as orders";
        if ($get_keyword != '') {
            
            // check/get similar restaurant ids
            $posts_sql = "SELECT ID FROM $wpdb->posts WHERE post_type='restaurants' AND post_title LIKE '%$get_keyword%'";
            $search_restaurants_ids = $wpdb->get_col($posts_sql);
            $search_restaurants_ids = !empty($search_restaurants_ids) ? $search_restaurants_ids : array(0);
            $search_restaurants_ids = implode(',', $search_restaurants_ids);
            //
            
            $sql .= " LEFT JOIN $order_meta_table as order_meta1 ON (order_meta1.order_id=orders.order_id)";
        }
        if ($get_order_type != '') {
            $sql .= " LEFT JOIN $order_meta_table as order_meta2 ON (order_meta2.order_id=orders.order_id)";
        }
        $sql .= " WHERE orders.customer_id=$customer_id";
        if ($get_keyword != '') {
            $sql .= " AND ((order_meta1.meta_key='restaurant_id' AND order_meta1.meta_value IN ($search_restaurants_ids)) OR orders.order_id='$get_keyword')";
        }
        if ($get_order_type != '') {
            $sql .= " AND order_meta2.meta_key='order_type' AND order_meta2.meta_value='$get_order_type'";
        }
        if ($get_order_status != '') {
            $sql .= " AND orders.status='$get_order_status'";
        }
        if ($get_order_date != '') {
            $sql .= " AND date_format(date(orders.date_created),'%d-%m-%Y')='$get_order_date'";
        }
        $sql .= " GROUP BY order_id ORDER BY orders.order_id DESC LIMIT $per_page OFFSET $offset";
        
        $order_results = $wpdb->get_results($sql, 'ARRAY_A');
        
        return $order_results;
    }
    
    public static function get_order_by_id($order_id) {
        global $wpdb, $table_prefix;
        
        $order_table = $table_prefix . 'fds_orders';
        
        $sql = "SELECT * FROM $order_table";
        $sql .= " WHERE order_id=$order_id";
        
        $order_result = $wpdb->get_results($sql, 'ARRAY_A');
        
        return $order_result;
    }
    
    public function before_order_completed($order_id) {
        global $wpdb, $table_prefix;
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        
        $query = "SELECT status from $wp_track_table WHERE order_id=" . $order_id;
        
        $result = $wpdb->get_col($query);
        
        if (isset($result[0]) && $result[0] != 'completed') {
            do_action('foodsearch_notify_to_restaurant_complete_order', $order_id);
            do_action('foodsearch_notify_to_customer_complete_order', $order_id);
        }
    }
    
    public function before_order_pending($order_id) {
        global $wpdb, $table_prefix;
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        
        $query = "SELECT status from $wp_track_table WHERE order_id=" . $order_id;
        
        $result = $wpdb->get_col($query);
        
        if (isset($result[0]) && $result[0] != 'pending') {
            do_action('foodsearch_notify_to_restaurant_pending_order', $order_id);
            do_action('foodsearch_notify_to_customer_pending_order', $order_id);
        }
    }
    
    public function before_order_processing($order_id) {
        global $wpdb, $table_prefix;
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        
        $query = "SELECT status from $wp_track_table WHERE order_id=" . $order_id;
        
        $result = $wpdb->get_col($query);
        
        if (isset($result[0]) && $result[0] != 'processing') {
            do_action('foodsearch_notify_to_restaurant_processing_order', $order_id);
            do_action('foodsearch_notify_to_customer_processing_order', $order_id);
        }
    }
    
    public function before_order_on_hold($order_id) {
        global $wpdb, $table_prefix;
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        
        $query = "SELECT status from $wp_track_table WHERE order_id=" . $order_id;
        
        $result = $wpdb->get_col($query);
        
        if (isset($result[0]) && $result[0] != 'on-hold') {
            do_action('foodsearch_notify_to_restaurant_onhold_order', $order_id);
            do_action('foodsearch_notify_to_customer_onhold_order', $order_id);
        }
    }
    
    public function before_order_cancelled($order_id) {
        global $wpdb, $table_prefix;
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        
        $query = "SELECT status from $wp_track_table WHERE order_id=" . $order_id;
        
        $result = $wpdb->get_col($query);
        
        if (isset($result[0]) && $result[0] != 'cancelled') {
            do_action('foodsearch_notify_to_restaurant_cancelled_order', $order_id);
            do_action('foodsearch_notify_to_customer_cancelled_order', $order_id);
        }
    }
    
    public function before_order_refundedd($order_id) {
        global $wpdb, $table_prefix;
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        
        $query = "SELECT status from $wp_track_table WHERE order_id=" . $order_id;
        
        $result = $wpdb->get_col($query);
        
        if (isset($result[0]) && $result[0] != 'refundedd') {
            do_action('foodsearch_notify_to_restaurant_refunded_order', $order_id);
            do_action('foodsearch_notify_to_customer_refunded_order', $order_id);
        }
    }
    
    public function before_order_failed($order_id) {
        global $wpdb, $table_prefix;
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        
        $query = "SELECT status from $wp_track_table WHERE order_id=" . $order_id;
        
        $result = $wpdb->get_col($query);
        
        if (isset($result[0]) && $result[0] != 'failed') {
            do_action('foodsearch_notify_to_restaurant_failed_order', $order_id);
            do_action('foodsearch_notify_to_customer_failed_order', $order_id);
        }
    }
    
    public function order_status_history($order_id, $status, $user_id) {
        global $table_prefix, $wpdb;
        
        $current_time = current_time('timestamp');
        $table_name = $table_prefix . 'fds_orders';
        $order_result = $wpdb->get_row("SELECT * FROM $table_name WHERE order_id=$order_id", 'ARRAY_A');
        $order_current_status = isset($order_result['status']) ? $order_result['status'] : '';
        
        if ($order_current_status != '' && $status != '' && $status != $order_current_status) {
            $order_meta = self::get_order_meta($order_id);

            $order_status_histry = self::order_meta_value($order_meta, 'status_history');
            $order_status_histry = $order_status_histry != '' ? maybe_unserialize($order_status_histry) : '';
            $order_status_histry = !empty($order_status_histry) ? $order_status_histry : array();
            $item = array(
                'status' => $status,
                'time' => $current_time,
                'user' => $user_id
            );

            $order_status_histry[] = $item;

            $order_status_histry = maybe_serialize($order_status_histry);

            $this->save_order_meta($order_id, 'status_history', $order_status_histry);

            //
            $order_notes = self::order_meta_value($order_meta, 'status_notes');
            $order_notes = $order_notes != '' ? maybe_unserialize($order_notes) : '';
            $order_notes = !empty($order_notes) ? $order_notes : array();
            
            $current_status_labl = $this->get_order_status_tclr($order_current_status);
            $status_labl = $this->get_order_status_tclr($status);
            
            $note_text = sprintf(esc_html__('order status changed from %s to %s.', 'wp-foodsearch'), $current_status_labl, $status_labl);
            $item = array(
                'note' => $note_text,
                'time' => $current_time,
                'user' => $user_id
            );

            $order_notes[] = $item;

            $order_notes = maybe_serialize($order_notes);

            $this->save_order_meta($order_id, 'status_notes', $order_notes);
        }
    }
    
    public function order_get_last_status($order_id) {
        $order_meta = self::get_order_meta($order_id);

        $status = 'pending';
        $order_status_histry = self::order_meta_value($order_meta, 'status_history');
        $order_status_histry = $order_status_histry != '' ? maybe_unserialize($order_status_histry) : '';
        
        if (!empty($order_status_histry) && is_array($order_status_histry)) {
            $last_status_histry = end($order_status_histry);
            if (isset($last_status_histry['status'])) {
                $status = $last_status_histry['status'];
            }
        }
        
        return $status;
    }

    public function delete_record($id) {
        global $wpdb, $table_prefix;
        
        do_action('foodsearch_order_delete_trigger_before', $id);
        
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        $wpdb->delete($wp_track_table, ['order_id' => $id], ['%d']);
        
        $tblname = $table_prefix . 'fds_order_meta';
        $wpdb->delete($tblname, ['order_id' => $id], ['%d']);
        
        $tblname = $table_prefix . 'fds_order_products';
        $wpdb->delete($tblname, ['order_id' => $id], ['%d']);
        
        $tblname = $table_prefix . 'fds_order_items';
        $order_items = $wpdb->get_results("SELECT * FROM $tblname WHERE order_id=$id", 'ARRAY_A');
        if (!empty($order_items)) {
            foreach ($order_items as $order_item) {
                $order_item_id = $order_item['order_item_id'];
                $item_meta_table = $table_prefix . 'fds_order_itemmeta';
                $wpdb->delete($item_meta_table, ['order_item_id' => $order_item_id], ['%d']);
            }
        }
        $wpdb->delete($tblname, ['order_id' => $id], ['%d']);
        
        //
        do_action('foodsearch_order_delete_trigger', $id);
    }

    public function trash_record($id) {
        global $wpdb, $table_prefix;
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        $data = array('status' => 'trash');
        $where = array('order_id' => $id);
        $wpdb->update($wp_track_table, $data, $where);
        
        //
        do_action('foodsearch_order_trash_trigger', $id);
    }

    public function completed_record($id) {
        global $wpdb, $table_prefix;
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        $data = array('status' => 'completed');
        $where = array('order_id' => $id);
        
        $this->before_order_completed($id);
        $wpdb->update($wp_track_table, $data, $where);
        
        //
        do_action('foodsearch_order_completed_trigger', $id);
    }

    public function pending_record($id) {
        global $wpdb, $table_prefix;
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        $data = array('status' => 'pending');
        $where = array('order_id' => $id);
        
        $this->before_order_pending($id);
        $wpdb->update($wp_track_table, $data, $where);
        
        //
        do_action('foodsearch_order_pending_trigger', $id);
    }

    public function processing_record($id) {
        global $wpdb, $table_prefix;
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        $data = array('status' => 'processing');
        $where = array('order_id' => $id);
        
        $this->before_order_processing($id);
        $wpdb->update($wp_track_table, $data, $where);
        
        //
        do_action('foodsearch_order_processing_trigger', $id);
    }

    public function on_hold_record($id) {
        global $wpdb, $table_prefix;
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        $data = array('status' => 'on-hold');
        $where = array('order_id' => $id);
        
        $this->before_order_on_hold($id);
        $wpdb->update($wp_track_table, $data, $where);
        
        //
        do_action('foodsearch_order_on_hold_trigger', $id);
    }

    public function cancelled_record($id) {
        global $wpdb, $table_prefix;
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        $data = array('status' => 'cancelled');
        $where = array('order_id' => $id);
        
        $this->before_order_cancelled($id);
        $wpdb->update($wp_track_table, $data, $where);
        
        //
        do_action('foodsearch_order_cancelled_trigger', $id);
    }

    public function failed_record($id) {
        global $wpdb, $table_prefix;
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        $data = array('status' => 'failed');
        $where = array('order_id' => $id);
        
        $this->before_order_failed($id);
        $wpdb->update($wp_track_table, $data, $where);
        
        //
        do_action('foodsearch_order_failed_trigger', $id);
    }

    public function refunded_record($id) {
        global $wpdb, $table_prefix;
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        $data = array('status' => 'refunded');
        $where = array('order_id' => $id);
        
        $this->before_order_refunded($id);
        $wpdb->update($wp_track_table, $data, $where);
        
        //
        do_action('foodsearch_order_refunded_trigger', $id);
    }
    
    public function order_update() {
        if (isset($_POST['foodsearch_order_modify']) && current_user_can('administrator')) {
            check_admin_referer('foodsearch-plugin-orderupdate');
            
            global $wpdb, $table_prefix;

            $user_id = get_current_user_id();
            $order_id = $_POST['order_id'];
            if (isset($_POST['order_status'])) {
                $order_status = $_POST['order_status'];
                
                $this->order_status_history($order_id, $order_status, $user_id);
                
                if ($order_status == 'completed') {
                    $this->completed_record($order_id);
                } else if ($order_status == 'pending') {
                    $this->pending_record($order_id);
                } else if ($order_status == 'processing') {
                    $this->processing_record($order_id);
                } else if ($order_status == 'on-hold') {
                    $this->on_hold_record($order_id);
                } else if ($order_status == 'cancelled') {
                    $this->cancelled_record($order_id);
                } else if ($order_status == 'refunded') {
                    $this->refunded_record($order_id);
                } else if ($order_status == 'failed') {
                    $this->failed_record($order_id);
                }
            }
            
            if (isset($_POST['order_billing']) && !empty($_POST['order_billing'])) {
                $order_bilings = $_POST['order_billing'];
                foreach ($order_bilings as $biling_key => $billing_val) {
                    $update_meta_key = 'billing_' . $biling_key;
                    
                    $data = array('meta_value' => $billing_val);
                    $where = array('meta_key' => $update_meta_key, 'order_id' => $order_id);
                    
                    $table_name = $table_prefix . "fds_order_meta";
                    $wpdb->update($table_name, $data, $where);
                }
            }
            
            if (isset($_POST['payment_method']) && !empty($_POST['payment_method'])) {
                $payment_method = $_POST['payment_method'];

                $data = array('meta_value' => $payment_method);
                $where = array('meta_key' => 'payment_method', 'order_id' => $order_id);
                    
                $table_name = $table_prefix . "fds_order_meta";
                $wpdb->update($table_name, $data, $where);
            }
            
            //
            do_action('foodsearch_order_modified_trigger', $order_id);
        }
    }
    
    public function in_mail_restaurant_orderdetail($order_id) {
        
        global $table_prefix, $wpdb;

        $table_name = $table_prefix . 'fds_orders';
        $order_result = $wpdb->get_row("SELECT * FROM $table_name WHERE order_id=$order_id", 'ARRAY_A');
        
        $order_meta = self::get_order_meta($order_id);
        $first_name = self::order_meta_value($order_meta, 'billing_first_name');
        $last_name = self::order_meta_value($order_meta, 'billing_last_name');
        $billing_email = self::order_meta_value($order_meta, 'billing_email');
        $billing_phone = self::order_meta_value($order_meta, 'billing_phone');
        $billing_address = self::order_meta_value($order_meta, 'billing_address');

        $customer_name = '';
        if ($first_name != '') {
            $customer_name .= $first_name;
            if ($last_name != '') {
                $customer_name .= ' ' . $last_name;
            }
        }

        $order_status = $order_result['status'];
        
        $status_list = self::get_order_statuses();
        
        $order_status_label = $this->get_order_status_tclr($order_status);
        
        $create_date = $order_result['date_created'];
        $create_date_formate = date_i18n(get_option('date_format'), strtotime($create_date));
        $create_time_formate = date_i18n(get_option('time_format'), strtotime($create_date));

        ob_start();
        ?>
        <div class="fds-booking-detail-title">
            <h2 class="fds-heading-title"><?php esc_html_e('order detail', 'wp-foodsearch'); ?></h2>
            <span><?php printf(esc_html__('status: %s', 'wp-foodsearch'), $order_status_label); ?></span>
        </div>
        <ul class="fds-booking-detail-info fds-options-wrap">
            <li class="fds-list-item">
                <span><?php esc_html_e('order date', 'wp-foodsearch'); ?></span>
                <small><?php echo ($create_date_formate) ?></small>
                <small><?php echo ($create_time_formate) ?></small>
            </li>
            <li class="fds-list-item">
                <span><?php esc_html_e('customer name', 'wp-foodsearch'); ?></span>
                <small><?php echo ($customer_name) ?></small>
                <small><?php printf(esc_html__('order id: #%s', 'wp-foodsearch'), $order_id); ?></small>
            </li>
            <li class="fds-list-item">
                <span><?php esc_html_e('customer contact', 'wp-foodsearch'); ?></span>
                <small><?php echo ($billing_phone) ?></small>
                <a href="mailto:<?php echo ($billing_email) ?>" class="fds-link"><?php echo ($billing_email) ?></a>
            </li>
        </ul>

        <div class="fds-plugin-modal-box-inner">
            <div class="fds-ordersum-address">
                <span><?php esc_html_e('customer address', 'wp-foodsearch'); ?></span>
                <small><?php echo ($billing_address) ?></small>
            </div>
            <span class="fds-booking-detail-mini-title"><?php esc_html_e('order summary', 'wp-foodsearch'); ?></span>
            <?php
            $order_items = $this->get_order_items($order_id, 'menu_items');
            if (!empty($order_items)) {

                $order_subtotal = $order_result['total_sales'];
                $order_net_total = $order_result['net_total'];
                $border_top = '1px solid #E2E2E2';
                ?>
                <table style="border-top: <?php echo ($border_top) ?>;" border="0" width="100%" cellspacing="0" cellpadding="10">
                    <tbody>
                        <tr>
                            <td><?php esc_html_e('item', 'wp-foodsearch'); ?></td>
                            <td><?php esc_html_e('cost', 'wp-foodsearch'); ?></td>
                            <td><?php esc_html_e('qty', 'wp-foodsearch'); ?></td>
                            <td><?php esc_html_e('total', 'wp-foodsearch'); ?></td>
                        </tr>
                        <?php
                        $items_counter = 1;
                        $total_order_items = count($order_items);
                        $menu_itms_open = false;
                        foreach ($order_items as $order_item) {
                            $order_item_id = $order_item['order_item_id'];
                            $order_item_name = $order_item['order_item_name'];
                            $order_item_type = $order_item['order_item_type'];
                            if ($order_item_type == 'menu_item' || $order_item_type == 'menu_item_extra') {
                                $order_item_meta = $this->get_order_item_meta($order_item_id);
                                $item_menu_id = $this->order_item_meta_value($order_item_meta, 'menu_id');
                                $item_qty = $this->order_item_meta_value($order_item_meta, 'qty');
                                $item_subtotal = $this->order_item_meta_value($order_item_meta, 'subtotal');

                                $table_name = $table_prefix . 'menu_items';
                                $menu_itmsql = "SELECT * FROM $table_name WHERE id=$item_menu_id";
                                $menu_itm_obj = $wpdb->get_row($menu_itmsql);

                                $image_src = '';
                                $image_id = $menu_itm_obj->attachment_id;
                                if ($image_id > 0) {
                                    $image_thumb = wp_get_attachment_image_src($image_id);
                                    $image_src = isset($image_thumb[0]) ? $image_thumb[0] : '';
                                }
                                $menu_itm_label = $menu_itm_obj->name;

                                $item_alltotal = $item_subtotal * $item_qty;

                                ?>
                                <tr class="fds-order-item-row fds-options-wrap">
                                    <td>
                                        <img src="<?php echo ($image_src) ?>" class="order-itm-thumbnail" alt="">
                                        <span class="order-name"><?php echo ($menu_itm_label) ?></span>
                                    </td>
                                    <td>
                                        <span class="order-itm-amount"><?php echo (Common_Functions::get_formatted_price($item_subtotal)) ?></span>
                                    </td>
                                    <td>
                                        <small class="times">x</small> <?php echo ($item_qty) ?>
                                    </td>
                                    <td>
                                        <span class="order-itm-total"><?php echo (Common_Functions::get_formatted_price($item_alltotal)) ?></span>
                                    </td>
                                </tr>
                                <?php
                                $items_counter++;
                            }
                        }
                        ?>
                        <tr>
                            <td><?php esc_html_e('items subtotal:', 'wp-foodsearch'); ?></td>
                            <td>&nbsp;</td>
                            <td>&nbsp;</td>
                            <td>
                                <span class="ordrtotl-amount"><?php echo (Common_Functions::get_formatted_price($order_subtotal)) ?></span>
                            </td>
                        </tr>
                        <?php
                        if ($order_result['shipping_total'] > 0) {
                            $delivery_fee = $order_result['shipping_total'];
                            ?>
                            <tr>
                                <td><?php esc_html_e('delivery charges:', 'wp-foodsearch'); ?></td>
                                <td>&nbsp;</td>
                                <td>&nbsp;</td>
                                <td>
                                    <span class="ordrtotl-amount"><?php echo (Common_Functions::get_formatted_price($delivery_fee)) ?></span>
                                </td>
                            </tr>
                            <?php
                        }
                        if ($order_result['tax_total'] > 0) {
                            $vat_tax = $order_result['tax_total'];
                            ?>
                            <tr>
                                <td><?php esc_html_e('vat:', 'wp-foodsearch'); ?></td>
                                <td>&nbsp;</td>
                                <td>&nbsp;</td>
                                <td>
                                    <span class="ordrtotl-amount"><?php echo (Common_Functions::get_formatted_price($vat_tax)) ?></span>
                                </td>
                            </tr>
                            <?php
                        }
                        ?>
                        <tr>
                            <td><?php esc_html_e('order total:', 'wp-foodsearch'); ?></td>
                            <td>&nbsp;</td>
                            <td>&nbsp;</td>
                            <td>
                                <span class="ordrtotl-amount"><?php echo (Common_Functions::get_formatted_price($order_net_total)) ?></span>
                            </td>
                        </tr>
                    </tbody>
                </table>
                <?php
            }
            ?>
        </div>
        <?php
        $html = ob_get_clean();
        
        return $html;
    }
    
    public function in_mail_customer_orderdetail($order_id) {
        
        global $table_prefix, $wpdb;

        $table_name = $table_prefix . 'fds_orders';
        $order_result = $wpdb->get_row("SELECT * FROM $table_name WHERE order_id=$order_id", 'ARRAY_A');
        
        $order_meta = self::get_order_meta($order_id);
        $first_name = self::order_meta_value($order_meta, 'billing_first_name');
        $last_name = self::order_meta_value($order_meta, 'billing_last_name');
        $billing_email = self::order_meta_value($order_meta, 'billing_email');
        $billing_phone = self::order_meta_value($order_meta, 'billing_phone');
        $billing_address = self::order_meta_value($order_meta, 'billing_address');

        $customer_name = '';
        if ($first_name != '') {
            $customer_name .= $first_name;
            if ($last_name != '') {
                $customer_name .= ' ' . $last_name;
            }
        }

        $order_status = $order_result['status'];
        
        $status_list = self::get_order_statuses();
        
        $order_status_label = $this->get_order_status_tclr($order_status);
        
        $create_date = $order_result['date_created'];
        $create_date_formate = date_i18n(get_option('date_format'), strtotime($create_date));
        $create_time_formate = date_i18n(get_option('time_format'), strtotime($create_date));

        ob_start();
        ?>
        <div class="fds-booking-detail-title">
            <h2 class="fds-heading-title"><?php esc_html_e('order detail', 'wp-foodsearch'); ?></h2>
            <span><?php printf(esc_html__('status: %s', 'wp-foodsearch'), $order_status_label); ?></span>
        </div>
        
        <div class="fds-plugin-modal-box-inner">
            <?php
            $order_items = $this->get_order_items($order_id, 'menu_items');
            if (!empty($order_items)) {

                $order_subtotal = $order_result['total_sales'];
                $order_net_total = $order_result['net_total'];
                $border_top = '1px solid #E2E2E2';
                ?>
                <table style="border-top: <?php echo ($border_top) ?>" border="0" width="100%" cellspacing="0" cellpadding="10">
                    <tbody>
                        <tr>
                            <td><?php esc_html_e('item', 'wp-foodsearch'); ?></td>
                            <td><?php esc_html_e('cost', 'wp-foodsearch'); ?></td>
                            <td><?php esc_html_e('qty', 'wp-foodsearch'); ?></td>
                            <td><?php esc_html_e('total', 'wp-foodsearch'); ?></td>
                        </tr>
                        <?php
                        $items_counter = 1;
                        $total_order_items = count($order_items);
                        $menu_itms_open = false;
                        foreach ($order_items as $order_item) {
                            $order_item_id = $order_item['order_item_id'];
                            $order_item_name = $order_item['order_item_name'];
                            $order_item_type = $order_item['order_item_type'];
                            if ($order_item_type == 'menu_item' || $order_item_type == 'menu_item_extra') {
                                $order_item_meta = $this->get_order_item_meta($order_item_id);
                                $item_menu_id = $this->order_item_meta_value($order_item_meta, 'menu_id');
                                $item_qty = $this->order_item_meta_value($order_item_meta, 'qty');
                                $item_subtotal = $this->order_item_meta_value($order_item_meta, 'subtotal');

                                $table_name = $table_prefix . 'menu_items';
                                $menu_itmsql = "SELECT * FROM $table_name WHERE id=$item_menu_id";
                                $menu_itm_obj = $wpdb->get_row($menu_itmsql);

                                $image_src = '';
                                $image_id = $menu_itm_obj->attachment_id;
                                if ($image_id > 0) {
                                    $image_thumb = wp_get_attachment_image_src($image_id);
                                    $image_src = isset($image_thumb[0]) ? $image_thumb[0] : '';
                                }
                                $menu_itm_label = $menu_itm_obj->name;

                                $item_alltotal = $item_subtotal * $item_qty;
                                ?>
                                <tr>
                                    <td>
                                        <img src="<?php echo ($image_src) ?>" class="order-itm-thumbnail" alt="">
                                        <span class="order-name"><?php echo ($menu_itm_label) ?></span>
                                    </td>
                                    <td>
                                        <span class="order-itm-amount"><?php echo (Common_Functions::get_formatted_price($item_subtotal)) ?></span>
                                    </td>
                                    <td>
                                        <small class="times">x</small> <?php echo ($item_qty) ?>
                                    </td>
                                    <td>
                                        <span class="order-itm-total"><?php echo (Common_Functions::get_formatted_price($item_alltotal)) ?></span>
                                    </td>
                                </tr>
                                <?php
                                $items_counter++;
                            }
                        }
                        ?>
                        <tr>
                            <td><?php esc_html_e('items subtotal:', 'wp-foodsearch'); ?></td>
                            <td>&nbsp;</td>
                            <td>&nbsp;</td>
                            <td>
                                <span class="ordrtotl-amount"><?php echo (Common_Functions::get_formatted_price($order_subtotal)) ?></span>
                            </td>
                        </tr>
                        <?php
                        if ($order_result['shipping_total'] > 0) {
                            $delivery_fee = $order_result['shipping_total'];
                            ?>
                            <tr>
                                <td><?php esc_html_e('delivery charges:', 'wp-foodsearch'); ?></td>
                                <td>&nbsp;</td>
                                <td>&nbsp;</td>
                                <td>
                                    <span class="ordrtotl-amount"><?php echo (Common_Functions::get_formatted_price($delivery_fee)) ?></span>
                                </td>
                            </tr>
                            <?php
                        }
                        if ($order_result['tax_total'] > 0) {
                            $vat_tax = $order_result['tax_total'];
                            ?>
                            <tr>
                                <td><?php esc_html_e('vat:', 'wp-foodsearch'); ?></td>
                                <td>&nbsp;</td>
                                <td>&nbsp;</td>
                                <td>
                                    <span class="ordrtotl-amount"><?php echo (Common_Functions::get_formatted_price($vat_tax)) ?></span>
                                </td>
                            </tr>
                            <?php
                        }
                        ?>
                        <tr>
                            <td><?php esc_html_e('order total:', 'wp-foodsearch'); ?></td>
                            <td>&nbsp;</td>
                            <td>&nbsp;</td>
                            <td>
                                <span class="ordrtotl-amount"><?php echo (Common_Functions::get_formatted_price($order_net_total)) ?></span>
                            </td>
                        </tr>
                    </tbody>
                </table>
                <?php
            }
            ?>
        </div>
        <?php
        $html = ob_get_clean();
        
        return $html;
    }
    
    public function order_detail_set_template() {
        if (isset($_GET['order_tab']) && $_GET['order_tab'] == 'detail' && isset($_GET['order_id']) && $_GET['order_id'] > 0) {
            $order_id = $_GET['order_id'];
            if (isset($_COOKIE['foodsearch_customer_created_order_id']) && $_COOKIE['foodsearch_customer_created_order_id'] == $order_id) {
                add_filter('foodsearch_show_template_with_hdrfootr', '__return_true');
                add_filter('foodsearch_dashboard_redirect_if_not_login', '__return_false');
            }
        }
    }
    
    public function order_thankyou_html($html) {
        if (isset($_GET['order_tab']) && $_GET['order_tab'] == 'detail' && isset($_GET['order_id']) && $_GET['order_id'] > 0) {
            $order_id = $_GET['order_id'];
            if (isset($_COOKIE['foodsearch_customer_created_order_id']) && $_COOKIE['foodsearch_customer_created_order_id'] == $order_id) {

                global $foodsearch_plugin_settings, $table_prefix, $wpdb;

                $detail_container = isset($foodsearch_plugin_settings['restaurant_settings']['detail_container']) ? $foodsearch_plugin_settings['restaurant_settings']['detail_container'] : '';
                $detail_container_width = isset($foodsearch_plugin_settings['restaurant_settings']['detail_container_width']) ? $foodsearch_plugin_settings['restaurant_settings']['detail_container_width'] : '';

                $table_name = $table_prefix . 'fds_orders';
                $order_result = $wpdb->get_row("SELECT * FROM $table_name WHERE order_id=$order_id", 'ARRAY_A');
                
                $create_date = $order_result['date_created'];
                $create_date_formate = date_i18n(get_option('date_format'), strtotime($create_date));
                
                //
                $net_total = $order_result['net_total'];
                
                $set_page_margin = '30px';

                ob_start();
                ?>
                <div class="fds-user-dashboard fds-reset-password-page"<?php echo ($detail_container == 'on' && $detail_container_width > 0 ? ' style="width: ' . absint($detail_container_width) . 'px; margin:' . $set_page_margin . ' auto;"' : '') ?>>
                    <div class="fds-resturant-dashboard-wrap-box">
                        <div class="fds-dashboard-inner-section">
                            <div class="foodsearch-order-thankyou-detail">
                                <img src="<?php echo foodsearch_plugin_get_url('assets/images/success.png') ?>" alt="">
                                <p class="order-thanks-msg"><?php esc_html_e('thank you. your order has been received.', 'wp-foodsearch') ?></p>
                                <div class="order-detail-itmscon">
                                    <div class="order-detail-infoitm">
                                        <span><?php esc_html_e('order id', 'wp-foodsearch') ?></span>
                                        <strong><?php echo ($order_id) ?></strong>
                                    </div>
                                    <div class="order-detail-infoitm">
                                        <span><?php esc_html_e('date', 'wp-foodsearch') ?></span>
                                        <strong><?php echo ($create_date_formate) ?></strong>
                                    </div>
                                    <div class="order-detail-infoitm">
                                        <span><?php esc_html_e('total', 'wp-foodsearch') ?></span>
                                        <strong><?php echo Common_Functions::get_formatted_price($net_total) ?></strong>
                                    </div>
                                    <div class="order-detail-infoitm">
                                        <span><?php esc_html_e('payment method', 'wp-foodsearch') ?></span>
                                        <strong><?php echo self::order_paymethod_name($order_result); ?></strong>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <?php
                $html = ob_get_clean();
            }
        }
        
        return $html;
    }

}

global $foodsearch_user_orders_obj;

$foodsearch_user_orders_obj = new user_orders();
