<?php

namespace FoodSearch\User_Forms;
use FoodSearch\User_Forms\Common_Functions;

class Shortcode {
    
    public function __construct() {
        $this->includes();
        add_shortcode('foodsearch_user_form', array($this, 'form_shortcode'));
        add_action('wp_footer', array($this, 'login_register_popup'), 15);
    }
    
    public function includes() {
        include plugin_dir_path(dirname(__FILE__)) . 'user-forms/common.php';
        include plugin_dir_path(dirname(__FILE__)) . 'user-forms/submit.php';
    }
    
    public function form_shortcode($atts = array()) {
        extract(shortcode_atts(array(
            'for' => 'login', // login_only, register_only, lost_password
        ), $atts));
        
        global $foodsearch_plugin_settings;

        $user_frstlast_names = isset($foodsearch_plugin_settings['register_settings']['first_last_name']) ? $foodsearch_plugin_settings['register_settings']['first_last_name'] : '';
        
        $approval_type = isset($foodsearch_plugin_settings['register_settings']['user_approval_type']) ? $foodsearch_plugin_settings['register_settings']['user_approval_type'] : '';
        
        $common_functions = new Common_Functions;
        
        $rand_num = rand(10000000, 99999999);
        
        $sec_nonce_allowats = array(
            'input' => array(
                'type' => array(),
                'name' => array(),
                'value' => array(),
            )
        );
        
        ob_start();
        ?>
        <div class="fds-useracount-formcon">
            <div class="fds-userform-lrtab">
                <div class="userform-lrtab-itm form-logn-tab active-frm-tab">
                    <a href="javascript:void(0);" class="fds-link"><i class="fds-icon fds-Login"></i> <?php esc_html_e('login', 'wp-foodsearch') ?></a>
                </div>
                <div class="userform-lrtab-itm form-reg-tab">
                    <a href="javascript:void(0);" class="fds-link"><i class="fds-icon fds-register"></i> <?php esc_html_e('register', 'wp-foodsearch') ?></a>
                </div>
            </div>
            <div class="fds-userform-mainholdr">
                <div class="form-holder-con login-frm-con">
                    <?php
                    $rand_num = rand(10000000, 99999999);
                    ?>
                    <form id="fds-login-form-<?php echo absint($rand_num) ?>" class="fds-user-login-form" method="post">
                        <?php
                        echo do_action('foodsearch_login_form_before_fields', $rand_num, $atts);
                        ?>
                        <div class="field-item-con">
                            <i class="fds-icon fds-envelope-line-1"></i>
                            <input id="useremail-<?php echo absint($rand_num) ?>" type="text" class="fds-form-field fds-input-style" name="username" required="" placeholder="<?php echo esc_html(_x('username/email*', 'login_user_email_placeholder', 'wp-foodsearch')) ?>" />
                        </div>
                        <div class="field-item-con user-pass-field">
                            <i class="fds-icon fds-lock-line"></i>
                            <input id="user-pass-<?php echo absint($rand_num) ?>" type="password" placeholder="<?php esc_html_e('password*', 'login_form_password', 'wp-foodsearch') ?>" class="fds-form-field fds-input-style" name="user_pass" required="" />
                            <a class="fds-show-userpass fds-link"><i class="fds-icon fds-eye-line"></i></a>
                        </div>
                        <div class="rember-forgt-con">
                            <div class="rember-sec-con fds-checkfield-con">
                                <label for="rember-me-<?php echo absint($rand_num) ?>" class="fds-input-label">
                                    <input id="rember-me-<?php echo absint($rand_num) ?>" type="checkbox" name="remember_me">
                                    <span><?php esc_html_e('remember me', 'wp-foodsearch') ?></span>
                                </label>
                            </div>
                            <div class="forgt-sec-con">
                                <a href="javascript:void(0);" class="fds-forgtpass-btn fds-link"><?php esc_html_e('forgot password', 'wp-foodsearch') ?></a>
                            </div>
                        </div>
                        <div class="form-submit-btncon fds-btn fds-large-btn">
                            <?php
                            echo do_action('foodsearch_login_form_before_submit', $rand_num, $atts);
                            ob_start();
                            wp_nonce_field('ajax-login-nonce', 'security-login');
                            $sec_html = ob_get_clean();
                            echo wp_kses($sec_html, $sec_nonce_allowats);
                            ?>
                            <input type="submit" class="fds-user-login-btn fds-btn fds-has-bg" data-id="<?php echo absint($rand_num) ?>" value="<?php echo esc_html(_x('login', 'login_submit_btn', 'wp-foodsearch')) ?>" />
                        </div>
                        <?php
                        if (defined('WSLU_LOGIN_PLUGIN')) {
                            echo do_shortcode('[xs_social_login class="fds-xsocial-login"]');
                        }
                        if (class_exists('NextendSocialLogin', false)) {
                            \NextendSocialLogin::renderButtonsWithContainer();
                        }
                        ?>
                    </form>
                </div>
                <div class="form-holder-con register-frm-con" style="display:none;">
                    <?php
                    $rand_num = rand(10000000, 99999999);
                    ?>
                    <form id="fds-register-form-<?php echo absint($rand_num) ?>" class="fds-user-register-form" method="post">
                        <?php
                        echo do_action('foodsearch_register_form_before_fields', $rand_num, $atts);
                        
                        if ($user_frstlast_names == 'on') {
                            ?>
                            <div class="field-item-con">
                                <i class="fds-icon fds-user-line"></i>
                                <input id="firstname-<?php echo absint($rand_num) ?>" type="text" class="fds-form-field fds-input-style" name="first_name" required="" placeholder="<?php echo esc_html(_x('first name*', 'user_firstname_placeholder', 'wp-foodsearch')) ?>" />
                            </div>
                            <div class="field-item-con">
                                <i class="fds-icon fds-user-line"></i>
                                <input id="lastname-<?php echo absint($rand_num) ?>" type="text" class="fds-form-field fds-input-style" name="last_name" required="" placeholder="<?php echo esc_html(_x('last name*', 'user_lastname_placeholder', 'wp-foodsearch')) ?>" />
                            </div>
                            <?php
                        }
                        ?>
                        <div class="field-item-con">
                            <i class="fds-icon fds-user-line"></i>
                            <input id="username-<?php echo absint($rand_num) ?>" type="text" class="fds-form-field fds-input-style" name="username" required="" placeholder="<?php echo esc_html(_x('username*', 'register_username_placeholder', 'wp-foodsearch')) ?>" />
                        </div>
                        <div class="field-item-con">
                            <i class="fds-icon fds-envelope-line-1"></i>
                            <input id="user-email-<?php echo absint($rand_num) ?>" type="email" class="fds-form-field fds-input-style" name="user_email" required="" placeholder="<?php esc_html_e('email*', 'wp-foodsearch') ?>" />
                        </div>
                        <?php
                        if ($approval_type != 'email_verify') {
                            ?>
                            <div class="field-item-con user-pass-field">
                                <i class="fds-icon fds-lock-line"></i>
                                <input id="user-pass-<?php echo absint($rand_num) ?>" type="password" class="fds-form-field fds-input-style fds-userchk-passtrength" name="user_pass" placeholder="<?php esc_html_e('password*', 'register_form_password', 'wp-foodsearch') ?>" required="" />
                                <a class="fds-show-userpass fds-link"><i class="fds-icon fds-eye-line"></i></a>
                            </div>
                            <div class="field-item-con passlenth-chk-holdr" style="display:none;">
                                <span class="passlenth-chk-msg"></span>
                            </div>
                            <div class="field-item-con user-pass-field">
                                <i class="fds-icon fds-lock-line"></i>
                                <input id="confirm-pass-<?php echo absint($rand_num) ?>" type="password" class="fds-form-field fds-input-style" name="confirm_pass" placeholder="<?php esc_html_e('confirm Password*', 'register_confirm_password', 'wp-foodsearch') ?>" required="" />
                                <a class="fds-show-userpass fds-link"><i class="fds-icon fds-eye-line"></i></a>
                            </div>
                            <?php
                        }
                        echo do_action('foodsearch_register_form_after_fields', $rand_num, $atts);
                        ?>
                        <?php $common_functions->form_submit_terms('register_form') ?>
                        <div class="form-submit-btncon  fds-btn fds-large-btn">
                            <?php
                            echo do_action('foodsearch_register_form_before_submit', $rand_num, $atts);
                            ob_start();
                            wp_nonce_field('ajax-signup-nonce', 'security-signup');
                            $sec_html = ob_get_clean();
                            echo wp_kses($sec_html, $sec_nonce_allowats);
                            ?>
                            <input type="submit" class="fds-user-register-btn fds-btn fds-has-bg" data-id="<?php echo absint($rand_num) ?>" value="<?php echo esc_html(_x('create account', 'register_submit_btn', 'wp-foodsearch')) ?>" />
                        </div>
                    </form>
                    <?php
                    if (defined('WSLU_LOGIN_PLUGIN')) {
                        echo do_shortcode('[xs_social_login class="fds-xsocial-login"]');
                    }
                    if (class_exists('NextendSocialLogin', false)) {
                        \NextendSocialLogin::renderButtonsWithContainer();
                    }
                    ?>
                </div>
                <div class="lostpass-frm-con" style="display:none;">
                    <?php
                    $rand_num = rand(10000000, 99999999);
                    ?>
                    <form id="fds-lostpass-form-<?php echo absint($rand_num) ?>" class="fds-user-lostpass-form" method="post">
                        <div class="form-top-msg">
                            <p><?php esc_html_e('lost your password? please enter your email address. you will receive mail with link to set new password.', 'wp-foodsearch') ?></p>
                        </div>
                        <?php
                        echo do_action('foodsearch_lost_pass_form_before_fields', $rand_num, $atts);
                        ?>
                        <div class="field-item-con">
                            <i class="fds-icon fds-envelope-line-1"></i>
                            <input id="username-<?php echo absint($rand_num) ?>" type="text" class="fds-form-field fds-input-style" name="username" required="" placeholder="<?php echo esc_html(_x('username/email address', 'lost_pass_useremail', 'wp-foodsearch')) ?>" />
                        </div>
                        <?php echo do_action('foodsearch_lost_pass_form_after_fields', $rand_num, $atts) ?>
                        <div class="form-submit-btncon fds-btn fds-large-btn">
                            <?php
                            echo do_action('foodsearch_lost_pass_form_before_submit', $rand_num, $atts);
                            ob_start();
                            wp_nonce_field('ajax-forgotpass-nonce', 'security-forgotpass');
                            $sec_html = ob_get_clean();
                            echo wp_kses($sec_html, $sec_nonce_allowats);
                            ?>
                            <input type="submit" class="fds-user-lostpass-btn fds-btn fds-has-bg" data-id="<?php echo absint($rand_num) ?>" value="<?php echo esc_html(_x('get a new password', 'lostpass_submit_btn', 'wp-foodsearch')) ?>" />
                        </div>
                        <div class="backto-login-con">
                            <a href="javascript:void(0);" class="fds-forgtologin-btn fds-link"><?php esc_html_e('back to login', 'wp-foodsearch') ?></a>
                        </div>
                    </form>
                </div>
            </div>
        </div>
        <?php
        $html = ob_get_clean();
        
        return $html;
    }
    
    public function login_register_popup() {
        if (!is_user_logged_in()) {
            ?>
            <div id="fds-user-loginreg-mpopup" class="fds-modal-popup fds-popup-hide fds-loginreg-modal">
                <div class="fds-modal-container">
                    <a href="javascript:void(0);" class="fds-popup-closebtn fds-link"><i class="fds-icon fds-time-simple"></i></a>
                    <div class="fds-modal-inner-area">
                        <div class="fds-modal-content-area">
                            <?php
                            echo do_shortcode('[foodsearch_user_form for="login"]');
                            ?>
                        </div>
                    </div>
                </div>
            </div>
            <?php
        }
    }

}

new Shortcode;
