<?php
use FoodSearch\Common_Functions;
use FoodSearch\User_Locations;

function foodsearch_custom_block_category( $categories, $post ) {
	return array_merge(
		$categories,
		array(
			array(
				'slug' => 'foodsearch',
				'title' => 'FoodSearch',
        'icon'  => 'wordpress',
			),
		)
	);
}
add_filter( 'block_categories_all', 'foodsearch_custom_block_category', 10, 2);

function foodsearch_load_blocks($hook) {
  
  if ( 'post.php' != $hook ) {
      return;
  }
  wp_register_style( 'inspector-panel', plugin_dir_url(__FILE__) . 'assets/inspector-panel.css' );
  wp_enqueue_script('restaurant-listing', plugin_dir_url(__FILE__) . 'jsx/restaurant_listing.js',  array('wp-i18n','wp-blocks','wp-editor'), true);
  wp_localize_script( 'restaurant-listing', 'localizedVariableName', ['plugin_dir_url' => plugin_dir_url(__FILE__),] );

  wp_set_script_translations( 'restaurant-listing', 'wp-foodsearch', WP_LANG_DIR . '/plugins/' );
}
add_action('admin_enqueue_scripts', 'foodsearch_load_blocks');

function foodsearch_register_block_restaurant_search(){
  register_block_type('foodsearch/restaurant-search', array(
      'render_callback' => 'foodsearch_callback_restaurant_search',
      'title' => 'Restaurants Search',
      'description' => 'Display search boxes for restaurant search',
      'category' => 'foodsearch',
      'icon' => 'search',
      'editor_style' => 'inspector-panel',
      'attributes' => [
        'backgroundColor' => [
          'type' => 'string',
          'default' => ''
        ],
        'textColor' => [
          'type' => 'string',
          'default' => ''
        ],
        'blockPaddingTop' => [
          'type' => 'integer',
          'default' => 5
        ],
        'blockPaddingRight' => [
          'type' => 'integer',
          'default' => 5
        ],
        'testControl' => [
          'type' => 'integer',
          'default' => 5
        ],

      ]

  ));

}
add_action('init', 'foodsearch_register_block_restaurant_search',10);
function foodsearch_callback_restaurant_search($attr, $content, $val){
  
  ob_start();
  $output = '';
    if ( file_exists( plugin_dir_path(__FILE__) . 'templates/restaurant_search.php' ) ){
      require_once plugin_dir_path(__FILE__) . 'templates/restaurant_search.php';
    }
  $output .= ob_get_clean();
  return $output;
}

function foodsearch_register_block_restaurants(){
    register_block_type('foodsearch/restaurants', array(
        'render_callback' => 'foodsearch_callback_restaurants',
        'title' => 'Restaurants Listing',
        'description' => esc_html__('Display a list of restaurants', 'wp-foodsearch'),
        'category' => 'foodsearch',
        'icon' => 'coffee',
        'editor_script' => 'dynamicblock',
        'attributes' => [

          'blockBackground' => [
            'type' => 'object',
            'default' => (object)[
              'bgType' => 'classic',
              'color1' => [ 'r' => '','g' => '','b' => '','a' => '',] ,
              'location1' => '',
              'color2' => [ 'r' => '','g' => '','b' => '','a' => '',] ,
              'location2' => '',
              'gradType' => 'linear',
              'angle' => '',
              'position' => 'center center',
              'img' => [ 
                'src' => ['lg' => '','md' => '','sm' => '','xs' => '', ],
                'pos' => ['lg' => '','md' => '','sm' => '','xs' => '',],
                'xpos' => ['lg' => '','lgUnit' => 'px','md' => '','mdUnit' => 'px','sm' => '','smUnit' => 'px','xs' => '','xsUnit' => 'px',],
                'ypos' => ['lg' => '','lgUnit' => 'px','md' => '','mdUnit' => 'px','sm' => '','smUnit' => 'px','xs' => '','xsUnit' => 'px',],
                'attach' => '',
                'repeat' => ['lg' => '','md' => '','sm' => '','xs' => '',],
                'size' => ['lg' => '','md' => '','sm' => '','xs' => '',],
                'width' => ['lg' => '','lgUnit' => 'px','md' => '','mdUnit' => 'px','sm' => '','smUnit' => 'px','xs' => '','xsUnit' => 'px',],
              ],
            ],
          ],
          'blockPadding' => [
            'type' => 'object',
            'default' => (object)[
              'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
            ],
          ],
          'blockMargin' => [
            'type' => 'object',
            'default' => (object)[
              'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
            ],
          ],
          'blockBorder' => [
            'type' => 'object',
            'default' => (object)[
              'type' => '',
              'width' => [
                'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              ], 
              'color' => [ 'r' => '','g' => '','b' => '','a' => '',] ,
              'radius' => [
                'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              ],
              'shadow' => ['color' => '', 'hor' => '', 'ver' => '', 'blur' => '', 'spread' => '', 'pos' => ''], 
            ],
          ],

          'show_title' => [ 'type' => 'boolean', 'default' => true ],
          'titleColor' => [ 'type' => 'object', 'default' => (object)['r' => '','g' => '','b' => '','a' => '',] ],
          'titleHColor' => [ 'type' => 'object', 'default' => (object)['r' => '','g' => '','b' => '','a' => '',] ],
          'titleTypo' => [
            'type' => 'object',
            'default' => (object)[
              'family' => '',
              'weight' => '',
              'style' => '',
              'transform' => '',
              'decoration' => '',
              'font' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
              'lineHeight' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
              'letterSpacing' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
            ],
          ],
          'titlePadding' => [
            'type' => 'object',
            'default' => (object)[
              'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
            ],
          ],
          'titleMargin' => [
            'type' => 'object',
            'default' => (object)[
              'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
            ],
          ],
          'titleBorder' => [
            'type' => 'object',
            'default' => (object)[
              'type' => '',
              'width' => [
                'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              ], 
              'color' => [ 'r' => '','g' => '','b' => '','a' => '',] ,
              'radius' => [
                'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              ],
              'shadow' => ['color' => '', 'hor' => '', 'ver' => '', 'blur' => '', 'spread' => '', 'pos' => ''], 
            ],
          ],


          'show_reviews' => [ 'type' => 'boolean', 'default' => true ],
          'reviewsColor' => [ 'type' => 'object', 'default' => (object)['r' => '','g' => '','b' => '','a' => '',] ],
          'reviewsHColor' => [ 'type' => 'object', 'default' => (object)['r' => '','g' => '','b' => '','a' => '',] ],
          'reviewsTypo' => [
            'type' => 'object',
            'default' => (object)[
              'family' => '',
              'weight' => '',
              'style' => '',
              'transform' => '',
              'decoration' => '',
              'font' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
              'lineHeight' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
              'letterSpacing' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
            ],
          ],
          'reviewsPadding' => [
            'type' => 'object',
            'default' => (object)[
              'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
            ],
          ],
          'reviewsMargin' => [
            'type' => 'object',
            'default' => (object)[
              'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
            ],
          ],
          'reviewsBorder' => [
            'type' => 'object',
            'default' => (object)[
              'type' => '',
              'width' => [
                'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              ], 
              'color' => [ 'r' => '','g' => '','b' => '','a' => '',] ,
              'radius' => [
                'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              ],
              'shadow' => ['color' => '', 'hor' => '', 'ver' => '', 'blur' => '', 'spread' => '', 'pos' => ''], 
            ],
          ],


          'show_distance' => [ 'type' => 'boolean', 'default' => true ],
          'distanceColor' => [ 'type' => 'object', 'default' => (object)['r' => '','g' => '','b' => '','a' => '',] ],
          'distanceHColor' => [ 'type' => 'object', 'default' => (object)['r' => '','g' => '','b' => '','a' => '',] ],
          'distanceTypo' => [
            'type' => 'object',
            'default' => (object)[
              'family' => '',
              'weight' => '',
              'style' => '',
              'transform' => '',
              'decoration' => '',
              'font' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
              'lineHeight' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
              'letterSpacing' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
            ],
          ],
          'distancePadding' => [
            'type' => 'object',
            'default' => (object)[
              'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
            ],
          ],
          'distanceMargin' => [
            'type' => 'object',
            'default' => (object)[
              'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
            ],
          ],
          'distanceBorder' => [
            'type' => 'object',
            'default' => (object)[
              'type' => '',
              'width' => [
                'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              ], 
              'color' => [ 'r' => '','g' => '','b' => '','a' => '',] ,
              'radius' => [
                'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              ],
              'shadow' => ['color' => '', 'hor' => '', 'ver' => '', 'blur' => '', 'spread' => '', 'pos' => ''], 
            ],
          ],


          'show_delFee' => [ 'type' => 'boolean', 'default' => true ],
          'delFeeColor' => [ 'type' => 'object', 'default' => (object)['r' => '','g' => '','b' => '','a' => '',] ],
          'delFeeHColor' => [ 'type' => 'object', 'default' => (object)['r' => '','g' => '','b' => '','a' => '',] ],
          'delFeeTypo' => [
            'type' => 'object',
            'default' => (object)[
              'family' => '',
              'weight' => '',
              'style' => '',
              'transform' => '',
              'decoration' => '',
              'font' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
              'lineHeight' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
              'letterSpacing' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
            ],
          ],
          'delFeePadding' => [
            'type' => 'object',
            'default' => (object)[
              'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
            ],
          ],
          'delFeeMargin' => [
            'type' => 'object',
            'default' => (object)[
              'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
            ],
          ],
          'delFeeBorder' => [
            'type' => 'object',
            'default' => (object)[
              'type' => '',
              'width' => [
                'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              ], 
              'color' => [ 'r' => '','g' => '','b' => '','a' => '',] ,
              'radius' => [
                'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              ],
              'shadow' => ['color' => '', 'hor' => '', 'ver' => '', 'blur' => '', 'spread' => '', 'pos' => ''], 
            ],
          ],


          'show_timing' => [ 'type' => 'boolean', 'default' => true ],
          'timingColor' => [ 'type' => 'object', 'default' => (object)['r' => '','g' => '','b' => '','a' => '',] ],
          'timingHColor' => [ 'type' => 'object', 'default' => (object)['r' => '','g' => '','b' => '','a' => '',] ],
          'timingTypo' => [
            'type' => 'object',
            'default' => (object)[
              'family' => '',
              'weight' => '',
              'style' => '',
              'transform' => '',
              'decoration' => '',
              'font' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
              'lineHeight' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
              'letterSpacing' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
            ],
          ],
          'timingPadding' => [
            'type' => 'object',
            'default' => (object)[
              'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
            ],
          ],
          'timingMargin' => [
            'type' => 'object',
            'default' => (object)[
              'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
            ],
          ],
          'timingBorder' => [
            'type' => 'object',
            'default' => (object)[
              'type' => '',
              'width' => [
                'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              ], 
              'color' => [ 'r' => '','g' => '','b' => '','a' => '',] ,
              'radius' => [
                'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              ],
              'shadow' => ['color' => '', 'hor' => '', 'ver' => '', 'blur' => '', 'spread' => '', 'pos' => ''], 
            ],
          ],


          'show_menuBTN' => [ 'type' => 'boolean', 'default' => true ],
          'menuBTNColor' => [ 'type' => 'object', 'default' => (object)['r' => '','g' => '','b' => '','a' => '',] ],
          'menuBTNHColor' => [ 'type' => 'object', 'default' => (object)['r' => '','g' => '','b' => '','a' => '',] ],
          'menuBTNTypo' => [
            'type' => 'object',
            'default' => (object)[
              'family' => '',
              'weight' => '',
              'style' => '',
              'transform' => '',
              'decoration' => '',
              'font' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
              'lineHeight' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
              'letterSpacing' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
            ],
          ],
          'menuBTNPadding' => [
            'type' => 'object',
            'default' => (object)[
              'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
            ],
          ],
          'menuBTNMargin' => [
            'type' => 'object',
            'default' => (object)[
              'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
            ],
          ],
          'menuBTNBorder' => [
            'type' => 'object',
            'default' => (object)[
              'type' => '',
              'width' => [
                'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              ], 
              'color' => [ 'r' => '','g' => '','b' => '','a' => '',] ,
              'radius' => [
                'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              ],
              'shadow' => ['color' => '', 'hor' => '', 'ver' => '', 'blur' => '', 'spread' => '', 'pos' => ''], 
            ],
          ],

          'show_image' => [ 'type' => 'boolean', 'default' => true ],
          'show_favourite' => [ 'type' => 'boolean', 'default' => true ],

          'blockId' => [ 'type' => 'string', ],
          'myRichHeading' => [ 'type' => 'string', 'default' => '' ],
          'myRichText' => [ 'type' => 'string', 'default' => '' ],
          'number_of_column' => [ 'type' => 'string', 'default' => '2' ],
          'number_of_items' => [ 'type' => 'integer', 'default' => 10 ],
          'records_count' => [ 'type' => 'boolean', 'default' => true ],
          'search_box' => [ 'type' => 'boolean', 'default' => true ],
          'order_by' => [ 'type' => 'string', 'default' => 'desc' ],
          'pagination' => [ 'type' => 'string', 'default' => 'on_scroll' ],
          'postBlockWidth' => [ 'type' => 'string', 'default' => '' ],
          'align' => [ 'type' => 'string', 'default' => 'left' ],
          'view_mod' => [ 'type' => 'string', 'default' => 'grid' ],

          'filterTitleColor' => [ 'type' => 'object', 'default' => (object)['r' => '','g' => '','b' => '','a' => '',] ],
          'filterTitleTypo' => [
            'type' => 'object',
            'default' => (object)[
              'family' => '',
              'weight' => '',
              'style' => '',
              'transform' => '',
              'decoration' => '',
              'font' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
              'lineHeight' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
              'letterSpacing' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
            ],
          ],
          'filterIconColor' => [ 'type' => 'object', 'default' => (object)['r' => '','g' => '','b' => '','a' => '',] ],
          'filterColor' => [ 'type' => 'object', 'default' => (object)['r' => '','g' => '','b' => '','a' => '',] ],
          'filterHColor' => [ 'type' => 'object', 'default' => (object)['r' => '','g' => '','b' => '','a' => '',] ],
          'filterTypo' => [
            'type' => 'object',
            'default' => (object)[
              'family' => '',
              'weight' => '',
              'style' => '',
              'transform' => '',
              'decoration' => '',
              'font' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
              'lineHeight' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
              'letterSpacing' => [
                'lg' => ['val' => '', 'unit' => 'px'], 
                'md' => ['val' => '', 'unit' => 'px'], 
                'sm' => ['val' => '', 'unit' => 'px'], 
                'xs' => ['val' => '', 'unit' => 'px'], 
              ],
            ],
          ],
          'filterBorder' => [
            'type' => 'object',
            'default' => (object)[
              'type' => '',
              'width' => [
                'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              ], 
              'color' => [ 'r' => '','g' => '','b' => '','a' => '',] ,
              'radius' => [
                'lg' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'md' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'sm' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
                'xs' => ['unit' => 'px', 'top' => '', 'right' => '', 'bottom' => '', 'left' => '',], 
              ],
              'shadow' => ['color' => '', 'hor' => '', 'ver' => '', 'blur' => '', 'spread' => '', 'pos' => ''], 
            ],
          ],
          'filter_options' => [ 'type' => 'boolean', 'default' => true ],
          'filter_counts' => [ 'type' => 'boolean', 'default' => true ],
          'filter_by' => [ 'type' => 'boolean', 'default' => true ],
          'cuisine_type' => [ 'type' => 'boolean', 'default' => true ],
          'see_more_counts' => [ 'type' => 'integer', 'default' => 5 ],
          'options' => [ 'type' => 'boolean', 'default' => true ],
          'rating' => [ 'type' => 'boolean', 'default' => true ],

          'sort_options' => [ 'type' => 'boolean', 'default' => true ],
          'highest_rated' => [ 'type' => 'boolean', 'default' => true ],
          'most_reviewed' => [ 'type' => 'boolean', 'default' => true ],
          'near_me' => [ 'type' => 'boolean', 'default' => true ],
          'grid_list' => [ 'type' => 'boolean', 'default' => true ],

          'paddingPxEm' => [ 'type' => 'string', 'default' => 'px' ],
          'backgroundColor' => [ 'type' => 'object', 'default' => (object)['r' => '','g' => '','b' => '','a' => '',] ],

        ]

      ));

}
add_action('init', 'foodsearch_register_block_restaurants',10);
function foodsearch_callback_restaurants($attr, $content, $val){
  
  ob_start();
  $output = '';
    if ( file_exists( plugin_dir_path(__FILE__) . 'templates/restaurant.php' ) ){
      require plugin_dir_path(__FILE__) . 'templates/restaurant.php';
    }
  $output .= ob_get_clean();
  return $output;
}

function foodsearch_get_dbfont ($val){
  if ( gettype( $val ) == "array" ) {
    $weight = ( $val['weight'] !== "normal" && $val['weight'] !== "" ) ? ":wght@" . $val['weight'] : "";
    if ( isset( $val['family']['value']) ){
      return "family=" . $val['family']['value'] . $weight . "&";
    }
  }
}
function foodsearch_register_backend_style(){
  global $post;
  if ( $post ) {
    // loading the google font family start
    if ( has_blocks( $post->post_content ) ) {
      $blocks = parse_blocks( $post->post_content );
      foreach ($blocks as $block) {
        if ( $block['blockName'] === 'foodsearch/restaurants' ) {
          $fonts = "";
          if ( isset($block['attrs']['titleTypo']) ) $fonts .= foodsearch_get_dbfont ($block['attrs']['titleTypo']);
          if ( isset($block['attrs']['reviewsTypo']) ) $fonts .= foodsearch_get_dbfont ($block['attrs']['reviewsTypo']);
          if ( isset($block['attrs']['distanceTypo']) ) $fonts .= foodsearch_get_dbfont ($block['attrs']['distanceTypo']);
          if ( isset($block['attrs']['delFeeTypo']) ) $fonts .= foodsearch_get_dbfont ($block['attrs']['delFeeTypo']);
          if ( isset($block['attrs']['timingTypo']) ) $fonts .= foodsearch_get_dbfont ($block['attrs']['timingTypo']);
          if ( isset($block['attrs']['menuBTNTypo']) ) $fonts .= foodsearch_get_dbfont ($block['attrs']['menuBTNTypo']);
          if ( isset($block['attrs']['filterTitleTypo']) ) $fonts .= foodsearch_get_dbfont ($block['attrs']['filterTitleTypo']);
          if ( isset($block['attrs']['filterTypo']) ) $fonts .= foodsearch_get_dbfont ($block['attrs']['filterTypo']);
          if ( $fonts ) {
            wp_enqueue_style( 'google-fonts', 'https://fonts.googleapis.com/css2?' . $fonts . 'display=swap', array(), null );
          }
        }
      }
    }
    // loading the google font family end
    $upload_dir = wp_upload_dir();
    $file = $upload_dir['basedir'] . '/wp-foodsearch/css/restaurant-listing-' . $post->ID . '.css';
    if (file_exists($file)) {
      wp_enqueue_style( 'current-page', $upload_dir['baseurl'] . '/wp-foodsearch/css/restaurant-listing-' . $post->ID . '.css' );
    }
  }
}

add_action('wp_enqueue_scripts', 'foodsearch_register_backend_style');

function foodsearch_register_frontend_style(){
  wp_enqueue_style('select2', plugins_url('/assets/select2.min.css', __FILE__), false);
}
add_action('wp_enqueue_scripts', 'foodsearch_register_frontend_style');
function foodsearch_register_frontend_script(){
  global $foodsearch_plugin_settings;
        
        $default_country = isset($foodsearch_plugin_settings['location_settings']['default_country']) ? $foodsearch_plugin_settings['location_settings']['default_country'] : '';
        
        $countries_json = '';
        if (!empty($default_country) && is_array($default_country)) {
          $countries_json = $default_country;
      } else if (!empty($default_country)) {
          $countries_json = [$default_country];
      }

        $location_maps = isset($foodsearch_plugin_settings['location_settings']['loc_maps']) ? $foodsearch_plugin_settings['location_settings']['loc_maps'] : '';
        $map_type = isset($foodsearch_plugin_settings['location_settings']['map_type']) ? $foodsearch_plugin_settings['location_settings']['map_type'] : '';
        $map_zoom = isset($foodsearch_plugin_settings['location_settings']['default_map_zoom']) ? $foodsearch_plugin_settings['location_settings']['default_map_zoom'] : '';

        $google_api_key = isset($foodsearch_plugin_settings['api_settings']['google_api']) ? $foodsearch_plugin_settings['api_settings']['google_api'] : '';
        $mapbox_api_key = isset($foodsearch_plugin_settings['api_settings']['mapbox_api']) ? $foodsearch_plugin_settings['api_settings']['mapbox_api'] : '';
        
        if ($location_maps == 'on' && $map_type == 'google') {
            $locations_obj = new User_Locations;
            
            $def_latlng = $locations_obj->get_default_latlng();

            $default_lat_val = $def_latlng[0];
            $default_lng_val = $def_latlng[1];
            
            if ($google_api_key != '') {
                wp_register_script('foodsearch-google-map', 'https://maps.googleapis.com/maps/api/js?key=' . $google_api_key . '&libraries=places', array(), \FoodSearch_Plugin::get_version(), true);
            } else {
              
                wp_register_script('foodsearch-google-map', 'https://maps.googleapis.com/maps/api/js?libraries=places', array(), \FoodSearch_Plugin::get_version(), true);
            }
            wp_register_script('foodsearch-googlemaps-js', foodsearch_plugin_get_url('assets/js/google-maps.js'), array('jquery'), \FoodSearch_Plugin::get_version(), true);
            $localize_arr = array(
              'site_url' => esc_url_raw( rest_url() ),
                'wpnonce' => wp_create_nonce('wp_rest'),
                'adminCheck' => (is_admin()?'true':'false'),
                'api_key' => $google_api_key,
                'mapbox_access_token' => $mapbox_api_key,
                'def_countries' => $countries_json,
                'lat' => $default_lat_val,
                'lng' => $default_lng_val,
                'loc_maps' => $location_maps,
                'maps_type' => $map_type, 'countries' => $countries_json,
                'zoom' => ($map_zoom > 0 ? $map_zoom : 6),
            );
            wp_localize_script('foodsearch-googlemaps-js', 'google_map_vars', $localize_arr);
            wp_enqueue_script('foodsearch-google-map');
            wp_enqueue_script('foodsearch-googlemaps-js');
        }
        else{   
          $mapbox_style = isset($foodsearch_plugin_settings['location_settings']['mapbox_style']) ? $foodsearch_plugin_settings['location_settings']['mapbox_style'] : '';
            
          $locations_obj = new User_Locations;
          
          $def_latlng = $locations_obj->get_default_latlng();
          
          $default_lat_val = $def_latlng[0];
          $default_lng_val = $def_latlng[1];
          $countries_json = json_encode($countries_json);
          wp_register_style('foodsearch-mapbox', foodsearch_plugin_get_url('assets/scss/build/css/mapbox-gl.css'), array(), \FoodSearch_Plugin::get_version());
          wp_register_script('foodsearch-mapbox', 'https://api.mapbox.com/mapbox-gl-js/v2.6.1/mapbox-gl.js', array(), \FoodSearch_Plugin::get_version(), true);
          wp_register_script('foodsearch-mapbox-geocode', 'https://api.mapbox.com/mapbox-gl-js/plugins/mapbox-gl-geocoder/v4.7.2/mapbox-gl-geocoder.min.js', array(), \FoodSearch_Plugin::get_version(), true);
          wp_register_style('foodsearch-mapbox-geocode', foodsearch_plugin_get_url('assets/scss/build/css/mapbox-gl-geocoder.css'), array(), \FoodSearch_Plugin::get_version());
          wp_register_script('foodsearch-mapbox-js', foodsearch_plugin_get_url('assets/js/mapbox.js'), array('jquery'), \FoodSearch_Plugin::get_version(), true);
          wp_register_script('foodsearch-location-script', foodsearch_plugin_get_url('assets/js/locations.js'), array('jquery'), \FoodSearch_Plugin::get_version(), true);

          $localize_arr = array(
              'api_key' => $mapbox_api_key,
              'site_url' => esc_url_raw( rest_url() ),
              'wpnonce' =>wp_create_nonce('wp-rest'),
              'adminCheck' => (is_admin()?'true':'false'),
              'map_style' => $mapbox_style,
              'def_countries' => $countries_json,
              'lat' => $default_lat_val,
              'lng' => $default_lng_val,
              'zoom' => ($map_zoom > 0 ? $map_zoom : 6),
              'search_placeholder' => esc_html__('search location', 'wp-foodsearch'),
          );
          wp_localize_script('foodsearch-mapbox-js', 'mapbox_loc_vars', $localize_arr);
          $script_str_arr = array(
            'site_url' => esc_url_raw( rest_url() ),
            'wpnonce' => wp_create_nonce('wp_rest'),
            'loc_maps' => $location_maps,
            'maps_type' => $map_type,
            'google_api' => $google_api_key,
            'mapbox_api' => $mapbox_api_key,
            'mapbox_style' => $mapbox_style,
            'map_zoom' => ($map_zoom > 0 ? $map_zoom : 6),
            'add_new_loctxt' => esc_html__('add new location', 'wp-foodsearch'),
            'delete_msg' => esc_html__('do you really wants to delete this?', 'wp-foodsearch'),
            'def_countries' => $countries_json,
        );
        wp_localize_script('foodsearch-location-script', 'dashboard_location_vars', $script_str_arr);
          wp_enqueue_style('foodsearch-mapbox');
            wp_enqueue_script('foodsearch-mapbox');
            wp_enqueue_script('foodsearch-mapbox-geocode');
            wp_enqueue_style('foodsearch-mapbox-geocode');
            wp_enqueue_script('foodsearch-mapbox-js');
            wp_enqueue_script('foodsearch-location-script');
        }
  wp_enqueue_script('select2', plugins_url('/assets/select2.min.js', __FILE__), array('jquery'));
  wp_enqueue_script( 'fronend_script', plugins_url( '/assets/frontend_script.js', __FILE__ ), array('jquery') );
  $localize_strings = array(
    'url' =>  esc_url_raw( rest_url() ),
    'nonce' => wp_create_nonce('wp_rest'),
    'adminCheck' => (is_admin()?'true':'false'),
    'go_back' => esc_html__('go back', 'wp-foodsearch'),
  );
  wp_localize_script( 'fronend_script', 'fronend_script_strings', $localize_strings);
  
}
add_action('wp_enqueue_scripts', 'foodsearch_register_frontend_script');

function foodsearch_guten_register_post_meta() {
  register_post_meta( 'restaurants', 'delivery_fee', array('show_in_rest' => true,'single' => true,'type' => 'string',) );
  register_post_meta( 'restaurants', 'restaurant_takeaway', array('show_in_rest' => true,'single' => true, 'type' => 'string',) );
  register_post_meta( 'restaurants', 'restaurant_delivery', array('show_in_rest' => true, 'single' => true, 'type' => 'string',) );
}
add_action( 'init', 'foodsearch_guten_register_post_meta' );

function foodsearch_set_cookie() {
  if(isset($_COOKIE["user_keyword"])){
  $cookie_data = $_COOKIE["user_keyword"];
  }
  else{
    $cookie_data = '';
  }
  $arr = explode(',', $cookie_data);
  if ( !in_array(trim($_GET['keyword']), $arr) ){
    $comma = ",";
    setcookie('user_keyword', trim($_GET['keyword']) . $comma . $cookie_data , time()+62208000, '/', $_SERVER['HTTP_HOST']);
  }
}

function foodsearch_register_api() {
  register_rest_route('wp/v1', 'get-suggestion', array(
    'methods' => 'GET',
    'callback' => 'foodsearch_get_suggestion',
    'permission_callback' =>  'admin_permissions_check',
  ));
  register_rest_route('wp/v1', 'remove-cookie', array(
    'methods' => 'GET',
    'callback' => 'foodsearch_remove_cookie',
    'permission_callback' =>  'admin_permissions_check',
  ));
  register_rest_route('wp/v1', 'call-restaurants', array(
    'methods' => 'GET',
    'callback' => 'foodsearch_call_restaurants',
    'permission_callback' =>  '__return_true',
  ));
  register_rest_route('wp/v1', 'update-user-delivery-location', array(
    'methods' => 'POST',
    'callback' => 'foodsearch_update_user_delivery_location',
    'permission_callback' =>  '__return_true',
  ));
  register_rest_route('wp/v1', 'update-counter', array(
    'methods' => 'GET',
    'callback' => 'foodsearch_update_counter',
    'permission_callback' =>  'admin_permissions_check',
  ));
  register_rest_route('wp/v1', 'update-loc', array(
    'methods' => 'GET',
    'callback' => 'foodsearch_update_loc',
    'permission_callback' =>  'admin_permissions_check',
  ));
  
}
add_action('rest_api_init', 'foodsearch_register_api', 5);

function admin_permissions_check() {
   $allowed_ips = array( $_SERVER['SERVER_ADDR'] );   
   $allowed_domains = array(site_url('/') );
   $request_server = $_SERVER['SERVER_ADDR'];
   $request_domain = $_SERVER['HTTP_HOST'];

  if( ! in_array( $request_server, $allowed_ips ) &&  ! in_array( $request_domain, $allowed_domains ))
      return new WP_Error( 'rest_forbidden', esc_html__( 'Access denied from your IP address.',  'wp-foodsearch' ), array( 'status' => 401 ) );

  return true;

}
function foodsearch_update_user_delivery_location(){
 // echo '<pre>'.print_r($_POST,true).'</pre>';
 if(isset($_SESSION['filterd_resutrants'])){
    unset($_SESSION['filterd_resutrants']);
 }
  $data = ['lat' => $_POST['lat'], 'lng' => $_POST['lng'], 'order_type' => $_POST['order_type'], 'address' => $_POST['address'], 'request_ip' => $_SERVER['SERVER_ADDR']];
  $_SESSION['customer_location'] = $data;
  if (isset($_POST['resID'])) {
    $_SESSION['restaurant'] = $_POST['resID'];
  }
  wp_send_json(['error'=>0,'msg'=>'location Updated','data'=>$data]);
}
function foodsearch_remove_cookie () {
  $data = str_replace($_GET['keyword'].",", "", $_COOKIE["user_keyword"]);
  setcookie('user_keyword', $data , time()+62208000, '/', $_SERVER['HTTP_HOST']);
  $html = "";
  wp_send_json($html);
}

function foodsearch_update_loc(){
  $return_arr = array();
  if ( !isset($_SESSION) ) session_start();
  $visitor_location = User_Locations::user_current_location();
  $distance = '';

  if ( isset($_SESSION['post_ids'])  ){
    foreach ($_SESSION['post_ids'] as $id){
      $restaurant_addreses = Common_Functions::restaurant_distance_from_user_loc($visitor_location, $id->ID);
      if ( isset($restaurant_addreses[0]['distance']) ) {
        $distance = $restaurant_addreses[0]['distance'];
      }
      else {
        $distance = esc_html__('(not found)', 'wp-foodsearch');
      }
      $return_arr["loc_" . $id->ID]= $distance;
    }
  
  }

  wp_send_json($return_arr);
  wp_die();
}
function getLngDegree($lat)
{
    return cos(deg2rad($lat)) * 69.172;
}
function haversine($lat1, $lng1, $lat2, $lng2)
{
    $earth_radius = 3961;

    $dLat = deg2rad($lat2 - $lat1);
    $dLng = deg2rad($lng2 - $lng1);

    $a = sin($dLat/2) * sin($dLat/2) + cos(deg2rad($lat1)) * cos(deg2rad($lat2)) * sin($dLng/2) * sin($dLng/2);
    $c = 2 * asin(sqrt($a));
    $d = $earth_radius * $c;

    return $d;
}
function disCalculate($dblLat1, $dblLong1, $dblLat2, $dblLong2) {
  $EARTH_RADIUS_MILES = 3963;
  $dist = 0;
  //convert degrees to radians
  // $dblLat1 = $dblLat1 * M_PI / 180;
  // $dblLong1 = $dblLong1 * M_PI / 180;
  // $dblLat2 = $dblLat2 * M_PI / 180;
  // $dblLong2 = $dblLong2 * M_PI / 180;
  // if ($dblLat1 != $dblLat2 || $dblLong1 != $dblLong2) {
  //     //the two points are not the same
  //     $dist = sin($dblLat1) * sin($dblLat2) + cos($dblLat1) * cos($dblLat2) * cos($dblLong2 - $dblLong1);
  //     $dist = $EARTH_RADIUS_MILES * (-1 * atan($dist / sqrt(1 - $dist * $dist)) + M_PI / 2);
  // }
 // return $dist;
  $rad = M_PI / 180;
  //Calculate distance from latitude and longitude
  $theta = $dblLat1 - $dblLat2;
  $dist = sin($dblLong1 * $rad) 
      * sin($dblLong2 * $rad) +  cos($dblLong1 * $rad)
      * cos($dblLong2 * $rad) * cos($theta * $rad);

  return acos($dist) / $rad * 60 *  1.853;
}
function resturant_filter_on_location($lat='31.5204',$lng='74.3587'){
  global $foodsearch_plugin_settings;
 // if (isset($foodsearch_plugin_settings['location_settings']['disply_res']) && $foodsearch_plugin_settings['location_settings']['disply_res'] == 'yes') {
    $kmc = 1.60934;
    $ddC = isset($foodsearch_plugin_settings['location_settings']['disply_distance']) ? $foodsearch_plugin_settings['location_settings']['disply_distance'] : 'km';
    $Miles = 3.10686;
    if (isset($foodsearch_plugin_settings['location_settings']['max_resturant_deilvery_km'])) {
     /* if ($ddC == 'mile') {
        $kmc = 1;
      }*/
      //$Miles = $foodsearch_plugin_settings['location_settings']['max_resturant_deilvery_km'] / $kmc;
      $Miles = $foodsearch_plugin_settings['location_settings']['max_resturant_deilvery_km'];
    }
    if (!isset($_SESSION['filterd_resutrants'])) {

      if (isset($_SESSION['customer_location']) && $_SESSION['customer_location']['lat'] != '') {
        $visitor_location = $_SESSION['customer_location'];
      } else {
        $visitor_location = User_Locations::user_current_location();
        $_SESSION['customer_location'] = $visitor_location;
      }
      $lat = $visitor_location['lat'];
      $lng = $visitor_location['lng'];
      $EQUATOR_LAT_MILE = 69.172; // in MIles
      $maxLat = $lat + $Miles / $EQUATOR_LAT_MILE;
      $minLat = $lat - ($maxLat - $lat);
      $maxLong = $lng + $Miles / (cos($minLat * M_PI / 180) * $EQUATOR_LAT_MILE);
      $minLong = $lng - ($maxLong - $lng);
      $address = User_Locations::get_address_from_latlng($lat, $lng);
      $_SESSION['customer_location']['address'] = $address['address'];
      global $wpdb;
      $sql = "SELECT id,post_id,lat,lng FROM {$wpdb->prefix}fds_locations where post_type = 'restaurants' AND lat BETWEEN {$minLat} AND {$maxLat} AND lng BETWEEN {$minLong} AND {$maxLong}";
     
      $ids = $wpdb->get_results($sql, ARRAY_A);
      $resID = [];
      $items = [];
      foreach ($ids as $id) {
        $dist = disCalculate($lat, $lng, $id['lat'], $id['lng']);
        // $dist = $dist;
        $resID[$id['post_id']] = $id['post_id'];
        $items[$id['post_id']] = ['lcID' => $id['id'], 'distancetype' => $ddC, 'distance' => $dist];
      }
      $price = array_column($items, 'distance');

      array_multisort($price, SORT_ASC, $resID);     
      $_SESSION['filterd_resutrants'] = ['resID' => $resID, 'items' => $items];
    } else {
      $res = $_SESSION['filterd_resutrants'];
      $resID = $res['resID'];
      $items = $res['items'];
    }
  /*}
  else{
    $resID = [];
    $items = [];
  }*/
  return ['resID'=>$resID,'items'=>$items];
}

function randomize_geoLocation($lat, $lng, $radiusConstraintLower, $radiusConstraintUpper)
{

//    Randomize Lat Lng
    $maxDegLat = ($radiusConstraintUpper / 69.172) * 1000;
    $maxDegLng = ($radiusConstraintUpper / getLngDegree($lat, $lng) ) * 1000;
    $rLat = $lat + rand(-$maxDegLat, $maxDegLat)/1000;
    $rLng = $lng + rand(-$maxDegLng, $maxDegLng)/1000;

    $obj = [
        'lat' => $rLat,
        'lng' => $rLng
    ];
    $jsonData = json_encode($obj);

    $dist = haversine($lat, $lng, $rLat, $rLng);


    if ($dist >= $radiusConstraintLower && $dist <= $radiusConstraintUpper) {
        return $jsonData;
    } else {
        $counter = 0;
        while ($dist < $radiusConstraintLower || $dist > $radiusConstraintUpper) {
            $maxDegLat = ($radiusConstraintUpper / 69.172) * 1000;
            $maxDegLng = ($radiusConstraintUpper / getLngDegree($lat) ) * 1000;
            $rLat = $lat + rand(-$maxDegLat, $maxDegLat)/1000;
            $rLng = $lng + rand(-$maxDegLng, $maxDegLng)/1000;

            $obj = [
                'lat' => $rLat,
                'lng' => $rLng
            ];
            $jsonData = json_encode($obj);

            $dist = haversine($lat, $lng, $rLat, $rLng);

            $counter++;
            if ($counter >= 10) {
                throw new Exception("Cannot Find Lat/Lng Within Boundaries");
            }
        }
        return $jsonData;
    }
    return $jsonData;
}
function location_list(){ 
  global $wpdb; echo $sql = "SELECT * FROM {$wpdb->prefix}fds_locations limit 1000 offset 3000";
  $res =$wpdb->get_results( $sql , ARRAY_A);
  $userLocation = new User_Locations;

    // echo '<pre>'.print_r($res,true).'</pre>';
    // exit();
      foreach($res as $rs){
        $details = $userLocation->get_address_from_latlng($rs['lat'], $rs['lng']);
   // exit();
        $table_name = $wpdb->prefix . 'fds_locations';
        $detais = [
          'address'=>$details['address'],
          'floor_unit'=>'',
          'map_zoom'=>6,
          'notes'=>'',
          'label'=>'',
          'label_other'=>'',
        ];
       
      
        $data = array(        
          'detail' =>  maybe_serialize($detais),
        );
        $where = array('id' => $rs['id']);
        $result = $wpdb->update($table_name, $data, $where);
    echo 'Updated: ' . $rs['id'] . '<br><pre>'.print_r($detais,true).'</pre>';
             
            }
  exit();
      
}
function foodsearch_update_counter(){
  global $foodsearch_plugin_settings;
  $return_arr = array();
  $cuisine_type = "";
  $arr = array();
  if ( isset($_GET['cuisine']) ) $arr = array_merge($arr, (array) $_GET['cuisine'] );
  $cuisine_type = array('taxonomy' => 'food_cuisine', 'field' => 'slug', 'terms' => $arr, 'operator' => 'AND' );

  $delivery = array('delivery', 'both');
  if ( isset($_GET['delivery']) && $_GET['delivery'] > 0 && $_GET['delivery'] != "undefined" ) {
    $take_away = array('both');
  }
  $take_away = array('takeaway', 'both');
  if ( isset($_GET['take_away']) && $_GET['take_away'] > 0 && $_GET['take_away'] != "undefined" ) {
    $delivery = array('both');
  }

    $ids = resturant_filter_on_location();
    if (isset($ids['resID']) && count($ids['resID']) > 0) {


      // getting all the cuisines
      $terms = get_terms(
        array(
          'taxonomy' => 'food_cuisine',
          'hide_empty' => true,
        )
      );
      foreach ($terms as $term) {
        $return_arr["sb_cuisine" . $term->term_id] = foodsearch_count_cuisines($term->slug, $ids);
      }
      // getting all the cuisines
    if ((isset($_SESSION['customer_location']['order_type']) && $_SESSION['customer_location']['order_type'] == 'deliver')) {
      $args = array(
        'post_type' => 'restaurants',
        'posts_per_page' => -1,
        'post_status' => 'publish',
        'post__in' => $ids['resID'],
        's' => isset($_GET['keyword']) ? $_GET['keyword'] : '',
        'tax_query' => array('relation' => 'OR', $cuisine_type),
        'meta_query' => array(array('key' => 'foodsearch_order_process_type', 'value' => $delivery, 'compare' => 'IN'), foodsearch_get_rating_string()),
      );
      $query = new WP_Query($args);
      $sb_delivery = $query->found_posts;
      
      $sb_take_away = 0;
    } 
    else if ((isset($_SESSION['customer_location']['order_type']) && $_SESSION['customer_location']['order_type'] == 'pickup')) {
      $args = array(
        'post_type' => 'restaurants',
        'posts_per_page' => -1,
        'post_status' => 'publish',
        'post__in' => $ids['resID'],
        's' => isset($_GET['keyword']) ? $_GET['keyword'] : '',
        'tax_query' => array('relation' => 'OR', $cuisine_type),
        'meta_query' => array(array('key' => 'foodsearch_order_process_type', 'value' => $take_away, 'compare' => 'IN'), foodsearch_get_rating_string()),
      );
      $query = new WP_Query($args);
      $sb_take_away = $query->found_posts;
      
      $sb_delivery = 0;
    } 
    else {
      $args = array(
        'post_type' => 'restaurants',
        'posts_per_page' => -1,
        'post_status' => 'publish',
        'post__in' => $ids['resID'],
        's' => isset($_GET['keyword']) ? $_GET['keyword'] : '',
        'tax_query' => array('relation' => 'OR', $cuisine_type),
        'meta_query' => array(array('key' => 'foodsearch_order_process_type', 'value' => $delivery, 'compare' => 'IN'), foodsearch_get_rating_string()),
      );
      $query = new WP_Query($args);
      $sb_delivery = $query->found_posts;

      $args = array(
        'post_type' => 'restaurants',
        'posts_per_page' => -1,
        'post_status' => 'publish',
        'post__in' => $ids['resID'],
        's' => isset($_GET['keyword']) ? $_GET['keyword'] : '',
        'tax_query' => array('relation' => 'OR', $cuisine_type),
        'meta_query' => array(array('key' => 'foodsearch_order_process_type', 'value' => $take_away, 'compare' => 'IN'), foodsearch_get_rating_string()),
      );
      $query = new WP_Query($args);
      $sb_take_away = $query->found_posts;
    }
    } 
    else {
      $terms = get_terms(
        array(
          'taxonomy' => 'food_cuisine',
          'hide_empty' => true,
        )
      );
      foreach ($terms as $term) {
        $return_arr["sb_cuisine" . $term->term_id] = 0;
      }
      $sb_delivery = $sb_take_away = 0;
    }
  

  

    $return_arr["sb_delivery"] = $sb_delivery;
    $return_arr["sb_take_away"] = $sb_take_away;
    $return_arr["sb_rating5"] = foodsearch_get_rating_val (5, 5);
    $return_arr["sb_rating4"] = foodsearch_get_rating_val (4, 4.9);
    $return_arr["sb_rating3"] = foodsearch_get_rating_val (3, 3.9);
    $return_arr["sb_rating2"] = foodsearch_get_rating_val (2, 2.9);

  wp_send_json($return_arr);
  wp_die();
}

function foodsearch_get_suggestion(){
  // getting suggestion from cookies
  $input = preg_quote($_GET['keyword'], '~'); // don't forget to quote input string!
  $cookie_data = explode(",", $_COOKIE["user_keyword"]) ;
  $result = preg_grep('~' . $input . '~', $cookie_data);
  $count = 0;
  $html = '';
  $html .= empty( $_GET['keyword']) && !empty($result[0]) ? "<li class='fds-list-item'><strong class='fds-recent-searches'>" . esc_html__('recent searches', 'wp-foodsearch') . "</strong></li>" : "";
  foreach ( $result as $val ) {
    if ( !empty($val) && $count < 4 ){
      $html .= '<li class="fds-list-item"><div class="fds-link"><a class="suggestion fds-link"><i class="fds-icon fds-clock-fast"></i><span>' . str_replace($input, '<strong>' . $input . '</strong>', $val) . '</span></a><a val="'. $val .'" class="remove_cookie fds-link" href="#"><i class="fds-icon fds-time-simple"></i></a></div></li>';
    }
    $count++;
  }

  if ( !empty( $_GET['keyword']) ){
    // getting suggestion from db for title and desc
    $args = array(
      'post_type'=>'restaurants',
      's' => $_GET['keyword'],
    );
    wp_reset_query();
    $query = new WP_Query( $args );
    if ( $query->have_posts() ) {
      while ( $query->have_posts() ) : $query->the_post();
      $html .= '<li class="fds-list-item"><div class="fds-link"><a class="suggestion fds-link"><i class="fds-icon fds-search"></i><span>' . str_replace($input, '<strong>' . $input . '</strong>', strtolower(get_the_title()) ) . '</span></a></div></li>';
      endwhile;
    }
    $html .= '<li class="fds-list-item"><div class="fds-link"><span class="fds-search-for">'. esc_html__('search for', 'wp-foodsearch') . '<strong class="suggestion fds-link">' . $_GET['keyword'] . '</strong></span></div></li>';
  }
  $html = array("html" => $html);
  wp_send_json($html);

  wp_die();
}

function foodsearch_search_field_html(){
  $display = ( isset($_GET['keyword']) and $_GET['keyword'] != "" ) ?  '' : 'style="display:none"';
  $val = isset($_GET['keyword']) ? $_GET['keyword'] : "";
  $html = '
    <div class="fds-list-search">
    <input class="fds-input-style" autocomplete="off" type="text" id="search_field" name="keyword" value="' . $val . '" placeholder="' . esc_html__('search for restaurant', 'wp-foodsearch') . '">
    <div class="loader-search-field"><div class="fds-inline-loader"><div class="fds-loader"></div></div></div>
    <a ' . $display .' class="fds-link" id="clear-search" href="' . get_permalink() . '"><i class="fds-icon fds-time-simple"></i></a>
      <div class="fds-suggestion-box">
        <ul id="cookie_result" class="fds-options-wrap"></ul>
      </div>
    </div>
  ';
  return $html;
}

function foodsearch_call_restaurants(){
  global $foodsearch_plugin_settings;
  foodsearch_set_cookie();
    ob_start();
    $output = '';
  //if ((!isset($_SESSION['customer_location']))) {
    require_once plugin_dir_path(__FILE__) . 'templates/location_popup.php';
  
    require_once plugin_dir_path(__FILE__) . 'templates/restaurant_listing.php';

  //}

    $output .= ob_get_clean();
    $return_arr = array("html" => $output);
    wp_send_json($return_arr);

  wp_die();
}

add_action ('wp_ajax_call_rest_cat', 'foodsearch_call_rest_cat') ;
add_action ('wp_ajax_nopriv_call_rest_cat', 'foodsearch_call_rest_cat') ;
function foodsearch_call_rest_cat(){
  $keyword = isset($_GET['search']) ? $_GET['search'] : '';
  $terms = get_terms( array(
    'taxonomy' => 'food_item_cat',
    'hide_empty' => false,
    'number' => 100,
    'name__like' => $keyword,
  ));
  $responsedata['results'] = array();
  foreach ($terms as $term){
    $responsedata['results'][] = array('id' => $term->term_id, 'text' => $term->name);
  }
  wp_send_json($responsedata);
  wp_die();
}

function foodsearch_get_rgba($val){
  if ( isset($val["r"]) && isset($val["g"]) && isset($val["b"]) && isset($val["a"]) ) {
    return " rgba(" . $val["r"] . ", " . $val["g"] . ", " . $val["b"] . ", " . $val["a"] . ") " ;
  }
  else return "";
}
function foodsearch_get_padding_css($attr, $media = "lg"){
  $unit = isset($attr[$media]['unit']) ? $attr[$media]['unit'] . " " : "px ";
  $top = (isset($attr[$media]['top']) and $attr[$media]['top'] >= 0) ? $attr[$media]['top'] . $unit : "";
  $right = (isset($attr[$media]['right']) and $attr[$media]['right'] >= 0) ? $attr[$media]['right'] . $unit : "";
  $bottom = (isset($attr[$media]['bottom']) and $attr[$media]['bottom'] >= 0)  ? $attr[$media]['bottom'] . $unit : "";
  $left = (isset($attr[$media]['left']) and $attr[$media]['left'] >= 0) ? $attr[$media]['left'] . $unit : "";
  if ( $top != "" || $right != "" || $bottom != "" || $left != "" ) {
    return "padding: " . $top . $right . $bottom . $left . ";" ;
  }
}
function foodsearch_get_margin_css($attr, $media = "lg"){
  $unit = isset($attr[$media]['unit']) ? $attr[$media]['unit'] . " " : "px ";
  $top = (isset($attr[$media]['top']) and $attr[$media]['top'] >= 0) ? $attr[$media]['top'] . $unit : "";
  $right = (isset($attr[$media]['right']) and $attr[$media]['right'] >= 0) ? $attr[$media]['right'] . $unit : "";
  $bottom = (isset($attr[$media]['bottom']) and $attr[$media]['bottom'] >= 0)  ? $attr[$media]['bottom'] . $unit : "";
  $left = (isset($attr[$media]['left']) and $attr[$media]['left'] >= 0) ? $attr[$media]['left'] . $unit : "";
  if ( $top != "" || $right != "" || $bottom != "" || $left != "" ) {
    return "margin: " . $top . $right . $bottom . $left . ";" ;
  }
}
function foodsearch_get_border_css($attr, $media = "lg"){
  $css = "";
  $unit = isset($attr['width'][$media]['unit']) ? $attr['width'][$media]['unit'] . " " : "px ";
  $top = (isset($attr['width'][$media]['top']) and $attr['width'][$media]['top'] >= 0) ? $attr['width'][$media]['top'] . $unit . $attr['type'] . foodsearch_get_rgba($attr['color']) : "";
  $right = (isset($attr['width'][$media]['right']) and $attr['width'][$media]['right'] >= 0) ? $attr['width'][$media]['right'] . $unit . $attr['type'] . foodsearch_get_rgba($attr['color']) : "";
  $bottom = (isset($attr['width'][$media]['bottom']) and $attr['width'][$media]['bottom'] >= 0)  ? $attr['width'][$media]['bottom'] . $unit . $attr['type'] . foodsearch_get_rgba($attr['color']) : "";
  $left = (isset($attr['width'][$media]['left']) and $attr['width'][$media]['left'] >= 0) ? $attr['width'][$media]['left'] . $unit . $attr['type'] . foodsearch_get_rgba($attr['color']) : "";
  if ( $top != "" ) {
    $css .= "border-top: " . $top . ";" ;
  }
  if ( $right != "" ) {
    $css .= "border-right: " . $right . ";" ;
  }
  if ( $bottom != "" ) {
    $css .= "border-bottom: " . $bottom . ";" ;
  }
  if ( $left != "" ) {
    $css .= "border-left: " . $left . ";" ;
  }
  $unit = isset($attr['radius'][$media]['unit']) ? $attr['radius'][$media]['unit'] . " " : "px ";
  $top = (isset($attr['radius'][$media]['top']) and $attr['radius'][$media]['top'] >= 0) ? $attr['radius'][$media]['top'] . $unit : "";
  $right = (isset($attr['radius'][$media]['right']) and $attr['radius'][$media]['right'] >= 0) ? $attr['radius'][$media]['right'] . $unit : "";
  $bottom = (isset($attr['radius'][$media]['bottom']) and $attr['radius'][$media]['bottom'] >= 0)  ? $attr['radius'][$media]['bottom'] . $unit : "";
  $left = (isset($attr['radius'][$media]['left']) and $attr['radius'][$media]['left'] >= 0) ? $attr['radius'][$media]['left'] . $unit : "";
  if ( $top != "" || $right != "" || $bottom != "" || $left != "" ) {
    $css .= "border-radius: " . $top . $right . $bottom . $left . ";" ;
  }
  $hor = ( isset( $attr['shadow']['hor'] ) && !empty($attr['shadow']['hor']) ) ? $attr['shadow']['hor'] . "px " : "";
  $ver = ( isset( $attr['shadow']['ver'] ) && !empty($attr['shadow']['ver']) ) ? $attr['shadow']['ver'] . "px " : "";
  $blur = ( isset( $attr['shadow']['blur'] ) && !empty($attr['shadow']['blur']) ) ? $attr['shadow']['blur'] . "px " : "";
  $spread = ( isset( $attr['shadow']['spread'] ) && !empty($attr['shadow']['spread']) ) ? $attr['shadow']['spread'] . "px" : "";
  $pos = isset( $attr['shadow']['pos'] ) ? $attr['shadow']['pos'] : "";
  if ( !empty($hor) && !empty($ver) && !empty($blur) && !empty($spread) && !empty($attr['shadow']['color']) ){
    $css .= "box-shadow: " . $hor . $ver . $blur . $spread . foodsearch_get_rgba($attr['shadow']['color']) . $pos . ";" ;
  }
  return $css;
}
function foodsearch_get_color_css($attr, $isbg = ""){
  $css = ( isset($attr["r"]) && $attr["r"] !== "" ) ? $isbg . "color: rgba(" . $attr["r"] . ", " . $attr["g"] . ", " . $attr["b"] . ", " . $attr["a"] . ");" : "";
  return $css ;
}
function foodsearch_get_typo_css($attr, $media = "lg"){
  $css = isset($attr['family']['value']) ? "font-family: '" . $attr['family']['value'] ."';" : "";
  $css .= (isset($attr['weight']) && !empty($attr['weight']) ) ? "font-weight: " . $attr['weight'] . ";" : "";
  $css .= (isset($attr['style']) && !empty($attr['style']) ) ? "font-style: " . $attr['style'] . ";" : "";
  $css .= (isset($attr['transform']) && !empty($attr['transform']) ) ? "text-transform: " . $attr['transform'] . ";" : "";
  $css .= (isset($attr['decoration']) && !empty($attr['decoration']) ) ? "text-decoration: " . $attr['decoration'] . ";" : "";
  $css .= (isset($attr['font'][$media]['val']) && !empty($attr['font'][$media]['val']) ) ? "font-size: " . $attr['font'][$media]['val'] . $attr['font'][$media]['unit'] . ";" : "";
  $css .= (isset($attr['lineHeight'][$media]['val']) && !empty($attr['lineHeight'][$media]['val']) ) ? "line-height: " . $attr['lineHeight'][$media]['val'] . $attr['lineHeight'][$media]['unit'] . ";" : "";
  $css .= (isset($attr['letterSpacing'][$media]['val']) && !empty($attr['letterSpacing'][$media]['val']) ) ? "letter-spacing: " . $attr['letterSpacing'][$media]['val'] . $attr['letterSpacing'][$media]['unit'] . ";" : "";
  return $css ;
}
function foodsearch_get_bg_css($attr, $media = "lg"){
  $color1 = "";
  $background_image = "";
  $background_position = "";
  $background_attachment = "";
  $background_repeat = "";
  $background_size = "";

  if ( $attr["bgType"] === "classic" ) {
    if ( !empty($attr['color1']['r']) ){
      $color1 .= "background-color:" . foodsearch_get_rgba($attr['color1']) . ";";
    }
    if ( !empty($attr['img']["src"][$media]) ){
      $background_image = "background-image:url('" . $attr['img']["src"][$media] . "')" . ";";
    }
    if ( !empty($attr['img']['pos'][$media]) ){
      if ( $attr['img']['pos'][$media] === "custom" ){
        $background_position = "background-position:" . $attr['img']['xpos'][$media] . $attr['img']['xpos']['lgUnit'] . " " . $attr['img']['ypos'][$media] . $attr['img']['ypos']['lgUnit'] . ";";
      }
      else $background_position = "background-position:" . $attr['img']['pos'][$media] . ";";
    }
    if ( !empty($attr['img']['attach']) ){
      $background_attachment = "background-attachment:" . $attr['img']['attach'] . ";";
    }
    if ( !empty($attr['img']['repeat'][$media]) ){
      $background_repeat = "background-repeat:" . $attr['img']['repeat'][$media] . ";";
    }
    if ( !empty($attr['img']['size'][$media]) ){
      if ( $attr['img']['size'][$media] === "custom" ){
        $background_size = "background-size:" . $attr['img']['width'][$media] . $attr['img']['width']['lgUnit'] . " auto;";
      }
      else $background_size = "background-size:" . $attr['img']['size'][$media] . ";";
    }

  }
  else if ( $attr["bgType"] === "gradient" ) {
    if ( $attr["gradType"] === "linear" ){
      $background_image = "background-image:linear-gradient(" . $attr['angle'] . "deg, " . foodsearch_get_rgba($attr['color1']) . " " . $attr['location1'] . "%, " . foodsearch_get_rgba($attr['color2']) . " " . $attr['location2'] . "%)" . ";";
    }
    if ( $attr["gradType"] === "radial" ){
      $background_image = "background-image:radial-gradient(at " . $attr['position'] . ", " . foodsearch_get_rgba($attr['color1']) . " " . $attr['location1'] . "%, " . foodsearch_get_rgba($attr['color2']) . " " . $attr['location2'] . "%)" . ";";
    }
  }

  return $color1 . $background_image . $background_position . $background_attachment . $background_repeat . $background_size ;
}

function foodsearch_css_path($dir = '') {
    $cus_dir = 'wp-foodsearch/css';
    $dir_path = array(
        'path' => $dir['basedir'] . '/' . $cus_dir,
        'url' => $dir['baseurl'] . '/' . $cus_dir,
        'subdir' => $cus_dir,
    );
    return $dir_path + $dir;
}

add_action('save_post', 'foodsearch_call_after_post_publish', 10, 3);

function foodsearch_call_after_post_publish($post_id, $post, $update ) {
  if ( wp_is_post_revision( $post_id ) ) {
    return;
  }

  require_once(ABSPATH . 'wp-admin/includes/file.php');
  WP_Filesystem();
  global $wp_filesystem;
  add_filter('upload_dir', 'foodsearch_css_path');
  $wp_upload_dir = wp_upload_dir();
  remove_filter('upload_dir', 'foodsearch_css_path');

  $blocks = parse_blocks( $post->post_content );
  $css = "";

  foreach ( $blocks as $block ) {
    if ( $block['blockName'] === 'foodsearch/restaurants' ) {

      if ( !isset($block['attrs']['backgroundColor']) ) $block['attrs']['backgroundColor']['r'] = "";
      if ( !isset($block['attrs']['blockBackground']) ) $block['attrs']['blockBackground']['bgType'] = "";
      if ( !isset($block['attrs']['blockPadding']) ) $block['attrs']['blockPadding'] = "";
      if ( !isset($block['attrs']['blockMargin']) ) $block['attrs']['blockMargin'] = "";
      if ( !isset($block['attrs']['blockBorder']) ) $block['attrs']['blockBorder'] = "";
      if ( !isset($block['attrs']['titleColor']) ) $block['attrs']['titleColor']['r'] = "";
      if ( !isset($block['attrs']['titleHColor']) ) $block['attrs']['titleHColor']['r'] = "";
      if ( !isset($block['attrs']['titleTypo']) ) $block['attrs']['titleTypo'] = "";
      if ( !isset($block['attrs']['titlePadding']) ) $block['attrs']['titlePadding'] = "";
      if ( !isset($block['attrs']['titleMargin']) ) $block['attrs']['titleMargin'] = "";
      if ( !isset($block['attrs']['titleBorder']) ) $block['attrs']['titleBorder'] = "";
      if ( !isset($block['attrs']['reviewsHColor']) ) $block['attrs']['reviewsHColor']['r'] = "";
      if ( !isset($block['attrs']['reviewsColor']) ) $block['attrs']['reviewsColor']['r'] = "";
      if ( !isset($block['attrs']['reviewsTypo']) ) $block['attrs']['reviewsTypo'] = "";
      if ( !isset($block['attrs']['reviewsPadding']) ) $block['attrs']['reviewsPadding'] = "";
      if ( !isset($block['attrs']['reviewsMargin']) ) $block['attrs']['reviewsMargin'] = "";
      if ( !isset($block['attrs']['reviewsBorder']) ) $block['attrs']['reviewsBorder'] = "";
      if ( !isset($block['attrs']['distanceHColor']) ) $block['attrs']['distanceHColor']['r'] = "";
      if ( !isset($block['attrs']['distanceColor']) ) $block['attrs']['distanceColor']['r'] = "";
      if ( !isset($block['attrs']['distanceTypo']) ) $block['attrs']['distanceTypo'] = "";
      if ( !isset($block['attrs']['distancePadding']) ) $block['attrs']['distancePadding'] = "";
      if ( !isset($block['attrs']['distanceMargin']) ) $block['attrs']['distanceMargin'] = "";
      if ( !isset($block['attrs']['distanceBorder']) ) $block['attrs']['distanceBorder'] = "";
      if ( !isset($block['attrs']['filterTitleColor']) ) $block['attrs']['filterTitleColor'] = "";
      if ( !isset($block['attrs']['filterTitleTypo']) ) $block['attrs']['filterTitleTypo'] = "";
      if ( !isset($block['attrs']['filterIconColor']) ) $block['attrs']['filterIconColor'] = "";
      if ( !isset($block['attrs']['filterColor']) ) $block['attrs']['filterColor'] = "";
      if ( !isset($block['attrs']['filterHColor']) ) $block['attrs']['filterHColor'] = "";
      if ( !isset($block['attrs']['filterTypo']) ) $block['attrs']['filterTypo'] = "";
      if ( !isset($block['attrs']['filterBorder']) ) $block['attrs']['filterBorder'] = "";
      if ( !isset($block['attrs']['filterTypo']) ) $block['attrs']['filterTypo'] = "";
      if ( !isset($block['attrs']['filterBorder']) ) $block['attrs']['filterBorder'] = "";
      if ( !isset($block['attrs']['filterTypo']) ) $block['attrs']['filterTypo'] = "";
      if ( !isset($block['attrs']['filterBorder']) ) $block['attrs']['filterBorder'] = "";
      if ( !isset($block['attrs']['filterTypo']) ) $block['attrs']['filterTypo'] = "";
      if ( !isset($block['attrs']['filterBorder']) ) $block['attrs']['filterBorder'] = "";

      
      $css .= "#fds-block-".$block['attrs']['blockId']." .fds-item-thumb {" .
        foodsearch_get_color_css($block['attrs']['backgroundColor'], "background-") . "}\r\n";
      
      $css .= "#fds-block-".$block['attrs']['blockId']." .fds-typo-wrap {" . 
        foodsearch_get_bg_css($block['attrs']['blockBackground'] ) .
        foodsearch_get_padding_css($block['attrs']['blockPadding']) .
        foodsearch_get_margin_css($block['attrs']['blockMargin']) .
        foodsearch_get_border_css($block['attrs']['blockBorder']) . "}\r\n";
            
      $css .= "#fds-block-".$block['attrs']['blockId']." .fds-post-title a {" .
        foodsearch_get_color_css($block['attrs']['titleColor']) . "}\r\n";
      
      $css .= "#fds-block-".$block['attrs']['blockId']." .fds-post-title a:hover {" .
        foodsearch_get_color_css($block['attrs']['titleHColor']) . "}\r\n";
      
      $css .= "#fds-block-".$block['attrs']['blockId']." .fds-post-title a {" .
        foodsearch_get_typo_css($block['attrs']['titleTypo']) .
        foodsearch_get_padding_css($block['attrs']['titlePadding']) .
        foodsearch_get_margin_css($block['attrs']['titleMargin']) .
        foodsearch_get_border_css($block['attrs']['titleBorder']) . "}\r\n";
            
      $css .= "#fds-block-".$block['attrs']['blockId']." .fds-restaurant-rate-count:hover {" .
        foodsearch_get_color_css($block['attrs']['reviewsHColor']) . "}\r\n";
      
      $css .= "#fds-block-".$block['attrs']['blockId']." .fds-restaurant-rate-count {" .
        foodsearch_get_color_css($block['attrs']['reviewsColor']) .
        foodsearch_get_typo_css($block['attrs']['reviewsTypo']) .
        foodsearch_get_padding_css($block['attrs']['reviewsPadding']) .
        foodsearch_get_margin_css($block['attrs']['reviewsMargin']) .
        foodsearch_get_border_css($block['attrs']['reviewsBorder']) . "}\r\n";
            
      $css .= "#fds-block-".$block['attrs']['blockId']." .fds-distance:hover {" .
        foodsearch_get_color_css($block['attrs']['distanceHColor']) . "}\r\n";
      
      $css .= "#fds-block-".$block['attrs']['blockId']." .fds-distance {" .
        foodsearch_get_color_css($block['attrs']['distanceColor']) .
        foodsearch_get_typo_css($block['attrs']['distanceTypo']) .
        foodsearch_get_padding_css($block['attrs']['distancePadding']) .
        foodsearch_get_margin_css($block['attrs']['distanceMargin']) .
        foodsearch_get_border_css($block['attrs']['distanceBorder']) . "}\r\n";
      
      $css .= "#fds-block-".$block['attrs']['blockId']." .plugin-filter-title {" .
        foodsearch_get_color_css($block['attrs']['filterTitleColor']) .
        foodsearch_get_typo_css($block['attrs']['filterTitleTypo']) . "}\r\n";
            
      $css .= "#fds-block-".$block['attrs']['blockId']." .fds-filter-radio .fds-icon, .fds-filter-radio input[type=radio]:checked + *:before {" .
        foodsearch_get_color_css($block['attrs']['filterIconColor']) . "}\r\n";

      $css .= "#fds-block-".$block['attrs']['blockId']." .plugin-filter-wrap a, .plugin-filter-wrap label {" .
        foodsearch_get_color_css($block['attrs']['filterColor']) . "}\r\n";

      $css .= "#fds-block-".$block['attrs']['blockId']." .plugin-filter-wrap a:hover, .plugin-filter-wrap label:hover {" .
        foodsearch_get_color_css($block['attrs']['filterHColor']) . "}\r\n";
      
      $css .= "#fds-block-".$block['attrs']['blockId']." .plugin-filter-wrap li, .plugin-filter-wrap li label {" .
        foodsearch_get_typo_css($block['attrs']['filterTypo']) . "}\r\n";
     
      $css .= "#fds-block-".$block['attrs']['blockId']." .plugin-filter-wrap {" .
        foodsearch_get_border_css($block['attrs']['filterBorder']) . "}\r\n";
            
      // responsive laptop 
      $css .= "@media (min-width: 1030px) and (max-width: 1366px) { \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .fds-typo-wrap {" .
          foodsearch_get_bg_css($block['attrs']['blockBackground'], "md" ) .
          foodsearch_get_padding_css($block['attrs']['blockPadding'], "md") .
          foodsearch_get_margin_css($block['attrs']['blockMargin'], "md") .
          foodsearch_get_border_css($block['attrs']['blockBorder'], "md") ;
        $css .= "} \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .fds-post-title a {" .
          foodsearch_get_typo_css($block['attrs']['titleTypo'], "md") .
          foodsearch_get_padding_css($block['attrs']['titlePadding'], "md") .
          foodsearch_get_margin_css($block['attrs']['titleMargin'], "md") .
          foodsearch_get_border_css($block['attrs']['titleBorder'], "md") ;
        $css .= "} \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .fds-restaurant-rate-count {" .
          foodsearch_get_typo_css($block['attrs']['reviewsTypo'], "md") .
          foodsearch_get_padding_css($block['attrs']['reviewsPadding'], "md") .
          foodsearch_get_margin_css($block['attrs']['reviewsMargin'], "md") .
          foodsearch_get_border_css($block['attrs']['reviewsBorder'], "md") ;
        $css .= "} \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .fds-distance {" .
          foodsearch_get_typo_css($block['attrs']['distanceTypo'], "md") .
          foodsearch_get_padding_css($block['attrs']['distancePadding'], "md") .
          foodsearch_get_margin_css($block['attrs']['distanceMargin'], "md") .
          foodsearch_get_border_css($block['attrs']['distanceBorder'], "md") ;
        $css .= "} \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .plugin-filter-title {" .
          foodsearch_get_typo_css($block['attrs']['filterTitleTypo'], "md");
        $css .= "} \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .plugin-filter-wrap li, .plugin-filter-wrap li label {" .
          foodsearch_get_typo_css($block['attrs']['filterTypo'], "md");
        $css .= "} \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .plugin-filter-wrap {" .
          foodsearch_get_border_css($block['attrs']['filterBorder'], "md") ;
        $css .= "} \r\n";
      $css .= "} \r\n";

      // responsive tablet 
      $css .= "@media (min-width: 768px) and (max-width: 1007px) { \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .fds-typo-wrap {" .
          foodsearch_get_bg_css($block['attrs']['blockBackground'], "sm" ) .
          foodsearch_get_padding_css($block['attrs']['blockPadding'], "sm") .
          foodsearch_get_margin_css($block['attrs']['blockMargin'], "sm") .
          foodsearch_get_border_css($block['attrs']['blockBorder'], "sm") ;
        $css .= "} \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .fds-post-title a {" .
          foodsearch_get_typo_css($block['attrs']['titleTypo'], "sm") .
          foodsearch_get_padding_css($block['attrs']['titlePadding'], "sm") .
          foodsearch_get_margin_css($block['attrs']['titleMargin'], "sm") .
          foodsearch_get_border_css($block['attrs']['titleBorder'], "sm") ;
        $css .= "} \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .fds-restaurant-rate-count {" .
          foodsearch_get_typo_css($block['attrs']['reviewsTypo'], "sm") .
          foodsearch_get_padding_css($block['attrs']['reviewsPadding'], "sm") .
          foodsearch_get_margin_css($block['attrs']['reviewsMargin'], "sm") .
          foodsearch_get_border_css($block['attrs']['reviewsBorder'], "sm") ;
        $css .= "} \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .fds-distance {" .
          foodsearch_get_typo_css($block['attrs']['distanceTypo'], "sm") .
          foodsearch_get_padding_css($block['attrs']['distancePadding'], "sm") .
          foodsearch_get_margin_css($block['attrs']['distanceMargin'], "sm") .
          foodsearch_get_border_css($block['attrs']['distanceBorder'], "sm") ;
        $css .= "} \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .plugin-filter-title {" .
          foodsearch_get_typo_css($block['attrs']['filterTitleTypo'], "sm");
        $css .= "} \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .plugin-filter-wrap li, .plugin-filter-wrap li label {" .
          foodsearch_get_typo_css($block['attrs']['filterTypo'], "sm");
        $css .= "} \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .plugin-filter-wrap {" .
          foodsearch_get_border_css($block['attrs']['filterBorder'], "sm") ;
        $css .= "} \r\n";
      $css .= "} \r\n";

      // responsive mobile 
      $css .= "@media (max-width: 480px) { \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .fds-typo-wrap {" .
          foodsearch_get_bg_css($block['attrs']['blockBackground'], "xs" ) .
          foodsearch_get_padding_css($block['attrs']['blockPadding'], "xs") .
          foodsearch_get_margin_css($block['attrs']['blockMargin'], "xs") .
          foodsearch_get_border_css($block['attrs']['blockBorder'], "xs") ;
        $css .= "} \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .fds-post-title a {" .
          foodsearch_get_typo_css($block['attrs']['titleTypo'], "xs") .
          foodsearch_get_padding_css($block['attrs']['titlePadding'], "xs") .
          foodsearch_get_margin_css($block['attrs']['titleMargin'], "xs") .
          foodsearch_get_border_css($block['attrs']['titleBorder'], "xs") ;
        $css .= "} \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .fds-restaurant-rate-count {" .
          foodsearch_get_typo_css($block['attrs']['reviewsTypo'], "xs") .
          foodsearch_get_padding_css($block['attrs']['reviewsPadding'], "xs") .
          foodsearch_get_margin_css($block['attrs']['reviewsMargin'], "xs") .
          foodsearch_get_border_css($block['attrs']['reviewsBorder'], "xs") ;
        $css .= "} \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .fds-distance {" .
          foodsearch_get_typo_css($block['attrs']['distanceTypo'], "xs") .
          foodsearch_get_padding_css($block['attrs']['distancePadding'], "xs") .
          foodsearch_get_margin_css($block['attrs']['distanceMargin'], "xs") .
          foodsearch_get_border_css($block['attrs']['distanceBorder'], "xs") ;
        $css .= "} \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .plugin-filter-title {" .
          foodsearch_get_typo_css($block['attrs']['filterTitleTypo'], "xs");
        $css .= "} \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .plugin-filter-wrap li, .plugin-filter-wrap li label {" .
          foodsearch_get_typo_css($block['attrs']['filterTypo'], "xs");
        $css .= "} \r\n";
        $css .= "#fds-block-".$block['attrs']['blockId']." .plugin-filter-wrap {" .
          foodsearch_get_border_css($block['attrs']['filterBorder'], "xs") ;
        $css .= "} \r\n";
      $css .= "} \r\n";

    }
  }

  if ( !empty($css)) $wp_filesystem->put_contents($wp_upload_dir['path'] . '/restaurant-listing-' . $post->ID . '.css', $css);

}

function foodsearch_get_rating_val ( $val1, $val2 ){
  global $foodsearch_plugin_settings;
  $cuisine_type = "";
  $arr = array();
  if ( isset($_GET['cuisine']) ) $arr = array_merge($arr, (array) $_GET['cuisine'] );
  $cuisine_type = array('taxonomy' => 'food_cuisine', 'field' => 'slug', 'terms' => $arr, 'operator' => 'AND' );

  $delivery = "";
  if ( isset($_GET['delivery']) && $_GET['delivery'] > 0 && $_GET['delivery'] != "undefined" ) {
      $delivery = array('key' => 'foodsearch_order_process_type', 'value' => array('delivery', 'both'), 'compare' => 'IN');
  }
  $take_away = "";
  if ( isset($_GET['take_away']) && $_GET['take_away'] > 0 && $_GET['take_away'] != "undefined" ) {
      $take_away = array('key' => 'foodsearch_order_process_type', 'value' => array('takeaway', 'both'), 'compare' => 'IN');
  }
  
  $ids = resturant_filter_on_location();
  if(isset($ids['resID']) && count($ids['resID'])>0){
    $args = array(
      'post_type'=>'restaurants',
      'posts_per_page' => -1,
      'post_status' => 'publish',
      'post__in'    => $ids['resID'],
      's' => isset($_GET['keyword']) ? $_GET['keyword'] : '',
      'tax_query' => array('relation' => 'OR', $cuisine_type ),
      'meta_query' => array('relation' => 'AND', array('key' => 'oveall_review_avg_rating', 'value' => array($val1, $val2),'type' => 'numeric', 'compare' => 'between' ), $take_away, $delivery, foodsearch_get_rating_string() )
    );
    $query = new WP_Query( $args );
    return $query->found_posts;
  }
  else{
    return 0;
  }

}

// Modify the WP_Query to use OR between the search and tax query parts
add_action( 'init', function()
{   
    if( class_exists( 'foodsearch_Modify_Query' ) )
    {
        $o = new foodsearch_Modify_Query;
        $o->foodsearch_activate();
    }
});
class foodsearch_Modify_Query
{
    private $search    = '';
    public function foodsearch_activate()
    {
        add_action( 'pre_get_posts', array( $this, 'foodsearch_pre_get_posts' ) );
    }
    public function foodsearch_pre_get_posts( WP_Query $q )
    {
        if( filter_var( 
                $q->get( 'wpse_search_or_tax_query' ), 
                FILTER_VALIDATE_BOOLEAN 
             ) 
             && $q->get( 'tax_query' ) 
             && $q->get( 's' )
        )
        {                                                           
            add_filter( 'posts_clauses', array( $this, 'foodsearch_posts_clauses' ), 10, 2 );
            add_filter( 'posts_search', array( $this, 'foodsearch_posts_search' ), 10, 2 );
        }
    }
    public function foodsearch_posts_clauses( $clauses, \WP_Query $q )
    {
        remove_filter( current_filter(), array( $this, __FUNCTION__ ) );
        // Generate the tax query:
        $tq = new WP_Tax_Query( $q->query_vars['tax_query'] );
        // Get the generated taxonomy clauses:
        global $wpdb;
        $tc = $tq->get_sql( $wpdb->posts, 'ID' );
        // Remove the search part:
        $clauses['where'] = str_ireplace( 
            $this->search, 
            ' ', 
            $clauses['where'] 
        );
        // Remove the taxonomy part:
        $clauses['where'] = str_ireplace( 
            $tc['where'], 
            ' ', 
            $clauses['where'] 
        );
        // Add the search OR taxonomy part:
        $clauses['where'] .= sprintf( 
            " AND ( ( 1=1 %s ) OR ( 1=1 %s ) ) ", 
            $tc['where'],
            $this->search
        );
        return $clauses;
    }
    public function foodsearch_posts_search( $search, \WP_Query $q )
    {
        remove_filter( current_filter(), array( $this, __FUNCTION__ ) );
        $this->search = $search;
        return $search;
    }
}
// Modify the WP_Query to use OR between the search and tax query parts

function foodsearch_count_cuisines($term_id,$ids){
  $delivery = "";
  if ( isset($_GET['delivery']) && $_GET['delivery'] > 0 && $_GET['delivery'] != "undefined" || (isset($_SESSION['customer_location']['order_type']) && $_SESSION['customer_location']['order_type']=='deliver') ) {
      $delivery = array('key' => 'foodsearch_order_process_type', 'value' => array('delivery', 'both'), 'compare' => 'IN');
  }
  $take_away = "";
  if ( isset($_GET['take_away']) && $_GET['take_away'] > 0 && $_GET['take_away'] != "undefined" || (isset($_SESSION['customer_location']['order_type']) && $_SESSION['customer_location']['order_type']=='pickup')) {
      $take_away = array('key' => 'foodsearch_order_process_type', 'value' => array('takeaway', 'both'), 'compare' => 'IN');
  }

  $arr = array($term_id);
  if ( isset($_GET['cuisine']) ) $arr = array_merge($arr, (array) $_GET['cuisine'] );

  $cuisine_type = array('taxonomy' => 'food_cuisine', 'field' => 'slug', 'terms' => $arr, 'operator' => 'AND' ); 
  if(count($ids)>0){
  $args = array(
    'post_type'=>'restaurants',
    'post_status' => 'publish',
    'post__in'    => $ids['resID'],
    's' => isset($_GET['keyword']) ? $_GET['keyword'] : '',
    'tax_query' => array('relation' => 'AND', $cuisine_type ),
    'meta_query' => array('relation' => 'AND', $take_away, $delivery, foodsearch_get_rating_string() ),
  );
}
else{
  $args = array(
    'post_type'=>'restaurants',
    'post_status' => 'publish',
    's' => isset($_GET['keyword']) ? $_GET['keyword'] : '',
    'tax_query' => array('relation' => 'AND', $cuisine_type ),
    'meta_query' => array('relation' => 'AND', $take_away, $delivery, foodsearch_get_rating_string() ),
  );
}
  wp_reset_query();
  $query = new WP_Query( $args );
  return $total = $query->found_posts;
}

function foodsearch_get_rating_string(){
  $ratings = "";
  if ( isset($_GET['ratings']) && $_GET['ratings'] > 0 && $_GET['ratings'] != "undefined" ) {
    if ( $_GET['ratings'] == 5 ) $val = array(5, 5);
    else if ( $_GET['ratings'] == 4 ) $val = array(4, 4.9);
    else if ( $_GET['ratings'] == 3 ) $val = array(3, 3.9);
    else if ( $_GET['ratings'] == 4 ) $val = array(2, 2.9);
    $ratings = array('key' => 'oveall_review_avg_rating', 'value' => $val,'type' => 'numeric', 'compare' => 'between' );
  }
  return $ratings;
}

function foodsearch_listing($offset, $per_page) {
  // location_list();
  // echo 'hi';
  // exit();
  global $wpdb, $post,$foodsearch_plugin_settings;
  wp_reset_query();
  wp_reset_postdata();
  
  $join = "";
  $keyword = "";
  $cuisine = "";
  $delivery = "";
  $take_away = "";
  $ratings = "";
  $meta_tbl = "";
  $order = "";
  
  if ( isset($_GET['keyword']) && $_GET['keyword'] != "" ) {
    $keyword = $wpdb->esc_like($_GET['keyword']);
    $keyword = " AND (
        p.post_title LIKE '" . esc_sql('%') . $keyword . esc_sql('%') . "'
        OR p.post_excerpt LIKE '" . esc_sql('%') . $keyword . esc_sql('%') . "'
        OR p.post_content LIKE '" . esc_sql('%') . $keyword . esc_sql('%') . "'
        OR ID IN (
            SELECT object_id 
            FROM $wpdb->term_relationships AS TR 
            INNER JOIN $wpdb->term_taxonomy AS TT ON TR.term_taxonomy_id = TT.term_taxonomy_id
            INNER JOIN $wpdb->terms AS T ON TT.term_id = T.term_id
            WHERE T.name LIKE '" . esc_sql('%') . $keyword . esc_sql('%') . "'
          )
      )
    ";
  }
  $order = ' ORDER BY p.ID DESC';
  if ( isset($_GET['order']) ) {
    if ( $_GET['order'] == "best-match" ) {
      $join = "INNER JOIN $wpdb->postmeta AS pm4 ON ( p.ID = pm4.post_id )";
      $order = " AND ( pm4.meta_key = 'foodsearch_total_orders' ) ORDER BY pm4.meta_value ASC ";
    }
    else if ( $_GET['order'] == "title" ) {
      $order = " ORDER BY p.post_title ASC ";
    }
    else if ( $_GET['order'] == "rating" ) {
      $join = "INNER JOIN $wpdb->postmeta AS pm4 ON ( p.ID = pm4.post_id )";
      $order = " AND ( pm4.meta_key = 'oveall_review_avg_rating' ) ORDER BY pm4.meta_value DESC ";
    }
    else if ( $_GET['order'] == "minimum-order" ) {
      $join = "INNER JOIN $wpdb->postmeta AS pm4 ON ( p.ID = pm4.post_id )";
      $order = " AND ( pm4.meta_key = 'foodsearch_min_delivery_order' ) ORDER BY pm4.meta_value ASC ";
    }
    else if ( $_GET['order'] == "minimum-delivery-fee" ) {
      $join = "INNER JOIN $wpdb->postmeta AS pm4 ON ( p.ID = pm4.post_id )";
      $order = " AND ( pm4.meta_key = 'foodsearch_delivery_fee' ) ORDER BY pm4.meta_value ASC ";
    }
    else if ( $_GET['order'] == "fastest-delivery" ) {
      $join = "INNER JOIN $wpdb->postmeta AS pm4 ON ( p.ID = pm4.post_id )";
      $order = " AND ( pm4.meta_key = 'foodsearch_delivery_time' ) ORDER BY pm4.meta_value ASC ";
    }
  }
  
  if ( isset($_GET['cuisine']) ) {
    // if(is_array($_GET['cuisine']))
    // {
    //   $cuisine_total = count(explode(",",$cuisine_ids));
    //   if($cuisine_total>1){
    //     $cuisine = implode (",", $_GET['cuisine']);
    //   }
    //   else{
    //     $cuisine = "'".trim($_GET['cuisine'][0])."'";
    //   }
    // }
    // echo $wpdb->esc_like( $_GET['cuisine'] );
    $cuisine = is_array($_GET['cuisine']) ? implode (",", $_GET['cuisine']) : trim($_GET['cuisine'], ",") ;
    
    $cuisine = preg_filter('/^/', "'", $cuisine);
    $cuisine = preg_filter('/$/', "'", $cuisine);
    $cuisine = str_replace(",", "','", $cuisine);
  
    $cuisine_ids = $wpdb->get_results( "SELECT GROUP_CONCAT(term_id) AS ids FROM `$wpdb->terms` WHERE slug IN ($cuisine) " );
    $cuisine_ids = $cuisine_ids[0]->ids;
    $cuisine_total = count(explode(",",$cuisine_ids));
    
    $cuisine = " AND ( 
        (
          SELECT COUNT(1)
          FROM $wpdb->term_relationships
          WHERE term_taxonomy_id IN ($cuisine_ids)
          AND object_id = p.ID
        ) = $cuisine_total
      )
    ";
  }
  
  if ( isset($_GET['delivery']) && $_GET['delivery'] == 1 && $_GET['delivery'] != "undefined" || (isset($_SESSION['customer_location']['order_type']) && $_SESSION['customer_location']['order_type']=='deliver')) {
    $join .= "INNER JOIN $wpdb->postmeta AS pm2 ON ( p.ID = pm2.post_id )";
    $delivery = " AND ( pm2.meta_key = 'foodsearch_order_process_type' AND pm2.meta_value IN ('delivery','both') ) ";
  }
  
  if ( isset($_GET['take_away']) && $_GET['take_away'] == 1 && $_GET['take_away'] != "undefined"|| (isset($_SESSION['customer_location']['order_type']) && $_SESSION['customer_location']['order_type']=='pickup') ) {
    $join .= "INNER JOIN $wpdb->postmeta AS pm3 ON ( p.ID = pm3.post_id )";
    $take_away = " AND ( pm3.meta_key = 'foodsearch_order_process_type' AND pm3.meta_value IN ('takeaway','both') ) ";
  }
  
  if ( isset($_GET['ratings']) && $_GET['ratings'] > 0 && $_GET['ratings'] != "undefined" ) {
    $ratings = $wpdb->esc_like( $_GET['ratings'] );
    $join .= "INNER JOIN $wpdb->postmeta AS pm1 ON ( p.ID = pm1.post_id )";
    if ( $ratings == 5 ) $rat = " BETWEEN '5' AND '5' ";
    else if ( $ratings == 4 ) $rat = " BETWEEN '4' AND '4.9' ";
    else if ( $ratings == 3 ) $rat = " BETWEEN '3' AND '3.9' ";
    else if ( $ratings == 2 ) $rat = " BETWEEN '2' AND '2.9' ";
    $ratings = " AND ( pm1.meta_key = 'oveall_review_avg_rating' AND CAST(pm1.meta_value AS SIGNED) " . $rat . " ) ";
  }
  $locID = '';
  //if( $foodsearch_plugin_settings['location_settings']['disply_res'] =='yes'){
   $ids = resturant_filter_on_location();
  
    if (isset($ids['resID']) && count($ids['resID']) > 0) {
      $locID = ' AND p.ID IN (' . implode(',', $ids['resID']) . ') ';
      if (empty($order) && isset($_GET['order_by']) && $_GET['order_by'] == "near_me") {
        $order = " ORDER BY FIELD (id, " . implode(',', $ids['resID']) . ") ASC";
      }
    }
 // }
 // echo '<pre>'.print_r($ids['items'],true).'</pre>';
  $sql = " SELECT SQL_CALC_FOUND_ROWS p.ID
        FROM $wpdb->posts AS p $meta_tbl
        $join
        WHERE 1=1 
        $keyword
        $cuisine
        $delivery
        $take_away
        $ratings
        AND p.post_type = 'restaurants' AND p.post_status = 'publish'
        $locID
        $order
        ";
   $sql .= " LIMIT " . $offset . ", " . $per_page;
  //$_SESSION['sql'] = $sql;
  $posts = $wpdb->get_results($sql);
//echo '<pre>'.print_r($posts,true).'</pre>';
  $sql = "Select FOUND_ROWS() AS total";
  $total = $wpdb->get_results($sql);
  $total = $total[0]->total;

  $listing['total'] = $total;
  $listing['posts'] = $posts;
  $listing['items'] = [];
  if(isset($ids['items'])){
    $listing['items'] = $ids['items'];
  }
  return $listing;
}

function foodsearch_pagination_number($total, $number_of_items , $offset){
  $total = 25;
  $number_of_items = 2;
  $offset = 2;

  $pre = "";
  $next = "";
  $html = "";
  $total_pages = ceil( $total / $number_of_items )  ;

  for ( $i = 1; $i <= $total_pages; $i++ ){
    //$html .= $i . " ";
  }

  if ( $offset > 0 ){
    $pre = "<a class=''>" . esc_html__('previous', 'wp-foodsearch') . "</a> ";
  }
  if ( $offset + $number_of_items < $total ){
    $next = " <a class='pagination-listing' data-offset='" . $offset . "'>" . esc_html__('next', 'wp-foodsearch') . "</a>";
  }

  return $pre . $html . $next;

}